(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     45565,       1523]
NotebookOptionsPosition[     32163,       1085]
NotebookOutlinePosition[     40012,       1334]
CellTagsIndexPosition[     39649,       1317]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["Basics of Cluster Model ", "Title",
 CellTags->"c:1"],

Cell["Cluster State computations, basics", "Subtitle"],

Cell[TextData[{
 "Version: 3.0-April-2010--For ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " 6.0-8.0"
}], "Abstract",
 CellChangeTimes->{{3.395090887981901*^9, 3.395090925377634*^9}, {
  3.512204743716008*^9, 3.512204766816266*^9}}],

Cell[CellGroupData[{

Cell["\<\
Cluster State basics:                                                    To \
open double click at down arrow------------------------------->>\
\>", "Section",
 CellChangeTimes->{{3.512204867845098*^9, 3.5122049049071093`*^9}},
 FontFamily->"Times",
 CellTags->"c:2"],

Cell[CellGroupData[{

Cell["Discard Theorem", "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:3", "b:0.0.0"}],

Cell[TextData[StyleBox["Uses the Qdensity package:",
 FontFamily->"Helvetica"]], "Text",
 FontFamily->"Courier New",
 CellTags->"b:0.0.0"],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<QDENSITY`Qdensity`\>\"", "]"}]], "Input",
 CellTags->"b:0.0.0"],

Cell["?QDENSITY`Qdensity`*", "Input",
 CellTags->"b:0.0.0"],

Cell[TextData[{
 StyleBox["Access the QDENSpalette it by clicking here: ",
  FontFamily->"Helvetica"],
 ButtonBox["QDENSpalette.nb",
  BaseStyle->"Hyperlink",
  ButtonData:>{"QDENSpalette.nb", None}]
}], "Text",
 FontFamily->"Courier New",
 CellTags->"b:0.0.0"],

Cell[TextData[StyleBox["We set the number of Qubits to 2",
 FontWeight->"Plain",
 FontVariations->{"CompatibilityType"->0},
 Background->None]], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:0.0.0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"nqx", "=", "2"}], ";"}]], "Input",
 CellTags->"b:0.0.0"],

Cell[TextData[StyleBox["Decide whether the computation will be carried out \
numerically (icalc=0) or \nalgebraically (icalc=1)",
 FontWeight->"Plain",
 FontVariations->{"CompatibilityType"->0},
 Background->None]], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:0.0.0"],

Cell[BoxData[
 RowBox[{"Icalc", "=", "0"}]], "Input",
 CellTags->"b:0.0.0"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"figure1", "=", 
   RowBox[{"Import", "[", 
    RowBox[{"\"\<QDENSITY/drawings/discard1.png\>\"", ",", "\"\<PNG\>\""}], 
    "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"figure2", "=", 
   RowBox[{"Import", "[", 
    RowBox[{"\"\<QDENSITY/drawings/discard2.png\>\"", ",", "\"\<PNG\>\""}], 
    "]"}]}], ";"}], "\n", 
 RowBox[{"Show", "[", "figure1", "]"}], "\n", 
 RowBox[{"Show", "[", "figure2", "]"}]}], "Input",
 CellTags->"b:0.0.0"],

Cell[TextData[StyleBox["We'll show that the two circuits in the figures are \
equivalent:\nThe unknown qubit one, will be generated at Random:", \
"DisplayText",
 FontWeight->"Plain",
 FontVariations->{"CompatibilityType"->0},
 Background->None]], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:0.0.0"],

Cell[BoxData[
 RowBox[{"\[Rho]", "=", "RandomQubit1"}]], "Input",
 CellTags->"b:0.0.0"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"If", " ", "[", 
   RowBox[{
    RowBox[{"Icalc", "==", "1"}], ",", 
    RowBox[{"\[Rho]1", "=", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"A", "*", 
         RowBox[{"Ket", "[", "0", "]"}]}], "+", 
        RowBox[{"B", "*", 
         RowBox[{"Ket", "[", "1", "]"}]}]}], ")"}], "\[CircleTimes]", 
      RowBox[{"Adj", "[", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"A", "*", 
          RowBox[{"Ket", "[", "0", "]"}]}], "+", 
         RowBox[{"B", "*", 
          RowBox[{"Ket", "[", "1", "]"}]}]}], ")"}], "]"}]}]}], ",", 
    RowBox[{"\[Rho]1", "=", "\[Rho]"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", "\[Rho]1"}], "Input",
 CellTags->"b:0.0.0"],

Cell[TextData[StyleBox["The second one is in the |+\[RightAngleBracket] \
state, its density matrix is thus:", "DisplayText",
 FontWeight->"Plain",
 FontVariations->{"CompatibilityType"->0},
 Background->None]], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:0.0.0"],

Cell[BoxData[
 RowBox[{"\[Rho]2", "=", 
  RowBox[{
   RowBox[{"KetX", "[", "0", "]"}], "\[CircleTimes]", 
   RowBox[{"BraX", "[", "0", "]"}]}]}]], "Input",
 CellTags->"b:0.0.0"],

Cell[TextData[StyleBox["The initial state is therefore:", "DisplayText",
 FontWeight->"Plain",
 FontVariations->{"CompatibilityType"->0},
 Background->None]], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:0.0.0"],

Cell[BoxData[
 RowBox[{"\[Rho]12", "=", 
  RowBox[{"\[Rho]1", " ", "\[CircleTimes]", " ", "\[Rho]2"}]}]], "Input",
 CellTags->"b:0.0.0"],

Cell[TextData[StyleBox["We perform the control phase operation between the \
two qubits,", "DisplayText",
 FontWeight->"Plain",
 FontVariations->{"CompatibilityType"->0},
 Background->None]], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:0.0.0"],

Cell[BoxData[
 RowBox[{"\[Rho]CP", "=", 
  RowBox[{"Chop", "[", " ", 
   RowBox[{
    RowBox[{"CPHASE", "[", 
     RowBox[{"2", ",", "1", ",", "2"}], "]"}], ".", "\[Rho]12", ".", 
    RowBox[{"Adj", "[", 
     RowBox[{"CPHASE", "[", 
      RowBox[{"2", ",", "1", ",", "2"}], "]"}], "]"}]}], "]"}]}]], "Input",
 CellTags->"b:0.0.0"],

Cell[TextData[StyleBox["Now we measure the second Qubit, in the Z basis:", \
"DisplayText",
 FontWeight->"Plain",
 FontVariations->{"CompatibilityType"->0},
 Background->None]], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:0.0.0"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   SubscriptBox["P", "a_"], ":=", 
   RowBox[{"\[DoubleStruckCapitalI]", "\[CircleTimes]", " ", 
    SubscriptBox["\[ScriptCapitalP]", "a"]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Rho]M", "[", "a_", "]"}], " ", ":=", 
  RowBox[{"Chop", "[", 
   RowBox[{"PTr", "[", 
    RowBox[{
     RowBox[{"{", "2", "}"}], ",", " ", 
     RowBox[{"2", "*", 
      RowBox[{
       SubscriptBox["P", "a"], ".", "\[Rho]CP", ".", 
       SubscriptBox["P", "a"]}]}]}], "]"}], "]"}]}]}], "Input",
 CellTags->"b:0.0.0"],

Cell[TextData[StyleBox["The two possible remaining density matrices for Qubit \
one are,", "DisplayText",
 FontWeight->"Plain",
 FontVariations->{"CompatibilityType"->0},
 Background->None]], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:0.0.0"],

Cell[BoxData[{
 RowBox[{"\[Rho]M", "[", "0", "]"}], "\[IndentingNewLine]", 
 RowBox[{"\[Rho]M", "[", "1", "]"}]}], "Input",
 CellTags->"b:0.0.0"],

Cell[TextData[{
 StyleBox["The ", "DisplayText",
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0},
  Background->None],
 StyleBox["second Circuit", "DisplayText",
  FontWeight->"Bold",
  FontVariations->{"CompatibilityType"->0},
  Background->None],
 StyleBox[" is simply:", "DisplayText",
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0},
  Background->None]
}], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:0.0.0"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"\[Rho]M2C", "[", "a_", "]"}], ":=", " ", 
   RowBox[{
    RowBox[{"MatrixPower", "[", 
     RowBox[{
      SubscriptBox["\[Sigma]", "3"], ",", "a"}], "]"}], ".", "\[Rho]1", ".", 
    RowBox[{"Adj", "[", 
     RowBox[{"MatrixPower", "[", 
      RowBox[{
       SubscriptBox["\[Sigma]", "3"], ",", "a"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Chop", "[", 
  RowBox[{"\[Rho]M2C", "[", "0", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Chop", "[", 
  RowBox[{"\[Rho]M2C", "[", "1", "]"}], "]"}]}], "Input",
 CellTags->"b:0.0.0"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Identity Gate with 3 qubits", "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:4", "b:0.0.1"}],

Cell[TextData[StyleBox["We set the number of Qubits to 3",
 FontWeight->"Plain",
 FontVariations->{"CompatibilityType"->0},
 Background->None]], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:0.0.1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"nqx", "=", "3"}], ";"}]], "Input",
 CellTags->"b:0.0.1"],

Cell[TextData[StyleBox["Decide whether the computation will be carried out \
numerically (icalc=0) or \nalgebraically (icalc=1)",
 FontWeight->"Plain",
 FontVariations->{"CompatibilityType"->0},
 Background->None]], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:0.0.1"],

Cell[BoxData[
 RowBox[{"Icalc", "=", "0"}]], "Input",
 CellTags->"b:0.0.1"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"figure1", "=", 
   RowBox[{"Import", "[", 
    RowBox[{"\"\<QDENSITY/drawings/ClusterI3q.png\>\"", ",", "\"\<PNG\>\""}], 
    "]"}]}], ";"}], "\n", 
 RowBox[{"Show", "[", "figure1", "]"}]}], "Input",
 CellTags->"b:0.0.1"],

Cell[TextData[{
 StyleBox["We'll show that the circuit in the figure is equivalent to doing \
nothing on qubit 1.\nThe", "DisplayText",
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0},
  Background->None],
 StyleBox[" unknown qubit one", "DisplayText",
  FontWeight->"Bold",
  FontVariations->{"CompatibilityType"->0},
  Background->None],
 StyleBox[", will be generated at Random:", "DisplayText",
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0},
  Background->None]
}], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:0.0.1"],

Cell[BoxData[
 RowBox[{"\[Rho]", "=", "RandomQubit1"}]], "Input",
 CellTags->"b:0.0.1"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"If", " ", "[", 
   RowBox[{
    RowBox[{"Icalc", "==", "1"}], ",", 
    RowBox[{"\[Rho]1", "=", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"A", "*", 
         RowBox[{"Ket", "[", "0", "]"}]}], "+", 
        RowBox[{"B", "*", 
         RowBox[{"Ket", "[", "1", "]"}]}]}], ")"}], "\[CircleTimes]", 
      RowBox[{"Adj", "[", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"A", "*", 
          RowBox[{"Ket", "[", "0", "]"}]}], "+", 
         RowBox[{"B", "*", 
          RowBox[{"Ket", "[", "1", "]"}]}]}], ")"}], "]"}]}]}], ",", 
    RowBox[{"\[Rho]1", "=", "\[Rho]"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", "\[Rho]1"}], "Input",
 CellTags->"b:0.0.1"],

Cell[TextData[{
 StyleBox["The ", "DisplayText",
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0},
  Background->None],
 StyleBox["second and third ones are in the |+\[RightAngleBracket] state", 
  "DisplayText",
  FontWeight->"Bold",
  FontVariations->{"CompatibilityType"->0},
  Background->None],
 StyleBox[", its density matrix are thus:", "DisplayText",
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0},
  Background->None]
}], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:0.0.1"],

Cell[BoxData[{
 RowBox[{"\[Rho]2", "=", 
  RowBox[{
   RowBox[{"KetX", "[", "0", "]"}], "\[CircleTimes]", 
   RowBox[{"BraX", "[", "0", "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"\[Rho]3", "=", 
  RowBox[{
   RowBox[{"KetX", "[", "0", "]"}], "\[CircleTimes]", 
   RowBox[{"BraX", "[", "0", "]"}]}]}]}], "Input",
 CellTags->"b:0.0.1"],

Cell[TextData[{
 StyleBox["The ", "DisplayText",
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0},
  Background->None],
 StyleBox["initial state", "DisplayText",
  FontWeight->"Bold",
  FontVariations->{"CompatibilityType"->0},
  Background->None],
 StyleBox[" i", "DisplayText",
  FontVariations->{"CompatibilityType"->0},
  Background->None],
 StyleBox["s therefo", "DisplayText",
  FontVariations->{"CompatibilityType"->0},
  Background->None],
 StyleBox["re:", "DisplayText",
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0},
  Background->None]
}], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:0.0.1"],

Cell[BoxData[
 RowBox[{"\[Rho]123", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"\[Rho]1", " ", "\[CircleTimes]", " ", "\[Rho]2"}], ")"}], 
   "\[CircleTimes]", "\[Rho]3"}]}]], "Input",
 CellTags->"b:0.0.1"],

Cell[TextData[StyleBox["We perform the control phase operation between the \
three qubits,", "DisplayText",
 FontWeight->"Plain",
 FontVariations->{"CompatibilityType"->0},
 Background->None]], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:0.0.1"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"CPOp", "=", 
   RowBox[{
    RowBox[{"CPHASE", "[", 
     RowBox[{"3", ",", "1", ",", "2"}], "]"}], ".", 
    RowBox[{"CPHASE", "[", 
     RowBox[{"3", ",", "2", ",", "3"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"\[Rho]CP", "=", 
  RowBox[{"Chop", "[", " ", 
   RowBox[{"CPOp", ".", "\[Rho]123", ".", 
    RowBox[{"Adj", "[", "CPOp", "]"}]}], "]"}]}]}], "Input",
 CellTags->"b:0.0.1"],

Cell[TextData[{
 StyleBox["Now we ", "DisplayText",
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0},
  Background->None],
 StyleBox["measure the first and second Qubits, in the X basis:", 
  "DisplayText",
  FontWeight->"Bold",
  FontVariations->{"CompatibilityType"->0},
  Background->None]
}], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:0.0.1"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   SubscriptBox["P", 
    RowBox[{"a_", ",", "b_"}]], ":=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"PX", "[", "a", "]"}], "\[CircleTimes]", 
      RowBox[{"PX", "[", "b", "]"}]}], ")"}], "\[CircleTimes]", 
    "\[DoubleStruckCapitalI]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Rho]M", "[", 
   RowBox[{"a_", ",", "b_"}], "]"}], " ", ":=", 
  RowBox[{"Chop", "[", 
   RowBox[{"PTr", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", " ", 
     RowBox[{
      RowBox[{"2", "^", "2"}], "*", 
      RowBox[{
       SubscriptBox["P", 
        RowBox[{"a", ",", "b"}]], ".", "\[Rho]CP", ".", 
       SubscriptBox["P", 
        RowBox[{"a", ",", "b"}]]}]}]}], "]"}], "]"}]}]}], "Input",
 CellTags->"b:0.0.1"],

Cell[TextData[StyleBox["The gate is realized up to a prefactor depending on \
the measurements which is of the form:", "DisplayText",
 FontWeight->"Plain",
 FontVariations->{"CompatibilityType"->0},
 Background->None]], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:0.0.1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Prefactor", "[", 
   RowBox[{"a_", ",", "b_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"MatrixPower", "[", 
    RowBox[{
     RowBox[{"s", "[", "1", "]"}], ",", "b"}], "]"}], ".", 
   RowBox[{"MatrixPower", "[", 
    RowBox[{
     RowBox[{"s", "[", "3", "]"}], ",", "a"}], "]"}]}]}]], "Input",
 CellTags->"b:0.0.1"],

Cell[TextData[{
 StyleBox["The action of the ",
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0},
  Background->None],
 StyleBox["prefactor",
  FontWeight->"Bold",
  FontVariations->{"CompatibilityType"->0},
  Background->None],
 StyleBox[" can removed performing:",
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0},
  Background->None]
}], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:0.0.1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Rho]Final", "[", 
   RowBox[{"a_", ",", "b_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"Prefactor", "[", 
    RowBox[{"a", ",", "b"}], "]"}], ".", 
   RowBox[{"\[Rho]M", "[", 
    RowBox[{"a", ",", "b"}], "]"}], ".", 
   RowBox[{"Adj", "[", 
    RowBox[{"Prefactor", "[", 
     RowBox[{"a", ",", "b"}], "]"}], "]"}]}]}]], "Input",
 CellTags->"b:0.0.1"],

Cell[TextData[StyleBox["We can then plot the four possible outcomes, which \
should all give the matrix, \nirrespective of the measured values at this \
point:",
 FontWeight->"Plain",
 FontVariations->{"CompatibilityType"->0},
 Background->None]], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:0.0.1"],

Cell[BoxData[{
 RowBox[{"Chop", "[", 
  RowBox[{"\[Rho]Final", "[", 
   RowBox[{"0", ",", "0"}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Chop", "[", 
  RowBox[{"\[Rho]Final", "[", 
   RowBox[{"1", ",", "0"}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Chop", "[", 
  RowBox[{"\[Rho]Final", "[", 
   RowBox[{"0", ",", "1"}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Chop", "[", 
  RowBox[{"\[Rho]Final", "[", 
   RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "Input",
 CellTags->"b:0.0.1"],

Cell[TextData[{
 StyleBox["The Identity", "DisplayText",
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0},
  Background->None],
 StyleBox[" Circuit", "DisplayText",
  FontWeight->"Bold",
  FontVariations->{"CompatibilityType"->0},
  Background->None],
 StyleBox[" is simply:", "DisplayText",
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0},
  Background->None]
}], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:0.0.1"],

Cell[BoxData["\[Rho]1"], "Input",
 CellTags->"b:0.0.1"],

Cell[TextData[{
 "Last Version:18-Aug-2005\n",
 Cell[BoxData[
  FormBox[GridBox[{
     {
      RowBox[{"References", ":"}], 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"[", "1", "]"}], " ", 
         RowBox[{"R", ".", " ", "Raussendorf"}], " ", "and", " ", 
         RowBox[{"H", ".", " ", "J", ".", " ", "Briegel"}]}], ",", " ", 
        RowBox[{
         RowBox[{"Phys", ".", " ", "Rev", ".", " ", "Lett", ".", " ", "86"}], 
         " ", 
         RowBox[{"(", "2001", ")"}], " ", "5188"}]}], "\n", 
       RowBox[{
        RowBox[{
         RowBox[{"[", "2", "]"}], " ", 
         RowBox[{"R", ".", " ", "Raussendorf"}]}], ",", " ", 
        RowBox[{
         RowBox[{"D", ".", " ", "Brownie"}], " ", "and", " ", 
         RowBox[{"H", ".", "J", ".", " ", "Briegel"}]}], ",", " ", "\n", 
        RowBox[{
         RowBox[{"Phys", ".", " ", "Rev", ".", " ", "A"}], " ", "68"}], ",", 
        " ", 
        RowBox[{"022312", " ", 
         RowBox[{"(", "2003", ")"}]}]}], "\n", 
       RowBox[{
        RowBox[{
         RowBox[{"[", "2", "]"}], " ", "Michael", " ", 
         RowBox[{"I", ".", " ", "Nielsen"}]}], ",", " ", 
        RowBox[{"quant", "-", 
         RowBox[{"ph", "/", "0504097"}]}]}], "\n", 
       RowBox[{
        RowBox[{
         RowBox[{"[", "3", "]"}], " ", "QDENSITY", " ", "manual"}], ",", " ", 
        
        RowBox[{"Sect", ".", " ", "11"}]}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {Right, {Left}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}], TraditionalForm]], 
  "DefinitionBox",
  GridBoxOptions->{
  GridBoxDividers->{
   "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
    "RowsIndexed" -> {}},
  GridBoxSpacings->{"Columns" -> {
      Offset[0.27999999999999997`], {
       Offset[0.5599999999999999]}, 
      Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
      Offset[0.2], {
       Offset[0.16]}, 
      Offset[0.2]}, "RowsIndexed" -> {}}},
  CellTags->"S5.1.1"]
}], "Abstract",
 CellTags->"b:0.0.1"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["An example of CNOT gate in the cluster model approach", "Section",
 FontFamily->"Times",
 CellTags->"c:5"],

Cell[CellGroupData[{

Cell["Step 1: Build the cluster state", "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:6", "b:0.1.0"}],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<QDENSITY`Qdensity`\>\"", "]"}]], "Input",
 CellTags->"b:0.1.0"],

Cell["?QDENSITY`Qdensity`*", "Input",
 CellTags->"b:0.1.0"],

Cell[TextData[StyleBox["The diagrammatic representation of the gate, as in \
Ref.[1], is :", "DisplayText",
 FontWeight->"Plain",
 FontVariations->{"CompatibilityType"->0},
 Background->None]], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:0.1.0"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"figure", "=", 
   RowBox[{"Import", "[", 
    RowBox[{
    "\"\<QDENSITY/drawings/CNOTc4qubits.png\>\"", ",", "\"\<PNG\>\""}], 
    "]"}]}], ";"}], "\n", 
 RowBox[{"Show", "[", "figure", "]"}]}], "Input",
 CellTags->"b:0.1.0"],

Cell[TextData[StyleBox["Icalc controls whether the qubits are handeld \
algebraically (1) or numerically (0):", "DisplayText",
 FontWeight->"Plain",
 FontVariations->{"CompatibilityType"->0},
 Background->None]], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:0.1.0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Icalc", "=", "0"}], ";"}]], "Input",
 CellTags->"b:0.1.0"],

Cell[TextData[StyleBox["Set total number of qubits to 4:",
 FontWeight->"Plain",
 FontVariations->{"CompatibilityType"->0},
 Background->None]], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:0.1.0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"nq", "=", "4"}], ";"}]], "Input",
 CellTags->"b:0.1.0"],

Cell[TextData[StyleBox["The figure tells us that qubits 2 and 3 are in |+\
\[RightAngleBracket] state while qubits 1 (target) and 4 (control) are in \na \
general 1 qubit state:",
 FontWeight->"Plain",
 FontVariations->{"CompatibilityType"->0},
 Background->None]], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:0.1.0"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ket1", "=", "RandomKet1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ket4", "=", "RandomKet1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"If", " ", "[", 
   RowBox[{
    RowBox[{"Icalc", "\[Equal]", "1"}], ",", 
    RowBox[{
     RowBox[{"ket1", "=", 
      RowBox[{"Ket1", "[", 
       RowBox[{
        SubscriptBox["\[Theta]", "1"], ",", 
        SubscriptBox["\[Phi]", "1"]}], "]"}]}], ";", 
     RowBox[{"ket4", "=", 
      RowBox[{"Ket1", "[", 
       RowBox[{
        SubscriptBox["\[Theta]", "4"], ",", 
        SubscriptBox["\[Phi]", "4"]}], "]"}]}]}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", "ket1", "\[IndentingNewLine]", "ket4"}], \
"Input",
 CellTags->"b:0.1.0"],

Cell[TextData[StyleBox["The structure of the Cluster is essentially described \
in ClusterLinks, which \ncontains the pairs of CPHASE interacting qubits:",
 FontWeight->"Plain",
 FontVariations->{"CompatibilityType"->0},
 Background->None]], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:0.1.0"],

Cell[BoxData[{
 RowBox[{"NCS", "=", "nq"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ClusterLinks", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "4"}], "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Nlinks", "=", 
  RowBox[{"Length", "[", "ClusterLinks", "]"}]}]}], "Input",
 CellTags->"b:0.1.0"],

Cell[TextData[StyleBox["The 4 qubit initial state before building in the \
correlations is:",
 FontWeight->"Plain",
 FontVariations->{"CompatibilityType"->0},
 Background->None]], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:0.1.0"],

Cell[BoxData[{
 RowBox[{"InitialState", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"ket1", "\[CircleTimes]", 
       RowBox[{"KetX", "[", "0", "]"}]}], ")"}], "\[CircleTimes]", 
     RowBox[{"KetX", "[", "0", "]"}]}], ")"}], "\[CircleTimes]", 
   "ket4"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Rho]initial", "=", 
   RowBox[{"InitialState", "\[CircleTimes]", 
    RowBox[{"Adj", "[", "InitialState", "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Chop", "[", 
  RowBox[{"Tr", "[", 
   RowBox[{"InitialState", "\[CircleTimes]", 
    RowBox[{"Adj", "[", "InitialState", "]"}]}], "]"}], "]"}]}], "Input",
 CellTags->"b:0.1.0"],

Cell[TextData[StyleBox["We define recursively the operation of the CPHASE \
gates:", "DisplayText",
 FontWeight->"Plain",
 FontVariations->{"CompatibilityType"->0},
 Background->None]], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:0.1.0"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"CPhaseG", "[", "0", "]"}], "=", "InitialState"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"CPhaseG", "[", "i_", "]"}], ":=", 
   RowBox[{
    RowBox[{"ChpaseG", "[", "i", "]"}], "=", 
    RowBox[{"CPHASEV", "[", 
     RowBox[{
      RowBox[{"ClusterLinks", "[", 
       RowBox[{"[", 
        RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
      RowBox[{"ClusterLinks", "[", 
       RowBox[{"[", 
        RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", 
      RowBox[{"CPhaseG", "[", 
       RowBox[{"i", "-", "1"}], "]"}]}], "]"}]}]}], ";"}]}], "Input",
 CellTags->"b:0.1.0"],

Cell[TextData[StyleBox["We compute the cluster vector and build its pure \
state density matrix:", "DisplayText",
 FontWeight->"Plain",
 FontVariations->{"CompatibilityType"->0},
 Background->None]], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:0.1.0"],

Cell[BoxData[{
 RowBox[{"ClusterVector", "=", 
  RowBox[{"CPhaseG", "[", "Nlinks", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ClusterDensity", "=", 
   RowBox[{"ClusterVector", "\[CircleTimes]", 
    RowBox[{"Adj", "[", "ClusterVector", "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Chop", "[", 
  RowBox[{"Tr", "[", "ClusterDensity", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Chop", "[", 
  RowBox[{"Eigenvalues", "[", "ClusterDensity", "]"}], "]"}]}], "Input",
 CellTags->"b:0.1.0"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Step 2: Measure qubits 1 and 2 in the X basis", "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:7", "b:0.1.1"}],

Cell[TextData[StyleBox["Preparation of measurements on the X bases for qubits \
1 and 2, first build the proyectors\nand then operate and Trace Off the \
measured qubits:",
 FontWeight->"Plain",
 FontVariations->{"CompatibilityType"->0},
 Background->None]], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:0.1.1"],

Cell[BoxData[{
 RowBox[{
  SubscriptBox["P", 
   RowBox[{"a_", ",", "b_"}]], ":=", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"PX", "[", "a", "]"}], "\[CircleTimes]", " ", 
        RowBox[{"PX", "[", "b", "]"}]}], ")"}], "\[CircleTimes]", 
      "\[DoubleStruckCapitalI]"}], ")"}], "\[CircleTimes]", 
    "\[DoubleStruckCapitalI]"}], ")"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Rho]M", "[", 
   RowBox[{"a_", ",", "b_"}], "]"}], " ", ":=", 
  RowBox[{"Chop", "[", 
   RowBox[{"PTr", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", " ", 
     RowBox[{
      RowBox[{"2", "^", "2"}], "*", 
      RowBox[{
       SubscriptBox["P", 
        RowBox[{"a", ",", "b"}]], ".", "ClusterDensity", ".", 
       RowBox[{"Adj", "[", 
        SubscriptBox["P", 
         RowBox[{"a", ",", "b"}]], "]"}]}]}]}], "]"}], "]"}]}]}], "Input",
 CellTags->"b:0.1.1"],

Cell[TextData[StyleBox["The result of the measurement is generated at \
random:", "DisplayText",
 FontWeight->"Plain",
 FontVariations->{"CompatibilityType"->0},
 Background->None]], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:0.1.1"],

Cell[BoxData[{
 RowBox[{"M1", "=", 
  RowBox[{"RandomInteger", "[", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1"}], "}"}], "]"}]}], "\n", 
 RowBox[{"M2", "=", 
  RowBox[{"RandomInteger", "[", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1"}], "}"}], "]"}]}]}], "Input",
 CellTags->"b:0.1.1"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Step 3: Undo prefactor cluster operations and compare to usual CNOT gate\
\>", "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:8", "b:0.1.2"}],

Cell[TextData[StyleBox["According to their PRL paper the outcome in qubits 3 \
and 4 will be \nthe target of the CNOT[1,4] and the control untouched up to \
this \noperations. We undo them to compare. The prefactor operations are:", \
"DisplayText",
 FontWeight->"Plain",
 FontVariations->{"CompatibilityType"->0},
 Background->None]], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:0.1.2"],

Cell[BoxData[
 RowBox[{"PrefactorOp", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"MatrixPower", "[", 
      RowBox[{
       RowBox[{"s", "[", "3", "]"}], ",", "M1"}], "]"}], ".", 
     RowBox[{"MatrixPower", "[", 
      RowBox[{
       RowBox[{"s", "[", "1", "]"}], ",", "M2"}], "]"}]}], ")"}], 
   "\[CircleTimes]", 
   RowBox[{"MatrixPower", "[", 
    RowBox[{
     RowBox[{"s", "[", "3", "]"}], ",", "M1"}], "]"}]}]}]], "Input",
 CellTags->"b:0.1.2"],

Cell[BoxData[
 RowBox[{"A34", "=", 
  RowBox[{"Chop", "[", 
   RowBox[{"PrefactorOp", ".", 
    RowBox[{"\[Rho]M", "[", 
     RowBox[{"M1", ",", "M2"}], "]"}], ".", 
    RowBox[{"Adj", "[", "PrefactorOp", "]"}]}], "]"}]}]], "Input",
 CellTags->"b:0.1.2"],

Cell[TextData[StyleBox["The reduced density matrix for both qubits are:", \
"DisplayText",
 FontWeight->"Plain",
 FontVariations->{"CompatibilityType"->0},
 Background->None]], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:0.1.2"],

Cell[BoxData[{
 RowBox[{"Chop", "[", 
  RowBox[{"PTr", "[", 
   RowBox[{
    RowBox[{"{", "2", "}"}], ",", "A34"}], "]"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Chop", "[", 
  RowBox[{"PTr", "[", 
   RowBox[{
    RowBox[{"{", "1", "}"}], ",", "A34"}], "]"}], "]"}]}], "Input",
 CellTags->"b:0.1.2"],

Cell[TextData[{
 StyleBox["And we ", "DisplayText",
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0},
  Background->None],
 StyleBox["compare with a standard realization of the CNOT", "DisplayText",
  FontWeight->"Bold",
  FontVariations->{"CompatibilityType"->0},
  Background->None],
 StyleBox[" gate between 1 and 4.", "DisplayText",
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0},
  Background->None]
}], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:0.1.2"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Ket14", "=", 
   RowBox[{"ket1", "\[CircleTimes]", "ket4"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Rho]14", "=", 
   RowBox[{"Ket14", "\[CircleTimes]", 
    RowBox[{"Adj", "[", "Ket14", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CN14", "=", 
   RowBox[{"Chop", "[", 
    RowBox[{
     RowBox[{"CNOT", "[", 
      RowBox[{"2", ",", "2", ",", "1"}], "]"}], ".", "\[Rho]14", ".", 
     RowBox[{"Adj", "[", 
      RowBox[{"CNOT", "[", 
       RowBox[{"2", ",", "2", ",", "1"}], "]"}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Chop", "[", 
  RowBox[{"PTr", "[", 
   RowBox[{
    RowBox[{"{", "2", "}"}], ",", "CN14"}], "]"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Chop", "[", 
  RowBox[{"PTr", "[", 
   RowBox[{
    RowBox[{"{", "1", "}"}], ",", "CN14"}], "]"}], "]"}]}], "Input",
 CellTags->"b:0.1.2"],

Cell[BoxData["Quit"], "Input",
 CellTags->"b:0.1.2"],

Cell[TextData[{
 "Last Version:18-Aug-2005\n",
 Cell[BoxData[
  FormBox[GridBox[{
     {
      RowBox[{"References", ":"}], 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"[", "1", "]"}], " ", 
         RowBox[{"R", ".", " ", "Raussendorf"}], " ", "and", " ", 
         RowBox[{"H", ".", " ", "J", ".", " ", "Briegel"}]}], ",", " ", 
        RowBox[{
         RowBox[{"Phys", ".", " ", "Rev", ".", " ", "Lett", ".", " ", "86"}], 
         " ", 
         RowBox[{"(", "2001", ")"}], " ", "5188"}]}], "\n", 
       RowBox[{
        RowBox[{
         RowBox[{"[", "2", "]"}], " ", 
         RowBox[{"R", ".", " ", "Raussendorf"}]}], ",", " ", 
        RowBox[{
         RowBox[{"D", ".", " ", "Brownie"}], " ", "and", " ", 
         RowBox[{"H", ".", "J", ".", " ", "Briegel"}]}], ",", " ", "\n", 
        RowBox[{
         RowBox[{"Phys", ".", " ", "Rev", ".", " ", "A"}], " ", "68"}], ",", 
        " ", 
        RowBox[{"022312", " ", 
         RowBox[{"(", "2003", ")"}]}]}], "\n", 
       RowBox[{
        RowBox[{
         RowBox[{"[", "2", "]"}], " ", "Michael", " ", 
         RowBox[{"I", ".", " ", "Nielsen"}]}], ",", " ", 
        RowBox[{"quant", "-", 
         RowBox[{"ph", "/", "0504097"}]}]}], "\n", 
       RowBox[{
        RowBox[{
         RowBox[{"[", "3", "]"}], " ", "QDENSITY", " ", "manual"}], ",", " ", 
        
        RowBox[{"Sect", ".", " ", "11"}]}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {Right, {Left}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}], TraditionalForm]], 
  "DefinitionBox",
  GridBoxOptions->{
  GridBoxDividers->{
   "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
    "RowsIndexed" -> {}},
  GridBoxSpacings->{"Columns" -> {
      Offset[0.27999999999999997`], {
       Offset[0.5599999999999999]}, 
      Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
      Offset[0.2], {
       Offset[0.16]}, 
      Offset[0.2]}, "RowsIndexed" -> {}}},
  CellTags->"S5.1.1"]
}], "Abstract",
 CellTags->"b:0.1.2"]
}, Open  ]]
}, Closed]]
},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{900, 626},
WindowMargins->{{202, Automatic}, {Automatic, 4}},
PrintingStartingPageNumber->77,
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"Magnification"->1,
"PaperOrientation"->"Portrait",
"PaperSize"->{612, 792},
"PostScriptOutputFile":>FrontEnd`FileName[{"export", "home", "brunojd"}, 
  "c.ps", CharacterEncoding -> "WindowsANSI"]},
ShowSelection->True,
TaggingRules:>{
 "PaginationCache" -> {{2005, 8, 9, 3, 36, 23.409337`8.121964096655068}, {77, 
    77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 77, 78, 78, 78, 78, 78, 
    78, 78, 78, 78, 78, 78, 78, 78, 78, 78, 78, 79, 79, 79, 79, 79, 79, 79, 
    79, 79, 79, 79, 79, 79, 79, 79, 79, 79, 80, 80, 80, 80, 80, 80, 80, 80, 
    80, 80, 80, 80, 80, 80, 80, 80, 81, 81, 81, 81, 81, 81, 81, 81, 81, 81, 
    81, 81, 81, 81, 82, 82, 82, 82, 82, 82, 82, 82, 82, 82, 82, 82, 82}, 
    Automatic}},
CellLabelAutoDelete->True,
Magnification->1,
FrontEndVersion->"8.0 for Mac OS X x86 (32-bit) (November 6, 2010)",
StyleDefinitions->"Classroom.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "c:1"->{
  Cell[545, 20, 59, 1, 50, "Title",
   CellTags->"c:1"]},
 "c:2"->{
  Cell[930, 36, 277, 6, 51, "Section",
   CellTags->"c:2"]},
 "c:3"->{
  Cell[1232, 46, 108, 3, 57, "Subsection",
   CellTags->{"c:3", "b:0.0.0"}]},
 "b:0.0.0"->{
  Cell[1232, 46, 108, 3, 57, "Subsection",
   CellTags->{"c:3", "b:0.0.0"}],
  Cell[1343, 51, 138, 3, 22, "Text",
   CellTags->"b:0.0.0"],
  Cell[1484, 56, 105, 2, 44, "Input",
   CellTags->"b:0.0.0"],
  Cell[1592, 60, 59, 1, 44, "Input",
   CellTags->"b:0.0.0"],
  Cell[1654, 63, 261, 8, 24, "Text",
   CellTags->"b:0.0.0"],
  Cell[1918, 73, 200, 5, 22, "Text",
   CellTags->"b:0.0.0"],
  Cell[2121, 80, 91, 3, 44, "Input",
   CellTags->"b:0.0.0"],
  Cell[2215, 85, 271, 6, 49, "Text",
   CellTags->"b:0.0.0"],
  Cell[2489, 93, 75, 2, 44, "Input",
   CellTags->"b:0.0.0"],
  Cell[2567, 97, 470, 13, 90, "Input",
   CellTags->"b:0.0.0"],
  Cell[3040, 112, 303, 7, 49, "Text",
   CellTags->"b:0.0.0"],
  Cell[3346, 121, 87, 2, 44, "Input",
   CellTags->"b:0.0.0"],
  Cell[3436, 125, 728, 22, 60, "Input",
   CellTags->"b:0.0.0"],
  Cell[4167, 149, 267, 6, 22, "Text",
   CellTags->"b:0.0.0"],
  Cell[4437, 157, 177, 5, 44, "Input",
   CellTags->"b:0.0.0"],
  Cell[4617, 164, 214, 5, 22, "Text",
   CellTags->"b:0.0.0"],
  Cell[4834, 171, 136, 3, 44, "Input",
   CellTags->"b:0.0.0"],
  Cell[4973, 176, 247, 6, 22, "Text",
   CellTags->"b:0.0.0"],
  Cell[5223, 184, 331, 9, 44, "Input",
   CellTags->"b:0.0.0"],
  Cell[5557, 195, 233, 6, 22, "Text",
   CellTags->"b:0.0.0"],
  Cell[5793, 203, 556, 17, 63, "Input",
   CellTags->"b:0.0.0"],
  Cell[6352, 222, 247, 6, 22, "Text",
   CellTags->"b:0.0.0"],
  Cell[6602, 230, 145, 3, 60, "Input",
   CellTags->"b:0.0.0"],
  Cell[6750, 235, 453, 15, 22, "Text",
   CellTags->"b:0.0.0"],
  Cell[7206, 252, 599, 17, 75, "Input",
   CellTags->"b:0.0.0"]},
 "c:4"->{
  Cell[7842, 274, 120, 3, 57, "Subsection",
   CellTags->{"c:4", "b:0.0.1"}]},
 "b:0.0.1"->{
  Cell[7842, 274, 120, 3, 57, "Subsection",
   CellTags->{"c:4", "b:0.0.1"}],
  Cell[7965, 279, 200, 5, 22, "Text",
   CellTags->"b:0.0.1"],
  Cell[8168, 286, 91, 3, 44, "Input",
   CellTags->"b:0.0.1"],
  Cell[8262, 291, 271, 6, 49, "Text",
   CellTags->"b:0.0.1"],
  Cell[8536, 299, 75, 2, 44, "Input",
   CellTags->"b:0.0.1"],
  Cell[8614, 303, 257, 7, 60, "Input",
   CellTags->"b:0.0.1"],
  Cell[8874, 312, 563, 16, 49, "Text",
   CellTags->"b:0.0.1"],
  Cell[9440, 330, 87, 2, 44, "Input",
   CellTags->"b:0.0.1"],
  Cell[9530, 334, 728, 22, 60, "Input",
   CellTags->"b:0.0.1"],
  Cell[10261, 358, 522, 16, 22, "Text",
   CellTags->"b:0.0.1"],
  Cell[10786, 376, 335, 9, 60, "Input",
   CellTags->"b:0.0.1"],
  Cell[11124, 387, 643, 21, 22, "Text",
   CellTags->"b:0.0.1"],
  Cell[11770, 410, 209, 6, 44, "Input",
   CellTags->"b:0.0.1"],
  Cell[11982, 418, 249, 6, 22, "Text",
   CellTags->"b:0.0.1"],
  Cell[12234, 426, 436, 13, 60, "Input",
   CellTags->"b:0.0.1"],
  Cell[12673, 441, 369, 12, 22, "Text",
   CellTags->"b:0.0.1"],
  Cell[13045, 455, 806, 26, 66, "Input",
   CellTags->"b:0.0.1"],
  Cell[13854, 483, 275, 6, 22, "Text",
   CellTags->"b:0.0.1"],
  Cell[14132, 491, 347, 11, 44, "Input",
   CellTags->"b:0.0.1"],
  Cell[14482, 504, 430, 15, 22, "Text",
   CellTags->"b:0.0.1"],
  Cell[14915, 521, 386, 12, 44, "Input",
   CellTags->"b:0.0.1"],
  Cell[15304, 535, 303, 7, 49, "Text",
   CellTags->"b:0.0.1"],
  Cell[15610, 544, 503, 13, 90, "Input",
   CellTags->"b:0.0.1"],
  Cell[16116, 559, 455, 15, 22, "Text",
   CellTags->"b:0.0.1"],
  Cell[16574, 576, 55, 1, 44, "Input",
   CellTags->"b:0.0.1"],
  Cell[16632, 579, 2052, 57, 95, "Abstract",
   CellTags->"b:0.0.1"]},
 "c:5"->{
  Cell[18733, 642, 112, 2, 31, "Section",
   CellTags->"c:5"]},
 "c:6"->{
  Cell[18870, 648, 124, 3, 57, "Subsection",
   CellTags->{"c:6", "b:0.1.0"}]},
 "b:0.1.0"->{
  Cell[18870, 648, 124, 3, 57, "Subsection",
   CellTags->{"c:6", "b:0.1.0"}],
  Cell[18997, 653, 105, 2, 44, "Input",
   CellTags->"b:0.1.0"],
  Cell[19105, 657, 59, 1, 44, "Input",
   CellTags->"b:0.1.0"],
  Cell[19167, 660, 249, 6, 22, "Text",
   CellTags->"b:0.1.0"],
  Cell[19419, 668, 262, 8, 60, "Input",
   CellTags->"b:0.1.0"],
  Cell[19684, 678, 268, 6, 22, "Text",
   CellTags->"b:0.1.0"],
  Cell[19955, 686, 93, 3, 44, "Input",
   CellTags->"b:0.1.0"],
  Cell[20051, 691, 200, 5, 22, "Text",
   CellTags->"b:0.1.0"],
  Cell[20254, 698, 90, 3, 44, "Input",
   CellTags->"b:0.1.0"],
  Cell[20347, 703, 321, 7, 49, "Text",
   CellTags->"b:0.1.0"],
  Cell[20671, 712, 734, 22, 105, "Input",
   CellTags->"b:0.1.0"],
  Cell[21408, 736, 297, 6, 49, "Text",
   CellTags->"b:0.1.0"],
  Cell[21708, 744, 472, 14, 75, "Input",
   CellTags->"b:0.1.0"],
  Cell[22183, 760, 235, 6, 22, "Text",
   CellTags->"b:0.1.0"],
  Cell[22421, 768, 680, 19, 75, "Input",
   CellTags->"b:0.1.0"],
  Cell[23104, 789, 241, 6, 22, "Text",
   CellTags->"b:0.1.0"],
  Cell[23348, 797, 643, 20, 60, "Input",
   CellTags->"b:0.1.0"],
  Cell[23994, 819, 255, 6, 22, "Text",
   CellTags->"b:0.1.0"],
  Cell[24252, 827, 510, 12, 90, "Input",
   CellTags->"b:0.1.0"]},
 "c:7"->{
  Cell[24799, 844, 138, 3, 57, "Subsection",
   CellTags->{"c:7", "b:0.1.1"}]},
 "b:0.1.1"->{
  Cell[24799, 844, 138, 3, 57, "Subsection",
   CellTags->{"c:7", "b:0.1.1"}],
  Cell[24940, 849, 314, 7, 49, "Text",
   CellTags->"b:0.1.1"],
  Cell[25257, 858, 958, 30, 66, "Input",
   CellTags->"b:0.1.1"],
  Cell[26218, 890, 238, 6, 22, "Text",
   CellTags->"b:0.1.1"],
  Cell[26459, 898, 286, 9, 60, "Input",
   CellTags->"b:0.1.1"]},
 "c:8"->{
  Cell[26782, 912, 173, 5, 57, "Subsection",
   CellTags->{"c:8", "b:0.1.2"}]},
 "b:0.1.2"->{
  Cell[26782, 912, 173, 5, 57, "Subsection",
   CellTags->{"c:8", "b:0.1.2"}],
  Cell[26958, 919, 391, 8, 76, "Text",
   CellTags->"b:0.1.2"],
  Cell[27352, 929, 470, 15, 44, "Input",
   CellTags->"b:0.1.2"],
  Cell[27825, 946, 254, 7, 44, "Input",
   CellTags->"b:0.1.2"],
  Cell[28082, 955, 232, 6, 22, "Text",
   CellTags->"b:0.1.2"],
  Cell[28317, 963, 304, 10, 60, "Input",
   CellTags->"b:0.1.2"],
  Cell[28624, 975, 500, 15, 22, "Text",
   CellTags->"b:0.1.2"],
  Cell[29127, 992, 898, 27, 105, "Input",
   CellTags->"b:0.1.2"],
  Cell[30028, 1021, 52, 1, 44, "Input",
   CellTags->"b:0.1.2"],
  Cell[30083, 1024, 2052, 57, 95, "Abstract",
   CellTags->"b:0.1.2"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"c:1", 33356, 1115},
 {"c:2", 33424, 1118},
 {"c:3", 33495, 1121},
 {"b:0.0.0", 33587, 1124},
 {"c:4", 35192, 1175},
 {"b:0.0.1", 35285, 1178},
 {"c:5", 36993, 1231},
 {"c:6", 37067, 1234},
 {"b:0.1.0", 37161, 1237},
 {"c:7", 38416, 1276},
 {"b:0.1.1", 38510, 1279},
 {"c:8", 38859, 1290},
 {"b:0.1.2", 38953, 1293}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 59, 1, 50, "Title",
 CellTags->"c:1"],
Cell[607, 23, 54, 0, 34, "Subtitle"],
Cell[664, 25, 241, 7, 20, "Abstract"],
Cell[CellGroupData[{
Cell[930, 36, 277, 6, 51, "Section",
 CellTags->"c:2"],
Cell[CellGroupData[{
Cell[1232, 46, 108, 3, 57, "Subsection",
 CellTags->{"c:3", "b:0.0.0"}],
Cell[1343, 51, 138, 3, 22, "Text",
 CellTags->"b:0.0.0"],
Cell[1484, 56, 105, 2, 44, "Input",
 CellTags->"b:0.0.0"],
Cell[1592, 60, 59, 1, 44, "Input",
 CellTags->"b:0.0.0"],
Cell[1654, 63, 261, 8, 24, "Text",
 CellTags->"b:0.0.0"],
Cell[1918, 73, 200, 5, 22, "Text",
 CellTags->"b:0.0.0"],
Cell[2121, 80, 91, 3, 44, "Input",
 CellTags->"b:0.0.0"],
Cell[2215, 85, 271, 6, 49, "Text",
 CellTags->"b:0.0.0"],
Cell[2489, 93, 75, 2, 44, "Input",
 CellTags->"b:0.0.0"],
Cell[2567, 97, 470, 13, 90, "Input",
 CellTags->"b:0.0.0"],
Cell[3040, 112, 303, 7, 49, "Text",
 CellTags->"b:0.0.0"],
Cell[3346, 121, 87, 2, 44, "Input",
 CellTags->"b:0.0.0"],
Cell[3436, 125, 728, 22, 60, "Input",
 CellTags->"b:0.0.0"],
Cell[4167, 149, 267, 6, 22, "Text",
 CellTags->"b:0.0.0"],
Cell[4437, 157, 177, 5, 44, "Input",
 CellTags->"b:0.0.0"],
Cell[4617, 164, 214, 5, 22, "Text",
 CellTags->"b:0.0.0"],
Cell[4834, 171, 136, 3, 44, "Input",
 CellTags->"b:0.0.0"],
Cell[4973, 176, 247, 6, 22, "Text",
 CellTags->"b:0.0.0"],
Cell[5223, 184, 331, 9, 44, "Input",
 CellTags->"b:0.0.0"],
Cell[5557, 195, 233, 6, 22, "Text",
 CellTags->"b:0.0.0"],
Cell[5793, 203, 556, 17, 63, "Input",
 CellTags->"b:0.0.0"],
Cell[6352, 222, 247, 6, 22, "Text",
 CellTags->"b:0.0.0"],
Cell[6602, 230, 145, 3, 60, "Input",
 CellTags->"b:0.0.0"],
Cell[6750, 235, 453, 15, 22, "Text",
 CellTags->"b:0.0.0"],
Cell[7206, 252, 599, 17, 75, "Input",
 CellTags->"b:0.0.0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7842, 274, 120, 3, 57, "Subsection",
 CellTags->{"c:4", "b:0.0.1"}],
Cell[7965, 279, 200, 5, 22, "Text",
 CellTags->"b:0.0.1"],
Cell[8168, 286, 91, 3, 44, "Input",
 CellTags->"b:0.0.1"],
Cell[8262, 291, 271, 6, 49, "Text",
 CellTags->"b:0.0.1"],
Cell[8536, 299, 75, 2, 44, "Input",
 CellTags->"b:0.0.1"],
Cell[8614, 303, 257, 7, 60, "Input",
 CellTags->"b:0.0.1"],
Cell[8874, 312, 563, 16, 49, "Text",
 CellTags->"b:0.0.1"],
Cell[9440, 330, 87, 2, 44, "Input",
 CellTags->"b:0.0.1"],
Cell[9530, 334, 728, 22, 60, "Input",
 CellTags->"b:0.0.1"],
Cell[10261, 358, 522, 16, 22, "Text",
 CellTags->"b:0.0.1"],
Cell[10786, 376, 335, 9, 60, "Input",
 CellTags->"b:0.0.1"],
Cell[11124, 387, 643, 21, 22, "Text",
 CellTags->"b:0.0.1"],
Cell[11770, 410, 209, 6, 44, "Input",
 CellTags->"b:0.0.1"],
Cell[11982, 418, 249, 6, 22, "Text",
 CellTags->"b:0.0.1"],
Cell[12234, 426, 436, 13, 60, "Input",
 CellTags->"b:0.0.1"],
Cell[12673, 441, 369, 12, 22, "Text",
 CellTags->"b:0.0.1"],
Cell[13045, 455, 806, 26, 66, "Input",
 CellTags->"b:0.0.1"],
Cell[13854, 483, 275, 6, 22, "Text",
 CellTags->"b:0.0.1"],
Cell[14132, 491, 347, 11, 44, "Input",
 CellTags->"b:0.0.1"],
Cell[14482, 504, 430, 15, 22, "Text",
 CellTags->"b:0.0.1"],
Cell[14915, 521, 386, 12, 44, "Input",
 CellTags->"b:0.0.1"],
Cell[15304, 535, 303, 7, 49, "Text",
 CellTags->"b:0.0.1"],
Cell[15610, 544, 503, 13, 90, "Input",
 CellTags->"b:0.0.1"],
Cell[16116, 559, 455, 15, 22, "Text",
 CellTags->"b:0.0.1"],
Cell[16574, 576, 55, 1, 44, "Input",
 CellTags->"b:0.0.1"],
Cell[16632, 579, 2052, 57, 95, "Abstract",
 CellTags->"b:0.0.1"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[18733, 642, 112, 2, 31, "Section",
 CellTags->"c:5"],
Cell[CellGroupData[{
Cell[18870, 648, 124, 3, 57, "Subsection",
 CellTags->{"c:6", "b:0.1.0"}],
Cell[18997, 653, 105, 2, 44, "Input",
 CellTags->"b:0.1.0"],
Cell[19105, 657, 59, 1, 44, "Input",
 CellTags->"b:0.1.0"],
Cell[19167, 660, 249, 6, 22, "Text",
 CellTags->"b:0.1.0"],
Cell[19419, 668, 262, 8, 60, "Input",
 CellTags->"b:0.1.0"],
Cell[19684, 678, 268, 6, 22, "Text",
 CellTags->"b:0.1.0"],
Cell[19955, 686, 93, 3, 44, "Input",
 CellTags->"b:0.1.0"],
Cell[20051, 691, 200, 5, 22, "Text",
 CellTags->"b:0.1.0"],
Cell[20254, 698, 90, 3, 44, "Input",
 CellTags->"b:0.1.0"],
Cell[20347, 703, 321, 7, 49, "Text",
 CellTags->"b:0.1.0"],
Cell[20671, 712, 734, 22, 105, "Input",
 CellTags->"b:0.1.0"],
Cell[21408, 736, 297, 6, 49, "Text",
 CellTags->"b:0.1.0"],
Cell[21708, 744, 472, 14, 75, "Input",
 CellTags->"b:0.1.0"],
Cell[22183, 760, 235, 6, 22, "Text",
 CellTags->"b:0.1.0"],
Cell[22421, 768, 680, 19, 75, "Input",
 CellTags->"b:0.1.0"],
Cell[23104, 789, 241, 6, 22, "Text",
 CellTags->"b:0.1.0"],
Cell[23348, 797, 643, 20, 60, "Input",
 CellTags->"b:0.1.0"],
Cell[23994, 819, 255, 6, 22, "Text",
 CellTags->"b:0.1.0"],
Cell[24252, 827, 510, 12, 90, "Input",
 CellTags->"b:0.1.0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24799, 844, 138, 3, 57, "Subsection",
 CellTags->{"c:7", "b:0.1.1"}],
Cell[24940, 849, 314, 7, 49, "Text",
 CellTags->"b:0.1.1"],
Cell[25257, 858, 958, 30, 66, "Input",
 CellTags->"b:0.1.1"],
Cell[26218, 890, 238, 6, 22, "Text",
 CellTags->"b:0.1.1"],
Cell[26459, 898, 286, 9, 60, "Input",
 CellTags->"b:0.1.1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[26782, 912, 173, 5, 57, "Subsection",
 CellTags->{"c:8", "b:0.1.2"}],
Cell[26958, 919, 391, 8, 76, "Text",
 CellTags->"b:0.1.2"],
Cell[27352, 929, 470, 15, 44, "Input",
 CellTags->"b:0.1.2"],
Cell[27825, 946, 254, 7, 44, "Input",
 CellTags->"b:0.1.2"],
Cell[28082, 955, 232, 6, 22, "Text",
 CellTags->"b:0.1.2"],
Cell[28317, 963, 304, 10, 60, "Input",
 CellTags->"b:0.1.2"],
Cell[28624, 975, 500, 15, 22, "Text",
 CellTags->"b:0.1.2"],
Cell[29127, 992, 898, 27, 105, "Input",
 CellTags->"b:0.1.2"],
Cell[30028, 1021, 52, 1, 44, "Input",
 CellTags->"b:0.1.2"],
Cell[30083, 1024, 2052, 57, 95, "Abstract",
 CellTags->"b:0.1.2"]
}, Open  ]]
}, Closed]]
}
]
*)

(* End of internal cache information *)
