(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     43370,       1513]
NotebookOptionsPosition[     26724,        974]
NotebookOutlinePosition[     36623,       1285]
CellTagsIndexPosition[     36052,       1260]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["Grover searching algorithms", "Title",
 CellTags->"c:1"],

Cell["Searching for one or two items on a database", "Subtitle"],

Cell[TextData[{
 "Version: 3.0-April-2011--For ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " 6.0-8.0"
}], "Abstract",
 CellChangeTimes->{{3.395090887981901*^9, 3.395090925377634*^9}, 
   3.5122121329923573`*^9}],

Cell[TextData[ButtonBox["Click here to get the palette: QDENSpalette.nb",
 BaseStyle->"Hyperlink",
 ButtonData:>{"QDENSpalette.nb", None}]], "Text"],

Cell[CellGroupData[{

Cell["\<\
Grover Searching Algorithm-Single Marked Item.             To open double \
click at down arrow---------------------------->>\
\>", "Section",
 CellChangeTimes->{{3.51221208965519*^9, 3.512212105663488*^9}},
 FontFamily->"Times",
 CellTags->"c:2"],

Cell[CellGroupData[{

Cell["Step 1: Setting the conditions", "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:3", "b:1.0.0"}],

Cell["\<\
Grover's search algorithm making use of density matrices in subspace |x\
\[RightAngleBracket]. 
The space |y\[RightAngleBracket] is part of the search, but keeps the same \
state during 
the process and can therefore be suppressed.\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:1.0.0"],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<QDENSITY`Qdensity`\>\"", "]"}]], "Input",
 CellTags->"b:1.0.0"],

Cell[BoxData[
 RowBox[{"?", "QDENSITY`Qdensity`*"}]], "Input",
 CellTags->"b:1.0.0"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"figure", "=", 
   RowBox[{"Import", "[", 
    RowBox[{"\"\<QDENSITY/drawings/Grover.png\>\"", ",", "\"\<PNG\>\""}], 
    "]"}]}], ";"}], "\n", 
 RowBox[{"Show", "[", "figure", "]"}]}], "Input",
 CellTags->"b:1.0.0"],

Cell[TextData[{
 "Set the number of x  \n- ",
 Cell[BoxData[
  FormBox["nqx", TraditionalForm]]],
 " is the number of qubits of the unknown state"
}], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:1.0.0"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"nqx", "=", "6"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"If", "[", 
  RowBox[{
   RowBox[{"nqx", " ", ">", "10"}], ",", 
   RowBox[{
   "Print", "[", "\"\<Check your nqx, it may take too long to compute\>\"", 
    "]"}], ","}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"qtab", ":=", 
  RowBox[{"Table", "[", 
   RowBox[{
    SubscriptBox["qx", "i"], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", "nqx"}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", "qtab"}], "Input",
 CellTags->"b:1.0.0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"nq", "=", "nqx"}], ";"}]], "Input",
 CellTags->"b:1.0.0"],

Cell["Total number of bits;  we suppress the y bit", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:1.0.0"],

Cell[BoxData[
 RowBox[{"nbits", "=", 
  RowBox[{"2", "^", "nq"}]}]], "Input",
 CellTags->"b:1.0.0"],

Cell["In the figure we depict the full searching circuit.", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:1.0.0"],

Cell["Initialize all n qubits ( x and y qubits)  to Zero State", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:1.0.0"],

Cell[TextData[{
 StyleBox["NOTE: The state  |0\[RightAngleBracket] is the array \
(1,0,0,0,...,0) in the nq bit space",
  FontSize->12],
 "\n",
 StyleBox["Here  \[Rho]0=rh0  is the density matrix in the |x\
\[RightAngleBracket]  space",
  FontSize->12],
 " "
}], "SmallText",
 CellChangeTimes->{{3.5122123980269423`*^9, 3.512212399913834*^9}},
 FontFamily->"Helvetica",
 CellTags->"b:1.0.0"],

Cell["\<\
 rh0=N[Table[KroneckerDelta[i, 1] * KroneckerDelta[i, j],{i, 1, nbits},{j, 1, \
nbits}]];\
\>", "Input",
 CellChangeTimes->{{3.512212354078671*^9, 3.512212386253564*^9}},
 CellTags->"b:1.0.0"],

Cell[TextData[{
 "Prepare State By Hadamarding all x qubits and since |y\[RightAngleBracket]  \
remains as ",
 Cell[BoxData[
  FractionBox["1", 
   SqrtBox["2"]]]],
 "( |0\[RightAngleBracket] - |1\[RightAngleBracket] ), the |y\
\[RightAngleBracket] space can be suppressed"
}], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:1.0.0"],

Cell["\<\
Prepare the x qubits in equi-weighted state by Hadamarding all of them using \
HALL\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:1.0.0"],

Cell[BoxData[
 RowBox[{
  RowBox[{
  "Generate", " ", "the", "  ", "density", " ", "matrix", "  ", "\[Rho]1"}], 
  "=", "rh1", " "}]], "Text",
 CellChangeTimes->{{3.512212417603921*^9, 3.512212420740584*^9}},
 FontFamily->"Helvetica",
 CellTags->"b:1.0.0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rh1", "=", 
   RowBox[{"N", "[", 
    RowBox[{
     RowBox[{"HALL", "[", "nqx", "]"}], ".", "rh0", ".", 
     RowBox[{"Adj", "[", 
      RowBox[{"N", "[", 
       RowBox[{"HALL", "[", "nqx", "]"}], "]"}], "]"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.512212412706369*^9, 3.512212426878147*^9}},
 CellTags->"b:1.0.0"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Step 2: Building the Grover operator", "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:4", "b:1.0.1"}],

Cell["\<\
Prepare the Grover operator G as the \"inversion about the mean\" times the \
Oracle
The Oracle defines an arbitrary single marked state as indicated by the \
function f.
When acting in just the |x\[RightAngleBracket] space, the Grover Oracle G \
changes the sign of the marked state.\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:1.0.1"],

Cell[BoxData[
 RowBox[{"nx", "=", 
  RowBox[{"2", "^", "nqx"}]}]], "Input",
 CellTags->"b:1.0.1"],

Cell[BoxData[
 RowBox[{"Generate", " ", "the", "  ", "marked", " ", "state", " ", 
  "randomly", " ", "and", " ", "incluse", " ", "in", " ", "the", " ", 
  "Oracle"}]], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:1.0.1"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"f", "=", 
   RowBox[{"ReplacePart", "[", 
    RowBox[{
     RowBox[{"ZeroT", "[", "nx", "]"}], ",", "1", ",", 
     RowBox[{"xpick", "=", 
      RowBox[{"RandomInteger", "[", 
       RowBox[{"{", 
        RowBox[{"1", ",", "nx"}], "}"}], "]"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"markit", "=", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}], "f"]}], ";"}]}], "Input",
 CellTags->"b:1.0.1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"OracleG", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"markit", "[", 
       RowBox[{"[", "i", "]"}], "]"}], "*", 
      RowBox[{"KroneckerDelta", "[", 
       RowBox[{"i", ",", "j"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "nx"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", "nx"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellTags->"b:1.0.1"],

Cell[TextData[{
 "phaseinvert is the (2 |0\[RightAngleBracket]\[LeftAngleBracket]0| - I)  \
phase inversion matrix  in the ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["n", "x"], TraditionalForm]]],
 " space "
}], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:1.0.1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"phaseinvert", "=", 
   RowBox[{"N", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"KroneckerDelta", "[", 
        RowBox[{"i", ",", "j"}], "]"}], "*", 
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], "*", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], "^", 
        RowBox[{"KroneckerDelta", "[", 
         RowBox[{"1", ",", "j"}], "]"}]}]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", 
        RowBox[{"2", "^", "nqx"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "1", ",", 
        RowBox[{"2", "^", "nqx"}]}], "}"}]}], "]"}], "]"}]}], ";"}]], "Input",
 CellTags->"b:1.0.1"],

Cell["\<\
Put the above together to form Inversion about the mean: Invmean \
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:1.0.1"],

Cell["Invmean = N[HALL[nq]].(phaseinvert .N[ HALL[nq]]);", "Input",
 CellTags->"b:1.0.1"],

Cell["Then the Grover operator reads:", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:1.0.1"],

Cell["G = N[Invmean . OracleG];", "Input",
 CellTags->"b:1.0.1"],

Cell["\<\
Apply G  nG Times  to obtain the final density matrix \[Rho]F [ nG ] =rhF[nG] \
\>", "Text",
 CellChangeTimes->{{3.512212571591008*^9, 3.512212580176152*^9}},
 FontFamily->"Helvetica",
 CellTags->"b:1.0.1"],

Cell["\<\
rhF[0] = N[rh1];
rhF[nG_] := rhF[nG] = G . (rhF[nG-1] . (Adj[G]))\
\>", "Input",
 CellChangeTimes->{{3.512212445601252*^9, 3.512212446651054*^9}, {
  3.512212586577342*^9, 3.5122126004141808`*^9}},
 CellTags->"b:1.0.1"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Step 3: Apply the Grover operator a certain number of times", \
"Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:5", "b:1.0.2"}],

Cell["\<\
The Grover operator, G, must be applied a number of times which 
is estimated here:\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:1.0.2"],

Cell[BoxData[
 RowBox[{"ntry", "=", 
  RowBox[{
   RowBox[{"IntegerPart", "[", 
    RowBox[{"Sqrt", "[", 
     RowBox[{"Length", "[", "f", "]"}], "]"}], "]"}], "-", "1"}]}]], "Input",
 CellTags->"b:1.0.2"],

Cell["Get final density matrix after ntry iterations.", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:1.0.2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Z", "=", 
   RowBox[{"rhF", "[", "ntry", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5122126126180477`*^9, 3.5122126136533957`*^9}},
 CellTags->"b:1.0.2"],

Cell["\<\
Take Trace for Projective Measurements using Tr  [ | n \[RightAngleBracket]\
\[LeftAngleBracket] n |  \[Rho]  ] = \[LeftAngleBracket] n | \[Rho]  | n \
\[RightAngleBracket] directly.\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:1.0.2"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"Clear", "[", "R", "]"}], ";", 
   RowBox[{"R", ":=", 
    RowBox[{"N", "[", 
     RowBox[{"Table", "[", " ", 
      RowBox[{
       RowBox[{"Z", "[", 
        RowBox[{"[", 
         RowBox[{"i", ",", "i"}], "]"}], "]"}], " ", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "nx"}], "}"}]}], "]"}], "]"}], 
    " "}]}]}]], "Input",
 CellTags->"b:1.0.2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Step 4: Analyze results ", "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:6", "b:1.0.3"}],

Cell["Look at results", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:1.0.3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"probsearch", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{"Table", "[", "  ", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"R", "[", 
        RowBox[{"[", " ", "i", "]"}], "]"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "nx"}], "}"}]}], "]"}], "]"}]}], 
  ";"}]], "Input",
 CellTags->"b:1.0.3"],

Cell["\<\
We can plot the possible outcomes of the search with their probabilities:\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:1.0.3"],

Cell[BoxData[
 RowBox[{"Plot1", "=", 
  RowBox[{"ListPlot", "[", 
   RowBox[{"probsearch", ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Item", " ", "number"}], ",", "Probability"}], "}"}]}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"PointSize", "[", "0.025`", "]"}]}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1.`"}], "}"}]}]}], "]"}]}]], "Input",
 CellTags->{"ListPlot", "b:1.0.3"}],

Cell["Isolate the maximum probability:", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:1.0.3"],

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"Max", "[", "probsearch", "]"}], "]"}]], "Input",
 CellTags->"b:1.0.3"],

Cell["\<\
And get the position corresponding to the maximum probability:\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:1.0.3"],

Cell[BoxData[
 RowBox[{"grover", " ", "=", 
  RowBox[{"Flatten", "[", 
   RowBox[{"Position", "[", 
    RowBox[{"probsearch", ",", 
     RowBox[{"Max", "[", "probsearch", "]"}]}], "]"}], "]"}]}]], "Input",
 CellTags->{"Ordering", "b:1.0.3"}],

Cell["Compare to the \"unknown\" marked state as stored in f ", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:1.0.3"],

Cell[BoxData[
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"f", "[", 
        RowBox[{"[", "s", "]"}], "]"}], "==", "1"}], ",", 
      RowBox[{"Print", "[", 
       RowBox[{
       "\"\<marked item is number=\>\"", ",", "s", ",", 
        "\"\<    \n          Grover search found=\>\"", ",", "grover"}], 
       "]"}], ",", "\"\<\>\""}], "]"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"s", ",", "1", ",", 
     RowBox[{"Length", "[", "f", "]"}]}], "}"}]}], "]"}]], "Input",
 CellTags->"b:1.0.3"],

Cell["Quit", "Input",
 CellTags->"b:1.0.3"],

Cell[TextData[{
 "Last Version: 18-Aug-2005\n",
 Cell[BoxData[
  FormBox[GridBox[{
     {
      RowBox[{"References", ":"}], 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"[", "1", "]"}], " ", 
         RowBox[{"Lov", ".", " ", "K", ".", " ", "Grover"}]}], ",", " ", 
        RowBox[{
         RowBox[{"Phys", ".", " ", "Rev", ".", " ", "Lett", ".", " ", "79"}], 
         " ", 
         RowBox[{"(", "1997", ")"}], " ", "325"}]}], "\n", 
       RowBox[{
        RowBox[{
         RowBox[{"[", "2", "]"}], " ", "QDENSITY", " ", "manual"}], ",", " ", 
        RowBox[{"Sect", ".", " ", "8"}]}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {Right, {Left}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}], TraditionalForm]], 
  "DefinitionBox",
  GridBoxOptions->{
  GridBoxDividers->{
   "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
    "RowsIndexed" -> {}},
  GridBoxSpacings->{"Columns" -> {
      Offset[0.27999999999999997`], {
       Offset[0.5599999999999999]}, 
      Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
      Offset[0.2], {
       Offset[0.16]}, 
      Offset[0.2]}, "RowsIndexed" -> {}}},
  CellTags->"S5.1.1"]
}], "Abstract",
 CellTags->"b:1.0.3"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Grover Searching Algorithm-Two Marked Items.              To open double \
click at down arrow---------------------------->>\
\>", "Section",
 CellChangeTimes->{{3.5122121106395903`*^9, 3.5122121176392*^9}},
 FontFamily->"Times",
 CellTags->"c:7"],

Cell[CellGroupData[{

Cell["Step 1: Setting the conditions", "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:8", "b:1.1.0"}],

Cell["\<\
Grover's search algorithm making use of density matrices in subspace |x\
\[RightAngleBracket]. 
The space |y\[RightAngleBracket] is part of the search, but keeps the same \
state during 
the process and can therefore be suppressed.\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:1.1.0"],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<QDENSITY`Qdensity`\>\"", "]"}]], "Input",
 CellTags->"b:1.1.0"],

Cell[BoxData[
 RowBox[{"?", "QDENSITY`Qdensity`*"}]], "Input",
 CellTags->"b:1.1.0"],

Cell["\<\
Set the number of x  
- nqx is the number of qubits of the unknown state\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:1.1.0"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"nqx", "=", "6"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"If", "[", 
  RowBox[{
   RowBox[{"nqx", " ", ">", "10"}], ",", 
   RowBox[{
   "Print", "[", "\"\<Check your nqx, it may take too long to compute\>\"", 
    "]"}], ","}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"qtab", ":=", 
  RowBox[{"Table", "[", 
   RowBox[{
    SubscriptBox["qx", "i"], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", "nqx"}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", "qtab"}], "Input",
 CellTags->"b:1.1.0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"nq", "=", "nqx"}], ";"}]], "Input",
 CellTags->"b:1.1.0"],

Cell["Total number of bits;  we suppress the y bit", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:1.1.0"],

Cell[BoxData[
 RowBox[{"n", "=", 
  RowBox[{"2", "^", "nq"}]}]], "Input",
 CellTags->"b:1.1.0"],

Cell["In the figure we depict the full searching circuit.", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:1.1.0"],

Cell["Initialize all n qubits ( x and y qubits)  to Zero State", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:1.1.0"],

Cell[TextData[{
 StyleBox["NOTE: the | 0  \[RightAngleBracket] state is the array \
(1,0,0,0,...,0) in the nq bit space",
  FontSize->12],
 "\n",
 StyleBox["Here  \[Rho]0 =rh0 is the density matrix in the |x \
\[RightAngleBracket]  space",
  FontSize->12],
 " "
}], "SmallText",
 CellChangeTimes->{{3.512212675614489*^9, 3.512212677314245*^9}},
 FontFamily->"Helvetica",
 CellTags->"b:1.1.0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rh0", "=", 
   RowBox[{"N", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"KroneckerDelta", "[", 
        RowBox[{"i", ",", "1"}], "]"}], "*", 
       RowBox[{"KroneckerDelta", "[", 
        RowBox[{"i", ",", "j"}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "n"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "1", ",", "n"}], "}"}]}], "]"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.5122126719441233`*^9, 3.512212672054604*^9}},
 CellTags->"b:1.1.0"],

Cell[TextData[{
 "Prepare State By Hadamarding all x qubits and  since |y\[RightAngleBracket] \
 remains as ",
 Cell[BoxData[
  FractionBox["1", 
   SqrtBox["2"]]]],
 "( |0\[RightAngleBracket] - |1\[RightAngleBracket] ), the |y\
\[RightAngleBracket] space can be suppressed"
}], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:1.1.0"],

Cell["\<\
Prepare the x qubits in equi-weighted state by Hadamarding all of them using \
HALL\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:1.1.0"],

Cell[BoxData[
 RowBox[{"Generate", " ", "the", "  ", "density", " ", "matrix", "  ", 
  "\[Rho]1", " "}]], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:1.1.0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rh1", "=", 
   RowBox[{
    RowBox[{"N", "[", 
     RowBox[{"HALL", "[", "nqx", "]"}], "]"}], ".", "rh0", ".", 
    RowBox[{"(", 
     RowBox[{"Adj", "[", 
      RowBox[{"N", "[", 
       RowBox[{"HALL", "[", "nqx", "]"}], "]"}], "]"}], ")"}]}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.5122126809292192`*^9, 3.5122126858539352`*^9}},
 CellTags->"b:1.1.0"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Step 2: Prepare the Grover operator", "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:9", "b:1.1.1"}],

Cell["\<\
Prepare the Grover operator G as the \"inversion about the mean\" times the \
Oracle.
The Oracle defines an arbitrary set of two marked states as indicated by the \
function f.
When acting in just the | x \[RightAngleBracket] space, the Grover OracleG \
changes the sign of the marked states.\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:1.1.1"],

Cell[BoxData[
 RowBox[{"nx", "=", 
  RowBox[{"2", "^", "nqx"}]}]], "Input",
 CellTags->"b:1.1.1"],

Cell[BoxData[{
 RowBox[{"f", "=", 
  RowBox[{"ReplacePart", "[", 
   RowBox[{
    RowBox[{"ZeroT", "[", "nx", "]"}], ",", "1", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"xpick1", "=", 
        RowBox[{"RandomInteger", "[", 
         RowBox[{"{", 
          RowBox[{"1", ",", "nx"}], "}"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"xpick2", "=", 
        RowBox[{"RandomInteger", "[", 
         RowBox[{"{", 
          RowBox[{"1", ",", "nx"}], "}"}], "]"}]}], "}"}]}], "}"}]}], 
   "]"}]}], "\n", 
 RowBox[{"markit", "=", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{"-", "1"}], ")"}], "f"]}]}], "Input",
 CellTags->"b:1.1.1"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"OracleG", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"markit", "[", 
       RowBox[{"[", "i", "]"}], "]"}], "*", 
      RowBox[{"KroneckerDelta", "[", 
       RowBox[{"i", ",", "j"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "nx"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", "nx"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{" "}]}], "Input",
 CellTags->"b:1.1.1"],

Cell["\<\
phaseinvert is the (2 | 0 \[RightAngleBracket] \[LeftAngleBracket]  0 | - I ) \
 phase inversion matrix in the nqx space \
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:1.1.1"],

Cell["\<\
phaseinvert = \
N[Table[KroneckerDelta[i,j]*(-1)*(-1)^KroneckerDelta[1,j],{i,1,2^nqx},{j, 1, \
nx}]];\
\>", "Input",
 CellTags->"b:1.1.1"],

Cell["\<\
Put the above together to form Inversion about the mean: Invmean \
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:1.1.1"],

Cell["Invmean = N[HALL[nq]] . (phaseinvert .N[ HALL[nq]]);", "Input",
 CellTags->"b:1.1.1"],

Cell["The Grover operator is thus:", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:1.1.1"],

Cell["G = N[Invmean . OracleG];", "Input",
 CellTags->"b:1.1.1"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Step 3: Apply the Grover Operator ntry times", "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:10", "b:1.1.2"}],

Cell["\<\
Apply G   nG Times to obtain the final density matrix \[Rho]F [ nG ]=rhF[nG]. \
The definition is 
done recursively:  \
\>", "Text",
 CellChangeTimes->{{3.512212701889825*^9, 3.512212707838779*^9}},
 FontFamily->"Helvetica",
 CellTags->"b:1.1.2"],

Cell["\<\
rhF[0] = N[rh1];
rhF[nG_] := rhF[nG] = G . (rhF[nG-1] . (Adj[G]))\
\>", "Input",
 CellChangeTimes->{{3.512212713102189*^9, 3.5122127333771*^9}},
 CellTags->"b:1.1.2"],

Cell["\<\
The number of times we apply the Grover operator is defined here:\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:1.1.2"],

Cell[BoxData[
 RowBox[{"ntry", "=", 
  RowBox[{
   RowBox[{"IntegerPart", "[", 
    RowBox[{"Sqrt", "[", 
     RowBox[{"Length", "[", "f", "]"}], "]"}], "]"}], "-", "4"}]}]], "Input",
 CellTags->"b:1.1.2"],

Cell["Get final density matrix after ntry iterations.", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:1.1.2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Z", "=", 
   RowBox[{"rhF", "[", "ntry", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.512212740566826*^9, 3.512212741403082*^9}},
 CellTags->"b:1.1.2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Step 4: Analyze results", "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:11", "b:1.1.3"}],

Cell["\<\
Take Trace for Projective Measurements using Tr  [ | n \[RightAngleBracket]\
\[LeftAngleBracket] n |  \[Rho] ] = \[LeftAngleBracket] n | \[Rho] | n \
\[RightAngleBracket] directly.\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:1.1.3"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"Clear", "[", "R", "]"}], ";", 
   RowBox[{"R", ":=", 
    RowBox[{"N", "[", 
     RowBox[{"Table", "[", " ", 
      RowBox[{
       RowBox[{"Z", "[", 
        RowBox[{"[", 
         RowBox[{"i", ",", "i"}], "]"}], "]"}], " ", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "nx"}], "}"}]}], "]"}], "]"}], 
    " "}]}]}]], "Input",
 CellTags->"b:1.1.3"],

Cell["Look at results", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:1.1.3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"probsearch", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{"Table", "[", "  ", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"R", "[", 
        RowBox[{"[", " ", "i", "]"}], "]"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "nx"}], "}"}]}], "]"}], "]"}]}], 
  ";"}]], "Input",
 CellTags->"b:1.1.3"],

Cell["Plot the possible results with their probabilities:", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:1.1.3"],

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{"probsearch", ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"PointSize", "[", "0.025`", "]"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "1.`"}], "}"}]}]}], "]"}]], "Input",
 CellTags->{"ListPlot", "b:1.1.3"}],

Cell["Find the highest probabilities from the table", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:1.1.3"],

Cell[BoxData[
 RowBox[{"val", "=", 
  RowBox[{"Max", "[", "probsearch", "]"}]}]], "Input",
 CellTags->"b:1.1.3"],

Cell[BoxData[
 RowBox[{"grover", " ", "=", 
  RowBox[{"Flatten", "[", 
   RowBox[{"Position", "[", 
    RowBox[{"probsearch", ",", 
     RowBox[{"_", "?", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"val", "-", ".01"}], ")"}], "<", "#", "<", 
         RowBox[{"(", 
          RowBox[{"val", "+", ".01"}], ")"}]}], "&"}], ")"}]}]}], "]"}], 
   "]"}]}]], "Input",
 CellTags->{"Ordering", "b:1.1.3"}],

Cell["Compare to the \"unknown\"  marked state as stored in f ", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:1.1.3"],

Cell[BoxData[
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"f", "[", 
        RowBox[{"[", "s", "]"}], "]"}], "==", "1"}], ",", 
      RowBox[{"Print", "[", 
       RowBox[{
       "\"\<marked item is number=\>\"", ",", "s", ",", 
        "\"\<    \n          Grover search found=\>\"", ",", "grover"}], 
       "]"}], ",", "\"\<\>\""}], "]"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"s", ",", "1", ",", 
     RowBox[{"Length", "[", "f", "]"}]}], "}"}]}], "]"}]], "Input",
 CellTags->"b:1.1.3"],

Cell["Quit", "Input",
 CellTags->"b:1.1.3"],

Cell[TextData[{
 "Last Version: 18-Aug-2005\n",
 Cell[BoxData[
  FormBox[GridBox[{
     {
      RowBox[{"References", ":"}], 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"[", "1", "]"}], " ", 
         RowBox[{"Lov", ".", " ", "K", ".", " ", "Grover"}]}], ",", " ", 
        RowBox[{
         RowBox[{"Phys", ".", " ", "Rev", ".", " ", "Lett", ".", " ", "79"}], 
         " ", 
         RowBox[{"(", "1997", ")"}], " ", "325"}]}], "\n", 
       RowBox[{
        RowBox[{
         RowBox[{"[", "2", "]"}], " ", "QDENSITY", " ", "manual"}], ",", " ", 
        RowBox[{"Sect", ".", " ", "8"}]}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {Right, {Left}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}], TraditionalForm]], 
  "DefinitionBox",
  GridBoxOptions->{
  GridBoxDividers->{
   "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
    "RowsIndexed" -> {}},
  GridBoxSpacings->{"Columns" -> {
      Offset[0.27999999999999997`], {
       Offset[0.5599999999999999]}, 
      Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
      Offset[0.2], {
       Offset[0.16]}, 
      Offset[0.2]}, "RowsIndexed" -> {}}},
  CellTags->"S5.1.1"]
}], "Abstract",
 CellTags->"b:1.1.3"]
}, Open  ]]
}, Closed]]
},
WindowToolbars->{},
WindowSize->{881, 678},
WindowMargins->{{Automatic, 135}, {Automatic, 73}},
PrintingStartingPageNumber->39,
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"Magnification"->1,
"PaperOrientation"->"Portrait",
"PaperSize"->{612, 792},
"PostScriptOutputFile":>FrontEnd`FileName[{"home", "bruno", "PITT", "QC"}, 
  "Test1.1.nb.ps", CharacterEncoding -> "WindowsANSI"]},
ShowSelection->True,
TaggingRules:>{
 "PaginationCache" -> {{2005, 8, 9, 3, 36, 20.212814`8.058201763306208}, {39, 
    39, 39, 39, 39, 39, 39, 39, 39, 39, 39, 39, 40, 40, 40, 40, 40, 40, 40, 
    40, 40, 40, 40, 40, 40, 40, 40, 40, 40, 41, 41, 41, 41, 41, 41, 41, 41, 
    41, 41, 41, 41, 41, 41, 41, 41, 41, 41, 42, 42, 42, 42, 42, 42, 42, 42, 
    42, 42, 42, 42, 42, 42, 42, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 43, 
    43, 43, 43, 43, 43, 44, 44, 44, 44, 44, 44, 44, 44, 44, 44, 44, 44, 44, 
    44, 44, 44, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45, 45}, 
    Automatic}},
CellLabelAutoDelete->True,
Magnification->1,
FrontEndVersion->"8.0 for Mac OS X x86 (32-bit) (November 6, 2010)",
StyleDefinitions->"Classroom.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "c:1"->{
  Cell[545, 20, 62, 1, 50, "Title",
   CellTags->"c:1"]},
 "c:2"->{
  Cell[1073, 40, 257, 6, 51, "Section",
   CellTags->"c:2"]},
 "c:3"->{
  Cell[1355, 50, 123, 3, 57, "Subsection",
   CellTags->{"c:3", "b:1.0.0"}]},
 "b:1.0.0"->{
  Cell[1355, 50, 123, 3, 57, "Subsection",
   CellTags->{"c:3", "b:1.0.0"}],
  Cell[1481, 55, 303, 8, 76, "Text",
   CellTags->"b:1.0.0"],
  Cell[1787, 65, 105, 2, 44, "Input",
   CellTags->"b:1.0.0"],
  Cell[1895, 69, 84, 2, 44, "Input",
   CellTags->"b:1.0.0"],
  Cell[1982, 73, 251, 7, 60, "Input",
   CellTags->"b:1.0.0"],
  Cell[2236, 82, 206, 7, 49, "Text",
   CellTags->"b:1.0.0"],
  Cell[2445, 91, 538, 16, 93, "Input",
   CellTags->"b:1.0.0"],
  Cell[2986, 109, 92, 3, 44, "Input",
   CellTags->"b:1.0.0"],
  Cell[3081, 114, 108, 2, 22, "Text",
   CellTags->"b:1.0.0"],
  Cell[3192, 118, 99, 3, 44, "Input",
   CellTags->"b:1.0.0"],
  Cell[3294, 123, 115, 2, 22, "Text",
   CellTags->"b:1.0.0"],
  Cell[3412, 127, 120, 2, 22, "Text",
   CellTags->"b:1.0.0"],
  Cell[3535, 131, 391, 12, 43, "SmallText",
   CellTags->"b:1.0.0"],
  Cell[3929, 145, 202, 5, 44, "Input",
   CellTags->"b:1.0.0"],
  Cell[4134, 152, 333, 10, 34, "Text",
   CellTags->"b:1.0.0"],
  Cell[4470, 164, 155, 5, 22, "Text",
   CellTags->"b:1.0.0"],
  Cell[4628, 171, 256, 7, 22, "Text",
   CellTags->"b:1.0.0"],
  Cell[4887, 180, 365, 11, 44, "Input",
   CellTags->"b:1.0.0"]},
 "c:4"->{
  Cell[5289, 196, 129, 3, 57, "Subsection",
   CellTags->{"c:4", "b:1.0.1"}]},
 "b:1.0.1"->{
  Cell[5289, 196, 129, 3, 57, "Subsection",
   CellTags->{"c:4", "b:1.0.1"}],
  Cell[5421, 201, 356, 9, 76, "Text",
   CellTags->"b:1.0.1"],
  Cell[5780, 212, 97, 3, 44, "Input",
   CellTags->"b:1.0.1"],
  Cell[5880, 217, 224, 5, 22, "Text",
   CellTags->"b:1.0.1"],
  Cell[6107, 224, 460, 15, 63, "Input",
   CellTags->"b:1.0.1"],
  Cell[6570, 241, 455, 14, 44, "Input",
   CellTags->"b:1.0.1"],
  Cell[7028, 257, 269, 9, 22, "Text",
   CellTags->"b:1.0.1"],
  Cell[7300, 268, 713, 22, 44, "Input",
   CellTags->"b:1.0.1"],
  Cell[8016, 292, 137, 4, 22, "Text",
   CellTags->"b:1.0.1"],
  Cell[8156, 298, 89, 1, 44, "Input",
   CellTags->"b:1.0.1"],
  Cell[8248, 301, 95, 2, 22, "Text",
   CellTags->"b:1.0.1"],
  Cell[8346, 305, 64, 1, 44, "Input",
   CellTags->"b:1.0.1"],
  Cell[8413, 308, 216, 5, 22, "Text",
   CellTags->"b:1.0.1"],
  Cell[8632, 315, 229, 6, 57, "Input",
   CellTags->"b:1.0.1"]},
 "c:5"->{
  Cell[8898, 326, 154, 4, 57, "Subsection",
   CellTags->{"c:5", "b:1.0.2"}]},
 "b:1.0.2"->{
  Cell[8898, 326, 154, 4, 57, "Subsection",
   CellTags->{"c:5", "b:1.0.2"}],
  Cell[9055, 332, 155, 5, 49, "Text",
   CellTags->"b:1.0.2"],
  Cell[9213, 339, 205, 6, 44, "Input",
   CellTags->"b:1.0.2"],
  Cell[9421, 347, 111, 2, 22, "Text",
   CellTags->"b:1.0.2"],
  Cell[9535, 351, 193, 5, 44, "Input",
   CellTags->"b:1.0.2"],
  Cell[9731, 358, 254, 6, 22, "Text",
   CellTags->"b:1.0.2"],
  Cell[9988, 366, 419, 14, 44, "Input",
   CellTags->"b:1.0.2"]},
 "c:6"->{
  Cell[10444, 385, 117, 3, 57, "Subsection",
   CellTags->{"c:6", "b:1.0.3"}]},
 "b:1.0.3"->{
  Cell[10444, 385, 117, 3, 57, "Subsection",
   CellTags->{"c:6", "b:1.0.3"}],
  Cell[10564, 390, 79, 2, 22, "Text",
   CellTags->"b:1.0.3"],
  Cell[10646, 394, 362, 12, 44, "Input",
   CellTags->"b:1.0.3"],
  Cell[11011, 408, 145, 4, 22, "Text",
   CellTags->"b:1.0.3"],
  Cell[11159, 414, 492, 13, 60, "Input",
   CellTags->{"ListPlot", "b:1.0.3"}],
  Cell[11654, 429, 96, 2, 22, "Text",
   CellTags->"b:1.0.3"],
  Cell[11753, 433, 115, 3, 44, "Input",
   CellTags->"b:1.0.3"],
  Cell[11871, 438, 134, 4, 22, "Text",
   CellTags->"b:1.0.3"],
  Cell[12008, 444, 241, 6, 44, "Input",
   CellTags->{"Ordering", "b:1.0.3"}],
  Cell[12252, 452, 119, 2, 22, "Text",
   CellTags->"b:1.0.3"],
  Cell[12374, 456, 569, 17, 60, "Input",
   CellTags->"b:1.0.3"],
  Cell[12946, 475, 43, 1, 44, "Input",
   CellTags->"b:1.0.3"],
  Cell[12992, 478, 1268, 37, 49, "Abstract",
   CellTags->"b:1.0.3"]},
 "ListPlot"->{
  Cell[11159, 414, 492, 13, 60, "Input",
   CellTags->{"ListPlot", "b:1.0.3"}],
  Cell[23695, 872, 311, 8, 44, "Input",
   CellTags->{"ListPlot", "b:1.1.3"}]},
 "Ordering"->{
  Cell[12008, 444, 241, 6, 44, "Input",
   CellTags->{"Ordering", "b:1.0.3"}],
  Cell[24236, 891, 448, 14, 44, "Input",
   CellTags->{"Ordering", "b:1.1.3"}]},
 "c:7"->{
  Cell[14309, 521, 257, 6, 31, "Section",
   CellTags->"c:7"]},
 "c:8"->{
  Cell[14591, 531, 123, 3, 57, "Subsection",
   CellTags->{"c:8", "b:1.1.0"}]},
 "b:1.1.0"->{
  Cell[14591, 531, 123, 3, 57, "Subsection",
   CellTags->{"c:8", "b:1.1.0"}],
  Cell[14717, 536, 303, 8, 76, "Text",
   CellTags->"b:1.1.0"],
  Cell[15023, 546, 105, 2, 44, "Input",
   CellTags->"b:1.1.0"],
  Cell[15131, 550, 84, 2, 44, "Input",
   CellTags->"b:1.1.0"],
  Cell[15218, 554, 144, 5, 49, "Text",
   CellTags->"b:1.1.0"],
  Cell[15365, 561, 538, 16, 93, "Input",
   CellTags->"b:1.1.0"],
  Cell[15906, 579, 92, 3, 44, "Input",
   CellTags->"b:1.1.0"],
  Cell[16001, 584, 108, 2, 22, "Text",
   CellTags->"b:1.1.0"],
  Cell[16112, 588, 95, 3, 44, "Input",
   CellTags->"b:1.1.0"],
  Cell[16210, 593, 115, 2, 22, "Text",
   CellTags->"b:1.1.0"],
  Cell[16328, 597, 120, 2, 22, "Text",
   CellTags->"b:1.1.0"],
  Cell[16451, 601, 392, 12, 43, "SmallText",
   CellTags->"b:1.1.0"],
  Cell[16846, 615, 568, 17, 44, "Input",
   CellTags->"b:1.1.0"],
  Cell[17417, 634, 334, 10, 34, "Text",
   CellTags->"b:1.1.0"],
  Cell[17754, 646, 155, 5, 22, "Text",
   CellTags->"b:1.1.0"],
  Cell[17912, 653, 162, 4, 22, "Text",
   CellTags->"b:1.1.0"],
  Cell[18077, 659, 394, 12, 44, "Input",
   CellTags->"b:1.1.0"]},
 "c:9"->{
  Cell[18508, 676, 128, 3, 57, "Subsection",
   CellTags->{"c:9", "b:1.1.1"}]},
 "b:1.1.1"->{
  Cell[18508, 676, 128, 3, 57, "Subsection",
   CellTags->{"c:9", "b:1.1.1"}],
  Cell[18639, 681, 364, 9, 76, "Text",
   CellTags->"b:1.1.1"],
  Cell[19006, 692, 97, 3, 44, "Input",
   CellTags->"b:1.1.1"],
  Cell[19106, 697, 677, 22, 63, "Input",
   CellTags->"b:1.1.1"],
  Cell[19786, 721, 500, 16, 60, "Input",
   CellTags->"b:1.1.1"],
  Cell[20289, 739, 193, 5, 22, "Text",
   CellTags->"b:1.1.1"],
  Cell[20485, 746, 148, 5, 44, "Input",
   CellTags->"b:1.1.1"],
  Cell[20636, 753, 137, 4, 22, "Text",
   CellTags->"b:1.1.1"],
  Cell[20776, 759, 91, 1, 44, "Input",
   CellTags->"b:1.1.1"],
  Cell[20870, 762, 92, 2, 22, "Text",
   CellTags->"b:1.1.1"],
  Cell[20965, 766, 64, 1, 44, "Input",
   CellTags->"b:1.1.1"]},
 "c:10"->{
  Cell[21066, 772, 138, 3, 57, "Subsection",
   CellTags->{"c:10", "b:1.1.2"}]},
 "b:1.1.2"->{
  Cell[21066, 772, 138, 3, 57, "Subsection",
   CellTags->{"c:10", "b:1.1.2"}],
  Cell[21207, 777, 256, 7, 49, "Text",
   CellTags->"b:1.1.2"],
  Cell[21466, 786, 176, 5, 57, "Input",
   CellTags->"b:1.1.2"],
  Cell[21645, 793, 137, 4, 22, "Text",
   CellTags->"b:1.1.2"],
  Cell[21785, 799, 205, 6, 44, "Input",
   CellTags->"b:1.1.2"],
  Cell[21993, 807, 111, 2, 22, "Text",
   CellTags->"b:1.1.2"],
  Cell[22107, 811, 189, 5, 44, "Input",
   CellTags->"b:1.1.2"]},
 "c:11"->{
  Cell[22333, 821, 117, 3, 57, "Subsection",
   CellTags->{"c:11", "b:1.1.3"}]},
 "b:1.1.3"->{
  Cell[22333, 821, 117, 3, 57, "Subsection",
   CellTags->{"c:11", "b:1.1.3"}],
  Cell[22453, 826, 252, 6, 22, "Text",
   CellTags->"b:1.1.3"],
  Cell[22708, 834, 419, 14, 44, "Input",
   CellTags->"b:1.1.3"],
  Cell[23130, 850, 79, 2, 22, "Text",
   CellTags->"b:1.1.3"],
  Cell[23212, 854, 362, 12, 44, "Input",
   CellTags->"b:1.1.3"],
  Cell[23577, 868, 115, 2, 22, "Text",
   CellTags->"b:1.1.3"],
  Cell[23695, 872, 311, 8, 44, "Input",
   CellTags->{"ListPlot", "b:1.1.3"}],
  Cell[24009, 882, 109, 2, 22, "Text",
   CellTags->"b:1.1.3"],
  Cell[24121, 886, 112, 3, 44, "Input",
   CellTags->"b:1.1.3"],
  Cell[24236, 891, 448, 14, 44, "Input",
   CellTags->{"Ordering", "b:1.1.3"}],
  Cell[24687, 907, 120, 2, 22, "Text",
   CellTags->"b:1.1.3"],
  Cell[24810, 911, 569, 17, 60, "Input",
   CellTags->"b:1.1.3"],
  Cell[25382, 930, 43, 1, 44, "Input",
   CellTags->"b:1.1.3"],
  Cell[25428, 933, 1268, 37, 49, "Abstract",
   CellTags->"b:1.1.3"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"c:1", 27967, 1004},
 {"c:2", 28035, 1007},
 {"c:3", 28107, 1010},
 {"b:1.0.0", 28199, 1013},
 {"c:4", 29366, 1050},
 {"b:1.0.1", 29459, 1053},
 {"c:5", 30373, 1082},
 {"b:1.0.2", 30466, 1085},
 {"c:6", 30937, 1100},
 {"b:1.0.3", 31031, 1103},
 {"ListPlot", 31934, 1130},
 {"Ordering", 32109, 1135},
 {"c:7", 32279, 1140},
 {"c:8", 32353, 1143},
 {"b:1.1.0", 32447, 1146},
 {"c:9", 33575, 1181},
 {"b:1.1.1", 33669, 1184},
 {"c:10", 34404, 1207},
 {"b:1.1.2", 34499, 1210},
 {"c:11", 34978, 1225},
 {"b:1.1.3", 35073, 1228}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 62, 1, 50, "Title",
 CellTags->"c:1"],
Cell[610, 23, 64, 0, 34, "Subtitle"],
Cell[677, 25, 220, 7, 20, "Abstract"],
Cell[900, 34, 148, 2, 22, "Text"],
Cell[CellGroupData[{
Cell[1073, 40, 257, 6, 51, "Section",
 CellTags->"c:2"],
Cell[CellGroupData[{
Cell[1355, 50, 123, 3, 57, "Subsection",
 CellTags->{"c:3", "b:1.0.0"}],
Cell[1481, 55, 303, 8, 76, "Text",
 CellTags->"b:1.0.0"],
Cell[1787, 65, 105, 2, 44, "Input",
 CellTags->"b:1.0.0"],
Cell[1895, 69, 84, 2, 44, "Input",
 CellTags->"b:1.0.0"],
Cell[1982, 73, 251, 7, 60, "Input",
 CellTags->"b:1.0.0"],
Cell[2236, 82, 206, 7, 49, "Text",
 CellTags->"b:1.0.0"],
Cell[2445, 91, 538, 16, 93, "Input",
 CellTags->"b:1.0.0"],
Cell[2986, 109, 92, 3, 44, "Input",
 CellTags->"b:1.0.0"],
Cell[3081, 114, 108, 2, 22, "Text",
 CellTags->"b:1.0.0"],
Cell[3192, 118, 99, 3, 44, "Input",
 CellTags->"b:1.0.0"],
Cell[3294, 123, 115, 2, 22, "Text",
 CellTags->"b:1.0.0"],
Cell[3412, 127, 120, 2, 22, "Text",
 CellTags->"b:1.0.0"],
Cell[3535, 131, 391, 12, 43, "SmallText",
 CellTags->"b:1.0.0"],
Cell[3929, 145, 202, 5, 44, "Input",
 CellTags->"b:1.0.0"],
Cell[4134, 152, 333, 10, 34, "Text",
 CellTags->"b:1.0.0"],
Cell[4470, 164, 155, 5, 22, "Text",
 CellTags->"b:1.0.0"],
Cell[4628, 171, 256, 7, 22, "Text",
 CellTags->"b:1.0.0"],
Cell[4887, 180, 365, 11, 44, "Input",
 CellTags->"b:1.0.0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5289, 196, 129, 3, 57, "Subsection",
 CellTags->{"c:4", "b:1.0.1"}],
Cell[5421, 201, 356, 9, 76, "Text",
 CellTags->"b:1.0.1"],
Cell[5780, 212, 97, 3, 44, "Input",
 CellTags->"b:1.0.1"],
Cell[5880, 217, 224, 5, 22, "Text",
 CellTags->"b:1.0.1"],
Cell[6107, 224, 460, 15, 63, "Input",
 CellTags->"b:1.0.1"],
Cell[6570, 241, 455, 14, 44, "Input",
 CellTags->"b:1.0.1"],
Cell[7028, 257, 269, 9, 22, "Text",
 CellTags->"b:1.0.1"],
Cell[7300, 268, 713, 22, 44, "Input",
 CellTags->"b:1.0.1"],
Cell[8016, 292, 137, 4, 22, "Text",
 CellTags->"b:1.0.1"],
Cell[8156, 298, 89, 1, 44, "Input",
 CellTags->"b:1.0.1"],
Cell[8248, 301, 95, 2, 22, "Text",
 CellTags->"b:1.0.1"],
Cell[8346, 305, 64, 1, 44, "Input",
 CellTags->"b:1.0.1"],
Cell[8413, 308, 216, 5, 22, "Text",
 CellTags->"b:1.0.1"],
Cell[8632, 315, 229, 6, 57, "Input",
 CellTags->"b:1.0.1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8898, 326, 154, 4, 57, "Subsection",
 CellTags->{"c:5", "b:1.0.2"}],
Cell[9055, 332, 155, 5, 49, "Text",
 CellTags->"b:1.0.2"],
Cell[9213, 339, 205, 6, 44, "Input",
 CellTags->"b:1.0.2"],
Cell[9421, 347, 111, 2, 22, "Text",
 CellTags->"b:1.0.2"],
Cell[9535, 351, 193, 5, 44, "Input",
 CellTags->"b:1.0.2"],
Cell[9731, 358, 254, 6, 22, "Text",
 CellTags->"b:1.0.2"],
Cell[9988, 366, 419, 14, 44, "Input",
 CellTags->"b:1.0.2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10444, 385, 117, 3, 57, "Subsection",
 CellTags->{"c:6", "b:1.0.3"}],
Cell[10564, 390, 79, 2, 22, "Text",
 CellTags->"b:1.0.3"],
Cell[10646, 394, 362, 12, 44, "Input",
 CellTags->"b:1.0.3"],
Cell[11011, 408, 145, 4, 22, "Text",
 CellTags->"b:1.0.3"],
Cell[11159, 414, 492, 13, 60, "Input",
 CellTags->{"ListPlot", "b:1.0.3"}],
Cell[11654, 429, 96, 2, 22, "Text",
 CellTags->"b:1.0.3"],
Cell[11753, 433, 115, 3, 44, "Input",
 CellTags->"b:1.0.3"],
Cell[11871, 438, 134, 4, 22, "Text",
 CellTags->"b:1.0.3"],
Cell[12008, 444, 241, 6, 44, "Input",
 CellTags->{"Ordering", "b:1.0.3"}],
Cell[12252, 452, 119, 2, 22, "Text",
 CellTags->"b:1.0.3"],
Cell[12374, 456, 569, 17, 60, "Input",
 CellTags->"b:1.0.3"],
Cell[12946, 475, 43, 1, 44, "Input",
 CellTags->"b:1.0.3"],
Cell[12992, 478, 1268, 37, 49, "Abstract",
 CellTags->"b:1.0.3"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[14309, 521, 257, 6, 31, "Section",
 CellTags->"c:7"],
Cell[CellGroupData[{
Cell[14591, 531, 123, 3, 57, "Subsection",
 CellTags->{"c:8", "b:1.1.0"}],
Cell[14717, 536, 303, 8, 76, "Text",
 CellTags->"b:1.1.0"],
Cell[15023, 546, 105, 2, 44, "Input",
 CellTags->"b:1.1.0"],
Cell[15131, 550, 84, 2, 44, "Input",
 CellTags->"b:1.1.0"],
Cell[15218, 554, 144, 5, 49, "Text",
 CellTags->"b:1.1.0"],
Cell[15365, 561, 538, 16, 93, "Input",
 CellTags->"b:1.1.0"],
Cell[15906, 579, 92, 3, 44, "Input",
 CellTags->"b:1.1.0"],
Cell[16001, 584, 108, 2, 22, "Text",
 CellTags->"b:1.1.0"],
Cell[16112, 588, 95, 3, 44, "Input",
 CellTags->"b:1.1.0"],
Cell[16210, 593, 115, 2, 22, "Text",
 CellTags->"b:1.1.0"],
Cell[16328, 597, 120, 2, 22, "Text",
 CellTags->"b:1.1.0"],
Cell[16451, 601, 392, 12, 43, "SmallText",
 CellTags->"b:1.1.0"],
Cell[16846, 615, 568, 17, 44, "Input",
 CellTags->"b:1.1.0"],
Cell[17417, 634, 334, 10, 34, "Text",
 CellTags->"b:1.1.0"],
Cell[17754, 646, 155, 5, 22, "Text",
 CellTags->"b:1.1.0"],
Cell[17912, 653, 162, 4, 22, "Text",
 CellTags->"b:1.1.0"],
Cell[18077, 659, 394, 12, 44, "Input",
 CellTags->"b:1.1.0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18508, 676, 128, 3, 57, "Subsection",
 CellTags->{"c:9", "b:1.1.1"}],
Cell[18639, 681, 364, 9, 76, "Text",
 CellTags->"b:1.1.1"],
Cell[19006, 692, 97, 3, 44, "Input",
 CellTags->"b:1.1.1"],
Cell[19106, 697, 677, 22, 63, "Input",
 CellTags->"b:1.1.1"],
Cell[19786, 721, 500, 16, 60, "Input",
 CellTags->"b:1.1.1"],
Cell[20289, 739, 193, 5, 22, "Text",
 CellTags->"b:1.1.1"],
Cell[20485, 746, 148, 5, 44, "Input",
 CellTags->"b:1.1.1"],
Cell[20636, 753, 137, 4, 22, "Text",
 CellTags->"b:1.1.1"],
Cell[20776, 759, 91, 1, 44, "Input",
 CellTags->"b:1.1.1"],
Cell[20870, 762, 92, 2, 22, "Text",
 CellTags->"b:1.1.1"],
Cell[20965, 766, 64, 1, 44, "Input",
 CellTags->"b:1.1.1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[21066, 772, 138, 3, 57, "Subsection",
 CellTags->{"c:10", "b:1.1.2"}],
Cell[21207, 777, 256, 7, 49, "Text",
 CellTags->"b:1.1.2"],
Cell[21466, 786, 176, 5, 57, "Input",
 CellTags->"b:1.1.2"],
Cell[21645, 793, 137, 4, 22, "Text",
 CellTags->"b:1.1.2"],
Cell[21785, 799, 205, 6, 44, "Input",
 CellTags->"b:1.1.2"],
Cell[21993, 807, 111, 2, 22, "Text",
 CellTags->"b:1.1.2"],
Cell[22107, 811, 189, 5, 44, "Input",
 CellTags->"b:1.1.2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[22333, 821, 117, 3, 57, "Subsection",
 CellTags->{"c:11", "b:1.1.3"}],
Cell[22453, 826, 252, 6, 22, "Text",
 CellTags->"b:1.1.3"],
Cell[22708, 834, 419, 14, 44, "Input",
 CellTags->"b:1.1.3"],
Cell[23130, 850, 79, 2, 22, "Text",
 CellTags->"b:1.1.3"],
Cell[23212, 854, 362, 12, 44, "Input",
 CellTags->"b:1.1.3"],
Cell[23577, 868, 115, 2, 22, "Text",
 CellTags->"b:1.1.3"],
Cell[23695, 872, 311, 8, 44, "Input",
 CellTags->{"ListPlot", "b:1.1.3"}],
Cell[24009, 882, 109, 2, 22, "Text",
 CellTags->"b:1.1.3"],
Cell[24121, 886, 112, 3, 44, "Input",
 CellTags->"b:1.1.3"],
Cell[24236, 891, 448, 14, 44, "Input",
 CellTags->{"Ordering", "b:1.1.3"}],
Cell[24687, 907, 120, 2, 22, "Text",
 CellTags->"b:1.1.3"],
Cell[24810, 911, 569, 17, 60, "Input",
 CellTags->"b:1.1.3"],
Cell[25382, 930, 43, 1, 44, "Input",
 CellTags->"b:1.1.3"],
Cell[25428, 933, 1268, 37, 49, "Abstract",
 CellTags->"b:1.1.3"]
}, Open  ]]
}, Closed]]
}
]
*)

(* End of internal cache information *)
