(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     53260,       1702]
NotebookOptionsPosition[     41588,       1329]
NotebookOutlinePosition[     48516,       1544]
CellTagsIndexPosition[     48208,       1529]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["Quantum Fourier Transform", "Title",
 CellTags->"c:1"],

Cell["Implementation of the QFT", "Subtitle"],

Cell[TextData[{
 "Version: 3.0-April-2011--For ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " 6.0-8.0"
}], "Abstract",
 CellChangeTimes->{{3.395090887981901*^9, 3.395090925377634*^9}, {
   3.512204933064251*^9, 3.5122049705968847`*^9}, 3.5122120582929077`*^9}],

Cell[TextData[ButtonBox["Click here to get the palette: QDENSpalette.nb",
 BaseStyle->"Hyperlink",
 ButtonData:>{"QDENSpalette.nb", None}]], "Text"],

Cell[CellGroupData[{

Cell["\<\
Quantum Fourier Transform                                                     \
                        To open double click at down \
arrow---------------------------->>\
\>", "Section",
 CellChangeTimes->{{3.512204977901103*^9, 3.512205004434519*^9}},
 FontFamily->"Times",
 CellTags->"c:2"],

Cell[CellGroupData[{

Cell["a) Quantum Fourier Transform using vectors", "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:3", "b:2.0.0"}],

Cell[TextData[{
 Cell[BoxData[
  FormBox[GridBox[{
     {
      RowBox[{"References", ":"}], 
      RowBox[{
       RowBox[{
        RowBox[{"[", "1", "]"}], " ", "Quantum", " ", "Computation", " ", 
        "and", " ", "Quantum", " ", "Information"}], ",", " ", 
       RowBox[{"Nielsen", " ", "and", " ", "Chuang"}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {Right, {Left}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}], TraditionalForm]], 
  "DefinitionBox",
  GridBoxOptions->{
  GridBoxDividers->{
   "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
    "RowsIndexed" -> {}},
  GridBoxSpacings->{"Columns" -> {
      Offset[0.27999999999999997`], {
       Offset[0.5599999999999999]}, 
      Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
      Offset[0.2], {
       Offset[0.16]}, 
      Offset[0.2]}, "RowsIndexed" -> {}}},
  CellTags->"S5.1.1"],
 "\nLast Version: 25-Nov-2005"
}], "Abstract",
 CellTags->"b:2.0.0"],

Cell["\<\
The Quantum Fourier Transform is equivalent to the Discrete Fourier Transform 
We present here two ways of writing down algorithms that perform the QFT; the \
first one deals with state vectors, while the second one uses the density \
matrix approach. \
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:2.0.0"],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<QDENSITY`Qdensity`\>\"", "]"}]], "Input",
 FontFamily->"Courier New",
 CellTags->"b:2.0.0"],

Cell[BoxData[
 RowBox[{"?", "QDENSITY`Qdensity`*"}]], "Input",
 FontFamily->"Courier New",
 CellTags->"b:2.0.0"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"figure", "=", 
   RowBox[{"Import", "[", 
    RowBox[{"\"\<QDENSITY/drawings/QFT.png\>\"", ",", "\"\<PNG\>\""}], 
    "]"}]}], ";"}], "\n", 
 RowBox[{"Show", "[", 
  RowBox[{"figure", ",", 
   RowBox[{"ImageSize", "\[Rule]", "900"}]}], "]"}]}], "Input",
 CellTags->"b:2.0.0"],

Cell["\<\
The quantum Fourier transform of a vector written in its binary \
representation has a very nice expression (we follow the notation of Ref [1]) \
:\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:2.0.0"],

Cell[BoxData[
 FormBox[GridBox[{
    {Cell[BoxData[
      FormBox[
       RowBox[{
        RowBox[{"QuantumFourierTransformV", "[", 
         RowBox[{
          SubscriptBox["j", "1"], ",", 
          SubscriptBox["j", "2"], ",", "..", ",", 
          SubscriptBox["j", "n"]}], "]"}], "=", " "}], TraditionalForm]]], 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"|", "0"}]}], "\[RightAngleBracket]"}], "+", 
                    SuperscriptBox["e", 
                    RowBox[{"\[ImaginaryI]2\[Pi]0", ".", 
                    SubscriptBox["j", "n"]}]]}], "|", "1"}], 
                   "\[RightAngleBracket]"}], " ", ")"}], "\[CircleTimes]", 
                 RowBox[{
                  RowBox[{"(", " ", 
                   RowBox[{"|", "0"}]}], "\[RightAngleBracket]"}]}], "+", 
                SuperscriptBox["e", 
                 RowBox[{
                  RowBox[{"\[ImaginaryI]2\[Pi]0", ".", 
                   SubscriptBox["j", 
                    RowBox[{"n", "-", "1"}]]}], 
                  SubscriptBox["j", "n"]}]]}], "|", "1"}], 
              "\[RightAngleBracket]"}], " ", ")"}], "..."}], "\[CircleTimes]", 
           RowBox[{
            RowBox[{"(", " ", 
             RowBox[{"|", "0"}]}], "\[RightAngleBracket]"}]}], "+", 
          SuperscriptBox["e", 
           RowBox[{
            RowBox[{
             RowBox[{"\[ImaginaryI]2\[Pi]0", ".", 
              SubscriptBox["j", "1"]}], ".."}], 
            SubscriptBox["j", "n"]}]]}], "|", "1"}], "\[RightAngleBracket]"}],
        ")"}], "\n", "\n", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"0.", 
          SubscriptBox["j", "m"]}], ".."}], 
        SubscriptBox["j", "L"]}], ":=", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           SubscriptBox["j", "m"], "/", "2"}], "+", 
          RowBox[{
           SubscriptBox["j", 
            RowBox[{"m", "+", "1"}]], "/", 
           SuperscriptBox["2", "2"]}], " ", "+"}], " ", "..."}], "+", 
        RowBox[{
         SubscriptBox["j", "L"], "/", 
         SuperscriptBox["2", 
          RowBox[{"L", "-", "m", "+", "1"}]]}]}]}]}]}
   },
   GridBoxAlignment->{
    "Columns" -> {Right, {Left}}, "ColumnsIndexed" -> {}, 
     "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}], 
  TraditionalForm]], "DefinitionBox",
 GridBoxOptions->{GridBoxSpacings->{"Columns" -> {
     Offset[0.27999999999999997`], {
      Offset[0.5599999999999999]}, 
     Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
     Offset[0.2], {
      Offset[0.16]}, 
     Offset[0.2]}, "RowsIndexed" -> {}}},
 CellTags->{"S5.1.1", "b:2.0.0"}],

Cell[TextData[{
 "\nThe binary representation of the base vectors is:",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FormBox[
     RowBox[{"|", 
      SubscriptBox["j", "1"]}],
     TraditionalForm], ",", 
    SubscriptBox["j", "2"]}], TraditionalForm]]],
 ", ..., ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["j", "N"], TraditionalForm]]],
 "\[RightAngleBracket].  A general vector maybe decomposed as:"
}], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:2.0.0"],

Cell[TextData[{
 " |\[Psi]\[RightAngleBracket] = ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Sum]", " "}], TraditionalForm]]],
 "[ ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "k"], TraditionalForm]]],
 "  * KetV[ IntegerDigits[k,2,N]] , {k,1,2^N}]\nThe function \
IntegerDigits[k,2,N] returns the number k in base 2 with N figures, which is \
the binary representation of the vector k."
}], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:2.0.0"],

Cell[TextData[{
 "Let's ",
 StyleBox["start ",
  FontWeight->"Bold"],
 "by defining the operation ",
 Cell[BoxData[
  FormBox[
   RowBox[{"0.", 
    SubscriptBox["j", "m"]}], TraditionalForm]]],
 " ... ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["j", "L"], TraditionalForm]]],
 ", which enters in the exponents of the Fourier Transform, we call it, \
Zeroff:\nThe symbol  ",
 Cell[BoxData[
  FormBox[
   RowBox[{"0.", 
    SubscriptBox["j", "m"]}], TraditionalForm]]],
 " ... ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["j", "L"], TraditionalForm]]],
 " denotes the series:     ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["j", "m"], TraditionalForm]]],
 " /  2  + ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["j", 
    RowBox[{"m", "+", "1"}]], TraditionalForm]]],
 "/ 4 +  ......+ ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["j", "L"], TraditionalForm]]],
 " / ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["2", 
    RowBox[{"L", "-", "m", "+", "1"}]], TraditionalForm]]],
 "= Zeroff.\nThe notation used is that vac is the vector in binary notation \
that we are going to Fourier Transform and the array R  stores the indices m \
to j ."
}], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:2.0.0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Zeroff", "[", 
   RowBox[{"vac_", ",", "R_"}], "]"}], ":=", 
  RowBox[{"Sum", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"vac", "[", 
      RowBox[{"[", 
       RowBox[{"R", "[", 
        RowBox[{"[", "i", "]"}], "]"}], "]"}], "]"}], "/", 
     RowBox[{"2", "^", "i"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", 
      RowBox[{"Length", "[", "R", "]"}]}], "}"}]}], "]"}]}]], "Input",
 CellTags->"b:2.0.0"],

Cell["\<\
Then the Quantum Fourier Transform can be readily written  using tensor \
products of Kets:  (and its inverse);  this corresponds to Eq. 5.4 in Ref.[1].\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:2.0.0"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"QuantumFourierTransformV", "[", "vac_", "]"}], ":=", 
    "\[IndentingNewLine]", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\[CapitalOmega]", ",", "L"}], "}"}], ",", 
      RowBox[{
       RowBox[{"L", "=", 
        RowBox[{"Length", "[", "vac", "]"}]}], ";", 
       RowBox[{"\[CapitalOmega]", "=", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Ket", "[", "0", "]"}], "+", 
          RowBox[{
           RowBox[{"Exp", "[", 
            RowBox[{"2", "*", "\[Pi]", "*", " ", "\[ImaginaryI]", "*", 
             RowBox[{"Zeroff", "[", 
              RowBox[{"vac", ",", 
               RowBox[{"Range", "[", 
                RowBox[{"L", ",", "L"}], "]"}]}], "]"}]}], "]"}], "*", 
           RowBox[{"Ket", "[", "1", "]"}]}]}], ")"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"i", "=", "2"}], ",", 
         RowBox[{"i", "\[LessEqual]", "L"}], ",", 
         RowBox[{"i", "++"}], ",", 
         RowBox[{
          RowBox[{"phass", "=", 
           RowBox[{"2", "*", "\[Pi]", "*", " ", "\[ImaginaryI]", "*", 
            RowBox[{"Zeroff", "[", 
             RowBox[{"vac", ",", 
              RowBox[{"Range", "[", 
               RowBox[{
                RowBox[{"L", "-", "i", "+", "1"}], ",", "L"}], "]"}]}], 
             "]"}]}]}], ";", 
          RowBox[{"\[CapitalOmega]", "=", 
           RowBox[{"\[CapitalOmega]", "\[CircleTimes]", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Ket", "[", "0", "]"}], "+", 
              RowBox[{
               RowBox[{"Exp", "[", "phass", "]"}], "*", 
               RowBox[{"Ket", "[", "1", "]"}]}]}], ")"}]}]}]}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"\[CapitalOmega]", "=", 
        RowBox[{"\[CapitalOmega]", "/", 
         RowBox[{"2", "^", 
          RowBox[{"(", 
           RowBox[{"L", "/", "2"}], ")"}]}]}]}], ";", "\[CapitalOmega]"}]}], 
     "]"}]}], ";"}], "  "}]], "Input",
 CellTags->"b:2.0.0"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"IQuantumFourierTransformV", "[", "vac_", "]"}], ":=", 
    "\[IndentingNewLine]", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\[CapitalOmega]", ",", "L"}], "}"}], ",", 
      RowBox[{
       RowBox[{"L", "=", 
        RowBox[{"Length", "[", "vac", "]"}]}], ";", 
       RowBox[{"\[CapitalOmega]", "=", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Ket", "[", "0", "]"}], "+", 
          RowBox[{
           RowBox[{"Exp", "[", 
            RowBox[{
             RowBox[{"-", "2"}], "*", "\[Pi]", "*", " ", "\[ImaginaryI]", "*", 
             RowBox[{"Zeroff", "[", 
              RowBox[{"vac", ",", 
               RowBox[{"Range", "[", 
                RowBox[{"L", ",", "L"}], "]"}]}], "]"}]}], "]"}], "*", 
           RowBox[{"Ket", "[", "1", "]"}]}]}], ")"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"i", "=", "2"}], ",", 
         RowBox[{"i", "\[LessEqual]", "L"}], ",", 
         RowBox[{"i", "++"}], ",", 
         RowBox[{
          RowBox[{"phass", "=", 
           RowBox[{
            RowBox[{"-", "2"}], "*", "\[Pi]", "*", " ", "\[ImaginaryI]", "*", 
            RowBox[{"Zeroff", "[", 
             RowBox[{"vac", ",", 
              RowBox[{"Range", "[", 
               RowBox[{
                RowBox[{"L", "-", "i", "+", "1"}], ",", "L"}], "]"}]}], 
             "]"}]}]}], ";", 
          RowBox[{"\[CapitalOmega]", "=", 
           RowBox[{"\[CapitalOmega]", "\[CircleTimes]", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Ket", "[", "0", "]"}], "+", 
              RowBox[{
               RowBox[{"Exp", "[", "phass", "]"}], "*", 
               RowBox[{"Ket", "[", "1", "]"}]}]}], ")"}]}]}]}]}], "]"}], ";", 
       RowBox[{"\[CapitalOmega]", "/", 
        RowBox[{"2", "^", 
         RowBox[{"(", 
          RowBox[{"L", "/", "2"}], ")"}]}]}]}]}], "]"}]}], ";"}], 
  "  "}]], "Input",
 CellTags->"b:2.0.0"],

Cell[TextData[{
 "For example, let us compute the QFT of state vector  | 0,1,1 \
\[RightAngleBracket]  ( In the full computational base, this vector would \
correspond to  the matrix (00010000) that is since binary 011 is decimal 3,\n\
the matrix representing the state has a 1 in location four.\n NOTE that \
|0,0,1\[RightAngleBracket]+|1,0,0\[RightAngleBracket] \[NotEqual] |1,0,1\
\[RightAngleBracket] !!  ) \n Now consider the QFT of the state state vector  \
| 0,1,1 \[RightAngleBracket]  which is of length ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["2", "3"], TraditionalForm]]]
}], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:2.0.0"],

Cell[BoxData[
 RowBox[{"QFT011", "=", 
  RowBox[{"QuantumFourierTransformV", "[", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1", ",", "1"}], "}"}], "]"}]}]], "Input",
 CellTags->"b:2.0.0"],

Cell[TextData[{
 "As can be seen the output is a list of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["2", "N"], TraditionalForm]]],
 " numbers, where N is the dimension of our vector in the binary \
representation."
}], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:2.0.0"],

Cell["We can check whether it is normalized:", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:2.0.0"],

Cell[BoxData[
 RowBox[{"Norm", "[", "QFT011", "]"}]], "Input",
 CellTags->"b:2.0.0"],

Cell[CellGroupData[{

Cell[TextData[{
 "A ",
 StyleBox["more general random vector (with N=4)",
  FontWeight->"Bold"],
 " could be:"
}], "Subsubsection",
 FontFamily->"Helvetica",
 CellTags->{"c:4", "b:2.0.0"}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"RanVector", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"RandomReal", "[", 
      RowBox[{"{", 
       RowBox[{"0", ",", "2"}], "}"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       SuperscriptBox["2", "4"]}], "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"RanVector", "=", 
  FractionBox["RanVector", 
   RowBox[{"Norm", "[", "RanVector", "]"}]]}], "\n", 
 RowBox[{"ListPlot", "[", 
  RowBox[{"RanVector", ",", 
   RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}]}], "Input",
 CellTags->"b:2.0.0"],

Cell["\<\
we apply the quantum fourier transform: (NOTE we compute the QFT of the base \
vectors)\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:2.0.0"],

Cell[BoxData[
 RowBox[{"QFTVec", "=", 
  RowBox[{"Sum", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"RanVector", "[", 
      RowBox[{"[", 
       RowBox[{"i", "+", "1"}], "]"}], "]"}], 
     RowBox[{"QuantumFourierTransformV", "[", 
      RowBox[{"IntegerDigits", "[", 
       RowBox[{"i", ",", "2", ",", "4"}], "]"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "0", ",", 
      RowBox[{
       RowBox[{"2", "^", "4"}], "-", "1"}]}], "}"}]}], "]"}]}]], "Input",
 CellTags->"b:2.0.0"],

Cell["\<\
An we can then use the inverse and compare with the original vector:\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:2.0.0"],

Cell[BoxData[{
 RowBox[{"IQFTVec", "=", 
  RowBox[{"Chop", "[", 
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"QFTVec", "[", 
        RowBox[{"[", 
         RowBox[{"i", "+", "1"}], "]"}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}], "*", 
      RowBox[{"IQuantumFourierTransformV", "[", 
       RowBox[{"IntegerDigits", "[", 
        RowBox[{"i", ",", "2", ",", "4"}], "]"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", 
       RowBox[{
        RowBox[{"2", "^", "4"}], "-", "1"}]}], "}"}]}], "]"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"IQFTVec", "=", 
   RowBox[{"Flatten", "[", "IQFTVec", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Chop", "[", 
  RowBox[{"RanVector", "-", "IQFTVec"}], "]"}]}], "Input",
 CellTags->"b:2.0.0"],

Cell["\<\
The  inverse of the QFT and  the original vector prove to be the same, which \
is a check on the procedures.\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:2.0.0"]
}, Open  ]],

Cell[CellGroupData[{

Cell["QFT of the Sin[x]/x function", "Subsubsection",
 FontFamily->"Helvetica",
 CellTags->{"c:5", "b:2.0.0"}],

Cell["\<\
In this example, we construct our vector out of a known function, Sin[x/a]/x. \
We make use of 6 qubits. \
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:2.0.0"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SinVector", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     FractionBox[
      RowBox[{"Sin", "[", 
       FractionBox[
        RowBox[{"i", " ", "4", " ", "\[Pi]"}], 
        SuperscriptBox["2", "6"]], "]"}], "i"], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       SuperscriptBox["2", "6"]}], "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"SinVector", "=", 
   FractionBox["SinVector", 
    RowBox[{"Norm", "[", "SinVector", "]"}]]}], ";"}], "\n", 
 RowBox[{"ListPlot", "[", 
  RowBox[{"SinVector", ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Number", ",", "\"\<Sin[Number]\>\""}], "}"}]}]}], 
  "]"}]}], "Input",
 CellTags->"b:2.0.0"],

Cell["\<\
we apply the quantum Fourier transform: (NOTE we compute the QFT of the base \
vectors)\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:2.0.0"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"QFTSin", "=", 
   RowBox[{"N", "[", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"i", "=", "0"}], 
      RowBox[{
       SuperscriptBox["2", "6"], "-", "1"}]], 
     RowBox[{
      RowBox[{"SinVector", "\[LeftDoubleBracket]", 
       RowBox[{"i", "+", "1"}], "\[RightDoubleBracket]"}], " ", 
      RowBox[{"QuantumFourierTransformV", "[", 
       RowBox[{"IntegerDigits", "[", 
        RowBox[{"i", ",", "2", ",", "6"}], "]"}], "]"}]}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"Chop", "[", "QFTSin", "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"QFTSinplotRe", "=", 
   RowBox[{"Chop", "[", 
    RowBox[{"Re", "[", 
     RowBox[{"N", "[", "QFTSin", "]"}], "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"QFTSinplotIM", "=", 
   RowBox[{"Chop", "[", 
    RowBox[{"Im", "[", "QFTSin", "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"Flatten", "[", "QFTSinplotRe", "]"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Number", ",", "\"\<Real part of QFT\>\""}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.05`"}], ",", "0.1`"}], "}"}]}]}], "]"}], "\n", 
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"Flatten", "[", "QFTSinplotIM", "]"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Number", ",", "\"\<Imaginary part QFT\>\""}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.2`"}], ",", "0.2`"}], "}"}]}]}], "]"}]}], "Input",
 CellTags->"b:2.0.0"],

Cell["And we invert it to recover the original function:", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:2.0.0"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"IQFTSin", "=", 
   RowBox[{"Chop", "[", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"i", "=", "0"}], 
      RowBox[{
       SuperscriptBox["2", "6"], "-", "1"}]], 
     RowBox[{
      RowBox[{
       RowBox[{"QFTSin", "\[LeftDoubleBracket]", 
        RowBox[{"i", "+", "1"}], "\[RightDoubleBracket]"}], 
       "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], " ", 
      RowBox[{"IQuantumFourierTransformV", "[", 
       RowBox[{"IntegerDigits", "[", 
        RowBox[{"i", ",", "2", ",", "6"}], "]"}], "]"}]}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"IQFTSin", "=", 
   RowBox[{"Chop", "[", 
    RowBox[{"Flatten", "[", 
     RowBox[{"N", "[", "IQFTSin", "]"}], "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"Flatten", "[", "IQFTSin", "]"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}]}], "Input",
 CellTags->"b:2.0.0"],

Cell["\<\
The Quantum Fourier Transform is in fact the same as the Discrete Fourier \
Transform (DFT):; therefore, 
we can check our results by performing the DFT that is already provided in \
Mathematica.  For instance,  this last 
step of inverting is invoked by the command  InverseFourier[ ].
[NOTE: Although mathematically the same thing, it is essential to emphasize \
that the physical implementation of the QFT making good use of quantum \
interference is what makes it appealing.]\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:2.0.0"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"itras", "=", 
   RowBox[{"Chop", "[", 
    RowBox[{"InverseFourier", "[", "QFTSin", "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{"ListPlot", "[", 
  RowBox[{"Flatten", "[", "itras", "]"}], "]"}]}], "Input",
 CellTags->"b:2.0.0"]
}, Open  ]],

Cell[CellGroupData[{

Cell["QFT of a constant function", "Subsubsection",
 FontFamily->"Helvetica",
 CellTags->{"c:6", "b:2.0.0"}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"CteVector", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"1", ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       SuperscriptBox["2", "6"]}], "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"CteVector", "=", 
   FractionBox["CteVector", 
    RowBox[{"Norm", "[", "CteVector", "]"}]]}], ";"}], "\n", 
 RowBox[{"ListPlot", "[", 
  RowBox[{"CteVector", ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Number", ",", "\"\<Cte\>\""}], "}"}]}]}], "]"}]}], "Input",
 CellTags->"b:2.0.0"],

Cell["\<\
we apply the quantum Fourier transform: (NOTE we compute the QFT of the base \
vectors)\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:2.0.0"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"QFTCte", "=", 
   RowBox[{"N", "[", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"i", "=", "0"}], 
      RowBox[{
       SuperscriptBox["2", "6"], "-", "1"}]], 
     RowBox[{
      RowBox[{"CteVector", "\[LeftDoubleBracket]", 
       RowBox[{"i", "+", "1"}], "\[RightDoubleBracket]"}], " ", 
      RowBox[{"QuantumFourierTransformV", "[", 
       RowBox[{"IntegerDigits", "[", 
        RowBox[{"i", ",", "2", ",", "6"}], "]"}], "]"}]}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"Chop", "[", "QFTCte", "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"QFTCteplotRe", "=", 
   RowBox[{"Chop", "[", 
    RowBox[{"Re", "[", 
     RowBox[{"N", "[", "QFTCte", "]"}], "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"QFTCteplotIM", "=", 
   RowBox[{"Chop", "[", 
    RowBox[{"Im", "[", "QFTCte", "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"Flatten", "[", "QFTCteplotRe", "]"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Number", ",", "\"\<Real part of QFT\>\""}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.05`"}], ",", "0.1`"}], "}"}]}]}], "]"}], "\n", 
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"Flatten", "[", "QFTCteplotIM", "]"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Number", ",", "\"\<Imaginary part QFT\>\""}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.2`"}], ",", "0.2`"}], "}"}]}]}], "]"}]}], "Input",
 CellTags->"b:2.0.0"],

Cell["And we invert it to recover the original function:", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:2.0.0"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"IQFTCte", "=", 
   RowBox[{"Chop", "[", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"i", "=", "0"}], 
      RowBox[{
       SuperscriptBox["2", "6"], "-", "1"}]], 
     RowBox[{
      RowBox[{
       RowBox[{"QFTCte", "\[LeftDoubleBracket]", 
        RowBox[{"i", "+", "1"}], "\[RightDoubleBracket]"}], 
       "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], " ", 
      RowBox[{"IQuantumFourierTransformV", "[", 
       RowBox[{"IntegerDigits", "[", 
        RowBox[{"i", ",", "2", ",", "6"}], "]"}], "]"}]}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"IQFTCte", "=", 
   RowBox[{"Chop", "[", 
    RowBox[{"Flatten", "[", 
     RowBox[{"N", "[", "IQFTCte", "]"}], "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"Flatten", "[", "IQFTCte", "]"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "1"}], "}"}]}]}], "]"}]}], "Input",
 CellTags->"b:2.0.0"]
}, Open  ]],

Cell[CellGroupData[{

Cell["QFT of the Mod[x,5] function", "Subsubsection",
 FontFamily->"Helvetica",
 CellTags->{"c:7", "b:2.0.0"}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ModVector", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Mod", "[", 
      RowBox[{"i", ",", "5"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       SuperscriptBox["2", "6"]}], "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"ModVector", "=", 
   FractionBox["ModVector", 
    RowBox[{"Norm", "[", "ModVector", "]"}]]}], ";"}], "\n", 
 RowBox[{"ListPlot", "[", 
  RowBox[{"ModVector", ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Number", ",", "\"\<Mod[Number,5]\>\""}], "}"}]}]}], 
  "]"}]}], "Input",
 CellTags->"b:2.0.0"],

Cell["\<\
we apply the quantum Fourier transform: (NOTE we compute the QFT of the base \
vectors)\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:2.0.0"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"QFTMod", "=", 
   RowBox[{"N", "[", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"i", "=", "0"}], 
      RowBox[{
       SuperscriptBox["2", "6"], "-", "1"}]], 
     RowBox[{
      RowBox[{"ModVector", "\[LeftDoubleBracket]", 
       RowBox[{"i", "+", "1"}], "\[RightDoubleBracket]"}], " ", 
      RowBox[{"QuantumFourierTransformV", "[", 
       RowBox[{"IntegerDigits", "[", 
        RowBox[{"i", ",", "2", ",", "6"}], "]"}], "]"}]}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"Chop", "[", "QFTMod", "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"QFTModplotRe", "=", 
   RowBox[{"Chop", "[", 
    RowBox[{"Re", "[", 
     RowBox[{"N", "[", "QFTMod", "]"}], "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"QFTModplotIM", "=", 
   RowBox[{"Chop", "[", 
    RowBox[{"Im", "[", "QFTMod", "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"Flatten", "[", "QFTModplotRe", "]"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Number", ",", "\"\<Real part of QFT\>\""}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.05`"}], ",", "0.1`"}], "}"}]}]}], "]"}], "\n", 
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"Flatten", "[", "QFTModplotIM", "]"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Number", ",", "\"\<Imaginary part QFT\>\""}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.2`"}], ",", "0.2`"}], "}"}]}]}], "]"}]}], "Input",
 CellTags->"b:2.0.0"],

Cell["And we invert it to recover the original function:", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:2.0.0"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"IQFTMod", "=", 
   RowBox[{"Chop", "[", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"i", "=", "0"}], 
      RowBox[{
       SuperscriptBox["2", "6"], "-", "1"}]], 
     RowBox[{
      RowBox[{
       RowBox[{"QFTMod", "\[LeftDoubleBracket]", 
        RowBox[{"i", "+", "1"}], "\[RightDoubleBracket]"}], 
       "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], " ", 
      RowBox[{"IQuantumFourierTransformV", "[", 
       RowBox[{"IntegerDigits", "[", 
        RowBox[{"i", ",", "2", ",", "6"}], "]"}], "]"}]}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"IQFTMod", "=", 
   RowBox[{"Chop", "[", 
    RowBox[{"Flatten", "[", 
     RowBox[{"N", "[", "IQFTMod", "]"}], "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"Flatten", "[", "IQFTMod", "]"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}]}], "Input",
 CellTags->"b:2.0.0"],

Cell["\<\
This kind of periodicity plays an important role in Shor's algorithm.\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:2.0.0"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["b) Quantum Fourier Transform using  density matrices", "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:8", "b:2.0.1"}],

Cell["\<\
To compute the Quantum Fourier Transform in a density matrix framework, we \
define it in a multiqubit system by following the above figure where it is \
built by combining Controlled phase gates and Hadamard gates. First we define \
the gates we need, and provide compiled versions to speed the computation.\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:2.0.1"],

Cell[TextData[{
 "The controlled phase gate used ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["R", "k"], " ", "="}], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{"(", GridBox[{
      {"1", "0"},
      {"0", 
       SuperscriptBox["e", 
        RowBox[{"2", "\[Pi]", " ", 
         RowBox[{"\[ImaginaryI]", "/", 
          SuperscriptBox["2", "k"]}]}]]}
     }], ")"}], TraditionalForm]]],
 ", can be written in the following way as a two qubit operator:"
}], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:2.0.1"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ControlP", "[", 
    RowBox[{"L_", ",", "q1_", ",", "q2_", ",", "k_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "\[Phi]", "}"}], ",", 
     RowBox[{
      RowBox[{"\[Phi]", "=", 
       RowBox[{"Exp", "[", 
        RowBox[{"2", "*", " ", "\[Pi]", " ", "*", " ", 
         RowBox[{"\[ImaginaryI]", " ", "/", 
          SuperscriptBox["2", "k"]}]}], "]"}]}], ";", 
      RowBox[{
       RowBox[{"1", "/", "4"}], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"3", "+", "\[Phi]"}], ")"}], "*", 
          RowBox[{"TwoOp", "[", 
           RowBox[{"L", ",", "q1", ",", "q2", ",", "0", ",", "0"}], "]"}]}], 
         "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "\[Phi]"}], ")"}], "*", 
          RowBox[{"TwoOp", "[", 
           RowBox[{"L", ",", "q1", ",", "q2", ",", "3", ",", "0"}], "]"}]}], 
         "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "\[Phi]"}], ")"}], "*", 
          RowBox[{"TwoOp", "[", 
           RowBox[{"L", ",", "q1", ",", "q2", ",", "0", ",", "3"}], "]"}]}], 
         "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"\[Phi]", "-", "1"}], ")"}], "*", 
          RowBox[{"TwoOp", "[", 
           RowBox[{"L", ",", "q1", ",", "q2", ",", "3", ",", "3"}], "]"}]}]}],
         ")"}]}]}]}], "]"}]}], ";"}]], "Input",
 CellTags->"b:2.0.1"],

Cell[" Forms Operator to Invert L qubits... the last step of QFT ", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:2.0.1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"InvertQubits", "[", "L_", "]"}], ":=", 
  RowBox[{
   RowBox[{"InvertQubits", "[", "L", "]"}], "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Reverse", "[", 
         RowBox[{"IntegerDigits", "[", 
          RowBox[{"i", ",", "2", ",", "L"}], "]"}], "]"}], "\[Equal]", " ", 
        RowBox[{"IntegerDigits", "[", 
         RowBox[{"j", ",", "2", ",", "L"}], "]"}]}], ",", "1", ",", "0"}], 
      "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", 
       RowBox[{
        RowBox[{"2", "^", "L"}], "-", "1"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "0", ",", 
       RowBox[{
        RowBox[{"2", "^", "L"}], "-", "1"}]}], "}"}]}], "]"}]}]}]], "Input",
 CellTags->"b:2.0.1"],

Cell[TextData[StyleBox["Generate Compiled versions of the Functions to speed \
the computation: ",
 FontWeight->"Bold"]], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:2.0.1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CompControlP", "=", " ", 
   RowBox[{"Compile", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"L", ",", "_Integer"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"q1", ",", "_Integer"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"q2", ",", "_Integer"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "_Integer"}], "}"}]}], "}"}], ",", 
     RowBox[{"Block", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Lv", "=", "L"}], ",", 
         RowBox[{"qv1", "=", "q1"}], ",", 
         RowBox[{"qv2", "=", "q2"}], ",", 
         RowBox[{"kv", "=", "k"}]}], "  ", "}"}], ",", " ", 
       RowBox[{"ControlP", "[", 
        RowBox[{"Lv", ",", "qv1", ",", "qv2", ",", "kv"}], "]"}]}], "]"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"{", "   ", 
       RowBox[{
        RowBox[{"ControlP", "[", 
         RowBox[{"Lv", ",", "qv1", ",", "qv2", ",", "kv"}], "]"}], ",", 
        "_Complex", ",", "2"}], "}"}], "}"}]}], "]"}]}], " ", ";"}]], "Input",
 CellTags->"b:2.0.1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CompHad", "=", " ", 
   RowBox[{"Compile", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"L", ",", "_Integer"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "_Integer"}], "}"}]}], "}"}], ",", 
     RowBox[{"Block", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Lv", "=", "L"}], ",", 
         RowBox[{"iv", "=", "i"}]}], "}"}], ",", " ", 
       RowBox[{"had", "[", 
        RowBox[{"Lv", ",", "iv"}], "]"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"{", "   ", 
       RowBox[{
        RowBox[{"had", "[", 
         RowBox[{"Lv", ",", "iv"}], "]"}], ",", "_Real", ",", "2"}], "}"}], 
      "}"}]}], "]"}]}], "  ", ";"}]], "Input",
 CellTags->"b:2.0.1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CompInvertQubits", "=", " ", 
   RowBox[{"Compile", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"L", ",", "_Integer"}], "}"}], "}"}], ",", 
     RowBox[{"Block", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Lv", "=", "L"}], " ", "}"}], ",", 
       RowBox[{"InvertQubits", "[", "Lv", "]"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"{", "  ", 
       RowBox[{
        RowBox[{"InvertQubits", "[", "Lv", "]"}], ",", "_Real", ",", "2"}], 
       "}"}], "}"}]}], "]"}]}], "  ", ";"}]], "Input",
 CellTags->"b:2.0.1"],

Cell["Then the Quantum Fourier Transform operator reads:", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:2.0.1"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"QuantumFourierTransform", "=", 
    RowBox[{"Compile", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"L", ",", "_Integer"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[CapitalOmega]s", ",", "_Complex", ",", "2"}], "}"}]}], 
       "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"Module", "[", 
       RowBox[{
        RowBox[{"{", "\[CapitalOmega]", "}"}], ",", 
        RowBox[{
         RowBox[{"\[CapitalOmega]", "=", "\[CapitalOmega]s"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"For", "[", 
          RowBox[{
           RowBox[{"i", "=", "1"}], ",", 
           RowBox[{"i", "\[LessEqual]", "L"}], ",", 
           RowBox[{"i", "++"}], ",", 
           RowBox[{
            RowBox[{"\[CapitalOmega]", "=", 
             RowBox[{"N", "[", 
              RowBox[{
               RowBox[{"CompHad", "[", 
                RowBox[{"L", ",", "i"}], "]"}], ".", "\[CapitalOmega]"}], 
              "]"}]}], ";", 
            RowBox[{"For", "[", " ", 
             RowBox[{
              RowBox[{"j", "=", 
               RowBox[{"i", "+", "1"}]}], ",", 
              RowBox[{"j", "\[LessEqual]", "L"}], ",", 
              RowBox[{"j", "++"}], ",", 
              RowBox[{"\[CapitalOmega]", "=", 
               RowBox[{"N", "[", 
                RowBox[{
                 RowBox[{"CompControlP", "[", 
                  RowBox[{"L", ",", "j", ",", "i", ",", 
                   RowBox[{"j", "-", "i", "+", "1"}]}], "]"}], ".", 
                 "\[CapitalOmega]"}], "]"}]}]}], "]"}]}]}], "]"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"\[CapitalOmega]", "=", 
          RowBox[{
           RowBox[{"CompInvertQubits", "[", "L", "]"}], ".", 
           "\[CapitalOmega]"}]}], ";", "\[CapitalOmega]"}]}], "]"}], ",", " ",
       "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", " ", 
         RowBox[{
          RowBox[{"CompHad", "[", 
           RowBox[{"L", ",", "i"}], "]"}], ",", "_Real", ",", "2"}], "}"}], 
        ",", 
        RowBox[{"{", " ", 
         RowBox[{
          RowBox[{"CompControlP", "[", 
           RowBox[{"L", ",", "j", ",", "i", ",", 
            RowBox[{"j", "-", "i", "+", "1"}]}], "]"}], ",", "_Complex", ",", 
          "2"}], "}"}], ",", 
        RowBox[{"{", " ", 
         RowBox[{
          RowBox[{"CompInvertQubits", "[", "L", "]"}], ",", "_Real", ",", 
          "2"}], "}"}]}], "}"}]}], " ", "]"}]}], ";"}], "  "}]], "Input",
 CellTags->"b:2.0.1"],

Cell["\<\
We can check both definitions, the density matrix one and the vector one. \
Making use of our previous RanVector, we can construct the pure state density \
matrix:\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:2.0.1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"DensRanVec", "=", 
   RowBox[{
    RowBox[{"{", "RanVector", "}"}], "\[CircleTimes]", 
    RowBox[{"Adj", "[", 
     RowBox[{"{", "RanVector", "}"}], "]"}]}]}], ";"}]], "Input",
 CellTags->"b:2.0.1"],

Cell["And apply the quantum fourier transform just defined:", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:2.0.1"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"QFTDens", "=", 
   RowBox[{"QuantumFourierTransform", "[", 
    RowBox[{"4", ",", 
     RowBox[{"IdentityMatrix", "[", 
      RowBox[{"4", "^", "2"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"QFTDensVec", "=", 
   RowBox[{"QFTDens", ".", "DensRanVec", ".", 
    RowBox[{"Adj", "[", "QFTDens", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Length", "[", "QFTDens", "]"}]}], "Input",
 CellTags->"b:2.0.1"],

Cell["\<\
Which we can compare to the pure state density matrix constructed with the \
fourier transform of RanVector:\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:2.0.1"],

Cell[BoxData[
 RowBox[{"DensQFTVec", "=", 
  RowBox[{"QFTVec", "\[CircleTimes]", 
   RowBox[{"Adj", "[", "QFTVec", "]"}]}]}]], "Input",
 CellTags->"b:2.0.1"],

Cell[BoxData[
 RowBox[{"Chop", "[", 
  RowBox[{"DensQFTVec", "-", "QFTDensVec"}], "]"}]], "Input",
 CellTags->"b:2.0.1"],

Cell[BoxData["Quit"], "Input",
 CellTags->"b:2.0.1"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[GridBox[{
     {
      RowBox[{"References", ":"}], 
      RowBox[{
       RowBox[{
        RowBox[{"[", "1", "]"}], " ", "Quantum", " ", "Computation", " ", 
        "and", " ", "Quantum", " ", "Information"}], ",", " ", 
       RowBox[{"Nielsen", " ", "and", " ", "Chuang"}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {Right, {Left}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}], TraditionalForm]], 
  "DefinitionBox",
  GridBoxOptions->{
  GridBoxDividers->{
   "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
    "RowsIndexed" -> {}},
  GridBoxSpacings->{"Columns" -> {
      Offset[0.27999999999999997`], {
       Offset[0.5599999999999999]}, 
      Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
      Offset[0.2], {
       Offset[0.16]}, 
      Offset[0.2]}, "RowsIndexed" -> {}}},
  CellTags->"S5.1.1"],
 "\nLast Version: 25-Nov-2005"
}], "Abstract",
 CellTags->"b:2.0.1"]
}, Open  ]]
}, Closed]]
},
WindowToolbars->{},
WindowSize->{1014, 678},
WindowMargins->{{177, Automatic}, {-27, Automatic}},
PrintingStartingPageNumber->46,
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"Magnification"->1,
"PaperOrientation"->"Portrait",
"PaperSize"->{612, 792},
"PostScriptOutputFile":>FrontEnd`FileName[{"export", "home", "brunojd"}, 
  "t.ps", CharacterEncoding -> "WindowsANSI"]},
ShowSelection->True,
TaggingRules:>{
 "PaginationCache" -> {{2005, 8, 9, 3, 36, 21.330055`8.081566958720561}, {46, 
    46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 47, 47, 47, 47, 47, 47, 
    47, 47, 47, 47, 47, 48, 48, 48, 48, 48, 48, 48, 48, 48, 48, 48, 48, 48, 
    49, 49, 49, 49, 49, 49, 49, 49, 49, 50, 50, 50, 50, 50, 50, 50, 50, 50, 
    50, 50, 50, 51, 51, 51, 51, 51, 51, 51, 51, 51, 51, 51, 51, 51, 51, 52}, 
    Automatic}},
CellLabelAutoDelete->True,
Magnification->1,
FrontEndVersion->"8.0 for Mac OS X x86 (32-bit) (November 6, 2010)",
StyleDefinitions->"Classroom.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "c:1"->{
  Cell[545, 20, 60, 1, 50, "Title",
   CellTags->"c:1"]},
 "c:2"->{
  Cell[1100, 40, 303, 7, 51, "Section",
   CellTags->"c:2"]},
 "c:3"->{
  Cell[1428, 51, 135, 3, 57, "Subsection",
   CellTags->{"c:3", "b:2.0.0"}]},
 "b:2.0.0"->{
  Cell[1428, 51, 135, 3, 57, "Subsection",
   CellTags->{"c:3", "b:2.0.0"}],
  Cell[1566, 56, 1005, 29, 35, "Abstract",
   CellTags->"b:2.0.0"],
  Cell[2574, 87, 324, 7, 49, "Text",
   CellTags->"b:2.0.0"],
  Cell[2901, 96, 133, 3, 46, "Input",
   CellTags->"b:2.0.0"],
  Cell[3037, 101, 112, 3, 46, "Input",
   CellTags->"b:2.0.0"],
  Cell[3152, 106, 311, 9, 60, "Input",
   CellTags->"b:2.0.0"],
  Cell[3466, 117, 219, 6, 22, "Text",
   CellTags->"b:2.0.0"],
  Cell[3688, 125, 2996, 84, 61, "DefinitionBox",
   CellTags->{"S5.1.1", "b:2.0.0"}],
  Cell[6687, 211, 461, 17, 51, "Text",
   CellTags->"b:2.0.0"],
  Cell[7151, 230, 451, 14, 49, "Text",
   CellTags->"b:2.0.0"],
  Cell[7605, 246, 1203, 46, 76, "Text",
   CellTags->"b:2.0.0"],
  Cell[8811, 294, 458, 15, 44, "Input",
   CellTags->"b:2.0.0"],
  Cell[9272, 311, 224, 5, 22, "Text",
   CellTags->"b:2.0.0"],
  Cell[9499, 318, 2072, 55, 90, "Input",
   CellTags->"b:2.0.0"],
  Cell[11574, 375, 2026, 55, 75, "Input",
   CellTags->"b:2.0.0"],
  Cell[13603, 432, 649, 13, 118, "Text",
   CellTags->"b:2.0.0"],
  Cell[14255, 447, 186, 5, 44, "Input",
   CellTags->"b:2.0.0"],
  Cell[14444, 454, 278, 9, 26, "Text",
   CellTags->"b:2.0.0"],
  Cell[14725, 465, 102, 2, 22, "Text",
   CellTags->"b:2.0.0"],
  Cell[14830, 469, 84, 2, 44, "Input",
   CellTags->"b:2.0.0"],
  Cell[14939, 475, 188, 7, 33, "Subsubsection",
   CellTags->{"c:4", "b:2.0.0"}],
  Cell[15130, 484, 568, 17, 105, "Input",
   CellTags->"b:2.0.0"],
  Cell[15701, 503, 159, 5, 22, "Text",
   CellTags->"b:2.0.0"],
  Cell[15863, 510, 496, 15, 44, "Input",
   CellTags->"b:2.0.0"],
  Cell[16362, 527, 140, 4, 22, "Text",
   CellTags->"b:2.0.0"],
  Cell[16505, 533, 823, 24, 75, "Input",
   CellTags->"b:2.0.0"],
  Cell[17331, 559, 180, 5, 22, "Text",
   CellTags->"b:2.0.0"],
  Cell[17548, 569, 110, 2, 33, "Subsubsection",
   CellTags->{"c:5", "b:2.0.0"}],
  Cell[17661, 573, 177, 5, 22, "Text",
   CellTags->"b:2.0.0"],
  Cell[17841, 580, 775, 24, 131, "Input",
   CellTags->"b:2.0.0"],
  Cell[18619, 606, 159, 5, 22, "Text",
   CellTags->"b:2.0.0"],
  Cell[18781, 613, 1714, 49, 156, "Input",
   CellTags->"b:2.0.0"],
  Cell[20498, 664, 114, 2, 22, "Text",
   CellTags->"b:2.0.0"],
  Cell[20615, 668, 936, 27, 111, "Input",
   CellTags->"b:2.0.0"],
  Cell[21554, 697, 551, 11, 118, "Text",
   CellTags->"b:2.0.0"],
  Cell[22108, 710, 258, 7, 60, "Input",
   CellTags->"b:2.0.0"],
  Cell[22403, 722, 108, 2, 33, "Subsubsection",
   CellTags->{"c:6", "b:2.0.0"}],
  Cell[22514, 726, 607, 18, 105, "Input",
   CellTags->"b:2.0.0"],
  Cell[23124, 746, 159, 5, 22, "Text",
   CellTags->"b:2.0.0"],
  Cell[23286, 753, 1714, 49, 156, "Input",
   CellTags->"b:2.0.0"],
  Cell[25003, 804, 114, 2, 22, "Text",
   CellTags->"b:2.0.0"],
  Cell[25120, 808, 1035, 30, 111, "Input",
   CellTags->"b:2.0.0"],
  Cell[26192, 843, 110, 2, 33, "Subsubsection",
   CellTags->{"c:7", "b:2.0.0"}],
  Cell[26305, 847, 680, 21, 105, "Input",
   CellTags->"b:2.0.0"],
  Cell[26988, 870, 159, 5, 22, "Text",
   CellTags->"b:2.0.0"],
  Cell[27150, 877, 1714, 49, 156, "Input",
   CellTags->"b:2.0.0"],
  Cell[28867, 928, 114, 2, 22, "Text",
   CellTags->"b:2.0.0"],
  Cell[28984, 932, 936, 27, 111, "Input",
   CellTags->"b:2.0.0"],
  Cell[29923, 961, 141, 4, 22, "Text",
   CellTags->"b:2.0.0"]},
 "S5.1.1"->{
  Cell[3688, 125, 2996, 84, 61, "DefinitionBox",
   CellTags->{"S5.1.1", "b:2.0.0"}]},
 "c:4"->{
  Cell[14939, 475, 188, 7, 33, "Subsubsection",
   CellTags->{"c:4", "b:2.0.0"}]},
 "c:5"->{
  Cell[17548, 569, 110, 2, 33, "Subsubsection",
   CellTags->{"c:5", "b:2.0.0"}]},
 "c:6"->{
  Cell[22403, 722, 108, 2, 33, "Subsubsection",
   CellTags->{"c:6", "b:2.0.0"}]},
 "c:7"->{
  Cell[26192, 843, 110, 2, 33, "Subsubsection",
   CellTags->{"c:7", "b:2.0.0"}]},
 "c:8"->{
  Cell[30113, 971, 145, 3, 57, "Subsection",
   CellTags->{"c:8", "b:2.0.1"}]},
 "b:2.0.1"->{
  Cell[30113, 971, 145, 3, 57, "Subsection",
   CellTags->{"c:8", "b:2.0.1"}],
  Cell[30261, 976, 380, 7, 37, "Text",
   CellTags->"b:2.0.1"],
  Cell[30644, 985, 539, 19, 51, "Text",
   CellTags->"b:2.0.1"],
  Cell[31186, 1006, 1476, 42, 100, "Input",
   CellTags->"b:2.0.1"],
  Cell[32665, 1050, 123, 2, 22, "Text",
   CellTags->"b:2.0.1"],
  Cell[32791, 1054, 813, 24, 60, "Input",
   CellTags->"b:2.0.1"],
  Cell[33607, 1080, 177, 4, 22, "Text",
   CellTags->"b:2.0.1"],
  Cell[33787, 1086, 1101, 32, 60, "Input",
   CellTags->"b:2.0.1"],
  Cell[34891, 1120, 786, 25, 44, "Input",
   CellTags->"b:2.0.1"],
  Cell[35680, 1147, 598, 18, 44, "Input",
   CellTags->"b:2.0.1"],
  Cell[36281, 1167, 114, 2, 22, "Text",
   CellTags->"b:2.0.1"],
  Cell[36398, 1171, 2561, 67, 105, "Input",
   CellTags->"b:2.0.1"],
  Cell[38962, 1240, 235, 6, 22, "Text",
   CellTags->"b:2.0.1"],
  Cell[39200, 1248, 234, 7, 44, "Input",
   CellTags->"b:2.0.1"],
  Cell[39437, 1257, 117, 2, 22, "Text",
   CellTags->"b:2.0.1"],
  Cell[39557, 1261, 474, 12, 75, "Input",
   CellTags->"b:2.0.1"],
  Cell[40034, 1275, 180, 5, 22, "Text",
   CellTags->"b:2.0.1"],
  Cell[40217, 1282, 157, 4, 44, "Input",
   CellTags->"b:2.0.1"],
  Cell[40377, 1288, 120, 3, 44, "Input",
   CellTags->"b:2.0.1"],
  Cell[40500, 1293, 52, 1, 44, "Input",
   CellTags->"b:2.0.1"],
  Cell[40555, 1296, 1005, 29, 35, "Abstract",
   CellTags->"b:2.0.1"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"c:1", 42676, 1357},
 {"c:2", 42744, 1360},
 {"c:3", 42816, 1363},
 {"b:2.0.0", 42908, 1366},
 {"S5.1.1", 46215, 1465},
 {"c:4", 46312, 1468},
 {"c:5", 46405, 1471},
 {"c:6", 46498, 1474},
 {"c:7", 46591, 1477},
 {"c:8", 46684, 1480},
 {"b:2.0.1", 46778, 1483}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 60, 1, 50, "Title",
 CellTags->"c:1"],
Cell[608, 23, 45, 0, 34, "Subtitle"],
Cell[656, 25, 268, 7, 20, "Abstract"],
Cell[927, 34, 148, 2, 22, "Text"],
Cell[CellGroupData[{
Cell[1100, 40, 303, 7, 51, "Section",
 CellTags->"c:2"],
Cell[CellGroupData[{
Cell[1428, 51, 135, 3, 57, "Subsection",
 CellTags->{"c:3", "b:2.0.0"}],
Cell[1566, 56, 1005, 29, 35, "Abstract",
 CellTags->"b:2.0.0"],
Cell[2574, 87, 324, 7, 49, "Text",
 CellTags->"b:2.0.0"],
Cell[2901, 96, 133, 3, 46, "Input",
 CellTags->"b:2.0.0"],
Cell[3037, 101, 112, 3, 46, "Input",
 CellTags->"b:2.0.0"],
Cell[3152, 106, 311, 9, 60, "Input",
 CellTags->"b:2.0.0"],
Cell[3466, 117, 219, 6, 22, "Text",
 CellTags->"b:2.0.0"],
Cell[3688, 125, 2996, 84, 61, "DefinitionBox",
 CellTags->{"S5.1.1", "b:2.0.0"}],
Cell[6687, 211, 461, 17, 51, "Text",
 CellTags->"b:2.0.0"],
Cell[7151, 230, 451, 14, 49, "Text",
 CellTags->"b:2.0.0"],
Cell[7605, 246, 1203, 46, 76, "Text",
 CellTags->"b:2.0.0"],
Cell[8811, 294, 458, 15, 44, "Input",
 CellTags->"b:2.0.0"],
Cell[9272, 311, 224, 5, 22, "Text",
 CellTags->"b:2.0.0"],
Cell[9499, 318, 2072, 55, 90, "Input",
 CellTags->"b:2.0.0"],
Cell[11574, 375, 2026, 55, 75, "Input",
 CellTags->"b:2.0.0"],
Cell[13603, 432, 649, 13, 118, "Text",
 CellTags->"b:2.0.0"],
Cell[14255, 447, 186, 5, 44, "Input",
 CellTags->"b:2.0.0"],
Cell[14444, 454, 278, 9, 26, "Text",
 CellTags->"b:2.0.0"],
Cell[14725, 465, 102, 2, 22, "Text",
 CellTags->"b:2.0.0"],
Cell[14830, 469, 84, 2, 44, "Input",
 CellTags->"b:2.0.0"],
Cell[CellGroupData[{
Cell[14939, 475, 188, 7, 33, "Subsubsection",
 CellTags->{"c:4", "b:2.0.0"}],
Cell[15130, 484, 568, 17, 105, "Input",
 CellTags->"b:2.0.0"],
Cell[15701, 503, 159, 5, 22, "Text",
 CellTags->"b:2.0.0"],
Cell[15863, 510, 496, 15, 44, "Input",
 CellTags->"b:2.0.0"],
Cell[16362, 527, 140, 4, 22, "Text",
 CellTags->"b:2.0.0"],
Cell[16505, 533, 823, 24, 75, "Input",
 CellTags->"b:2.0.0"],
Cell[17331, 559, 180, 5, 22, "Text",
 CellTags->"b:2.0.0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[17548, 569, 110, 2, 33, "Subsubsection",
 CellTags->{"c:5", "b:2.0.0"}],
Cell[17661, 573, 177, 5, 22, "Text",
 CellTags->"b:2.0.0"],
Cell[17841, 580, 775, 24, 131, "Input",
 CellTags->"b:2.0.0"],
Cell[18619, 606, 159, 5, 22, "Text",
 CellTags->"b:2.0.0"],
Cell[18781, 613, 1714, 49, 156, "Input",
 CellTags->"b:2.0.0"],
Cell[20498, 664, 114, 2, 22, "Text",
 CellTags->"b:2.0.0"],
Cell[20615, 668, 936, 27, 111, "Input",
 CellTags->"b:2.0.0"],
Cell[21554, 697, 551, 11, 118, "Text",
 CellTags->"b:2.0.0"],
Cell[22108, 710, 258, 7, 60, "Input",
 CellTags->"b:2.0.0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[22403, 722, 108, 2, 33, "Subsubsection",
 CellTags->{"c:6", "b:2.0.0"}],
Cell[22514, 726, 607, 18, 105, "Input",
 CellTags->"b:2.0.0"],
Cell[23124, 746, 159, 5, 22, "Text",
 CellTags->"b:2.0.0"],
Cell[23286, 753, 1714, 49, 156, "Input",
 CellTags->"b:2.0.0"],
Cell[25003, 804, 114, 2, 22, "Text",
 CellTags->"b:2.0.0"],
Cell[25120, 808, 1035, 30, 111, "Input",
 CellTags->"b:2.0.0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[26192, 843, 110, 2, 33, "Subsubsection",
 CellTags->{"c:7", "b:2.0.0"}],
Cell[26305, 847, 680, 21, 105, "Input",
 CellTags->"b:2.0.0"],
Cell[26988, 870, 159, 5, 22, "Text",
 CellTags->"b:2.0.0"],
Cell[27150, 877, 1714, 49, 156, "Input",
 CellTags->"b:2.0.0"],
Cell[28867, 928, 114, 2, 22, "Text",
 CellTags->"b:2.0.0"],
Cell[28984, 932, 936, 27, 111, "Input",
 CellTags->"b:2.0.0"],
Cell[29923, 961, 141, 4, 22, "Text",
 CellTags->"b:2.0.0"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[30113, 971, 145, 3, 57, "Subsection",
 CellTags->{"c:8", "b:2.0.1"}],
Cell[30261, 976, 380, 7, 37, "Text",
 CellTags->"b:2.0.1"],
Cell[30644, 985, 539, 19, 51, "Text",
 CellTags->"b:2.0.1"],
Cell[31186, 1006, 1476, 42, 100, "Input",
 CellTags->"b:2.0.1"],
Cell[32665, 1050, 123, 2, 22, "Text",
 CellTags->"b:2.0.1"],
Cell[32791, 1054, 813, 24, 60, "Input",
 CellTags->"b:2.0.1"],
Cell[33607, 1080, 177, 4, 22, "Text",
 CellTags->"b:2.0.1"],
Cell[33787, 1086, 1101, 32, 60, "Input",
 CellTags->"b:2.0.1"],
Cell[34891, 1120, 786, 25, 44, "Input",
 CellTags->"b:2.0.1"],
Cell[35680, 1147, 598, 18, 44, "Input",
 CellTags->"b:2.0.1"],
Cell[36281, 1167, 114, 2, 22, "Text",
 CellTags->"b:2.0.1"],
Cell[36398, 1171, 2561, 67, 105, "Input",
 CellTags->"b:2.0.1"],
Cell[38962, 1240, 235, 6, 22, "Text",
 CellTags->"b:2.0.1"],
Cell[39200, 1248, 234, 7, 44, "Input",
 CellTags->"b:2.0.1"],
Cell[39437, 1257, 117, 2, 22, "Text",
 CellTags->"b:2.0.1"],
Cell[39557, 1261, 474, 12, 75, "Input",
 CellTags->"b:2.0.1"],
Cell[40034, 1275, 180, 5, 22, "Text",
 CellTags->"b:2.0.1"],
Cell[40217, 1282, 157, 4, 44, "Input",
 CellTags->"b:2.0.1"],
Cell[40377, 1288, 120, 3, 44, "Input",
 CellTags->"b:2.0.1"],
Cell[40500, 1293, 52, 1, 44, "Input",
 CellTags->"b:2.0.1"],
Cell[40555, 1296, 1005, 29, 35, "Abstract",
 CellTags->"b:2.0.1"]
}, Open  ]]
}, Closed]]
}
]
*)

(* End of internal cache information *)
