(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    167378,       5606]
NotebookOptionsPosition[    123549,       4211]
NotebookOutlinePosition[    149153,       4999]
CellTagsIndexPosition[    147324,       4927]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["Shor's factoring algorithms", "Title",
 CellTags->"c:1"],

Cell["Four examples of Shor's factoring algorithm", "Subtitle"],

Cell[TextData[{
 "Version: 3.0-April-2011--For ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " 6.0-8.0"
}], "Abstract",
 CellChangeTimes->{{3.395090887981901*^9, 3.395090925377634*^9}, {
   3.512204933064251*^9, 3.5122049705968847`*^9}, 3.5122120029978447`*^9}],

Cell[CellGroupData[{

Cell["\<\
Four examples of Shor's factoring algorithm                        To open \
double click at down arrow---------------------------->>\
\>", "Section",
 CellChangeTimes->{{3.512205126506694*^9, 3.51220512963229*^9}},
 FontFamily->"Times",
 CellTags->{"c:2", "b:3.0"}],

Cell[TextData[{
 "Last Version: 18-Aug-2005\n",
 Cell[BoxData[
  FormBox[GridBox[{
     {
      RowBox[{"References", ":"}], 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"[", "1", "]"}], " ", "Peter", " ", 
         RowBox[{"W", ".", " ", "Shor"}]}], ",", " ", 
        RowBox[{"SIAM", " ", 
         RowBox[{"J", ".", " ", "COMPUT"}], " ", "26", " ", 
         RowBox[{"(", "5", ")"}], " ", "1484", " ", 
         RowBox[{"(", "1997", ")"}]}]}], "\n", 
       RowBox[{
        RowBox[{"[", "2", "]"}], " ", "Edward", " ", "Gerjuoy", " ", 
        RowBox[{"Am", ".", " ", "J", ".", " ", "Phys", ".", " ", "73"}], " ", 
        RowBox[{"(", "6", ")"}], " ", "521", " ", 
        RowBox[{"(", "2005", ")"}]}], "\n", 
       RowBox[{
        RowBox[{
         RowBox[{"[", "3", "]"}], " ", "QDENSITY", " ", "Manual"}], ",", " ", 
        RowBox[{"Sect", ".", " ", "9"}]}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {Right, {Left}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}], TraditionalForm]], 
  "DefinitionBox",
  GridBoxOptions->{
  GridBoxDividers->{
   "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
    "RowsIndexed" -> {}},
  GridBoxSpacings->{"Columns" -> {
      Offset[0.27999999999999997`], {
       Offset[0.5599999999999999]}, 
      Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
      Offset[0.2], {
       Offset[0.16]}, 
      Offset[0.2]}, "RowsIndexed" -> {}}},
  CellTags->"S5.1.1"],
 "\n\nWe present four different implementations of the factoring algorithm. \
The differences between them arise from the method used to perform the \
Quantum Fourier Transform. All of them follow essentially the same steps and \
mostly share the same comments and explanations.\n\n(1) The first case is \
closer to an experiment implementation, using a density matrix, where the QFT \
is explicitly constructed quantum mechanically using Hadamards and Controlled \
gates. \n\n(2) In the second case, a state vector formulation is used , \
instead of a density matrix, to compute the QFT.  This approach saves space, \
as explained in ",
 ButtonBox["QFT.nb",
  BaseStyle->"Hyperlink",
  ButtonData:>{"QFT.nb", None}],
 ". \n\n(3) The third case, is based on the second approach but also \
explictly constructs the state vectors for both registers, and uses the state \
vector formula for QFT.\n\n(4) Finally, if one is interested in analyzing the \
probabilities for factoring larger numbers, and not in a voracious, closer to \
reality implementation of the QFT, then use this version which replaces QFT \
by  Fourier and InverseFourier, the built-in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " functions for Discreet Fourier Transforms (DFT), check ",
 ButtonBox["QFT.nb",
  BaseStyle->"Hyperlink",
  ButtonData:>{"QFT.nb", None}],
 "."
}], "Abstract",
 CellTags->"b:3.0"],

Cell[TextData[ButtonBox["Click here to get the palette: QDENSpalette.nb",
 BaseStyle->"Hyperlink",
 ButtonData:>{"QDENSpalette.nb", None}]], "Text",
 CellTags->"b:3.0"]
}, Closed]],

Cell[CellGroupData[{

Cell["Shor's Factoring algorithm using density matrix", "Section",
 FontFamily->"Times",
 CellTags->"c:2"],

Cell[CellGroupData[{

Cell["\<\
Step 0: Preliminars: Define functions for QFT [check QFT.nb ] and NumberTheory\
\>", "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:3", "b:3.1.0"}],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<QDENSITY`Qdensity`\>\"", "]"}]], "Input",
 FontFamily->"Courier New",
 CellTags->"b:3.1.0"],

Cell[BoxData[
 RowBox[{"?", "QDENSITY`Qdensity`*"}]], "Input",
 FontFamily->"Courier New",
 CellTags->"b:3.1.0"],

Cell["\<\
To improve performance we precompile the quantum Fourier transform.  We \
prepare some utilities first, for alter application:\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.1.0"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ControlP", "[", 
    RowBox[{"L_", ",", "q1_", ",", "q2_", ",", "k_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "\[Phi]", "}"}], ",", 
     RowBox[{
      RowBox[{"\[Phi]", "=", 
       RowBox[{"Exp", "[", 
        RowBox[{"2", "*", " ", "\[Pi]", " ", "*", " ", 
         RowBox[{"\[ImaginaryI]", " ", "/", 
          SuperscriptBox["2", "k"]}]}], "]"}]}], ";", 
      RowBox[{
       RowBox[{"1", "/", "4"}], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"3", "+", "\[Phi]"}], ")"}], "*", 
          RowBox[{"TwoOp", "[", 
           RowBox[{"L", ",", "q1", ",", "q2", ",", "0", ",", "0"}], "]"}]}], 
         "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "\[Phi]"}], ")"}], "*", 
          RowBox[{"TwoOp", "[", 
           RowBox[{"L", ",", "q1", ",", "q2", ",", "3", ",", "0"}], "]"}]}], 
         "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "\[Phi]"}], ")"}], "*", 
          RowBox[{"TwoOp", "[", 
           RowBox[{"L", ",", "q1", ",", "q2", ",", "0", ",", "3"}], "]"}]}], 
         "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"\[Phi]", "-", "1"}], ")"}], "*", 
          RowBox[{"TwoOp", "[", 
           RowBox[{"L", ",", "q1", ",", "q2", ",", "3", ",", "3"}], "]"}]}]}],
         ")"}]}]}]}], "]"}]}], ";"}]], "Input",
 CellTags->"b:3.1.0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"InvertQubits", "[", "L_", "]"}], ":=", 
  RowBox[{
   RowBox[{"InvertQubits", "[", "L", "]"}], "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Reverse", "[", 
         RowBox[{"IntegerDigits", "[", 
          RowBox[{"i", ",", "2", ",", "L"}], "]"}], "]"}], "\[Equal]", " ", 
        RowBox[{"IntegerDigits", "[", 
         RowBox[{"j", ",", "2", ",", "L"}], "]"}]}], ",", "1", ",", "0"}], 
      "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", 
       RowBox[{
        RowBox[{"2", "^", "L"}], "-", "1"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "0", ",", 
       RowBox[{
        RowBox[{"2", "^", "L"}], "-", "1"}]}], "}"}]}], "]"}]}]}]], "Input",
 CellTags->"b:3.1.0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CompControlP", "=", " ", 
   RowBox[{"Compile", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"L", ",", "_Integer"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"q1", ",", "_Integer"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"q2", ",", "_Integer"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "_Integer"}], "}"}]}], "}"}], ",", 
     RowBox[{"Block", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Lv", "=", "L"}], ",", 
         RowBox[{"qv1", "=", "q1"}], ",", 
         RowBox[{"qv2", "=", "q2"}], ",", 
         RowBox[{"kv", "=", "k"}]}], "  ", "}"}], ",", " ", 
       RowBox[{"ControlP", "[", 
        RowBox[{"Lv", ",", "qv1", ",", "qv2", ",", "kv"}], "]"}]}], "]"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"{", "   ", 
       RowBox[{
        RowBox[{"ControlP", "[", 
         RowBox[{"Lv", ",", "qv1", ",", "qv2", ",", "kv"}], "]"}], ",", 
        "_Complex", ",", "2"}], "}"}], "}"}]}], "]"}]}], " ", ";"}]], "Input",
 CellTags->"b:3.1.0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CompHad", "=", " ", 
   RowBox[{"Compile", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"L", ",", "_Integer"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "_Integer"}], "}"}]}], "}"}], ",", 
     RowBox[{"Block", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Lv", "=", "L"}], ",", 
         RowBox[{"iv", "=", "i"}]}], "}"}], ",", " ", 
       RowBox[{"had", "[", 
        RowBox[{"Lv", ",", "iv"}], "]"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"{", "   ", 
       RowBox[{
        RowBox[{"had", "[", 
         RowBox[{"Lv", ",", "iv"}], "]"}], ",", "_Real", ",", "2"}], "}"}], 
      "}"}]}], "]"}]}], "  ", ";"}]], "Input",
 CellTags->"b:3.1.0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CompInvertQubits", "=", " ", 
   RowBox[{"Compile", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"L", ",", "_Integer"}], "}"}], "}"}], ",", 
     RowBox[{"Block", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Lv", "=", "L"}], " ", "}"}], ",", 
       RowBox[{"InvertQubits", "[", "Lv", "]"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"{", "  ", 
       RowBox[{
        RowBox[{"InvertQubits", "[", "Lv", "]"}], ",", "_Real", ",", "2"}], 
       "}"}], "}"}]}], "]"}]}], "  ", ";"}]], "Input",
 CellTags->"b:3.1.0"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"QuantumFourierTransform", "=", 
    RowBox[{"Compile", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"L", ",", "_Integer"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[CapitalOmega]s", ",", "_Complex", ",", "2"}], "}"}]}], 
       "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"Module", "[", 
       RowBox[{
        RowBox[{"{", "\[CapitalOmega]", "}"}], ",", 
        RowBox[{
         RowBox[{"\[CapitalOmega]", "=", "\[CapitalOmega]s"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"For", "[", 
          RowBox[{
           RowBox[{"i", "=", "1"}], ",", 
           RowBox[{"i", "\[LessEqual]", "L"}], ",", 
           RowBox[{"i", "++"}], ",", 
           RowBox[{
            RowBox[{"\[CapitalOmega]", "=", 
             RowBox[{"N", "[", 
              RowBox[{
               RowBox[{"CompHad", "[", 
                RowBox[{"L", ",", "i"}], "]"}], ".", "\[CapitalOmega]"}], 
              "]"}]}], ";", 
            RowBox[{"For", "[", " ", 
             RowBox[{
              RowBox[{"j", "=", 
               RowBox[{"i", "+", "1"}]}], ",", 
              RowBox[{"j", "\[LessEqual]", "L"}], ",", 
              RowBox[{"j", "++"}], ",", 
              RowBox[{"\[CapitalOmega]", "=", 
               RowBox[{"N", "[", 
                RowBox[{
                 RowBox[{"CompControlP", "[", 
                  RowBox[{"L", ",", "j", ",", "i", ",", 
                   RowBox[{"j", "-", "i", "+", "1"}]}], "]"}], ".", 
                 "\[CapitalOmega]"}], "]"}]}]}], "]"}]}]}], "]"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"\[CapitalOmega]", "=", 
          RowBox[{
           RowBox[{"CompInvertQubits", "[", "L", "]"}], ".", 
           "\[CapitalOmega]"}]}], ";", "\[CapitalOmega]"}]}], "]"}], ",", " ",
       "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", " ", 
         RowBox[{
          RowBox[{"CompHad", "[", 
           RowBox[{"L", ",", "i"}], "]"}], ",", "_Real", ",", "2"}], "}"}], 
        ",", 
        RowBox[{"{", " ", 
         RowBox[{
          RowBox[{"CompControlP", "[", 
           RowBox[{"L", ",", "j", ",", "i", ",", 
            RowBox[{"j", "-", "i", "+", "1"}]}], "]"}], ",", "_Complex", ",", 
          "2"}], "}"}], ",", 
        RowBox[{"{", " ", 
         RowBox[{
          RowBox[{"CompInvertQubits", "[", "L", "]"}], ",", "_Real", ",", 
          "2"}], "}"}]}], "}"}]}], " ", "]"}]}], ";"}], "  "}]], "Input",
 CellTags->"b:3.1.0"],

Cell["\<\
To get the period r which will appear in a quotient of the form s/r we will \
use the 
continued fraction. i is the ith cycle of continued fraction and j is the \
number measured. \
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.1.0"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"denomi", "[", 
    RowBox[{"i_", ",", "j_"}], "]"}], ":=", 
   RowBox[{"Denominator", "[", 
    RowBox[{"FromContinuedFraction", "[", " ", 
     RowBox[{"ContinuedFraction", "[", 
      RowBox[{
       FractionBox["j", 
        SuperscriptBox["2", 
         SubscriptBox["n", "1"]]], ",", "i"}], "]"}], "]"}], "]"}]}], 
  ";"}]], "Input",
 CellTags->"b:3.1.0"],

Cell["Flag for the case when factoring an even number ", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.1.0"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"Even", "=", "False"}], ";"}]}]], "Input",
 CellTags->"b:3.1.0"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Step 1: Choose the number to be factorized: 15, 21, 33, 35, 39, 55, 77 and \
determine size of registers needed\
\>", "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:4", "b:3.1.1"}],

Cell["M is the number we are trying to factor:", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.1.1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"M", "=", "21"}], ";"}]], "Input",
 CellTags->"b:3.1.1"],

Cell["MP is the number we will work with and possibly modify:", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.1.1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"MP", "=", "M"}], ";"}]], "Input",
 CellTags->"b:3.1.1"],

Cell["\<\
 We perform a couple of tests to check whether the number is a power of 2 or \
prime, in which case we quit the process:\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.1.1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"While", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Mod", "[", 
      RowBox[{"MP", ",", "2"}], "]"}], "\[Equal]", "0"}], ",", 
    RowBox[{
     RowBox[{"Even", "=", "True"}], ";", 
     RowBox[{"MP", "=", 
      RowBox[{"MP", "/", "2"}]}]}]}], "]"}], ";"}]], "Input",
 CellTags->"b:3.1.1"],

Cell[BoxData[
 RowBox[{"If", "[", 
  RowBox[{
   RowBox[{"MP", "\[Equal]", "1"}], ",", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"M", ",", " ", "\"\< is a power of 2\>\""}], "]"}], ";", 
    RowBox[{"Quit", "[", "]"}]}], ","}], "]"}]], "Input",
 CellTags->"b:3.1.1"],

Cell[BoxData[
 RowBox[{"If", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"PrimeQ", "[", "MP", "]"}], "\[Equal]", "True"}], ",", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"Even", "\[Equal]", "False"}], ",", 
     RowBox[{
      RowBox[{"Print", "[", 
       RowBox[{"M", ",", "\"\< is prime, therefore has no factors\>\""}], 
       "]"}], ";", 
      RowBox[{"Quit", "[", "]"}]}], ",", 
     RowBox[{
      RowBox[{"Print", "[", 
       RowBox[{
       "\"\<The prime factors of \>\"", ",", "M", ",", "\"\< are \>\"", ",", 
        "2", ",", "\"\< and \>\"", ",", "MP"}], "]"}], ";", 
      RowBox[{"Quit", "[", "]"}]}]}], "]"}], ","}], "]"}]], "Input",
 CellTags->"b:3.1.1"],

Cell[TextData[{
 " We need the ",
 StyleBox["minimun number",
  FontWeight->"Bold"],
 " of qubits for both registers. \nHere we should be careful, a high ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["n", "1"], TraditionalForm]]],
 " number will lengthen the computation.  \nBy default we give estimates for ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["n", "1"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["n", "2"], TraditionalForm]]],
 ",based on the fact that ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["n", "1"], TraditionalForm]]],
 " should be able to \nrepresent numbers up to M^2, while ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["n", "2"], TraditionalForm]]],
 "should allow to write up to M/2. However, in \nmany cases it could be more \
illustrative to lower the value of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["n", "1"], TraditionalForm]]],
 " \n[ ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["n", "2"], TraditionalForm]]],
 "is not relevant for the code's performance] and check the resulting \
probabilities."
}], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.1.1"],

Cell[BoxData[
 RowBox[{"Q", "=", 
  RowBox[{"2", "^", 
   RowBox[{"Ceiling", "[", 
    RowBox[{"Log", "[", 
     RowBox[{"2", ",", 
      RowBox[{"MP", "^", "2"}]}], "]"}], "]"}]}]}]], "Input",
 CellTags->"b:3.1.1"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   SubscriptBox["n", "1"], "=", 
   RowBox[{"Ceiling", "[", 
    RowBox[{"Log", "[", 
     RowBox[{"2", ",", "Q"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["n", "2"], "=", 
   RowBox[{"Ceiling", "[", 
    RowBox[{"Log", "[", 
     RowBox[{"2", ",", "MP"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["n", "1"], "=", "6"}], "\[IndentingNewLine]", 
 SubscriptBox["n", "2"]}], "Input",
 CellTags->"b:3.1.1"],

Cell["\<\
Gerjuoy's test: a failure to pass this test  means we cannot ensure that we \
will 
in fact find the period using the continued fraction expansion [ After \
Eq.(54) of Ref.[2] ]\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.1.1"],

Cell[BoxData[
 RowBox[{"If", " ", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"2", "^", 
     SubscriptBox["n", "1"]}], "<", 
    RowBox[{
     RowBox[{"MP", "^", "2"}], "/", "4"}]}], ",", " ", 
   RowBox[{
   "Print", "[", 
    "\"\<CHECK YOUR \!\(\*SubscriptBox[\(n\), \(1\)]\), YOU MAY HAVE PROBLEMS \
GETTING THE PERIOD\>\"", "]"}], ","}], "]"}]], "Input",
 CellTags->"b:3.1.1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Step 2: Load the first register with the integers less than or equal to ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["2", 
     SubscriptBox["n", "1"]], "-", "1"}], TraditionalForm]]],
 "(a.k.a. Hadamard all qubits in register 1)"
}], "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:5", "b:3.1.2"}],

Cell[TextData[{
 " Register one needs to be set to the following: ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"|", 
       SubscriptBox["\[Psi]", "1"]}], "\[RightAngleBracket]"}], "=", " ", 
     RowBox[{
      RowBox[{
       SuperscriptBox["2", 
        RowBox[{
         RowBox[{"-", 
          SubscriptBox["n", "1"]}], "/", "2"}]], " ", 
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"j", "=", "0"}], 
        RowBox[{
         SuperscriptBox["2", 
          SubscriptBox["n", "1"]], "-", "1"}]]}], " ", "|", "j"}]}], "   ", 
    "\[RightAngleBracket]"}], TraditionalForm]]],
 " ; which is a \nstate where all ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["n", "1"], TraditionalForm]]],
 " qubits have been Hadamarded.\nIn this computer simulation we will not \
explicty construct it.  "
}], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.1.2"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Step 3: Select an integer (xguess) coprime to M and load ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["f", "j"], "\[Congruent]", " ", 
    RowBox[{
     RowBox[{
      SuperscriptBox["xguess", "j"], 
      RowBox[{"(", 
       RowBox[{"mod", " ", "M"}], ")"}]}], " ", "into", " ", "the", " ", 
     "second", " ", "register"}]}], TraditionalForm]]]
}], "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:6", "b:3.1.3"}],

Cell[" This is the random Coprime to MP: ", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.1.3"],

Cell[BoxData[
 RowBox[{"xguess", "=", 
  RowBox[{
   RowBox[{"Select", "[", 
    RowBox[{
     RowBox[{"Range", "[", "MP", "]"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"GCD", "[", 
        RowBox[{"#1", ",", "MP"}], "]"}], "\[Equal]", "1"}], "&"}]}], "]"}], 
   "\[LeftDoubleBracket]", 
   RowBox[{"RandomInteger", "[", 
    RowBox[{"{", 
     RowBox[{"2", ",", 
      RowBox[{"EulerPhi", "[", "MP", "]"}]}], "}"}], "]"}], 
   "\[RightDoubleBracket]"}]}]], "Input",
 CellTags->"b:3.1.3"],

Cell[TextData[{
 " The full wave function after we build the second register with  ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "j"], TraditionalForm]]],
 "reads:\n ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"|", 
         SubscriptBox["\[Psi]", "12"]}], "\[RightAngleBracket]"}], "=", " ", 
       RowBox[{
        RowBox[{
         SuperscriptBox["2", 
          RowBox[{
           RowBox[{"-", 
            SubscriptBox["n", "1"]}], "/", "2"}]], " ", 
         UnderoverscriptBox["\[Sum]", 
          RowBox[{"j", "=", "0"}], 
          RowBox[{
           SuperscriptBox["2", 
            SubscriptBox["n", "1"]], "-", "1"}]]}], " ", "|", "j"}]}], "   ", 
      "\[RightAngleBracket]"}], "|", 
     SubscriptBox["f", "j"]}], "  ", "\[RightAngleBracket]"}], 
   TraditionalForm]]],
 ", with ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["f", "j"], "\[Congruent]", " ", 
    RowBox[{
     SuperscriptBox["xguess", "j"], 
     RowBox[{"(", 
      RowBox[{"mod", " ", "M"}], ")"}]}]}], TraditionalForm]]]
}], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.1.3"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Step 4: Now we measure the state of the second register", "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:7", "b:3.1.4"}],

Cell[TextData[{
 "We take an hypothetical measurement of the second register: (NOTE that by \
construction the \nmeasured value must be one fo the ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "j"], TraditionalForm]]],
 "]"
}], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.1.4"],

Cell[BoxData[
 RowBox[{"reg2Measurement", "=", 
  RowBox[{"Mod", "[", 
   RowBox[{
    SuperscriptBox["xguess", 
     RowBox[{"RandomInteger", "[", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{
         SuperscriptBox["2", 
          SubscriptBox["n", "1"]], "-", "1"}]}], "}"}], "]"}]], ",", "MP"}], 
   "]"}]}]], "Input",
 CellTags->"b:3.1.4"],

Cell[BoxData[{
 SuperscriptBox["2", 
  SubscriptBox["n", "1"]], "\[IndentingNewLine]", 
 SuperscriptBox["2", 
  SubscriptBox["n", "2"]], "\[IndentingNewLine]", 
 SuperscriptBox["2", 
  RowBox[{"(", 
   RowBox[{
    SubscriptBox["n", "1"], "+", 
    SubscriptBox["n", "2"]}], ")"}]]}], "Input",
 CellTags->"b:3.1.4"],

Cell[TextData[{
 "The next function gives the number in the ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["n", "1"], TraditionalForm]]],
 "register in decimal basis from a given number i in the ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FormBox[
     SubscriptBox["n", "1"],
     TraditionalForm], "+", 
    SubscriptBox["n", "2"]}], TraditionalForm]]],
 " bases."
}], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.1.4"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"xv", "[", "i_", "]"}], ":=", 
   RowBox[{"FromDigits", "[", 
    RowBox[{
     RowBox[{"Take", "[", 
      RowBox[{
       RowBox[{"IntegerDigits", "[", 
        RowBox[{"i", ",", "2", ",", 
         RowBox[{
          SubscriptBox["n", "1"], "+", 
          SubscriptBox["n", "2"]}]}], "]"}], ",", 
       SubscriptBox["n", "1"]}], "]"}], ",", "2"}], "]"}]}], ";"}]], "Input",
 CellTags->"b:3.1.4"],

Cell[TextData[{
 "We select the positions in the ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["n", "1"], "+", 
    SubscriptBox["n", "2"]}], TraditionalForm]]],
 "register which remain when reg2 has been measured:"
}], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.1.4"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dens1", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Do", "[", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Mod", "[", 
         RowBox[{
          RowBox[{"xguess", "^", 
           RowBox[{"xv", "[", "i", "]"}]}], ",", "MP"}], "]"}], "\[Equal]", 
        "reg2Measurement"}], ",", " ", 
       RowBox[{"dens1", "=", 
        RowBox[{"Join", "[", " ", 
         RowBox[{"dens1", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"xv", "[", "i", "]"}], "+", "1"}], " ", "}"}]}], "]"}]}], 
       ",", "\"\<\>\""}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", 
       RowBox[{
        SuperscriptBox["2", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["n", "1"], "+", 
           SubscriptBox["n", "2"]}], ")"}]], "-", "1"}], ",", 
       SuperscriptBox["2", 
        SubscriptBox["n", "2"]]}], " ", "}"}]}], "]"}], ";"}], 
  " "}]}], "Input",
 CellTags->"b:3.1.4"],

Cell["\<\
And then after the measurement reg1 is in the following state:\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.1.4"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"reg1", "=", 
   RowBox[{"Table", "[", " ", 
    RowBox[{"0", ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"2", "^", 
        SubscriptBox["n", "1"]}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{"reg1", "=", 
    RowBox[{"ReplacePart", "[", 
     RowBox[{"reg1", ",", "1", ",", 
      RowBox[{"dens1", "[", 
       RowBox[{"[", "i", "]"}], "]"}]}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "1", ",", 
     RowBox[{"Length", "[", "dens1", "]"}]}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"reg1", "=", 
   RowBox[{"reg1", "/", 
    RowBox[{"Norm", "[", "reg1", "]"}]}]}], ";"}]}], "Input",
 CellTags->"b:3.1.4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"densx", "=", 
   RowBox[{"Distribute", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"dens1", ",", "dens1"}], "}"}], ",", "List"}], "]"}]}], 
  ";"}]], "Input",
 CellTags->"b:3.1.4"],

Cell["Share some memory.:", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.1.4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Share", "[", " ", "]"}], ";"}]], "Input",
 CellTags->"b:3.1.4"],

Cell["Prepere desnity matrix for reg1", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.1.4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rho1", " ", "=", 
   RowBox[{"Compile", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"m", ",", "_Integer", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "_Integer", ",", "2"}], "}"}]}], "}"}], ",", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", "t", "}"}], ",", 
       RowBox[{
        RowBox[{"t", "=", "n"}], ";", " ", 
        RowBox[{"ReplacePart", "[", 
         RowBox[{"m", ",", "1", ",", "densx"}], "]"}]}]}], "]"}]}], "   ", 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{3.395094265479423*^9},
 CellTags->"b:3.1.4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Rho]1", " ", "=", 
   RowBox[{
    FractionBox["1", 
     SqrtBox[
      RowBox[{"Length", "[", " ", "densx", "]"}]]], 
    RowBox[{"rho1", "[", 
     RowBox[{
      RowBox[{"ConstantArray", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", 
         RowBox[{
          SuperscriptBox["2", 
           SubscriptBox["n", "1"]], ",", 
          SuperscriptBox["2", 
           SubscriptBox["n", "1"]]}], "}"}]}], "]"}], ",", "densx"}], 
     "]"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.395094076233127*^9, 3.3950940974912663`*^9}},
 CellTags->"b:3.1.4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Share", "[", " ", "]"}], ";"}]], "Input",
 CellTags->"b:3.1.4"]
}, Closed]],

Cell[CellGroupData[{

Cell["Step 5: Perform the inverse QFT on first register", "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:8", "b:3.1.5"}],

Cell["\<\
We apply the inverse of the quantum fourier transform to \[Rho]1:\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.1.5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rho2", " ", "=", 
   RowBox[{"Compile", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x", ",", "_Complex", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", "_Complex", ",", "2"}], "}"}]}], "}"}], ",", " ", 
     RowBox[{"N", "[", 
      RowBox[{
       RowBox[{"Conjugate", "[", "x", "]"}], ".", "y", ".", "x"}], "]"}]}], 
    "]"}]}], ";"}]], "Input",
 CellTags->"b:3.1.5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"time1", "=", 
   RowBox[{"SessionTime", "[", "]"}]}], ";"}]], "Input",
 CellTags->"b:3.1.5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Rho]2", "=", " ", 
   RowBox[{"rho2", " ", "[", 
    RowBox[{
     RowBox[{"QuantumFourierTransform", "[", 
      RowBox[{
       SubscriptBox["n", "1"], ",", " ", 
       RowBox[{"N", "[", 
        RowBox[{"IdentityMatrix", "[", 
         SuperscriptBox["2", 
          SubscriptBox["n", "1"]], "]"}], "]"}]}], "]"}], ",", " ", 
     "\[Rho]1"}], "  ", "]"}]}], ";"}]], "Input",
 CellTags->"b:3.1.5"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"time2", "=", 
   RowBox[{"SessionTime", "[", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<The QFT took \>\"", ",", 
   RowBox[{"time2", "-", "time1"}], ",", "\"\< seconds\>\""}], 
  "]"}]}], "Input",
 CellTags->"b:3.1.5"],

Cell[BoxData[
 RowBox[{"Chop", "[", 
  RowBox[{"Tr", "[", "\[Rho]2", "]"}], "]"}]], "Input",
 CellTags->"b:3.1.5"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Step 6: Measure register 1, instead: study all possible results and their \
probabilites\
\>", "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:9", "b:3.1.6"}],

Cell["\<\
We store the possible measurements and their probabilities in variable \
MeasProb:\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.1.6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"MeasProb", "=", 
   RowBox[{"{", " ", "}"}]}], ";"}]], "Input",
 CellTags->"b:3.1.6"],

Cell[BoxData[
 RowBox[{"For", "[", 
  RowBox[{
   RowBox[{"num", "=", "0"}], ",", 
   RowBox[{"num", "<", 
    SuperscriptBox["2", 
     SubscriptBox["n", "1"]]}], ",", 
   RowBox[{
    RowBox[{"\[CapitalOmega]", "=", 
     RowBox[{"Chop", "[", 
      RowBox[{"\[Rho]2", "[", 
       RowBox[{"[", 
        RowBox[{
         RowBox[{"num", "+", "1"}], ",", 
         RowBox[{"num", "+", "1"}]}], "]"}], "]"}], "]"}]}], ";", 
    RowBox[{"MeasProb", "=", 
     RowBox[{"Append", "[", 
      RowBox[{"MeasProb", ",", 
       RowBox[{"{", 
        RowBox[{"num", ",", "\[CapitalOmega]"}], "}"}]}], "]"}]}], ";", 
    RowBox[{"num", "++"}]}]}], "]"}]], "Input",
 CellTags->"b:3.1.6"],

Cell["\<\
Plots of the possible measurements and their probabilities are quite \
illustrative:\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.1.6"],

Cell[BoxData[{
 RowBox[{"Plot1", "=", 
  RowBox[{"ListPlot", "[", 
   RowBox[{"MeasProb", ",", 
    RowBox[{"Joined", "\[Rule]", "True"}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Measured", " ", "number"}], ",", "Probability"}], "}"}]}], 
    ",", 
    RowBox[{"ImageSize", "\[Rule]", "400"}]}], "]"}]}], "\n", 
 RowBox[{"ListPlot", "[", 
  RowBox[{"MeasProb", ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Measured", " ", "number"}], ",", "Probability"}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0.3`"}], "}"}]}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "400"}]}], "]"}]}], "Input",
 CellTags->"b:3.1.6"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Step 7: Attempt to infer the period r for all possible measurements\
\>", "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:10", "b:3.1.7"}],

Cell[TextData[{
 "Finally we go through all the measurements, compute the periods and check \
the \nfactors we would find and their probabilities. \nSchematically: we \
search for the period using ContinuedFraction, once a possible \nperiod is \
found it checks whether ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["xguess", 
    RowBox[{"r", "/", "2"}]], TraditionalForm]]],
 "is an integer, if so, it computes the two \npossible factors f1 and f2."
}], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.1.7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"r", "=", "0"}], ";"}]], "Input",
 CellTags->"b:3.1.7"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Alldata", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "Period", ",", "Number", ",", "\"\<f1\>\"", ",", "\"\<f2\>\"", ",", 
       "Prob"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<\>\"", ",", "\"\<\>\"", ",", "\"\<\>\"", ",", 
       "\"\<\>\""}], "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"j", "=", "1"}], ",", 
    RowBox[{"j", "\[LessEqual]", 
     RowBox[{"Length", "[", "MeasProb", "]"}]}], ",", 
    RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"i", "=", "2"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"FromContinuedFraction", "[", " ", 
          RowBox[{"ContinuedFraction", "[", 
           RowBox[{
            FractionBox[
             RowBox[{"MeasProb", "[", 
              RowBox[{"[", 
               RowBox[{"j", ",", "1"}], "]"}], "]"}], 
             SuperscriptBox["2", 
              SubscriptBox["n", "1"]]], ",", 
            RowBox[{"i", "-", "1"}]}], "]"}], "]"}], "\[NotEqual]", 
         FractionBox[
          RowBox[{"MeasProb", "[", 
           RowBox[{"[", 
            RowBox[{"j", ",", "1"}], "]"}], "]"}], 
          SuperscriptBox["2", 
           SubscriptBox["n", "1"]]]}], " ", "&&", " ", 
        RowBox[{
         RowBox[{"denomi", "[", 
          RowBox[{"i", ",", 
           RowBox[{"MeasProb", "[", 
            RowBox[{"[", 
             RowBox[{"j", ",", "1"}], "]"}], "]"}]}], "]"}], "<=", 
         RowBox[{"MP", "/", "2"}]}]}], ",", 
       RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
       RowBox[{"r", "=", 
        RowBox[{"denomi", "[", 
         RowBox[{"i", ",", 
          RowBox[{"MeasProb", "[", 
           RowBox[{"[", 
            RowBox[{"j", ",", "1"}], "]"}], "]"}]}], "]"}]}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"IntegerQ", "[", 
        SuperscriptBox["xguess", 
         RowBox[{"r", "/", "2"}]], "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"f1", "=", 
         RowBox[{"GCD", "[", 
          RowBox[{
           RowBox[{
            SuperscriptBox["xguess", 
             RowBox[{"r", "/", "2"}]], " ", "+", "1"}], ",", "MP"}], "]"}]}], 
        " ", ";", "\[IndentingNewLine]", 
        RowBox[{"f2", "=", 
         RowBox[{"GCD", "[", 
          RowBox[{
           RowBox[{
            SuperscriptBox["xguess", 
             RowBox[{"r", "/", "2"}]], "-", "1"}], ",", "MP"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"MeasProb", "[", 
             RowBox[{"[", 
              RowBox[{"j", ",", "2"}], "]"}], "]"}], ">", "0.001"}], "&&", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"f1", ",", "f2"}], "}"}], "\[NotEqual]", " ", 
            RowBox[{"{", 
             RowBox[{"M", ",", "1"}], "}"}]}], "&&", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"f1", ",", "f2"}], "}"}], "\[NotEqual]", 
            RowBox[{"{", 
             RowBox[{"1", ",", "M"}], "}"}]}], "&&", 
           RowBox[{
            RowBox[{"f1", "*", "f2"}], "\[NotEqual]", "1"}], "&&", 
           RowBox[{"f1", "\[NotEqual]", "1"}], "&&", 
           RowBox[{"f2", "\[NotEqual]", "1"}]}], ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Alldata", "=", 
            RowBox[{"Join", "[", 
             RowBox[{"Alldata", ",", 
              RowBox[{"{", 
               RowBox[{"{", 
                RowBox[{"r", ",", 
                 RowBox[{"MeasProb", "[", 
                  RowBox[{"[", 
                   RowBox[{"j", ",", "1"}], "]"}], "]"}], ",", "f1", ",", 
                 "f2", ",", 
                 RowBox[{"MeasProb", "[", 
                  RowBox[{"[", 
                   RowBox[{"j", ",", "2"}], "]"}], "]"}]}], "}"}], "}"}]}], 
             "]"}]}], ";"}], "\[IndentingNewLine]", ",", 
          "\"\<you were quite unlucky in your xguess!\>\""}], "]"}]}]}], 
      "]"}]}]}], "]"}], ";"}]}], "Input",
 CellTags->"b:3.1.7"],

Cell[BoxData[{"Alldata", "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"TotalProbSucc", "=", 
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{"Alldata", "[", 
      RowBox[{"[", 
       RowBox[{"i", ",", "5"}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "3", ",", 
       RowBox[{"Length", "[", "Alldata", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<xguess=\>\"", ",", "xguess"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{
  "\"\<The TOTAL PROBABILITY OF SUCCESS is thus:\>\"", ",", "TotalProbSucc", 
   ",", "\"\<  with xguess=\>\"", ",", "xguess", ",", " ", 
   "\"\< and measured register=\>\"", ",", "reg2Measurement"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"If", " ", "[", 
  RowBox[{
   RowBox[{"TotalProbSucc", "\[Equal]", "0"}], ",", " ", 
   RowBox[{
   "Print", "[", 
    "\"\<Your total probability was zero, you xguess was not very lucky!\>\"",
     "]"}]}], "]"}]}], "Input",
 CellTags->"b:3.1.7"],

Cell[BoxData[
 RowBox[{"SessionTime", "[", "]"}]], "Input",
 CellTags->"b:3.1.7"],

Cell["\<\
In these examples, where we consider small numbers, 21, 35, 15, 33, 55 etc, 
it is possible to plot the function xguess^j and check whether the correct \
period
was found with Shor's Algorithm\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.1.7"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"a", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Mod", "[", 
      RowBox[{
       SuperscriptBox["xguess", "i"], ",", "M"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "60"}], "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"ListPlot", "[", 
  RowBox[{"a", ",", 
   RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}]}], "Input",
 CellTags->"b:3.1.7"],

Cell["Quit", "Input",
 CellTags->"b:3.1.7"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Shor's Factoring algorithm using state vector formula for QFT\
\>", "Section",
 FontFamily->"Times",
 CellTags->"c:11"],

Cell[CellGroupData[{

Cell["\<\
Step 0: Preliminars: Define functions for QFT [check QFT.nb ] and NumberTheory\
\>", "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:12", "b:3.2.0"}],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<QDENSITY`Qdensity`\>\"", "]"}]], "Input",
 FontFamily->"Courier New",
 CellTags->"b:3.2.0"],

Cell[BoxData[
 RowBox[{"?", "QDENSITY`Qdensity`*"}]], "Input",
 FontFamily->"Courier New",
 CellTags->"b:3.2.0"],

Cell["\<\
To improve performance we precompile the quantum Fourier transform, now using \
state vectors:\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.2.0"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Zeroff", "[", 
   RowBox[{"vac_", ",", "R_"}], "]"}], ":=", 
  RowBox[{"Sum", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"vac", "[", 
      RowBox[{"[", 
       RowBox[{"R", "[", 
        RowBox[{"[", "i", "]"}], "]"}], "]"}], "]"}], "/", 
     RowBox[{"2", "^", "i"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", 
      RowBox[{"Length", "[", "R", "]"}]}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CompZeroff", " ", "=", " ", 
   RowBox[{"Compile", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"vac", ",", "_Integer", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"R", ",", "_Integer", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"Zeroff", "[", 
      RowBox[{"vac", ",", "R"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Zeroff", "[", 
         RowBox[{"vac", ",", "R"}], "]"}], ",", "_Real"}], "}"}], "}"}]}], 
    "]"}]}], ";"}]}], "Input",
 CellTags->"b:3.2.0"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"QuantumFourierTransformV", "[", "vac_", "]"}], ":=", 
    "\[IndentingNewLine]", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\[CapitalOmega]", ",", "L"}], "}"}], ",", 
      RowBox[{
       RowBox[{"L", "=", 
        RowBox[{"Length", "[", "vac", "]"}]}], ";", 
       RowBox[{"\[CapitalOmega]", "=", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Ket", "[", "0", "]"}], "+", 
          RowBox[{
           RowBox[{"Exp", "[", 
            RowBox[{"2", "*", "\[Pi]", "*", " ", "\[ImaginaryI]", "*", 
             RowBox[{"CompZeroff", "[", 
              RowBox[{"vac", ",", 
               RowBox[{"Range", "[", 
                RowBox[{"L", ",", "L"}], "]"}]}], "]"}]}], "]"}], "*", 
           RowBox[{"Ket", "[", "1", "]"}]}]}], ")"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"i", "=", "2"}], ",", 
         RowBox[{"i", "\[LessEqual]", "L"}], ",", 
         RowBox[{"i", "++"}], ",", 
         RowBox[{
          RowBox[{"phass", "=", 
           RowBox[{"2", "*", "\[Pi]", "*", " ", "\[ImaginaryI]", "*", 
            RowBox[{"Zeroff", "[", 
             RowBox[{"vac", ",", 
              RowBox[{"Range", "[", 
               RowBox[{
                RowBox[{"L", "-", "i", "+", "1"}], ",", "L"}], "]"}]}], 
             "]"}]}]}], ";", 
          RowBox[{"\[CapitalOmega]", "=", 
           RowBox[{"\[CapitalOmega]", "\[CircleTimes]", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Ket", "[", "0", "]"}], "+", 
              RowBox[{
               RowBox[{"Exp", "[", "phass", "]"}], "*", 
               RowBox[{"Ket", "[", "1", "]"}]}]}], ")"}]}]}]}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"\[CapitalOmega]", "=", 
        RowBox[{"\[CapitalOmega]", "/", 
         RowBox[{"2", "^", 
          RowBox[{"(", 
           RowBox[{"L", "/", "2"}], ")"}]}]}]}], ";", "\[CapitalOmega]"}]}], 
     "]"}]}], ";"}], "  "}]], "Input",
 CellTags->"b:3.2.0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CompQuantumFourierTransformV", "=", 
   RowBox[{"Compile", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"v", ",", "_Integer", ",", "1"}], "}"}], "}"}], ",", " ", 
     RowBox[{"QuantumFourierTransformV", "[", "v", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"{", "   ", 
       RowBox[{
        RowBox[{"QuantumFourierTransformV", "[", "v", "]"}], ",", "_Complex", 
        ",", "2"}], "}"}], "}"}]}], "]"}]}], "  ", ";"}]], "Input",
 CellTags->"b:3.2.0"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"IQuantumFourierTransformV", "[", "vac_", "]"}], ":=", 
    "\[IndentingNewLine]", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\[CapitalOmega]", ",", "L"}], "}"}], ",", 
      RowBox[{
       RowBox[{"L", "=", 
        RowBox[{"Length", "[", "vac", "]"}]}], ";", 
       RowBox[{"\[CapitalOmega]", "=", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Ket", "[", "0", "]"}], "+", 
          RowBox[{
           RowBox[{"Exp", "[", 
            RowBox[{
             RowBox[{"-", "2"}], "*", "\[Pi]", "*", " ", "\[ImaginaryI]", "*", 
             RowBox[{"CompZeroff", "[", 
              RowBox[{"vac", ",", 
               RowBox[{"Range", "[", 
                RowBox[{"L", ",", "L"}], "]"}]}], "]"}]}], "]"}], "*", 
           RowBox[{"Ket", "[", "1", "]"}]}]}], ")"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"i", "=", "2"}], ",", 
         RowBox[{"i", "\[LessEqual]", "L"}], ",", 
         RowBox[{"i", "++"}], ",", 
         RowBox[{
          RowBox[{"phass", "=", 
           RowBox[{
            RowBox[{"-", "2"}], "*", "\[Pi]", "*", " ", "\[ImaginaryI]", "*", 
            RowBox[{"Zeroff", "[", 
             RowBox[{"vac", ",", 
              RowBox[{"Range", "[", 
               RowBox[{
                RowBox[{"L", "-", "i", "+", "1"}], ",", "L"}], "]"}]}], 
             "]"}]}]}], ";", 
          RowBox[{"\[CapitalOmega]", "=", 
           RowBox[{"\[CapitalOmega]", "\[CircleTimes]", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Ket", "[", "0", "]"}], "+", 
              RowBox[{
               RowBox[{"Exp", "[", "phass", "]"}], "*", 
               RowBox[{"Ket", "[", "1", "]"}]}]}], ")"}]}]}]}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"\[CapitalOmega]", "=", 
        RowBox[{"\[CapitalOmega]", "/", 
         RowBox[{"2", "^", 
          RowBox[{"(", 
           RowBox[{"L", "/", "2"}], ")"}]}]}]}], ";", "\[CapitalOmega]"}]}], 
     "]"}]}], ";"}], "  "}]], "Input",
 CellTags->"b:3.2.0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CompIQuantumFourierTransformV", "=", 
   RowBox[{"Compile", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"v", ",", "_Integer", ",", "1"}], "}"}], "}"}], ",", " ", 
     RowBox[{"QuantumFourierTransformV", "[", "v", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"{", "   ", 
       RowBox[{
        RowBox[{"QuantumFourierTransformV", "[", "v", "]"}], ",", "_Complex", 
        ",", "2"}], "}"}], "}"}]}], "]"}]}], "  ", ";"}]], "Input",
 CellTags->"b:3.2.0"],

Cell["\<\
To get the period r which will appear in a quotient of the form s/r we will \
use the 
continued fraction. i is the ith cycle of continued fraction and j is the \
number measured. \
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.2.0"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"denomi", "[", 
    RowBox[{"i_", ",", "j_"}], "]"}], ":=", 
   RowBox[{"Denominator", "[", 
    RowBox[{"FromContinuedFraction", "[", " ", 
     RowBox[{"ContinuedFraction", "[", 
      RowBox[{
       FractionBox["j", 
        SuperscriptBox["2", 
         SubscriptBox["n", "1"]]], ",", "i"}], "]"}], "]"}], "]"}]}], 
  ";"}]], "Input",
 CellTags->"b:3.2.0"],

Cell["Flag for the case when factoring an even number ", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.2.0"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"Even", "=", "False"}], ";"}]}]], "Input",
 CellTags->"b:3.2.0"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Step 1: Choose the number to be factorized: 15, 21, 33, 35, 39, 55, 77 and \
determine size of registers\
\>", "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:13", "b:3.2.1"}],

Cell["M is the number we are trying to factor:", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.2.1"],

Cell[BoxData[
 RowBox[{"M", "=", 
  RowBox[{"13", "*", "17"}]}]], "Input",
 CellTags->"b:3.2.1"],

Cell["MP is the number we will work with and possibly modify:", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.2.1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"MP", "=", "M"}], ";"}]], "Input",
 CellTags->"b:3.2.1"],

Cell["\<\
 We perform a couple of tests to check whether the number is a power of 2 or \
prime and quit if it is:\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.2.1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"While", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Mod", "[", 
      RowBox[{"MP", ",", "2"}], "]"}], "\[Equal]", "0"}], ",", 
    RowBox[{
     RowBox[{"Even", "=", "True"}], ";", 
     RowBox[{"MP", "=", 
      RowBox[{"MP", "/", "2"}]}]}]}], "]"}], ";"}]], "Input",
 CellTags->"b:3.2.1"],

Cell[BoxData[
 RowBox[{"If", "[", 
  RowBox[{
   RowBox[{"MP", "\[Equal]", "1"}], ",", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"M", ",", " ", "\"\< is a power of 2\>\""}], "]"}], ";", 
    RowBox[{"Quit", "[", "]"}]}], ","}], "]"}]], "Input",
 CellTags->"b:3.2.1"],

Cell[BoxData[
 RowBox[{"If", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"PrimeQ", "[", "MP", "]"}], "\[Equal]", "True"}], ",", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"Even", "\[Equal]", "False"}], ",", 
     RowBox[{
      RowBox[{"Print", "[", 
       RowBox[{"M", ",", "\"\< is prime, therefore has no factors\>\""}], 
       "]"}], ";", 
      RowBox[{"Quit", "[", "]"}]}], ",", 
     RowBox[{
      RowBox[{"Print", "[", 
       RowBox[{
       "\"\<The prime factors of \>\"", ",", "M", ",", "\"\< are \>\"", ",", 
        "2", ",", "\"\< and \>\"", ",", "MP"}], "]"}], ";", 
      RowBox[{"Quit", "[", "]"}]}]}], "]"}], ","}], "]"}]], "Input",
 CellTags->"b:3.2.1"],

Cell[TextData[{
 " We need the ",
 StyleBox["minimun number",
  FontWeight->"Bold"],
 " of qubits for both registers. \nHere we should be careful, a high ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["n", "1"], TraditionalForm]]],
 " number will lengthen the computation.  \nBy default we give estimates for ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["n", "1"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["n", "2"], TraditionalForm]]],
 ",based on the fact that ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["n", "1"], TraditionalForm]]],
 " should be able to \nrepresent numbers up to M^2, while ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["n", "2"], TraditionalForm]]],
 "should allow to write up to M/2. However,  in \nmany cases it could be more \
illustrative to lower the value of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["n", "1"], TraditionalForm]]],
 " \n[ ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["n", "2"], TraditionalForm]]],
 "is not relevant for the code's performance] and check the resulting \
probabilities."
}], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.2.1"],

Cell[BoxData[
 RowBox[{"Q", "=", 
  RowBox[{"2", "^", 
   RowBox[{"Ceiling", "[", 
    RowBox[{"Log", "[", 
     RowBox[{"2", ",", 
      RowBox[{"MP", "^", "2"}]}], "]"}], "]"}]}]}]], "Input",
 CellTags->"b:3.2.1"],

Cell[TextData[{
 "Note the user should experiment with the value of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["n", 
    RowBox[{"1", "   "}]], TraditionalForm]]],
 "to reduce the computation time, especially for large M."
}], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.2.1"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   SubscriptBox["n", "1"], "=", 
   RowBox[{"Ceiling", "[", 
    RowBox[{"Log", "[", 
     RowBox[{"2", ",", "Q"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["n", "2"], "=", 
   RowBox[{"Ceiling", "[", 
    RowBox[{"Log", "[", 
     RowBox[{"2", ",", "MP"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["n", "1"], "=", "9"}], "\[IndentingNewLine]", 
 SubscriptBox["n", "1"], "\[IndentingNewLine]", 
 SubscriptBox["n", "2"]}], "Input",
 CellTags->"b:3.2.1"],

Cell["\<\
Gerjuoy's test: a failure to pass this test  means we cannot ensure that we \
will 
in fact find the period using the continued fraction expansion [ After \
Eq.(54) of Ref.[2] ]\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.2.1"],

Cell[BoxData[
 RowBox[{"If", " ", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"2", "^", 
     SubscriptBox["n", "1"]}], "<", 
    RowBox[{
     RowBox[{"MP", "^", "2"}], "/", "4"}]}], ",", " ", 
   RowBox[{
   "Print", "[", 
    "\"\<CHECK YOUR \!\(\*SubscriptBox[\(n\), \(1\)]\), YOU MAY HAVE PROBLEMS \
GETTING THE PERIOD\>\"", "]"}], ","}], "]"}]], "Input",
 CellTags->"b:3.2.1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Step 2: Load the first register with the integers less than or equal to ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["2", 
     SubscriptBox["n", "1"]], "-", "1"}], TraditionalForm]]],
 "(a.k.a. Hadamard all qubits in register 1)"
}], "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:14", "b:3.2.2"}],

Cell[TextData[{
 " Register one needs to be set to the following: ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"|", 
       SubscriptBox["\[Psi]", "1"]}], "\[RightAngleBracket]"}], "=", " ", 
     RowBox[{
      RowBox[{
       SuperscriptBox["2", 
        RowBox[{
         RowBox[{"-", 
          SubscriptBox["n", "1"]}], "/", "2"}]], " ", 
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"j", "=", "0"}], 
        RowBox[{
         SuperscriptBox["2", 
          SubscriptBox["n", "1"]], "-", "1"}]]}], " ", "|", "j"}]}], "   ", 
    "\[RightAngleBracket]"}], TraditionalForm]]],
 " ; which is a \nstate where all ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["n", "1"], TraditionalForm]]],
 " qubits have been Hadamarded.\nIn this computer simulation we will not \
explicty construct it.  "
}], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.2.2"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Step 3: Select an integer (xguess) coprime to M and load ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["f", "j"], "\[Congruent]", " ", 
    RowBox[{
     RowBox[{
      SuperscriptBox["xguess", "j"], 
      RowBox[{"(", 
       RowBox[{"mod", " ", "M"}], ")"}]}], " ", "into", " ", "the", " ", 
     "second", " ", "register"}]}], TraditionalForm]]]
}], "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:15", "b:3.2.3"}],

Cell[" This is the random Coprime to MP: ", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.2.3"],

Cell[BoxData[
 RowBox[{"xguess", "=", 
  RowBox[{
   RowBox[{"Select", "[", 
    RowBox[{
     RowBox[{"Range", "[", "MP", "]"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"GCD", "[", 
        RowBox[{"#1", ",", "MP"}], "]"}], "\[Equal]", "1"}], "&"}]}], "]"}], 
   "\[LeftDoubleBracket]", 
   RowBox[{"RandomInteger", "[", 
    RowBox[{"{", 
     RowBox[{"2", ",", 
      RowBox[{"EulerPhi", "[", "MP", "]"}]}], "}"}], "]"}], 
   "\[RightDoubleBracket]"}]}]], "Input",
 CellTags->"b:3.2.3"],

Cell[BoxData[
 RowBox[{"xguess", "=", "16"}]], "Input",
 CellTags->"b:3.2.3"],

Cell[TextData[{
 " The full wave function after we build the second register with  ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "j"], TraditionalForm]]],
 "reads:\n ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"|", 
         SubscriptBox["\[Psi]", "12"]}], "\[RightAngleBracket]"}], "=", " ", 
       RowBox[{
        RowBox[{
         SuperscriptBox["2", 
          RowBox[{
           RowBox[{"-", 
            SubscriptBox["n", "1"]}], "/", "2"}]], " ", 
         UnderoverscriptBox["\[Sum]", 
          RowBox[{"j", "=", "0"}], 
          RowBox[{
           SuperscriptBox["2", 
            SubscriptBox["n", "1"]], "-", "1"}]]}], " ", "|", "j"}]}], "   ", 
      "\[RightAngleBracket]"}], "|", 
     SubscriptBox["f", "j"]}], "  ", "\[RightAngleBracket]"}], 
   TraditionalForm]]],
 ", with ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["f", "j"], "\[Congruent]", " ", 
    RowBox[{
     SuperscriptBox["xguess", "j"], 
     RowBox[{"(", 
      RowBox[{"mod", " ", "M"}], ")"}]}]}], TraditionalForm]]]
}], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.2.3"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Step 4: Now we measure the state of the second register", "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:16", "b:3.2.4"}],

Cell[TextData[{
 "We take an hypotetical measurement of the second register: (NOTE that by \
construction the \nmeasured value must be one fo the ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "j"], TraditionalForm]]],
 "]"
}], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.2.4"],

Cell[BoxData[
 RowBox[{"reg2Measurement", "=", 
  RowBox[{"Mod", "[", 
   RowBox[{
    SuperscriptBox["xguess", 
     RowBox[{"RandomInteger", "[", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{
         SuperscriptBox["2", 
          SubscriptBox["n", "1"]], "-", "1"}]}], "}"}], "]"}]], ",", "MP"}], 
   "]"}]}]], "Input",
 CellTags->"b:3.2.4"],

Cell[BoxData[{
 SuperscriptBox["2", 
  SubscriptBox["n", "1"]], "\[IndentingNewLine]", 
 SuperscriptBox["2", 
  SubscriptBox["n", "2"]], "\[IndentingNewLine]", 
 SuperscriptBox["2", 
  RowBox[{"(", 
   RowBox[{
    SubscriptBox["n", "1"], "+", 
    SubscriptBox["n", "2"]}], ")"}]]}], "Input",
 CellTags->"b:3.2.4"],

Cell[TextData[{
 "The next function gives the number in the ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["n", "1"], TraditionalForm]]],
 "register in decimal basis from a given number i in the ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FormBox[
     SubscriptBox["n", "1"],
     TraditionalForm], "+", 
    SubscriptBox["n", "2"]}], TraditionalForm]]],
 " bases."
}], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.2.4"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"xv", "[", "i_", "]"}], ":=", 
   RowBox[{"FromDigits", "[", 
    RowBox[{
     RowBox[{"Take", "[", 
      RowBox[{
       RowBox[{"IntegerDigits", "[", 
        RowBox[{"i", ",", "2", ",", 
         RowBox[{
          SubscriptBox["n", "1"], "+", 
          SubscriptBox["n", "2"]}]}], "]"}], ",", 
       SubscriptBox["n", "1"]}], "]"}], ",", "2"}], "]"}]}], ";"}]], "Input",
 CellTags->"b:3.2.4"],

Cell[TextData[{
 "We select the positions in the ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["n", "1"], "+", 
    SubscriptBox["n", "2"]}], TraditionalForm]]],
 "register which remain when reg2 has been measured:"
}], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.2.4"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dens1", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Do", "[", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Mod", "[", 
         RowBox[{
          RowBox[{"xguess", "^", 
           RowBox[{"xv", "[", "i", "]"}]}], ",", "MP"}], "]"}], "\[Equal]", 
        "reg2Measurement"}], ",", " ", 
       RowBox[{"dens1", "=", 
        RowBox[{"Join", "[", " ", 
         RowBox[{"dens1", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"xv", "[", "i", "]"}], "+", "1"}], " ", "}"}]}], "]"}]}], 
       ",", "\"\<\>\""}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", 
       RowBox[{
        SuperscriptBox["2", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["n", "1"], "+", 
           SubscriptBox["n", "2"]}], ")"}]], "-", "1"}], ",", 
       SuperscriptBox["2", 
        SubscriptBox["n", "2"]]}], " ", "}"}]}], "]"}], ";"}], 
  " "}]}], "Input",
 CellTags->"b:3.2.4"],

Cell["\<\
And then after the measurement reg1 is in the following state:\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.2.4"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"reg1", "=", 
   RowBox[{"Table", "[", " ", 
    RowBox[{"0", ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"2", "^", 
        SubscriptBox["n", "1"]}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{"reg1", "=", 
    RowBox[{"ReplacePart", "[", 
     RowBox[{"reg1", ",", "1", ",", 
      RowBox[{"dens1", "[", 
       RowBox[{"[", "i", "]"}], "]"}]}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "1", ",", 
     RowBox[{"Length", "[", "dens1", "]"}]}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"reg1", "=", 
   RowBox[{"reg1", "/", 
    RowBox[{"Norm", "[", "reg1", "]"}]}]}], ";"}]}], "Input",
 CellTags->"b:3.2.4"],

Cell["Share some memory", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.2.4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Share", "[", " ", "]"}], ";"}]], "Input",
 CellTags->"b:3.2.4"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Step 5: Perform the inverse QFT on first register", "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:17", "b:3.2.5"}],

Cell["\<\
We apply the inverse of the quantum Fourier transform to reg1 and check \
normalization:\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.2.5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"time1", "=", 
   RowBox[{"SessionTime", "[", "]"}]}], ";"}]], "Input",
 CellTags->"b:3.2.5"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"QFTVec", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"reg1", "[", 
        RowBox[{"[", 
         RowBox[{"i", "+", "1"}], "]"}], "]"}], "*", 
       RowBox[{"CompIQuantumFourierTransformV", "[", 
        RowBox[{"IntegerDigits", "[", 
         RowBox[{"i", ",", "2", ",", 
          SubscriptBox["n", "1"]}], "]"}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "0", ",", 
        RowBox[{
         RowBox[{"2", "^", 
          SubscriptBox["n", "1"]}], "-", "1"}]}], "}"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"QFTVec", "=", "QFTVec"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Print", " ", "[", 
  RowBox[{
  "\"\<The norm of the inverse fourier transformed vector is: \>\"", ",", 
   RowBox[{"Norm", "[", "QFTVec", "]"}]}], "]"}]}], "Input",
 CellTags->"b:3.2.5"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"time2", "=", 
   RowBox[{"SessionTime", "[", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<The QFT took \>\"", ",", 
   RowBox[{"time2", "-", "time1"}], ",", "\"\< seconds\>\""}], 
  "]"}]}], "Input",
 CellTags->"b:3.2.5"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Step 6: Measure register 1, instead: study all possible results and their \
probabilites\
\>", "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:18", "b:3.2.6"}],

Cell["\<\
We store the possible measurements and their probabilities in variable \
MeasProb:\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.2.6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"MeasProb", "=", 
   RowBox[{"{", " ", "}"}]}], ";"}]], "Input",
 CellTags->"b:3.2.6"],

Cell[BoxData[
 RowBox[{"For", "[", 
  RowBox[{
   RowBox[{"num", "=", "0"}], ",", 
   RowBox[{"num", "<", 
    SuperscriptBox["2", 
     SubscriptBox["n", "1"]]}], ",", 
   RowBox[{
    RowBox[{"\[CapitalOmega]", "=", 
     RowBox[{"Chop", "[", 
      RowBox[{
       RowBox[{"Abs", "[", 
        RowBox[{
         RowBox[{"QFTVec", "[", 
          RowBox[{"[", 
           RowBox[{"num", "+", "1"}], "]"}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], "]"}], "^", "2"}], "]"}]}], ";", 
    RowBox[{"MeasProb", "=", 
     RowBox[{"Append", "[", 
      RowBox[{"MeasProb", ",", 
       RowBox[{"{", 
        RowBox[{"num", ",", "\[CapitalOmega]"}], "}"}]}], "]"}]}], ";", 
    RowBox[{"num", "++"}]}]}], "]"}]], "Input",
 CellTags->"b:3.2.6"],

Cell["\<\
Plots of the possible measurements and their probabilities are quite \
illustrative:\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.2.6"],

Cell[BoxData[{
 RowBox[{"Plot1", "=", 
  RowBox[{"ListPlot", "[", 
   RowBox[{"MeasProb", ",", 
    RowBox[{"Joined", "\[Rule]", "True"}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Measured", " ", "number"}], ",", "Probability"}], "}"}]}], 
    ",", 
    RowBox[{"ImageSize", "\[Rule]", "400"}]}], "]"}]}], "\n", 
 RowBox[{"ListPlot", "[", 
  RowBox[{"MeasProb", ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Measured", " ", "number"}], ",", "Probability"}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0.3`"}], "}"}]}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "400"}]}], "]"}]}], "Input",
 CellTags->"b:3.2.6"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Step 7: Attempt to infer the period r for all possible measurements\
\>", "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:19", "b:3.2.7"}],

Cell[TextData[{
 "Finally we go through all the measurements, compute the periods and check \
the \nfactors we would find and their probabilities. \nSchematically: we \
search for the period using ContinuedFraction, once a possible \nperiod is \
found it checks whether ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["xguess", 
    RowBox[{"r", "/", "2"}]], TraditionalForm]]],
 "is an integer, if so, it computes the two \npossible factors f1 and f2."
}], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.2.7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"r", "=", "0"}], ";"}]], "Input",
 CellTags->"b:3.2.7"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Alldata", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "Period", ",", "Number", ",", "\"\<f1\>\"", ",", "\"\<f2\>\"", ",", 
       "Prob"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<\>\"", ",", "\"\<\>\"", ",", "\"\<\>\"", ",", 
       "\"\<\>\""}], "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"j", "=", "1"}], ",", 
    RowBox[{"j", "\[LessEqual]", 
     RowBox[{"Length", "[", "MeasProb", "]"}]}], ",", 
    RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"i", "=", "2"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"FromContinuedFraction", "[", " ", 
          RowBox[{"ContinuedFraction", "[", 
           RowBox[{
            FractionBox[
             RowBox[{"MeasProb", "[", 
              RowBox[{"[", 
               RowBox[{"j", ",", "1"}], "]"}], "]"}], 
             SuperscriptBox["2", 
              SubscriptBox["n", "1"]]], ",", 
            RowBox[{"i", "-", "1"}]}], "]"}], "]"}], "\[NotEqual]", 
         FractionBox[
          RowBox[{"MeasProb", "[", 
           RowBox[{"[", 
            RowBox[{"j", ",", "1"}], "]"}], "]"}], 
          SuperscriptBox["2", 
           SubscriptBox["n", "1"]]]}], " ", "&&", " ", 
        RowBox[{
         RowBox[{"denomi", "[", 
          RowBox[{"i", ",", 
           RowBox[{"MeasProb", "[", 
            RowBox[{"[", 
             RowBox[{"j", ",", "1"}], "]"}], "]"}]}], "]"}], "<=", 
         RowBox[{"MP", "/", "2"}]}]}], ",", 
       RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
       RowBox[{"r", "=", 
        RowBox[{"denomi", "[", 
         RowBox[{"i", ",", 
          RowBox[{"MeasProb", "[", 
           RowBox[{"[", 
            RowBox[{"j", ",", "1"}], "]"}], "]"}]}], "]"}]}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"IntegerQ", "[", 
        SuperscriptBox["xguess", 
         RowBox[{"r", "/", "2"}]], "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"f1", "=", 
         RowBox[{"GCD", "[", 
          RowBox[{
           RowBox[{
            SuperscriptBox["xguess", 
             RowBox[{"r", "/", "2"}]], " ", "+", "1"}], ",", "MP"}], "]"}]}], 
        " ", ";", "\[IndentingNewLine]", 
        RowBox[{"f2", "=", 
         RowBox[{"GCD", "[", 
          RowBox[{
           RowBox[{
            SuperscriptBox["xguess", 
             RowBox[{"r", "/", "2"}]], "-", "1"}], ",", "MP"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"MeasProb", "[", 
             RowBox[{"[", 
              RowBox[{"j", ",", "2"}], "]"}], "]"}], ">", "0.001"}], "&&", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"f1", ",", "f2"}], "}"}], "\[NotEqual]", " ", 
            RowBox[{"{", 
             RowBox[{"M", ",", "1"}], "}"}]}], "&&", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"f1", ",", "f2"}], "}"}], "\[NotEqual]", 
            RowBox[{"{", 
             RowBox[{"1", ",", "M"}], "}"}]}], "&&", 
           RowBox[{
            RowBox[{"f1", "*", "f2"}], "\[NotEqual]", "1"}], "&&", 
           RowBox[{"f1", "\[NotEqual]", "1"}], "&&", 
           RowBox[{"f2", "\[NotEqual]", "1"}]}], ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Alldata", "=", 
            RowBox[{"Join", "[", 
             RowBox[{"Alldata", ",", 
              RowBox[{"{", 
               RowBox[{"{", 
                RowBox[{"r", ",", 
                 RowBox[{"MeasProb", "[", 
                  RowBox[{"[", 
                   RowBox[{"j", ",", "1"}], "]"}], "]"}], ",", "f1", ",", 
                 "f2", ",", 
                 RowBox[{"MeasProb", "[", 
                  RowBox[{"[", 
                   RowBox[{"j", ",", "2"}], "]"}], "]"}]}], "}"}], "}"}]}], 
             "]"}]}], ";"}], "\[IndentingNewLine]", ",", 
          "\"\<you were quite unlucky in your xguess!\>\""}], "]"}]}]}], 
      "]"}]}]}], "]"}], ";"}]}], "Input",
 CellTags->"b:3.2.7"],

Cell[BoxData[{"Alldata", "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"TotalProbSucc", "=", 
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{"Alldata", "[", 
      RowBox[{"[", 
       RowBox[{"i", ",", "5"}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "3", ",", 
       RowBox[{"Length", "[", "Alldata", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<xguess=\>\"", ",", "xguess"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{
  "\"\<The TOTAL PROBABILITY OF SUCCESS is thus:\>\"", ",", "TotalProbSucc", 
   ",", "\"\<  with xguess=\>\"", ",", "xguess", ",", " ", 
   "\"\< and measured register=\>\"", ",", "reg2Measurement"}], 
  "]"}]}], "Input",
 CellTags->"b:3.2.7"],

Cell[BoxData[
 RowBox[{"SessionTime", "[", "]"}]], "Input",
 CellTags->"b:3.2.7"],

Cell["\<\
In these examples, where we consider small numbers, 21, 35, 15, 33, 55 etc, 
it is possible to plot the function xguess^j and check whether the correct \
period
was found with Shor's Algorithm\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.2.7"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"a", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Mod", "[", 
      RowBox[{
       SuperscriptBox["xguess", "i"], ",", "M"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "60"}], "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"ListPlot", "[", 
  RowBox[{"a", ",", 
   RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}]}], "Input",
 CellTags->"b:3.2.7"],

Cell["Quit", "Input",
 CellTags->"b:3.2.7"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Shor's Factoring algorithm with explict construction of both registers (using \
state vectors)\
\>", "Section",
 FontFamily->"Times",
 CellTags->"c:20"],

Cell[CellGroupData[{

Cell[TextData[{
 "Step 0: Define functions for QFT and Number Theory[check ",
 ButtonBox["QFT.nb ",
  BaseStyle->"Hyperlink",
  ButtonData:>{"QFT.nb", None}],
 "for details]"
}], "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:21", "b:3.3.0"}],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<QDENSITY`Qdensity`\>\"", "]"}]], "Input",
 FontFamily->"Courier New",
 CellTags->"b:3.3.0"],

Cell[BoxData[
 RowBox[{"?", "QDENSITY`Qdensity`*"}]], "Input",
 FontFamily->"Courier New",
 CellTags->"b:3.3.0"],

Cell["\<\
To improve performance we precompile the quantum Fourier transform:\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.3.0"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Zeroff", "[", 
   RowBox[{"vac_", ",", "R_"}], "]"}], ":=", 
  RowBox[{"Sum", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"vac", "[", 
      RowBox[{"[", 
       RowBox[{"R", "[", 
        RowBox[{"[", "i", "]"}], "]"}], "]"}], "]"}], "/", 
     RowBox[{"2", "^", "i"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", 
      RowBox[{"Length", "[", "R", "]"}]}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CompZeroff", " ", "=", " ", 
   RowBox[{"Compile", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"vac", ",", "_Integer", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"R", ",", "_Integer", ",", "1"}], "}"}]}], "}"}], ",", 
     RowBox[{"Zeroff", "[", 
      RowBox[{"vac", ",", "R"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Zeroff", "[", 
         RowBox[{"vac", ",", "R"}], "]"}], ",", "_Real"}], "}"}], "}"}]}], 
    "]"}]}], ";"}]}], "Input",
 CellTags->"b:3.3.0"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"QuantumFourierTransformV", "[", "vac_", "]"}], ":=", 
    "\[IndentingNewLine]", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\[CapitalOmega]", ",", "L"}], "}"}], ",", 
      RowBox[{
       RowBox[{"L", "=", 
        RowBox[{"Length", "[", "vac", "]"}]}], ";", 
       RowBox[{"\[CapitalOmega]", "=", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Ket", "[", "0", "]"}], "+", 
          RowBox[{
           RowBox[{"Exp", "[", 
            RowBox[{"2", "*", "\[Pi]", "*", " ", "\[ImaginaryI]", "*", 
             RowBox[{"CompZeroff", "[", 
              RowBox[{"vac", ",", 
               RowBox[{"Range", "[", 
                RowBox[{"L", ",", "L"}], "]"}]}], "]"}]}], "]"}], "*", 
           RowBox[{"Ket", "[", "1", "]"}]}]}], ")"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"i", "=", "2"}], ",", 
         RowBox[{"i", "\[LessEqual]", "L"}], ",", 
         RowBox[{"i", "++"}], ",", 
         RowBox[{
          RowBox[{"phass", "=", 
           RowBox[{"2", "*", "\[Pi]", "*", " ", "\[ImaginaryI]", "*", 
            RowBox[{"Zeroff", "[", 
             RowBox[{"vac", ",", 
              RowBox[{"Range", "[", 
               RowBox[{
                RowBox[{"L", "-", "i", "+", "1"}], ",", "L"}], "]"}]}], 
             "]"}]}]}], ";", 
          RowBox[{"\[CapitalOmega]", "=", 
           RowBox[{"\[CapitalOmega]", "\[CircleTimes]", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Ket", "[", "0", "]"}], "+", 
              RowBox[{
               RowBox[{"Exp", "[", "phass", "]"}], "*", 
               RowBox[{"Ket", "[", "1", "]"}]}]}], ")"}]}]}]}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"\[CapitalOmega]", "=", 
        RowBox[{"\[CapitalOmega]", "/", 
         RowBox[{"2", "^", 
          RowBox[{"(", 
           RowBox[{"L", "/", "2"}], ")"}]}]}]}], ";", "\[CapitalOmega]"}]}], 
     "]"}]}], ";"}], "  "}]], "Input",
 CellTags->"b:3.3.0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CompQuantumFourierTransformV", "=", 
   RowBox[{"Compile", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"v", ",", "_Integer", ",", "1"}], "}"}], "}"}], ",", " ", 
     RowBox[{"QuantumFourierTransformV", "[", "v", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"{", "   ", 
       RowBox[{
        RowBox[{"QuantumFourierTransformV", "[", "v", "]"}], ",", "_Complex", 
        ",", "2"}], "}"}], "}"}]}], "]"}]}], "  ", ";"}]], "Input",
 CellTags->"b:3.3.0"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"IQuantumFourierTransformV", "[", "vac_", "]"}], ":=", 
    "\[IndentingNewLine]", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\[CapitalOmega]", ",", "L"}], "}"}], ",", 
      RowBox[{
       RowBox[{"L", "=", 
        RowBox[{"Length", "[", "vac", "]"}]}], ";", 
       RowBox[{"\[CapitalOmega]", "=", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Ket", "[", "0", "]"}], "+", 
          RowBox[{
           RowBox[{"Exp", "[", 
            RowBox[{
             RowBox[{"-", "2"}], "*", "\[Pi]", "*", " ", "\[ImaginaryI]", "*", 
             RowBox[{"CompZeroff", "[", 
              RowBox[{"vac", ",", 
               RowBox[{"Range", "[", 
                RowBox[{"L", ",", "L"}], "]"}]}], "]"}]}], "]"}], "*", 
           RowBox[{"Ket", "[", "1", "]"}]}]}], ")"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"i", "=", "2"}], ",", 
         RowBox[{"i", "\[LessEqual]", "L"}], ",", 
         RowBox[{"i", "++"}], ",", 
         RowBox[{
          RowBox[{"phass", "=", 
           RowBox[{
            RowBox[{"-", "2"}], "*", "\[Pi]", "*", " ", "\[ImaginaryI]", "*", 
            RowBox[{"Zeroff", "[", 
             RowBox[{"vac", ",", 
              RowBox[{"Range", "[", 
               RowBox[{
                RowBox[{"L", "-", "i", "+", "1"}], ",", "L"}], "]"}]}], 
             "]"}]}]}], ";", 
          RowBox[{"\[CapitalOmega]", "=", 
           RowBox[{"\[CapitalOmega]", "\[CircleTimes]", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Ket", "[", "0", "]"}], "+", 
              RowBox[{
               RowBox[{"Exp", "[", "phass", "]"}], "*", 
               RowBox[{"Ket", "[", "1", "]"}]}]}], ")"}]}]}]}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"\[CapitalOmega]", "=", 
        RowBox[{"\[CapitalOmega]", "/", 
         RowBox[{"2", "^", 
          RowBox[{"(", 
           RowBox[{"L", "/", "2"}], ")"}]}]}]}], ";", "\[CapitalOmega]"}]}], 
     "]"}]}], ";"}], "  "}]], "Input",
 CellTags->"b:3.3.0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CompIQuantumFourierTransformV", "=", 
   RowBox[{"Compile", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"v", ",", "_Integer", ",", "1"}], "}"}], "}"}], ",", " ", 
     RowBox[{"QuantumFourierTransformV", "[", "v", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"{", "   ", 
       RowBox[{
        RowBox[{"QuantumFourierTransformV", "[", "v", "]"}], ",", "_Complex", 
        ",", "2"}], "}"}], "}"}]}], "]"}]}], "  ", ";"}]], "Input",
 CellTags->"b:3.3.0"],

Cell["\<\
To get the period r which will appear in a quotient of the form s/r we will \
use the continued fraction expansion. 
i is the ith cycle of continued fraction and j is the number measured. \
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.3.0"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"denomi", "[", 
    RowBox[{"i_", ",", "j_"}], "]"}], ":=", 
   RowBox[{"Denominator", "[", 
    RowBox[{"FromContinuedFraction", "[", " ", 
     RowBox[{"ContinuedFraction", "[", 
      RowBox[{
       FractionBox["j", 
        SuperscriptBox["2", 
         SubscriptBox["n", "1"]]], ",", "i"}], "]"}], "]"}], "]"}]}], 
  ";"}]], "Input",
 CellTags->"b:3.3.0"],

Cell["Flag for the case when factoring an even number ", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.3.0"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"Even", "=", "False"}], ";"}]}]], "Input",
 CellTags->"b:3.3.0"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Step 1: Choose the number to be factorized: 15, 21, 33, 35, 39,55,77 and \
determine the computer size required \
\>", "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:22", "b:3.3.1"}],

Cell["M is the number we are trying to factorize:", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.3.1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"M", "=", "35"}], ";"}]], "Input",
 CellTags->"b:3.3.1"],

Cell["MP is the number we will work with and possibly modify:", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.3.1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"MP", "=", "M"}], ";"}]], "Input",
 CellTags->"b:3.3.1"],

Cell["\<\
 We perform a couple of tests to check whether the number is a power of 2 or \
prime and quit if it is:\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.3.1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Mod", "[", 
      RowBox[{"MP", ",", "2"}], "]"}], "\[Equal]", "0"}], ",", 
    RowBox[{
    "Print", "[", "\"\<Your number is a Even, please revise it\>\"", "]"}]}], 
   "]"}], ";"}]], "Input",
 CellTags->"b:3.3.1"],

Cell[BoxData[
 RowBox[{"If", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"PrimeQ", "[", "MP", "]"}], "\[Equal]", "True"}], ",", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"Even", "\[Equal]", "False"}], ",", 
     RowBox[{
      RowBox[{"Print", "[", 
       RowBox[{"M", ",", "\"\< is prime, therefore has no factors\>\""}], 
       "]"}], ";", 
      RowBox[{"Quit", "[", "]"}]}], ",", 
     RowBox[{
      RowBox[{"Print", "[", 
       RowBox[{
       "\"\<The prime factors of \>\"", ",", "M", ",", "\"\< are \>\"", ",", 
        "2", ",", "\"\< and \>\"", ",", "MP"}], "]"}], ";", 
      RowBox[{"Quit", "[", "]"}]}]}], "]"}], ","}], "]"}]], "Input",
 CellTags->"b:3.3.1"],

Cell[BoxData[
 RowBox[{"Q", "=", 
  RowBox[{"2", "^", 
   RowBox[{"Ceiling", "[", 
    RowBox[{"Log", "[", 
     RowBox[{"2", ",", 
      RowBox[{"MP", "^", "2"}]}], "]"}], "]"}]}]}]], "Input",
 CellTags->"b:3.3.1"],

Cell[TextData[{
 " We need the ",
 StyleBox["minimun number",
  FontWeight->"Bold"],
 " of qubits for both registers. Here we should be careful, \na high ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["n", "1"], TraditionalForm]]],
 " number will lengthen the computation, while providing high probability of \
success, \nhowever in many cases it could be more illustrative to lower the \
value of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["n", "1"], TraditionalForm]]],
 " and check the \nresulting probabilities."
}], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.3.1"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   SubscriptBox["n", "1"], "=", 
   RowBox[{"Ceiling", "[", 
    RowBox[{"Log", "[", 
     RowBox[{"2", ",", "Q"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["n", "2"], "=", 
   RowBox[{"Ceiling", "[", 
    RowBox[{"Log", "[", 
     RowBox[{"2", ",", "MP"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["n", "1"], "=", "9"}], "\[IndentingNewLine]", 
 SubscriptBox["n", "2"]}], "Input",
 CellTags->"b:3.3.1"],

Cell["\<\
Gerjuoy's test: a failure to pass this test means we cannot ensure that we \
will 
in fact find the period using the continued fraction expansion [ After \
Eq.(54) of Ref.[2] ]\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.3.1"],

Cell[BoxData[
 RowBox[{"If", " ", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"2", "^", 
     SubscriptBox["n", "1"]}], "<", 
    RowBox[{
     RowBox[{"MP", "^", "2"}], "/", "4"}]}], ",", " ", 
   RowBox[{
   "Print", "[", 
    "\"\<CHECK YOUR \!\(\*SubscriptBox[\(n\), \(1\)]\), YOU MAY HAVE PROBLEMS \
GETTING THE PERIOD\>\"", "]"}], ","}], "]"}]], "Input",
 CellTags->"b:3.3.1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Step 2: Load the first register with the integers less than or equal to ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["2", 
     SubscriptBox["n", "1"]], "-", "1"}], TraditionalForm]]],
 "(a.k.a. Hadamard all qubits in register 1)"
}], "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:23", "b:3.3.2"}],

Cell[TextData[{
 " Register one needs to be set to the following: ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"|", 
       SubscriptBox["\[Psi]", "1"]}], "\[RightAngleBracket]"}], "=", " ", 
     RowBox[{
      RowBox[{
       SuperscriptBox["2", 
        RowBox[{
         RowBox[{"-", 
          SubscriptBox["n", "1"]}], "/", "2"}]], " ", 
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"j", "=", "0"}], 
        RowBox[{
         SuperscriptBox["2", 
          SubscriptBox["n", "1"]], "-", "1"}]]}], " ", "|", "j"}]}], "   ", 
    "\[RightAngleBracket]"}], TraditionalForm]]],
 " ; which is a \nstate where all qubits have been Hadamarded"
}], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.3.2"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   SubscriptBox["\[Psi]", "1"], "=", 
   RowBox[{
    RowBox[{"2", "^", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SubscriptBox["n", "1"]}], "/", "2"}], ")"}]}], "*", 
    RowBox[{"Table", "[", 
     RowBox[{"1", ",", 
      RowBox[{"{", 
       RowBox[{"2", "^", 
        SubscriptBox["n", "1"]}], "}"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Norm", "[", 
  SubscriptBox["\[Psi]", "1"], "]"}]}], "Input",
 CellTags->"b:3.3.2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Step 3: Select an integer (xguess) coprime to M and load ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["f", "j"], "\[Congruent]", " ", 
    RowBox[{
     RowBox[{
      SuperscriptBox["xguess", "j"], 
      RowBox[{"(", 
       RowBox[{"mod", " ", "M"}], ")"}]}], " ", "into", " ", "the", " ", 
     "second", " ", "register"}]}], TraditionalForm]]]
}], "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:24", "b:3.3.3"}],

Cell[" This is the random Coprime to MP used in Shor's Algo ", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.3.3"],

Cell[BoxData[
 RowBox[{"xguess", "=", 
  RowBox[{
   RowBox[{"Select", "[", 
    RowBox[{
     RowBox[{"Range", "[", "MP", "]"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"GCD", "[", 
        RowBox[{"#1", ",", "MP"}], "]"}], "\[Equal]", "1"}], "&"}]}], "]"}], 
   "\[LeftDoubleBracket]", 
   RowBox[{"RandomInteger", "[", 
    RowBox[{"{", 
     RowBox[{"2", ",", 
      RowBox[{"EulerPhi", "[", "MP", "]"}]}], "}"}], "]"}], 
   "\[RightDoubleBracket]"}]}]], "Input",
 CellTags->"b:3.3.3"],

Cell["\<\
The full state composed of register 1 and register 2 is build in the 
following way:\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.3.3"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   SubscriptBox["\[Psi]", "12"], "=", 
   RowBox[{"Table", "[", " ", 
    RowBox[{"0", ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"2", "^", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["n", "1"], "+", 
          SubscriptBox["n", "2"]}], ")"}]}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[Psi]", "12"], "=", 
    RowBox[{"ReplacePart", "[", 
     RowBox[{
      SubscriptBox["\[Psi]", "12"], ",", "1", ",", 
      RowBox[{
       RowBox[{"Mod", "[", 
        RowBox[{
         RowBox[{"xguess", "^", "i"}], ",", "MP"}], "]"}], " ", "+", 
       RowBox[{"i", "*", 
        SuperscriptBox["2", 
         SubscriptBox["n", "2"]]}], "+", "1"}]}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "0", ",", 
     RowBox[{
      SuperscriptBox["2", 
       SubscriptBox["n", "1"]], "-", "1"}]}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["\[Psi]", "12"], "=", 
   RowBox[{
    SubscriptBox["\[Psi]", "12"], "/", 
    RowBox[{"Norm", "[", 
     SubscriptBox["\[Psi]", "12"], "]"}]}]}], ";"}]}], "Input",
 CellTags->"b:3.3.3"],

Cell[BoxData[{
 RowBox[{"ListPlot", "[", 
  SubscriptBox["\[Psi]", "12"], "]"}], "\n", 
 RowBox[{
  RowBox[{"Norm", "[", 
   SubscriptBox["\[Psi]", "12"], "]"}], ";"}]}], "Input",
 CellTags->"b:3.3.3"],

Cell["Therefore the state of the full system is,", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.3.3"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Step 4: Measure the second register", "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:25", "b:3.3.4"}],

Cell["\<\
We perform a measurement on register 2, that can be done in the following \
way. First a random 
possible outcome for register two is generated:\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.3.4"],

Cell[BoxData[
 RowBox[{"reg2Measurement", "=", 
  RowBox[{"Mod", "[", 
   RowBox[{
    SuperscriptBox["xguess", 
     RowBox[{"RandomInteger", "[", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{
         SuperscriptBox["2", 
          SubscriptBox["n", "1"]], "-", "1"}]}], "}"}], "]"}]], ",", "MP"}], 
   "]"}]}]], "Input",
 CellTags->"b:3.3.4"],

Cell[TextData[{
 "Then register 1 will be in the following state, making use of the function ",
 ButtonBox["MeasureKet",
  BaseStyle->"Hyperlink",
  ButtonData:>{"Tutorial.nb", "MeasureKet"}],
 ": "
}], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.3.4"],

Cell[BoxData[{
 RowBox[{"reg2list", "=", 
  RowBox[{"Table", "[", 
   RowBox[{"i", ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", 
      RowBox[{
       SubscriptBox["n", "1"], "+", "1"}], ",", 
      RowBox[{
       SubscriptBox["n", "1"], "+", 
       SubscriptBox["n", "2"]}]}], "}"}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"reg2mes", "=", 
  RowBox[{"IntegerDigits", "[", 
   RowBox[{"reg2Measurement", ",", "2", ",", 
    SubscriptBox["n", "2"]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["\[Psi]", 
    RowBox[{"1", "P"}]], "=", 
   RowBox[{"MeasureKet", "[", 
    RowBox[{
     SubscriptBox["\[Psi]", "12"], ",", "reg2list", ",", "reg2mes"}], "]"}]}],
   ";"}]}], "Input",
 CellTags->"b:3.3.4"],

Cell[BoxData[{
 RowBox[{"Norm", "[", 
  SubscriptBox["\[Psi]", 
   RowBox[{"1", " ", "P"}]], "]"}], "\n", 
 RowBox[{"ListPlot", "[", 
  SubscriptBox["\[Psi]", 
   RowBox[{"1", " ", "P"}]], "]"}]}], "Input",
 CellTags->"b:3.3.4"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Step 5: Quantum Fourier Transform register 1", "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:26", "b:3.3.5"}],

Cell[TextData[{
 "We apply the inverse of the quantum Fourier transform to ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Psi]", 
    RowBox[{"1", "P"}]], TraditionalForm]]],
 ":"
}], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.3.5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"time1", "=", 
   RowBox[{"SessionTime", "[", "]"}]}], ";"}]], "Input",
 CellTags->"b:3.3.5"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"QFTVec", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        SubscriptBox["\[Psi]", 
         RowBox[{"1", "P"}]], "[", 
        RowBox[{"[", 
         RowBox[{"i", "+", "1"}], "]"}], "]"}], "*", 
       RowBox[{"CompIQuantumFourierTransformV", "[", 
        RowBox[{"IntegerDigits", "[", 
         RowBox[{"i", ",", "2", ",", 
          SubscriptBox["n", "1"]}], "]"}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "0", ",", 
        RowBox[{
         SuperscriptBox["2", 
          SubscriptBox["n", "1"]], "-", "1"}]}], "}"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"QFTVec", "=", 
   RowBox[{"QFTVec", "/", 
    RowBox[{"Norm", "[", "QFTVec", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Norm", "[", "QFTVec", "]"}]}], "Input",
 CellTags->"b:3.3.5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"time2", "=", 
   RowBox[{"SessionTime", "[", "]"}]}], ";"}]], "Input",
 CellTags->"b:3.3.5"],

Cell[BoxData[
 RowBox[{"Print", "[", 
  RowBox[{"\"\<The QFT took \>\"", ",", 
   RowBox[{"time2", "-", "time1"}], ",", "\"\< Seconds\>\""}], "]"}]], "Input",
 CellTags->"b:3.3.5"],

Cell["\<\
We store the possible measurements and their probabilities in MeasProb:\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.3.5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"MeasProb", "=", 
   RowBox[{"{", " ", "}"}]}], ";"}]], "Input",
 CellTags->"b:3.3.5"],

Cell[BoxData[
 RowBox[{"For", "[", 
  RowBox[{
   RowBox[{"num", "=", "0"}], ",", 
   RowBox[{"num", "<", 
    SuperscriptBox["2", 
     SubscriptBox["n", "1"]]}], ",", 
   RowBox[{
    RowBox[{"\[CapitalOmega]", "=", 
     RowBox[{"Chop", "[", 
      RowBox[{
       RowBox[{"Abs", "[", 
        RowBox[{
         RowBox[{"QFTVec", "[", 
          RowBox[{"[", 
           RowBox[{"num", "+", "1"}], "]"}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], "]"}], "^", "2"}], "]"}]}], ";", 
    RowBox[{"MeasProb", "=", 
     RowBox[{"Append", "[", 
      RowBox[{"MeasProb", ",", 
       RowBox[{"{", 
        RowBox[{"num", ",", "\[CapitalOmega]"}], "}"}]}], "]"}]}], ";", 
    RowBox[{"num", "++"}]}]}], "]"}]], "Input",
 CellTags->"b:3.3.5"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Normali", "=", "0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{"Normali", "=", 
     RowBox[{"Normali", "+", 
      RowBox[{"MeasProb", "[", 
       RowBox[{"[", 
        RowBox[{"i", ",", "2"}], "]"}], "]"}]}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", 
      RowBox[{"Length", "[", "MeasProb", "]"}]}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", "Normali"}], "Input",
 CellTags->"b:3.3.5"],

Cell[BoxData[{
 RowBox[{"Plot1", "=", 
  RowBox[{"ListPlot", "[", 
   RowBox[{"MeasProb", ",", 
    RowBox[{"Joined", "\[Rule]", "True"}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Meassured", " ", "number"}], ",", "Probability"}], "}"}]}], 
    ",", 
    RowBox[{"ImageSize", "\[Rule]", "400"}]}], "]"}]}], "\n", 
 RowBox[{"ListPlot", "[", 
  RowBox[{"MeasProb", ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Meassured", " ", "number"}], ",", "Probability"}], "}"}]}], 
   ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0.12`"}], "}"}]}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "400"}]}], "]"}]}], "Input",
 CellTags->"b:3.3.5"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Step 6: Measure register 1, instead, we study all posible measurements and \
their probabilities\
\>", "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:27", "b:3.3.6"}],

Cell["\<\
Finally,  we go through all the measurements, compute the periods and check \
the 
factors we would find and their probabilities:\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.3.6"],

Cell[BoxData["xguess"], "Input",
 CellTags->"b:3.3.6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"r", "=", "0"}], ";"}]], "Input",
 CellTags->"b:3.3.6"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Alldata", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "Period", ",", "Number", ",", "\"\<f1\>\"", ",", "\"\<f2\>\"", ",", 
       "Prob"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<\>\"", ",", "\"\<\>\"", ",", "\"\<\>\"", ",", 
       "\"\<\>\""}], "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"j", "=", "1"}], ",", 
    RowBox[{"j", "\[LessEqual]", 
     RowBox[{"Length", "[", "MeasProb", "]"}]}], ",", 
    RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"i", "=", "2"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"FromContinuedFraction", "[", " ", 
          RowBox[{"ContinuedFraction", "[", 
           RowBox[{
            FractionBox[
             RowBox[{"MeasProb", "[", 
              RowBox[{"[", 
               RowBox[{"j", ",", "1"}], "]"}], "]"}], 
             SuperscriptBox["2", 
              SubscriptBox["n", "1"]]], ",", 
            RowBox[{"i", "-", "1"}]}], "]"}], "]"}], "\[NotEqual]", 
         FractionBox[
          RowBox[{"MeasProb", "[", 
           RowBox[{"[", 
            RowBox[{"j", ",", "1"}], "]"}], "]"}], 
          SuperscriptBox["2", 
           SubscriptBox["n", "1"]]]}], " ", "&&", " ", 
        RowBox[{
         RowBox[{"denomi", "[", 
          RowBox[{"i", ",", 
           RowBox[{"MeasProb", "[", 
            RowBox[{"[", 
             RowBox[{"j", ",", "1"}], "]"}], "]"}]}], "]"}], "<=", 
         RowBox[{"MP", "/", "2"}]}]}], ",", 
       RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
       RowBox[{"r", "=", 
        RowBox[{"denomi", "[", 
         RowBox[{"i", ",", 
          RowBox[{"MeasProb", "[", 
           RowBox[{"[", 
            RowBox[{"j", ",", "1"}], "]"}], "]"}]}], "]"}]}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"IntegerQ", "[", 
        SuperscriptBox["xguess", 
         RowBox[{"r", "/", "2"}]], "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"f1", "=", 
         RowBox[{"GCD", "[", 
          RowBox[{
           RowBox[{
            SuperscriptBox["xguess", 
             RowBox[{"r", "/", "2"}]], " ", "+", "1"}], ",", "MP"}], "]"}]}], 
        " ", ";", "\[IndentingNewLine]", 
        RowBox[{"f2", "=", 
         RowBox[{"GCD", "[", 
          RowBox[{
           RowBox[{
            SuperscriptBox["xguess", 
             RowBox[{"r", "/", "2"}]], "-", "1"}], ",", "MP"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"MeasProb", "[", 
             RowBox[{"[", 
              RowBox[{"j", ",", "2"}], "]"}], "]"}], ">", "0.001"}], "&&", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"f1", ",", "f2"}], "}"}], "\[NotEqual]", " ", 
            RowBox[{"{", 
             RowBox[{"M", ",", "1"}], "}"}]}], "&&", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"f1", ",", "f2"}], "}"}], "\[NotEqual]", 
            RowBox[{"{", 
             RowBox[{"1", ",", "M"}], "}"}]}], "&&", 
           RowBox[{
            RowBox[{"f1", "*", "f2"}], "\[NotEqual]", "1"}], "&&", 
           RowBox[{"f1", "\[NotEqual]", "1"}], "&&", 
           RowBox[{"f2", "\[NotEqual]", "1"}]}], ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Alldata", "=", 
            RowBox[{"Join", "[", 
             RowBox[{"Alldata", ",", 
              RowBox[{"{", 
               RowBox[{"{", 
                RowBox[{"r", ",", 
                 RowBox[{"MeasProb", "[", 
                  RowBox[{"[", 
                   RowBox[{"j", ",", "1"}], "]"}], "]"}], ",", "f1", ",", 
                 "f2", ",", 
                 RowBox[{"MeasProb", "[", 
                  RowBox[{"[", 
                   RowBox[{"j", ",", "2"}], "]"}], "]"}]}], "}"}], "}"}]}], 
             "]"}]}], ";"}], "\[IndentingNewLine]", ",", 
          "\"\<you were quite unlucky in your xguess!\>\""}], "]"}]}]}], 
      "]"}]}]}], "]"}], ";"}]}], "Input",
 CellTags->"b:3.3.6"],

Cell[BoxData[{"Alldata", "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"TotalProbSucc", "=", 
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{"Alldata", "[", 
      RowBox[{"[", 
       RowBox[{"i", ",", "5"}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "3", ",", 
       RowBox[{"Length", "[", "Alldata", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{
  "\"\<The TOTAL PROBABILITY OF SUCCESS is thus:\>\"", ",", "TotalProbSucc", 
   ",", "\"\<  with xguess=\>\"", ",", "xguess", ",", " ", 
   "\"\< and measured register=\>\"", ",", "reg2Measurement"}], 
  "]"}]}], "Input",
 CellTags->"b:3.3.6"],

Cell[BoxData[
 RowBox[{"SessionTime", "[", "]"}]], "Input",
 CellTags->"b:3.3.6"],

Cell[BoxData["Quit"], "Input",
 CellTags->"b:3.3.6"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Shor's Factoring algorithm using ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " DFT formula"
}], "Section",
 FontFamily->"Times",
 CellTags->"c:28"],

Cell[CellGroupData[{

Cell["\<\
Step 0: Preliminars: Define functions for QFT [check QFT.nb ] and NumberTheory\
\>", "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:29", "b:3.4.0"}],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<QDENSITY`Qdensity`\>\"", "]"}]], "Input",
 FontFamily->"Courier New",
 CellTags->"b:3.4.0"],

Cell[BoxData[
 RowBox[{"?", "QDENSITY`Qdensity`*"}]], "Input",
 FontFamily->"Courier New",
 CellTags->"b:3.4.0"],

Cell["\<\
In this notebook we make use of the Discrete Fourier Transform already \
present in Mathematica.\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.4.0"],

Cell["\<\
To get the period r which will appear in a quotient of the form s/r we will \
use the 
continued fraction. i is the ith cycle of continued fraction and j is the \
number measured. \
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.4.0"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"denomi", "[", 
    RowBox[{"i_", ",", "j_"}], "]"}], ":=", 
   RowBox[{"Denominator", "[", 
    RowBox[{"FromContinuedFraction", "[", " ", 
     RowBox[{"ContinuedFraction", "[", 
      RowBox[{
       FractionBox["j", 
        SuperscriptBox["2", 
         SubscriptBox["n", "1"]]], ",", "i"}], "]"}], "]"}], "]"}]}], 
  ";"}]], "Input",
 CellTags->"b:3.4.0"],

Cell["Flag for the case when factoring an even number ", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.4.0"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"Even", "=", "False"}], ";"}]}]], "Input",
 CellTags->"b:3.4.0"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Step 1: Choose the number to be factorized: 15, 21, 33, 35, 39, 55, 77 and \
determine size of registers\
\>", "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:30", "b:3.4.1"}],

Cell["M is the number we are trying to factor:", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.4.1"],

Cell[BoxData[
 RowBox[{"M", "=", 
  RowBox[{"11", "*", "7"}]}]], "Input",
 CellTags->"b:3.4.1"],

Cell["MP is the number we will work with and possibly modify:", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.4.1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"MP", "=", "M"}], ";"}]], "Input",
 CellTags->"b:3.4.1"],

Cell["\<\
 We perform a couple of tests to check whether the number is a power of 2 or \
prime:\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.4.1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"While", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Mod", "[", 
      RowBox[{"MP", ",", "2"}], "]"}], "\[Equal]", "0"}], ",", 
    RowBox[{
     RowBox[{"Even", "=", "True"}], ";", 
     RowBox[{"MP", "=", 
      RowBox[{"MP", "/", "2"}]}]}]}], "]"}], ";"}]], "Input",
 CellTags->"b:3.4.1"],

Cell[BoxData[
 RowBox[{"If", "[", 
  RowBox[{
   RowBox[{"MP", "\[Equal]", "1"}], ",", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"M", ",", " ", "\"\< is a power of 2\>\""}], "]"}], ";", 
    RowBox[{"Quit", "[", "]"}]}], ","}], "]"}]], "Input",
 CellTags->"b:3.4.1"],

Cell[BoxData[
 RowBox[{"If", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"PrimeQ", "[", "MP", "]"}], "\[Equal]", "True"}], ",", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"Even", "\[Equal]", "False"}], ",", 
     RowBox[{
      RowBox[{"Print", "[", 
       RowBox[{"M", ",", "\"\< is prime, therefore has no factors\>\""}], 
       "]"}], ";", 
      RowBox[{"Quit", "[", "]"}]}], ",", 
     RowBox[{
      RowBox[{"Print", "[", 
       RowBox[{
       "\"\<The prime factors of \>\"", ",", "M", ",", "\"\< are \>\"", ",", 
        "2", ",", "\"\< and \>\"", ",", "MP"}], "]"}], ";", 
      RowBox[{"Quit", "[", "]"}]}]}], "]"}], ","}], "]"}]], "Input",
 CellTags->"b:3.4.1"],

Cell[TextData[{
 " We need the ",
 StyleBox["minimun number",
  FontWeight->"Bold"],
 " of qubits for both registers. \nHere we should be careful, a high ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["n", "1"], TraditionalForm]]],
 " number will lengthen the computation.  \nBy default we give estimates for ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["n", "1"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["n", "2"], TraditionalForm]]],
 ",based on the fact that ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["n", "1"], TraditionalForm]]],
 " should be able to \nrepresent numbers up to M^2, while ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["n", "2"], TraditionalForm]]],
 "should allow to write up to M/2. However in \nmany cases it could be more \
illustrative to lower the value of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["n", "1"], TraditionalForm]]],
 " \n[ ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["n", "2"], TraditionalForm]]],
 "is not relevant for the code's performance] and check the resulting \
probabilities."
}], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.4.1"],

Cell[BoxData[
 RowBox[{"Q", "=", 
  RowBox[{"2", "^", 
   RowBox[{"Ceiling", "[", 
    RowBox[{"Log", "[", 
     RowBox[{"2", ",", 
      RowBox[{"MP", "^", "2"}]}], "]"}], "]"}]}]}]], "Input",
 CellTags->"b:3.4.1"],

Cell[BoxData[{
 RowBox[{
  SubscriptBox["n", "1"], "=", 
  RowBox[{"Ceiling", "[", 
   RowBox[{"Log", "[", 
    RowBox[{"2", ",", "Q"}], "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["n", "2"], "=", 
  RowBox[{"Ceiling", "[", 
   RowBox[{"Log", "[", 
    RowBox[{"2", ",", "MP"}], "]"}], "]"}]}], "\[IndentingNewLine]", 
 SubscriptBox["n", 
  RowBox[{"1", " "}]], "\[IndentingNewLine]", 
 SubscriptBox["n", "2"]}], "Input",
 CellTags->"b:3.4.1"],

Cell["\<\
Gerjuoy's test: a failure to pass this test means we cannot ensure that we \
will 
in fact find the period using the continued fraction expansion [ After \
Eq.(54) of Ref.[2] ]\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.4.1"],

Cell[BoxData[
 RowBox[{"If", " ", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"2", "^", 
     SubscriptBox["n", "1"]}], "<", 
    RowBox[{
     RowBox[{"MP", "^", "2"}], "/", "4"}]}], ",", " ", 
   RowBox[{
   "Print", "[", 
    "\"\<CHECK YOUR \!\(\*SubscriptBox[\(n\), \(1\)]\), YOU MAY HAVE PROBLEMS \
GETTING THE PERIOD\>\"", "]"}], ","}], "]"}]], "Input",
 CellTags->"b:3.4.1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Step 2: Load the first register with the integers less than or equal to ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["2", 
     SubscriptBox["n", "1"]], "-", "1"}], TraditionalForm]]],
 "(a.k.a. Hadamard all qubits in register 1)"
}], "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:31", "b:3.4.2"}],

Cell[TextData[{
 " Register one needs to be set to the following: ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"|", 
       SubscriptBox["\[Psi]", "1"]}], "\[RightAngleBracket]"}], "=", " ", 
     RowBox[{
      RowBox[{
       SuperscriptBox["2", 
        RowBox[{
         RowBox[{"-", 
          SubscriptBox["n", "1"]}], "/", "2"}]], " ", 
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"j", "=", "0"}], 
        RowBox[{
         SuperscriptBox["2", 
          SubscriptBox["n", "1"]], "-", "1"}]]}], " ", "|", "j"}]}], "   ", 
    "\[RightAngleBracket]"}], TraditionalForm]]],
 " ; which is a \nstate where all ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["n", "1"], TraditionalForm]]],
 " qubits have been Hadamarded.\nIn this computer simulation we will not \
explicty construct it.  "
}], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.4.2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Step 3: Select an integer (xguess) coprime to M and load ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["f", "j"], "\[Congruent]", " ", 
    RowBox[{
     RowBox[{
      SuperscriptBox["xguess", "j"], 
      RowBox[{"(", 
       RowBox[{"mod", " ", "M"}], ")"}]}], " ", "into", " ", "the", " ", 
     "second", " ", "register"}]}], TraditionalForm]]]
}], "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:32", "b:3.4.3"}],

Cell[" This is the random Coprime to MP: ", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.4.3"],

Cell[BoxData[
 RowBox[{"xguess", "=", 
  RowBox[{
   RowBox[{"Select", "[", 
    RowBox[{
     RowBox[{"Range", "[", "MP", "]"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"GCD", "[", 
        RowBox[{"#1", ",", "MP"}], "]"}], "\[Equal]", "1"}], "&"}]}], "]"}], 
   "\[LeftDoubleBracket]", 
   RowBox[{"RandomInteger", "[", 
    RowBox[{"{", 
     RowBox[{"2", ",", 
      RowBox[{"EulerPhi", "[", "MP", "]"}]}], "}"}], "]"}], 
   "\[RightDoubleBracket]"}]}]], "Input",
 CellTags->"b:3.4.3"],

Cell[TextData[{
 " The full wave function after we build the second register with  ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "j"], TraditionalForm]]],
 "reads:\n ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"|", 
         SubscriptBox["\[Psi]", "12"]}], "\[RightAngleBracket]"}], "=", " ", 
       RowBox[{
        RowBox[{
         SuperscriptBox["2", 
          RowBox[{
           RowBox[{"-", 
            SubscriptBox["n", "1"]}], "/", "2"}]], " ", 
         UnderoverscriptBox["\[Sum]", 
          RowBox[{"j", "=", "0"}], 
          RowBox[{
           SuperscriptBox["2", 
            SubscriptBox["n", "1"]], "-", "1"}]]}], " ", "|", "j"}]}], "   ", 
      "\[RightAngleBracket]"}], "|", 
     SubscriptBox["f", "j"]}], "  ", "\[RightAngleBracket]"}], 
   TraditionalForm]]],
 ", with ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["f", "j"], "\[Congruent]", " ", 
    RowBox[{
     SuperscriptBox["xguess", "j"], 
     RowBox[{"(", 
      RowBox[{"mod", " ", "M"}], ")"}]}]}], TraditionalForm]]]
}], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.4.3"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Step 4: Now we measure the state of the second register", "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:33", "b:3.4.4"}],

Cell[TextData[{
 "We take an hypotetical measurement of the second register: (NOTE that by \
construction the \nmeasured value must be one fo the ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "j"], TraditionalForm]]],
 "]"
}], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.4.4"],

Cell[BoxData[
 RowBox[{"reg2Measurement", "=", 
  RowBox[{"Mod", "[", 
   RowBox[{
    SuperscriptBox["xguess", 
     RowBox[{"RandomInteger", "[", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{
         SuperscriptBox["2", 
          SubscriptBox["n", "1"]], "-", "1"}]}], "}"}], "]"}]], ",", "MP"}], 
   "]"}]}]], "Input",
 CellTags->"b:3.4.4"],

Cell[BoxData[{
 SuperscriptBox["2", 
  SubscriptBox["n", "1"]], "\[IndentingNewLine]", 
 SuperscriptBox["2", 
  SubscriptBox["n", "2"]], "\[IndentingNewLine]", 
 SuperscriptBox["2", 
  RowBox[{"(", 
   RowBox[{
    SubscriptBox["n", "1"], "+", 
    SubscriptBox["n", "2"]}], ")"}]]}], "Input",
 CellTags->"b:3.4.4"],

Cell[TextData[{
 "The next function gives the number in the ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["n", "1"], TraditionalForm]]],
 "register in decimal basis from a given number i in the ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FormBox[
     SubscriptBox["n", "1"],
     TraditionalForm], "+", 
    SubscriptBox["n", "2"]}], TraditionalForm]]],
 " bases."
}], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.4.4"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"xv", "[", "i_", "]"}], ":=", 
   RowBox[{"FromDigits", "[", 
    RowBox[{
     RowBox[{"Take", "[", 
      RowBox[{
       RowBox[{"IntegerDigits", "[", 
        RowBox[{"i", ",", "2", ",", 
         RowBox[{
          SubscriptBox["n", "1"], "+", 
          SubscriptBox["n", "2"]}]}], "]"}], ",", 
       SubscriptBox["n", "1"]}], "]"}], ",", "2"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Compxv", "=", 
   RowBox[{"Compile", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"i", ",", "_Integer", ",", "0"}], "}"}], "}"}], ",", 
     RowBox[{"xv", "[", "i", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"xv", "[", "i", "]"}], ",", "_Integer", ",", "0"}], "}"}], 
      "}"}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{3.395094492673421*^9},
 CellTags->"b:3.4.4"],

Cell[TextData[{
 "We select the positions in the ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["n", "1"], "+", 
    SubscriptBox["n", "2"]}], TraditionalForm]]],
 "register which remain when reg2 has been measured:"
}], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.4.4"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dens1", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Do", "[", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Mod", "[", 
          RowBox[{
           RowBox[{"xguess", "^", 
            RowBox[{"xv", "[", "i", "]"}]}], ",", "MP"}], "]"}], "\[Equal]", 
         "reg2Measurement"}], ",", " ", 
        RowBox[{"dens1", "=", 
         RowBox[{"Join", "[", " ", 
          RowBox[{"dens1", ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"xv", "[", "i", "]"}], "+", "1"}], " ", "}"}]}], "]"}]}],
         ",", "\"\<\>\""}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "0", ",", 
        RowBox[{
         SuperscriptBox["2", 
          RowBox[{"(", 
           RowBox[{
            SubscriptBox["n", "1"], "+", 
            SubscriptBox["n", "2"]}], ")"}]], "-", "1"}], ",", 
        SuperscriptBox["2", 
         SubscriptBox["n", "2"]]}], " ", "}"}]}], "]"}], ";"}], " ", "*)"}], 
  RowBox[{
   RowBox[{"Do", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"xx", "=", 
       RowBox[{"Compxv", "[", 
        RowBox[{"i", "*", 
         SuperscriptBox["2", 
          SubscriptBox["n", "2"]]}], "]"}]}], ";", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Mod", "[", 
          RowBox[{
           RowBox[{"xguess", "^", "xx"}], ",", "MP"}], "]"}], "\[Equal]", 
         "reg2Measurement"}], ",", " ", 
        RowBox[{"dens1", "=", 
         RowBox[{"Join", "[", " ", 
          RowBox[{"dens1", ",", 
           RowBox[{"{", 
            RowBox[{"xx", "+", "1"}], " ", "}"}]}], "]"}]}], ",", 
        "\"\<\>\""}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", 
       RowBox[{
        SuperscriptBox["2", 
         SubscriptBox["n", "1"]], "-", "1"}]}], " ", "}"}]}], "]"}], 
   ";"}]}]}], "Input",
 CellTags->"b:3.4.4"],

Cell["\<\
And then after the measurement reg1 is in the following state:\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.4.4"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"reg1", "=", 
   RowBox[{"Table", "[", " ", 
    RowBox[{"0", ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"2", "^", 
        SubscriptBox["n", "1"]}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{"reg1", "=", 
    RowBox[{"ReplacePart", "[", 
     RowBox[{"reg1", ",", "1", ",", 
      RowBox[{"dens1", "[", 
       RowBox[{"[", "i", "]"}], "]"}]}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "1", ",", 
     RowBox[{"Length", "[", "dens1", "]"}]}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"reg1", "=", 
   RowBox[{"reg1", "/", 
    RowBox[{"Norm", "[", "reg1", "]"}]}]}], ";"}]}], "Input",
 CellTags->"b:3.4.4"],

Cell[BoxData[
 RowBox[{"Share", "[", " ", "]"}]], "Input",
 CellTags->"b:3.4.4"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Step 5: Perform the inverse QFT on first register", "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:34", "b:3.4.5"}],

Cell["\<\
We apply the inverse of the quantum Fourier transform to reg1 and check \
normalization:\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.4.5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"time1", "=", 
   RowBox[{"SessionTime", "[", "]"}]}], ";"}]], "Input",
 CellTags->"b:3.4.5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"QFTVec", "=", 
   RowBox[{"Fourier", "[", "reg1", "]"}]}], ";"}]], "Input",
 CellTags->"b:3.4.5"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"time2", "=", 
   RowBox[{"SessionTime", "[", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<The QFT took \>\"", ",", 
   RowBox[{"time2", "-", "time1"}], ",", "\"\< seconds\>\""}], 
  "]"}]}], "Input",
 CellTags->"b:3.4.5"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Step 6: Measure register 1, instead: study all possible results and their \
probabilites\
\>", "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:35", "b:3.4.6"}],

Cell["\<\
We store the possible measurements and their probabilities in variable \
MeasProb:\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.4.6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"MeasProb", "=", 
   RowBox[{"{", " ", "}"}]}], ";"}]], "Input",
 CellTags->"b:3.4.6"],

Cell[BoxData[
 RowBox[{"For", "[", 
  RowBox[{
   RowBox[{"num", "=", "0"}], ",", 
   RowBox[{"num", "<", 
    SuperscriptBox["2", 
     SubscriptBox["n", "1"]]}], ",", 
   RowBox[{
    RowBox[{"\[CapitalOmega]", "=", 
     RowBox[{"Chop", "[", 
      RowBox[{
       RowBox[{"Abs", "[", 
        RowBox[{"QFTVec", "[", 
         RowBox[{"[", 
          RowBox[{"num", "+", "1"}], "]"}], "]"}], "]"}], "^", "2"}], "]"}]}],
     ";", 
    RowBox[{"MeasProb", "=", 
     RowBox[{"Append", "[", 
      RowBox[{"MeasProb", ",", 
       RowBox[{"{", 
        RowBox[{"num", ",", "\[CapitalOmega]"}], "}"}]}], "]"}]}], ";", 
    RowBox[{"num", "++"}]}]}], "]"}]], "Input",
 CellTags->"b:3.4.6"],

Cell["\<\
Plots of the possible measurements and their probabilities are quite \
illustrative:\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.4.6"],

Cell[BoxData[{
 RowBox[{"Plot1", "=", 
  RowBox[{"ListPlot", "[", 
   RowBox[{"MeasProb", ",", 
    RowBox[{"Joined", "\[Rule]", "True"}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Measured", " ", "number"}], ",", "Probability"}], "}"}]}], 
    ",", 
    RowBox[{"ImageSize", "\[Rule]", "400"}]}], "]"}]}], "\n", 
 RowBox[{"ListPlot", "[", 
  RowBox[{"MeasProb", ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Measured", " ", "number"}], ",", "Probability"}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0.3`"}], "}"}]}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "400"}]}], "]"}]}], "Input",
 CellTags->"b:3.4.6"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Step 7: Attempt to infer the period r for all possible measurements\
\>", "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:36", "b:3.4.7"}],

Cell[TextData[{
 "Finally,  we go through all the measurements, compute the periods and check \
the \nfactors we would find and their probabilities. \nSchematically: we \
search for the period using ContinuedFraction, once a possible \nperiod is \
found it checks whether ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["xguess", 
    RowBox[{"r", "/", "2"}]], TraditionalForm]]],
 "is an integer, if so, it computes the two \npossible factors f1 and f2."
}], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.4.7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"r", "=", "0"}], ";"}]], "Input",
 CellTags->"b:3.4.7"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Alldata", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "Period", ",", "Number", ",", "\"\<f1\>\"", ",", "\"\<f2\>\"", ",", 
       "Prob"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\>\"", ",", "\"\<\>\"", ",", "\"\<\>\"", ",", "\"\<\>\"", ",", 
       "\"\<\>\""}], "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"j", "=", "1"}], ",", 
    RowBox[{"j", "\[LessEqual]", 
     RowBox[{"Length", "[", "MeasProb", "]"}]}], ",", 
    RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"i", "=", "2"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"FromContinuedFraction", "[", " ", 
          RowBox[{"ContinuedFraction", "[", 
           RowBox[{
            FractionBox[
             RowBox[{"MeasProb", "[", 
              RowBox[{"[", 
               RowBox[{"j", ",", "1"}], "]"}], "]"}], 
             SuperscriptBox["2", 
              SubscriptBox["n", "1"]]], ",", 
            RowBox[{"i", "-", "1"}]}], "]"}], "]"}], "\[NotEqual]", 
         FractionBox[
          RowBox[{"MeasProb", "[", 
           RowBox[{"[", 
            RowBox[{"j", ",", "1"}], "]"}], "]"}], 
          SuperscriptBox["2", 
           SubscriptBox["n", "1"]]]}], " ", "&&", " ", 
        RowBox[{
         RowBox[{"denomi", "[", 
          RowBox[{"i", ",", 
           RowBox[{"MeasProb", "[", 
            RowBox[{"[", 
             RowBox[{"j", ",", "1"}], "]"}], "]"}]}], "]"}], "<=", 
         RowBox[{"MP", "/", "2"}]}]}], ",", 
       RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
       RowBox[{"r", "=", 
        RowBox[{"denomi", "[", 
         RowBox[{"i", ",", 
          RowBox[{"MeasProb", "[", 
           RowBox[{"[", 
            RowBox[{"j", ",", "1"}], "]"}], "]"}]}], "]"}]}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"IntegerQ", "[", 
        SuperscriptBox["xguess", 
         RowBox[{"r", "/", "2"}]], "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"f1", "=", 
         RowBox[{"GCD", "[", 
          RowBox[{
           RowBox[{
            SuperscriptBox["xguess", 
             RowBox[{"r", "/", "2"}]], " ", "+", "1"}], ",", "MP"}], "]"}]}], 
        " ", ";", "\[IndentingNewLine]", 
        RowBox[{"f2", "=", 
         RowBox[{"GCD", "[", 
          RowBox[{
           RowBox[{
            SuperscriptBox["xguess", 
             RowBox[{"r", "/", "2"}]], "-", "1"}], ",", "MP"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"MeasProb", "[", 
             RowBox[{"[", 
              RowBox[{"j", ",", "2"}], "]"}], "]"}], ">", "0.001"}], "&&", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"f1", ",", "f2"}], "}"}], "\[NotEqual]", " ", 
            RowBox[{"{", 
             RowBox[{"M", ",", "1"}], "}"}]}], "&&", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"f1", ",", "f2"}], "}"}], "\[NotEqual]", 
            RowBox[{"{", 
             RowBox[{"1", ",", "M"}], "}"}]}], "&&", 
           RowBox[{
            RowBox[{"f1", "*", "f2"}], "\[NotEqual]", "1"}], "&&", 
           RowBox[{"f1", "\[NotEqual]", "1"}], "&&", 
           RowBox[{"f2", "\[NotEqual]", "1"}]}], ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Alldata", "=", 
            RowBox[{"Join", "[", 
             RowBox[{"Alldata", ",", 
              RowBox[{"{", 
               RowBox[{"{", 
                RowBox[{"r", ",", 
                 RowBox[{"MeasProb", "[", 
                  RowBox[{"[", 
                   RowBox[{"j", ",", "1"}], "]"}], "]"}], ",", "f1", ",", 
                 "f2", ",", 
                 RowBox[{"MeasProb", "[", 
                  RowBox[{"[", 
                   RowBox[{"j", ",", "2"}], "]"}], "]"}]}], "}"}], "}"}]}], 
             "]"}]}], ";"}], "\[IndentingNewLine]", ",", 
          "\"\<you were quite unlucky in your xguess!\>\""}], "]"}]}]}], 
      "]"}]}]}], "]"}], ";"}]}], "Input",
 CellTags->"b:3.4.7"],

Cell[BoxData[{"Alldata", "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"TotalProbSucc", "=", 
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{"Alldata", "[", 
      RowBox[{"[", 
       RowBox[{"i", ",", "5"}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "3", ",", 
       RowBox[{"Length", "[", "Alldata", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<xguess=\>\"", ",", "xguess"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{
  "\"\<The TOTAL PROBABILITY OF SUCCESS is thus:\>\"", ",", "TotalProbSucc", 
   ",", "\"\<  with xguess=\>\"", ",", "xguess", ",", " ", 
   "\"\< and measured register=\>\"", ",", "reg2Measurement"}], 
  "]"}]}], "Input",
 CellTags->"b:3.4.7"],

Cell[BoxData[
 RowBox[{"SessionTime", "[", "]"}]], "Input",
 CellTags->"b:3.4.7"],

Cell["\<\
In these examples, where we consider small numbers, 21, 35, 15, 33, 55 etc, 
it is possible to plot the function xguess^j and check whether the correct \
period
was found with Shor's Algorithm\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:3.4.7"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"a", "=", 
   RowBox[{"Table", "[", " ", 
    RowBox[{
     RowBox[{"Mod", "[", 
      RowBox[{
       RowBox[{"xguess", "^", "i"}], ",", "M"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "60"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"ListPlot", "[", 
  RowBox[{"a", ",", 
   RowBox[{"PlotJoined", "\[Rule]", "True"}]}], "]"}]}], "Input",
 CellTags->"b:3.4.7"],

Cell["Quit", "Input",
 CellTags->"b:3.4.7"]
}, Open  ]]
}, Closed]]
},
WindowToolbars->{},
WindowSize->{892, 606},
WindowMargins->{{337, Automatic}, {Automatic, 90}},
PrintingCopies->1,
PrintingStartingPageNumber->53,
PrintingPageRange->{1, Automatic},
PrintingOptions->{"Magnification"->1,
"PaperOrientation"->"Portrait",
"PaperSize"->{612, 792},
"PostScriptOutputFile":>FrontEnd`FileName[{
  "export", "home", "brunojd", "PITT", "QC", "QdensityPK"}, "35_22.ps", 
  CharacterEncoding -> "WindowsANSI"],
"PrintCellBrackets"->False,
"PrintMultipleHorizontalPages"->False,
"PrintRegistrationMarks"->True,
"PrintingMargins"->{{54, 54}, {72, 72}}},
ShowSelection->True,
TaggingRules:>{
 "PaginationCache" -> {{2005, 8, 9, 3, 36, 22.593709`8.106562514035977}, {53, 
    53, 53, 53, 53, 53, 53, 53, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 54, 
    55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 55, 56, 56, 56, 56, 56, 
    56, 56, 56, 56, 56, 56, 56, 57, 57, 57, 57, 57, 57, 57, 57, 57, 57, 57, 
    57, 57, 57, 57, 57, 57, 58, 58, 58, 58, 58, 58, 58, 58, 58, 58, 58, 58, 
    59, 59, 59, 59, 59, 59, 59, 59, 60, 60, 60, 60, 60, 60, 60, 60, 60, 60, 
    60, 60, 61, 61, 61, 61, 61, 61, 61, 61, 61, 61, 61, 61, 61, 61, 62, 62, 
    62, 62, 62, 62, 62, 62, 62, 62, 62, 62, 63, 63, 63, 63, 63, 63, 63, 63, 
    63, 63, 63, 63, 63, 63, 64, 64, 64, 64, 64, 64, 64, 64, 64, 65, 65, 65, 
    65, 65, 65, 65, 65, 66, 66, 66, 66, 66, 66, 66, 66, 66, 66, 66, 66, 67, 
    67, 67, 67, 67, 67, 67, 67, 67, 67, 67, 67, 67, 68, 68, 68, 68, 68, 68, 
    68, 68, 68, 68, 68, 68, 69, 69, 69, 69, 69, 69, 69, 69, 69, 69, 69, 69, 
    69, 69, 70, 70, 70, 70, 70, 70, 70, 70, 71, 71, 71, 71, 71, 71, 71, 71, 
    71, 71, 71, 71, 71, 71, 71, 72, 72, 72, 72, 72, 72, 72, 72, 72, 72, 72, 
    72, 73, 73, 73, 73, 73, 73, 73, 73, 73, 73, 73, 73, 73, 74, 74, 74, 74, 
    74, 74, 74, 74, 74, 74, 74, 74, 74, 75, 75, 75, 75, 75, 75, 75, 76, 76}, 
    Automatic}},
CellLabelAutoDelete->True,
Magnification->1,
FrontEndVersion->"8.0 for Mac OS X x86 (32-bit) (November 6, 2010)",
StyleDefinitions->"Classroom.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "c:1"->{
  Cell[545, 20, 62, 1, 50, "Title",
   CellTags->"c:1"]},
 "c:2"->{
  Cell[969, 36, 276, 6, 51, "Section",
   CellTags->{"c:2", "b:3.0"}],
  Cell[4350, 121, 106, 2, 31, "Section",
   CellTags->"c:2"]},
 "b:3.0"->{
  Cell[969, 36, 276, 6, 51, "Section",
   CellTags->{"c:2", "b:3.0"}],
  Cell[1248, 44, 2894, 67, 234, "Abstract",
   CellTags->"b:3.0"],
  Cell[4145, 113, 168, 3, 22, "Text",
   CellTags->"b:3.0"]},
 "c:3"->{
  Cell[4481, 127, 179, 5, 57, "Subsection",
   CellTags->{"c:3", "b:3.1.0"}]},
 "b:3.1.0"->{
  Cell[4481, 127, 179, 5, 57, "Subsection",
   CellTags->{"c:3", "b:3.1.0"}],
  Cell[4663, 134, 133, 3, 46, "Input",
   CellTags->"b:3.1.0"],
  Cell[4799, 139, 112, 3, 46, "Input",
   CellTags->"b:3.1.0"],
  Cell[4914, 144, 198, 5, 22, "Text",
   CellTags->"b:3.1.0"],
  Cell[5115, 151, 1476, 42, 100, "Input",
   CellTags->"b:3.1.0"],
  Cell[6594, 195, 813, 24, 75, "Input",
   CellTags->"b:3.1.0"],
  Cell[7410, 221, 1101, 32, 75, "Input",
   CellTags->"b:3.1.0"],
  Cell[8514, 255, 786, 25, 60, "Input",
   CellTags->"b:3.1.0"],
  Cell[9303, 282, 598, 18, 60, "Input",
   CellTags->"b:3.1.0"],
  Cell[9904, 302, 2561, 67, 135, "Input",
   CellTags->"b:3.1.0"],
  Cell[12468, 371, 252, 7, 49, "Text",
   CellTags->"b:3.1.0"],
  Cell[12723, 380, 407, 13, 63, "Input",
   CellTags->"b:3.1.0"],
  Cell[13133, 395, 112, 2, 22, "Text",
   CellTags->"b:3.1.0"],
  Cell[13248, 399, 115, 4, 44, "Input",
   CellTags->"b:3.1.0"]},
 "c:4"->{
  Cell[13400, 408, 212, 6, 57, "Subsection",
   CellTags->{"c:4", "b:3.1.1"}]},
 "b:3.1.1"->{
  Cell[13400, 408, 212, 6, 57, "Subsection",
   CellTags->{"c:4", "b:3.1.1"}],
  Cell[13615, 416, 104, 2, 22, "Text",
   CellTags->"b:3.1.1"],
  Cell[13722, 420, 90, 3, 44, "Input",
   CellTags->"b:3.1.1"],
  Cell[13815, 425, 119, 2, 22, "Text",
   CellTags->"b:3.1.1"],
  Cell[13937, 429, 90, 3, 44, "Input",
   CellTags->"b:3.1.1"],
  Cell[14030, 434, 192, 5, 22, "Text",
   CellTags->"b:3.1.1"],
  Cell[14225, 441, 327, 11, 44, "Input",
   CellTags->"b:3.1.1"],
  Cell[14555, 454, 277, 8, 44, "Input",
   CellTags->"b:3.1.1"],
  Cell[14835, 464, 680, 19, 60, "Input",
   CellTags->"b:3.1.1"],
  Cell[15518, 485, 1122, 37, 157, "Text",
   CellTags->"b:3.1.1"],
  Cell[16643, 524, 215, 7, 44, "Input",
   CellTags->"b:3.1.1"],
  Cell[16861, 533, 513, 16, 90, "Input",
   CellTags->"b:3.1.1"],
  Cell[17377, 551, 249, 7, 49, "Text",
   CellTags->"b:3.1.1"],
  Cell[17629, 560, 379, 12, 44, "Input",
   CellTags->"b:3.1.1"]},
 "c:5"->{
  Cell[18045, 577, 352, 11, 59, "Subsection",
   CellTags->{"c:5", "b:3.1.2"}]},
 "b:3.1.2"->{
  Cell[18045, 577, 352, 11, 59, "Subsection",
   CellTags->{"c:5", "b:3.1.2"}],
  Cell[18400, 590, 896, 29, 111, "Text",
   CellTags->"b:3.1.2"]},
 "c:6"->{
  Cell[19333, 624, 468, 15, 47, "Subsection",
   CellTags->{"c:6", "b:3.1.3"}]},
 "b:3.1.3"->{
  Cell[19333, 624, 468, 15, 47, "Subsection",
   CellTags->{"c:6", "b:3.1.3"}],
  Cell[19804, 641, 99, 2, 22, "Text",
   CellTags->"b:3.1.3"],
  Cell[19906, 645, 499, 16, 44, "Input",
   CellTags->"b:3.1.3"],
  Cell[20408, 663, 1154, 40, 60, "Text",
   CellTags->"b:3.1.3"]},
 "c:7"->{
  Cell[21599, 708, 148, 3, 57, "Subsection",
   CellTags->{"c:7", "b:3.1.4"}]},
 "b:3.1.4"->{
  Cell[21599, 708, 148, 3, 57, "Subsection",
   CellTags->{"c:7", "b:3.1.4"}],
  Cell[21750, 713, 287, 9, 52, "Text",
   CellTags->"b:3.1.4"],
  Cell[22040, 724, 363, 12, 57, "Input",
   CellTags->"b:3.1.4"],
  Cell[22406, 738, 315, 10, 81, "Input",
   CellTags->"b:3.1.4"],
  Cell[22724, 750, 425, 16, 22, "Text",
   CellTags->"b:3.1.4"],
  Cell[23152, 768, 446, 14, 44, "Input",
   CellTags->"b:3.1.4"],
  Cell[23601, 784, 287, 10, 22, "Text",
   CellTags->"b:3.1.4"],
  Cell[23891, 796, 1054, 34, 68, "Input",
   CellTags->"b:3.1.4"],
  Cell[24948, 832, 134, 4, 22, "Text",
   CellTags->"b:3.1.4"],
  Cell[25085, 838, 764, 25, 71, "Input",
   CellTags->"b:3.1.4"],
  Cell[25852, 865, 223, 8, 44, "Input",
   CellTags->"b:3.1.4"],
  Cell[26078, 875, 83, 2, 22, "Text",
   CellTags->"b:3.1.4"],
  Cell[26164, 879, 98, 3, 44, "Input",
   CellTags->"b:3.1.4"],
  Cell[26265, 884, 95, 2, 22, "Text",
   CellTags->"b:3.1.4"],
  Cell[26363, 888, 653, 20, 44, "Input",
   CellTags->"b:3.1.4"],
  Cell[27019, 910, 597, 19, 75, "Input",
   CellTags->"b:3.1.4"],
  Cell[27619, 931, 98, 3, 44, "Input",
   CellTags->"b:3.1.4"]},
 "c:8"->{
  Cell[27754, 939, 142, 3, 41, "Subsection",
   CellTags->{"c:8", "b:3.1.5"}]},
 "b:3.1.5"->{
  Cell[27754, 939, 142, 3, 41, "Subsection",
   CellTags->{"c:8", "b:3.1.5"}],
  Cell[27899, 944, 137, 4, 22, "Text",
   CellTags->"b:3.1.5"],
  Cell[28039, 950, 477, 15, 44, "Input",
   CellTags->"b:3.1.5"],
  Cell[28519, 967, 127, 4, 44, "Input",
   CellTags->"b:3.1.5"],
  Cell[28649, 973, 438, 13, 50, "Input",
   CellTags->"b:3.1.5"],
  Cell[29090, 988, 291, 8, 60, "Input",
   CellTags->"b:3.1.5"],
  Cell[29384, 998, 114, 3, 44, "Input",
   CellTags->"b:3.1.5"]},
 "c:9"->{
  Cell[29535, 1006, 189, 6, 57, "Subsection",
   CellTags->{"c:9", "b:3.1.6"}]},
 "b:3.1.6"->{
  Cell[29535, 1006, 189, 6, 57, "Subsection",
   CellTags->{"c:9", "b:3.1.6"}],
  Cell[29727, 1014, 154, 5, 22, "Text",
   CellTags->"b:3.1.6"],
  Cell[29884, 1021, 120, 4, 44, "Input",
   CellTags->"b:3.1.6"],
  Cell[30007, 1027, 678, 21, 50, "Input",
   CellTags->"b:3.1.6"],
  Cell[30688, 1050, 156, 5, 22, "Text",
   CellTags->"b:3.1.6"],
  Cell[30847, 1057, 803, 22, 75, "Input",
   CellTags->"b:3.1.6"]},
 "c:10"->{
  Cell[31687, 1084, 169, 5, 57, "Subsection",
   CellTags->{"c:10", "b:3.1.7"}]},
 "b:3.1.7"->{
  Cell[31687, 1084, 169, 5, 57, "Subsection",
   CellTags->{"c:10", "b:3.1.7"}],
  Cell[31859, 1091, 512, 12, 130, "Text",
   CellTags->"b:3.1.7"],
  Cell[32374, 1105, 89, 3, 44, "Input",
   CellTags->"b:3.1.7"],
  Cell[32466, 1110, 4219, 115, 265, "Input",
   CellTags->"b:3.1.7"],
  Cell[36688, 1227, 1016, 27, 120, "Input",
   CellTags->"b:3.1.7"],
  Cell[37707, 1256, 81, 2, 44, "Input",
   CellTags->"b:3.1.7"],
  Cell[37791, 1260, 264, 7, 76, "Text",
   CellTags->"b:3.1.7"],
  Cell[38058, 1269, 413, 13, 66, "Input",
   CellTags->"b:3.1.7"],
  Cell[38474, 1284, 43, 1, 44, "Input",
   CellTags->"b:3.1.7"]},
 "c:11"->{
  Cell[38566, 1291, 129, 4, 31, "Section",
   CellTags->"c:11"]},
 "c:12"->{
  Cell[38720, 1299, 180, 5, 57, "Subsection",
   CellTags->{"c:12", "b:3.2.0"}]},
 "b:3.2.0"->{
  Cell[38720, 1299, 180, 5, 57, "Subsection",
   CellTags->{"c:12", "b:3.2.0"}],
  Cell[38903, 1306, 133, 3, 46, "Input",
   CellTags->"b:3.2.0"],
  Cell[39039, 1311, 112, 3, 46, "Input",
   CellTags->"b:3.2.0"],
  Cell[39154, 1316, 166, 5, 22, "Text",
   CellTags->"b:3.2.0"],
  Cell[39323, 1323, 1050, 34, 60, "Input",
   CellTags->"b:3.2.0"],
  Cell[40376, 1359, 2076, 55, 90, "Input",
   CellTags->"b:3.2.0"],
  Cell[42455, 1416, 520, 14, 60, "Input",
   CellTags->"b:3.2.0"],
  Cell[42978, 1432, 2134, 57, 90, "Input",
   CellTags->"b:3.2.0"],
  Cell[45115, 1491, 521, 14, 60, "Input",
   CellTags->"b:3.2.0"],
  Cell[45639, 1507, 252, 7, 49, "Text",
   CellTags->"b:3.2.0"],
  Cell[45894, 1516, 407, 13, 63, "Input",
   CellTags->"b:3.2.0"],
  Cell[46304, 1531, 112, 2, 22, "Text",
   CellTags->"b:3.2.0"],
  Cell[46419, 1535, 115, 4, 44, "Input",
   CellTags->"b:3.2.0"]},
 "c:13"->{
  Cell[46571, 1544, 206, 6, 57, "Subsection",
   CellTags->{"c:13", "b:3.2.1"}]},
 "b:3.2.1"->{
  Cell[46571, 1544, 206, 6, 57, "Subsection",
   CellTags->{"c:13", "b:3.2.1"}],
  Cell[46780, 1552, 104, 2, 22, "Text",
   CellTags->"b:3.2.1"],
  Cell[46887, 1556, 96, 3, 44, "Input",
   CellTags->"b:3.2.1"],
  Cell[46986, 1561, 119, 2, 22, "Text",
   CellTags->"b:3.2.1"],
  Cell[47108, 1565, 90, 3, 44, "Input",
   CellTags->"b:3.2.1"],
  Cell[47201, 1570, 175, 5, 22, "Text",
   CellTags->"b:3.2.1"],
  Cell[47379, 1577, 327, 11, 44, "Input",
   CellTags->"b:3.2.1"],
  Cell[47709, 1590, 277, 8, 44, "Input",
   CellTags->"b:3.2.1"],
  Cell[47989, 1600, 680, 19, 60, "Input",
   CellTags->"b:3.2.1"],
  Cell[48672, 1621, 1123, 37, 157, "Text",
   CellTags->"b:3.2.1"],
  Cell[49798, 1660, 215, 7, 44, "Input",
   CellTags->"b:3.2.1"],
  Cell[50016, 1669, 284, 9, 22, "Text",
   CellTags->"b:3.2.1"],
  Cell[50303, 1680, 562, 17, 105, "Input",
   CellTags->"b:3.2.1"],
  Cell[50868, 1699, 249, 7, 49, "Text",
   CellTags->"b:3.2.1"],
  Cell[51120, 1708, 379, 12, 44, "Input",
   CellTags->"b:3.2.1"]},
 "c:14"->{
  Cell[51536, 1725, 353, 11, 59, "Subsection",
   CellTags->{"c:14", "b:3.2.2"}]},
 "b:3.2.2"->{
  Cell[51536, 1725, 353, 11, 59, "Subsection",
   CellTags->{"c:14", "b:3.2.2"}],
  Cell[51892, 1738, 896, 29, 95, "Text",
   CellTags->"b:3.2.2"]},
 "c:15"->{
  Cell[52825, 1772, 469, 15, 47, "Subsection",
   CellTags->{"c:15", "b:3.2.3"}]},
 "b:3.2.3"->{
  Cell[52825, 1772, 469, 15, 47, "Subsection",
   CellTags->{"c:15", "b:3.2.3"}],
  Cell[53297, 1789, 99, 2, 22, "Text",
   CellTags->"b:3.2.3"],
  Cell[53399, 1793, 499, 16, 44, "Input",
   CellTags->"b:3.2.3"],
  Cell[53901, 1811, 77, 2, 44, "Input",
   CellTags->"b:3.2.3"],
  Cell[53981, 1815, 1154, 40, 60, "Text",
   CellTags->"b:3.2.3"]},
 "c:16"->{
  Cell[55172, 1860, 149, 3, 57, "Subsection",
   CellTags->{"c:16", "b:3.2.4"}]},
 "b:3.2.4"->{
  Cell[55172, 1860, 149, 3, 57, "Subsection",
   CellTags->{"c:16", "b:3.2.4"}],
  Cell[55324, 1865, 286, 9, 52, "Text",
   CellTags->"b:3.2.4"],
  Cell[55613, 1876, 363, 12, 59, "Input",
   CellTags->"b:3.2.4"],
  Cell[55979, 1890, 315, 10, 82, "Input",
   CellTags->"b:3.2.4"],
  Cell[56297, 1902, 425, 16, 22, "Text",
   CellTags->"b:3.2.4"],
  Cell[56725, 1920, 446, 14, 44, "Input",
   CellTags->"b:3.2.4"],
  Cell[57174, 1936, 287, 10, 22, "Text",
   CellTags->"b:3.2.4"],
  Cell[57464, 1948, 1054, 34, 84, "Input",
   CellTags->"b:3.2.4"],
  Cell[58521, 1984, 134, 4, 22, "Text",
   CellTags->"b:3.2.4"],
  Cell[58658, 1990, 764, 25, 75, "Input",
   CellTags->"b:3.2.4"],
  Cell[59425, 2017, 81, 2, 22, "Text",
   CellTags->"b:3.2.4"],
  Cell[59509, 2021, 98, 3, 44, "Input",
   CellTags->"b:3.2.4"]},
 "c:17"->{
  Cell[59644, 2029, 143, 3, 57, "Subsection",
   CellTags->{"c:17", "b:3.2.5"}]},
 "b:3.2.5"->{
  Cell[59644, 2029, 143, 3, 57, "Subsection",
   CellTags->{"c:17", "b:3.2.5"}],
  Cell[59790, 2034, 160, 5, 22, "Text",
   CellTags->"b:3.2.5"],
  Cell[59953, 2041, 127, 4, 44, "Input",
   CellTags->"b:3.2.5"],
  Cell[60083, 2047, 913, 26, 75, "Input",
   CellTags->"b:3.2.5"],
  Cell[60999, 2075, 291, 8, 60, "Input",
   CellTags->"b:3.2.5"]},
 "c:18"->{
  Cell[61327, 2088, 190, 6, 57, "Subsection",
   CellTags->{"c:18", "b:3.2.6"}]},
 "b:3.2.6"->{
  Cell[61327, 2088, 190, 6, 57, "Subsection",
   CellTags->{"c:18", "b:3.2.6"}],
  Cell[61520, 2096, 154, 5, 22, "Text",
   CellTags->"b:3.2.6"],
  Cell[61677, 2103, 120, 4, 44, "Input",
   CellTags->"b:3.2.6"],
  Cell[61800, 2109, 750, 23, 70, "Input",
   CellTags->"b:3.2.6"],
  Cell[62553, 2134, 156, 5, 22, "Text",
   CellTags->"b:3.2.6"],
  Cell[62712, 2141, 803, 22, 75, "Input",
   CellTags->"b:3.2.6"]},
 "c:19"->{
  Cell[63552, 2168, 169, 5, 57, "Subsection",
   CellTags->{"c:19", "b:3.2.7"}]},
 "b:3.2.7"->{
  Cell[63552, 2168, 169, 5, 57, "Subsection",
   CellTags->{"c:19", "b:3.2.7"}],
  Cell[63724, 2175, 512, 12, 130, "Text",
   CellTags->"b:3.2.7"],
  Cell[64239, 2189, 89, 3, 44, "Input",
   CellTags->"b:3.2.7"],
  Cell[64331, 2194, 4219, 115, 265, "Input",
   CellTags->"b:3.2.7"],
  Cell[68553, 2311, 767, 20, 105, "Input",
   CellTags->"b:3.2.7"],
  Cell[69323, 2333, 81, 2, 44, "Input",
   CellTags->"b:3.2.7"],
  Cell[69407, 2337, 264, 7, 76, "Text",
   CellTags->"b:3.2.7"],
  Cell[69674, 2346, 413, 13, 66, "Input",
   CellTags->"b:3.2.7"],
  Cell[70090, 2361, 43, 1, 44, "Input",
   CellTags->"b:3.2.7"]},
 "c:20"->{
  Cell[70182, 2368, 162, 5, 31, "Section",
   CellTags->"c:20"]},
 "c:21"->{
  Cell[70369, 2377, 264, 9, 57, "Subsection",
   CellTags->{"c:21", "b:3.3.0"}]},
 "b:3.3.0"->{
  Cell[70369, 2377, 264, 9, 57, "Subsection",
   CellTags->{"c:21", "b:3.3.0"}],
  Cell[70636, 2388, 133, 3, 46, "Input",
   CellTags->"b:3.3.0"],
  Cell[70772, 2393, 112, 3, 46, "Input",
   CellTags->"b:3.3.0"],
  Cell[70887, 2398, 139, 4, 22, "Text",
   CellTags->"b:3.3.0"],
  Cell[71029, 2404, 1050, 34, 60, "Input",
   CellTags->"b:3.3.0"],
  Cell[72082, 2440, 2076, 55, 90, "Input",
   CellTags->"b:3.3.0"],
  Cell[74161, 2497, 520, 14, 60, "Input",
   CellTags->"b:3.3.0"],
  Cell[74684, 2513, 2134, 57, 90, "Input",
   CellTags->"b:3.3.0"],
  Cell[76821, 2572, 521, 14, 60, "Input",
   CellTags->"b:3.3.0"],
  Cell[77345, 2588, 260, 6, 49, "Text",
   CellTags->"b:3.3.0"],
  Cell[77608, 2596, 407, 13, 63, "Input",
   CellTags->"b:3.3.0"],
  Cell[78018, 2611, 112, 2, 22, "Text",
   CellTags->"b:3.3.0"],
  Cell[78133, 2615, 115, 4, 44, "Input",
   CellTags->"b:3.3.0"]},
 "c:22"->{
  Cell[78285, 2624, 214, 6, 57, "Subsection",
   CellTags->{"c:22", "b:3.3.1"}]},
 "b:3.3.1"->{
  Cell[78285, 2624, 214, 6, 57, "Subsection",
   CellTags->{"c:22", "b:3.3.1"}],
  Cell[78502, 2632, 107, 2, 22, "Text",
   CellTags->"b:3.3.1"],
  Cell[78612, 2636, 90, 3, 44, "Input",
   CellTags->"b:3.3.1"],
  Cell[78705, 2641, 119, 2, 22, "Text",
   CellTags->"b:3.3.1"],
  Cell[78827, 2645, 90, 3, 44, "Input",
   CellTags->"b:3.3.1"],
  Cell[78920, 2650, 175, 5, 22, "Text",
   CellTags->"b:3.3.1"],
  Cell[79098, 2657, 301, 10, 44, "Input",
   CellTags->"b:3.3.1"],
  Cell[79402, 2669, 680, 19, 60, "Input",
   CellTags->"b:3.3.1"],
  Cell[80085, 2690, 215, 7, 44, "Input",
   CellTags->"b:3.3.1"],
  Cell[80303, 2699, 576, 17, 103, "Text",
   CellTags->"b:3.3.1"],
  Cell[80882, 2718, 513, 16, 90, "Input",
   CellTags->"b:3.3.1"],
  Cell[81398, 2736, 248, 7, 49, "Text",
   CellTags->"b:3.3.1"],
  Cell[81649, 2745, 379, 12, 44, "Input",
   CellTags->"b:3.3.1"]},
 "c:23"->{
  Cell[82065, 2762, 353, 11, 59, "Subsection",
   CellTags->{"c:23", "b:3.3.2"}]},
 "b:3.3.2"->{
  Cell[82065, 2762, 353, 11, 59, "Subsection",
   CellTags->{"c:23", "b:3.3.2"}],
  Cell[82421, 2775, 748, 24, 65, "Text",
   CellTags->"b:3.3.2"],
  Cell[83172, 2801, 503, 18, 60, "Input",
   CellTags->"b:3.3.2"]},
 "c:24"->{
  Cell[83712, 2824, 469, 15, 63, "Subsection",
   CellTags->{"c:24", "b:3.3.3"}]},
 "b:3.3.3"->{
  Cell[83712, 2824, 469, 15, 63, "Subsection",
   CellTags->{"c:24", "b:3.3.3"}],
  Cell[84184, 2841, 118, 2, 22, "Text",
   CellTags->"b:3.3.3"],
  Cell[84305, 2845, 499, 16, 44, "Input",
   CellTags->"b:3.3.3"],
  Cell[84807, 2863, 156, 5, 49, "Text",
   CellTags->"b:3.3.3"],
  Cell[84966, 2870, 1224, 41, 80, "Input",
   CellTags->"b:3.3.3"],
  Cell[86193, 2913, 201, 6, 60, "Input",
   CellTags->"b:3.3.3"],
  Cell[86397, 2921, 106, 2, 22, "Text",
   CellTags->"b:3.3.3"]},
 "c:25"->{
  Cell[86540, 2928, 129, 3, 57, "Subsection",
   CellTags->{"c:25", "b:3.3.4"}]},
 "b:3.3.4"->{
  Cell[86540, 2928, 129, 3, 57, "Subsection",
   CellTags->{"c:25", "b:3.3.4"}],
  Cell[86672, 2933, 216, 6, 49, "Text",
   CellTags->"b:3.3.4"],
  Cell[86891, 2941, 363, 12, 59, "Input",
   CellTags->"b:3.3.4"],
  Cell[87257, 2955, 258, 8, 22, "Text",
   CellTags->"b:3.3.4"],
  Cell[87518, 2965, 736, 23, 75, "Input",
   CellTags->"b:3.3.4"],
  Cell[88257, 2990, 228, 7, 60, "Input",
   CellTags->"b:3.3.4"]},
 "c:26"->{
  Cell[88522, 3002, 138, 3, 57, "Subsection",
   CellTags->{"c:26", "b:3.3.5"}]},
 "b:3.3.5"->{
  Cell[88522, 3002, 138, 3, 57, "Subsection",
   CellTags->{"c:26", "b:3.3.5"}],
  Cell[88663, 3007, 240, 9, 22, "Text",
   CellTags->"b:3.3.5"],
  Cell[88906, 3018, 127, 4, 44, "Input",
   CellTags->"b:3.3.5"],
  Cell[89036, 3024, 905, 27, 81, "Input",
   CellTags->"b:3.3.5"],
  Cell[89944, 3053, 127, 4, 44, "Input",
   CellTags->"b:3.3.5"],
  Cell[90074, 3059, 180, 4, 44, "Input",
   CellTags->"b:3.3.5"],
  Cell[90257, 3065, 143, 4, 22, "Text",
   CellTags->"b:3.3.5"],
  Cell[90403, 3071, 120, 4, 44, "Input",
   CellTags->"b:3.3.5"],
  Cell[90526, 3077, 750, 23, 70, "Input",
   CellTags->"b:3.3.5"],
  Cell[91279, 3102, 496, 15, 75, "Input",
   CellTags->"b:3.3.5"],
  Cell[91778, 3119, 810, 23, 75, "Input",
   CellTags->"b:3.3.5"]},
 "c:27"->{
  Cell[92625, 3147, 198, 6, 57, "Subsection",
   CellTags->{"c:27", "b:3.3.6"}]},
 "b:3.3.6"->{
  Cell[92625, 3147, 198, 6, 57, "Subsection",
   CellTags->{"c:27", "b:3.3.6"}],
  Cell[92826, 3155, 201, 6, 49, "Text",
   CellTags->"b:3.3.6"],
  Cell[93030, 3163, 54, 1, 44, "Input",
   CellTags->"b:3.3.6"],
  Cell[93087, 3166, 89, 3, 44, "Input",
   CellTags->"b:3.3.6"],
  Cell[93179, 3171, 4219, 115, 265, "Input",
   CellTags->"b:3.3.6"],
  Cell[97401, 3288, 666, 18, 90, "Input",
   CellTags->"b:3.3.6"],
  Cell[98070, 3308, 81, 2, 44, "Input",
   CellTags->"b:3.3.6"],
  Cell[98154, 3312, 52, 1, 44, "Input",
   CellTags->"b:3.3.6"]},
 "c:28"->{
  Cell[98255, 3319, 174, 7, 31, "Section",
   CellTags->"c:28"]},
 "c:29"->{
  Cell[98454, 3330, 180, 5, 57, "Subsection",
   CellTags->{"c:29", "b:3.4.0"}]},
 "b:3.4.0"->{
  Cell[98454, 3330, 180, 5, 57, "Subsection",
   CellTags->{"c:29", "b:3.4.0"}],
  Cell[98637, 3337, 133, 3, 46, "Input",
   CellTags->"b:3.4.0"],
  Cell[98773, 3342, 112, 3, 46, "Input",
   CellTags->"b:3.4.0"],
  Cell[98888, 3347, 168, 5, 22, "Text",
   CellTags->"b:3.4.0"],
  Cell[99059, 3354, 252, 7, 49, "Text",
   CellTags->"b:3.4.0"],
  Cell[99314, 3363, 407, 13, 63, "Input",
   CellTags->"b:3.4.0"],
  Cell[99724, 3378, 112, 2, 22, "Text",
   CellTags->"b:3.4.0"],
  Cell[99839, 3382, 115, 4, 44, "Input",
   CellTags->"b:3.4.0"]},
 "c:30"->{
  Cell[99991, 3391, 206, 6, 57, "Subsection",
   CellTags->{"c:30", "b:3.4.1"}]},
 "b:3.4.1"->{
  Cell[99991, 3391, 206, 6, 57, "Subsection",
   CellTags->{"c:30", "b:3.4.1"}],
  Cell[100200, 3399, 104, 2, 22, "Text",
   CellTags->"b:3.4.1"],
  Cell[100307, 3403, 95, 3, 44, "Input",
   CellTags->"b:3.4.1"],
  Cell[100405, 3408, 119, 2, 22, "Text",
   CellTags->"b:3.4.1"],
  Cell[100527, 3412, 90, 3, 44, "Input",
   CellTags->"b:3.4.1"],
  Cell[100620, 3417, 157, 5, 22, "Text",
   CellTags->"b:3.4.1"],
  Cell[100780, 3424, 327, 11, 44, "Input",
   CellTags->"b:3.4.1"],
  Cell[101110, 3437, 277, 8, 44, "Input",
   CellTags->"b:3.4.1"],
  Cell[101390, 3447, 680, 19, 60, "Input",
   CellTags->"b:3.4.1"],
  Cell[102073, 3468, 1121, 37, 157, "Text",
   CellTags->"b:3.4.1"],
  Cell[103197, 3507, 215, 7, 44, "Input",
   CellTags->"b:3.4.1"],
  Cell[103415, 3516, 464, 14, 90, "Input",
   CellTags->"b:3.4.1"],
  Cell[103882, 3532, 248, 7, 49, "Text",
   CellTags->"b:3.4.1"],
  Cell[104133, 3541, 379, 12, 44, "Input",
   CellTags->"b:3.4.1"]},
 "c:31"->{
  Cell[104549, 3558, 353, 11, 59, "Subsection",
   CellTags->{"c:31", "b:3.4.2"}]},
 "b:3.4.2"->{
  Cell[104549, 3558, 353, 11, 59, "Subsection",
   CellTags->{"c:31", "b:3.4.2"}],
  Cell[104905, 3571, 896, 29, 92, "Text",
   CellTags->"b:3.4.2"]},
 "c:32"->{
  Cell[105838, 3605, 469, 15, 63, "Subsection",
   CellTags->{"c:32", "b:3.4.3"}]},
 "b:3.4.3"->{
  Cell[105838, 3605, 469, 15, 63, "Subsection",
   CellTags->{"c:32", "b:3.4.3"}],
  Cell[106310, 3622, 99, 2, 22, "Text",
   CellTags->"b:3.4.3"],
  Cell[106412, 3626, 499, 16, 44, "Input",
   CellTags->"b:3.4.3"],
  Cell[106914, 3644, 1154, 40, 60, "Text",
   CellTags->"b:3.4.3"]},
 "c:33"->{
  Cell[108105, 3689, 149, 3, 57, "Subsection",
   CellTags->{"c:33", "b:3.4.4"}]},
 "b:3.4.4"->{
  Cell[108105, 3689, 149, 3, 57, "Subsection",
   CellTags->{"c:33", "b:3.4.4"}],
  Cell[108257, 3694, 286, 9, 52, "Text",
   CellTags->"b:3.4.4"],
  Cell[108546, 3705, 363, 12, 59, "Input",
   CellTags->"b:3.4.4"],
  Cell[108912, 3719, 315, 10, 82, "Input",
   CellTags->"b:3.4.4"],
  Cell[109230, 3731, 425, 16, 22, "Text",
   CellTags->"b:3.4.4"],
  Cell[109658, 3749, 906, 29, 60, "Input",
   CellTags->"b:3.4.4"],
  Cell[110567, 3780, 287, 10, 22, "Text",
   CellTags->"b:3.4.4"],
  Cell[110857, 3792, 1964, 62, 104, "Input",
   CellTags->"b:3.4.4"],
  Cell[112824, 3856, 134, 4, 22, "Text",
   CellTags->"b:3.4.4"],
  Cell[112961, 3862, 764, 25, 75, "Input",
   CellTags->"b:3.4.4"],
  Cell[113728, 3889, 80, 2, 44, "Input",
   CellTags->"b:3.4.4"]},
 "c:34"->{
  Cell[113845, 3896, 143, 3, 57, "Subsection",
   CellTags->{"c:34", "b:3.4.5"}]},
 "b:3.4.5"->{
  Cell[113845, 3896, 143, 3, 57, "Subsection",
   CellTags->{"c:34", "b:3.4.5"}],
  Cell[113991, 3901, 160, 5, 22, "Text",
   CellTags->"b:3.4.5"],
  Cell[114154, 3908, 127, 4, 44, "Input",
   CellTags->"b:3.4.5"],
  Cell[114284, 3914, 132, 4, 44, "Input",
   CellTags->"b:3.4.5"],
  Cell[114419, 3920, 291, 8, 60, "Input",
   CellTags->"b:3.4.5"]},
 "c:35"->{
  Cell[114747, 3933, 190, 6, 57, "Subsection",
   CellTags->{"c:35", "b:3.4.6"}]},
 "b:3.4.6"->{
  Cell[114747, 3933, 190, 6, 57, "Subsection",
   CellTags->{"c:35", "b:3.4.6"}],
  Cell[114940, 3941, 154, 5, 22, "Text",
   CellTags->"b:3.4.6"],
  Cell[115097, 3948, 120, 4, 44, "Input",
   CellTags->"b:3.4.6"],
  Cell[115220, 3954, 688, 22, 70, "Input",
   CellTags->"b:3.4.6"],
  Cell[115911, 3978, 156, 5, 22, "Text",
   CellTags->"b:3.4.6"],
  Cell[116070, 3985, 803, 22, 75, "Input",
   CellTags->"b:3.4.6"]},
 "c:36"->{
  Cell[116910, 4012, 169, 5, 57, "Subsection",
   CellTags->{"c:36", "b:3.4.7"}]},
 "b:3.4.7"->{
  Cell[116910, 4012, 169, 5, 57, "Subsection",
   CellTags->{"c:36", "b:3.4.7"}],
  Cell[117082, 4019, 514, 12, 130, "Text",
   CellTags->"b:3.4.7"],
  Cell[117599, 4033, 89, 3, 44, "Input",
   CellTags->"b:3.4.7"],
  Cell[117691, 4038, 4219, 115, 265, "Input",
   CellTags->"b:3.4.7"],
  Cell[121913, 4155, 767, 20, 105, "Input",
   CellTags->"b:3.4.7"],
  Cell[122683, 4177, 81, 2, 44, "Input",
   CellTags->"b:3.4.7"],
  Cell[122767, 4181, 264, 7, 76, "Text",
   CellTags->"b:3.4.7"],
  Cell[123034, 4190, 441, 14, 60, "Input",
   CellTags->"b:3.4.7"],
  Cell[123478, 4206, 43, 1, 44, "Input",
   CellTags->"b:3.4.7"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"c:1", 125668, 4256},
 {"c:2", 125736, 4259},
 {"b:3.0", 125882, 4264},
 {"c:3", 126092, 4271},
 {"b:3.1.0", 126185, 4274},
 {"c:4", 127119, 4303},
 {"b:3.1.1", 127213, 4306},
 {"c:5", 128148, 4335},
 {"b:3.1.2", 128243, 4338},
 {"c:6", 128400, 4343},
 {"b:3.1.3", 128495, 4346},
 {"c:7", 128781, 4355},
 {"b:3.1.4", 128875, 4358},
 {"c:8", 130005, 4393},
 {"b:3.1.5", 130099, 4396},
 {"c:9", 130580, 4411},
 {"b:3.1.6", 130675, 4414},
 {"c:10", 131097, 4427},
 {"b:3.1.7", 131193, 4430},
 {"c:11", 131819, 4449},
 {"c:12", 131896, 4452},
 {"b:3.2.0", 131992, 4455},
 {"c:13", 132883, 4482},
 {"b:3.2.1", 132979, 4485},
 {"c:14", 133996, 4516},
 {"b:3.2.2", 134093, 4519},
 {"c:15", 134253, 4524},
 {"b:3.2.3", 134350, 4527},
 {"c:16", 134707, 4538},
 {"b:3.2.4", 134803, 4541},
 {"c:17", 135623, 4566},
 {"b:3.2.5", 135719, 4569},
 {"c:18", 136076, 4580},
 {"b:3.2.6", 136172, 4583},
 {"c:19", 136595, 4596},
 {"b:3.2.7", 136691, 4599},
 {"c:20", 137316, 4618},
 {"c:21", 137393, 4621},
 {"b:3.3.0", 137489, 4624},
 {"c:22", 138380, 4651},
 {"b:3.3.1", 138476, 4654},
 {"c:23", 139360, 4681},
 {"b:3.3.2", 139457, 4684},
 {"c:24", 139684, 4691},
 {"b:3.3.3", 139781, 4694},
 {"c:25", 140271, 4709},
 {"b:3.3.4", 140367, 4712},
 {"c:26", 140790, 4725},
 {"b:3.3.5", 140886, 4728},
 {"c:27", 141641, 4751},
 {"b:3.3.6", 141737, 4754},
 {"c:28", 142292, 4771},
 {"c:29", 142369, 4774},
 {"b:3.4.0", 142465, 4777},
 {"c:30", 143018, 4794},
 {"b:3.4.1", 143114, 4797},
 {"c:31", 144078, 4826},
 {"b:3.4.2", 144176, 4829},
 {"c:32", 144338, 4834},
 {"b:3.4.3", 144436, 4837},
 {"c:33", 144732, 4846},
 {"b:3.4.4", 144829, 4849},
 {"c:34", 145597, 4872},
 {"b:3.4.5", 145694, 4875},
 {"c:35", 146055, 4886},
 {"b:3.4.6", 146152, 4889},
 {"c:36", 146581, 4902},
 {"b:3.4.7", 146678, 4905}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 62, 1, 50, "Title",
 CellTags->"c:1"],
Cell[610, 23, 63, 0, 34, "Subtitle"],
Cell[676, 25, 268, 7, 20, "Abstract"],
Cell[CellGroupData[{
Cell[969, 36, 276, 6, 51, "Section",
 CellTags->{"c:2", "b:3.0"}],
Cell[1248, 44, 2894, 67, 234, "Abstract",
 CellTags->"b:3.0"],
Cell[4145, 113, 168, 3, 22, "Text",
 CellTags->"b:3.0"]
}, Closed]],
Cell[CellGroupData[{
Cell[4350, 121, 106, 2, 31, "Section",
 CellTags->"c:2"],
Cell[CellGroupData[{
Cell[4481, 127, 179, 5, 57, "Subsection",
 CellTags->{"c:3", "b:3.1.0"}],
Cell[4663, 134, 133, 3, 46, "Input",
 CellTags->"b:3.1.0"],
Cell[4799, 139, 112, 3, 46, "Input",
 CellTags->"b:3.1.0"],
Cell[4914, 144, 198, 5, 22, "Text",
 CellTags->"b:3.1.0"],
Cell[5115, 151, 1476, 42, 100, "Input",
 CellTags->"b:3.1.0"],
Cell[6594, 195, 813, 24, 75, "Input",
 CellTags->"b:3.1.0"],
Cell[7410, 221, 1101, 32, 75, "Input",
 CellTags->"b:3.1.0"],
Cell[8514, 255, 786, 25, 60, "Input",
 CellTags->"b:3.1.0"],
Cell[9303, 282, 598, 18, 60, "Input",
 CellTags->"b:3.1.0"],
Cell[9904, 302, 2561, 67, 135, "Input",
 CellTags->"b:3.1.0"],
Cell[12468, 371, 252, 7, 49, "Text",
 CellTags->"b:3.1.0"],
Cell[12723, 380, 407, 13, 63, "Input",
 CellTags->"b:3.1.0"],
Cell[13133, 395, 112, 2, 22, "Text",
 CellTags->"b:3.1.0"],
Cell[13248, 399, 115, 4, 44, "Input",
 CellTags->"b:3.1.0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13400, 408, 212, 6, 57, "Subsection",
 CellTags->{"c:4", "b:3.1.1"}],
Cell[13615, 416, 104, 2, 22, "Text",
 CellTags->"b:3.1.1"],
Cell[13722, 420, 90, 3, 44, "Input",
 CellTags->"b:3.1.1"],
Cell[13815, 425, 119, 2, 22, "Text",
 CellTags->"b:3.1.1"],
Cell[13937, 429, 90, 3, 44, "Input",
 CellTags->"b:3.1.1"],
Cell[14030, 434, 192, 5, 22, "Text",
 CellTags->"b:3.1.1"],
Cell[14225, 441, 327, 11, 44, "Input",
 CellTags->"b:3.1.1"],
Cell[14555, 454, 277, 8, 44, "Input",
 CellTags->"b:3.1.1"],
Cell[14835, 464, 680, 19, 60, "Input",
 CellTags->"b:3.1.1"],
Cell[15518, 485, 1122, 37, 157, "Text",
 CellTags->"b:3.1.1"],
Cell[16643, 524, 215, 7, 44, "Input",
 CellTags->"b:3.1.1"],
Cell[16861, 533, 513, 16, 90, "Input",
 CellTags->"b:3.1.1"],
Cell[17377, 551, 249, 7, 49, "Text",
 CellTags->"b:3.1.1"],
Cell[17629, 560, 379, 12, 44, "Input",
 CellTags->"b:3.1.1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18045, 577, 352, 11, 59, "Subsection",
 CellTags->{"c:5", "b:3.1.2"}],
Cell[18400, 590, 896, 29, 111, "Text",
 CellTags->"b:3.1.2"]
}, Closed]],
Cell[CellGroupData[{
Cell[19333, 624, 468, 15, 47, "Subsection",
 CellTags->{"c:6", "b:3.1.3"}],
Cell[19804, 641, 99, 2, 22, "Text",
 CellTags->"b:3.1.3"],
Cell[19906, 645, 499, 16, 44, "Input",
 CellTags->"b:3.1.3"],
Cell[20408, 663, 1154, 40, 60, "Text",
 CellTags->"b:3.1.3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[21599, 708, 148, 3, 57, "Subsection",
 CellTags->{"c:7", "b:3.1.4"}],
Cell[21750, 713, 287, 9, 52, "Text",
 CellTags->"b:3.1.4"],
Cell[22040, 724, 363, 12, 57, "Input",
 CellTags->"b:3.1.4"],
Cell[22406, 738, 315, 10, 81, "Input",
 CellTags->"b:3.1.4"],
Cell[22724, 750, 425, 16, 22, "Text",
 CellTags->"b:3.1.4"],
Cell[23152, 768, 446, 14, 44, "Input",
 CellTags->"b:3.1.4"],
Cell[23601, 784, 287, 10, 22, "Text",
 CellTags->"b:3.1.4"],
Cell[23891, 796, 1054, 34, 68, "Input",
 CellTags->"b:3.1.4"],
Cell[24948, 832, 134, 4, 22, "Text",
 CellTags->"b:3.1.4"],
Cell[25085, 838, 764, 25, 71, "Input",
 CellTags->"b:3.1.4"],
Cell[25852, 865, 223, 8, 44, "Input",
 CellTags->"b:3.1.4"],
Cell[26078, 875, 83, 2, 22, "Text",
 CellTags->"b:3.1.4"],
Cell[26164, 879, 98, 3, 44, "Input",
 CellTags->"b:3.1.4"],
Cell[26265, 884, 95, 2, 22, "Text",
 CellTags->"b:3.1.4"],
Cell[26363, 888, 653, 20, 44, "Input",
 CellTags->"b:3.1.4"],
Cell[27019, 910, 597, 19, 75, "Input",
 CellTags->"b:3.1.4"],
Cell[27619, 931, 98, 3, 44, "Input",
 CellTags->"b:3.1.4"]
}, Closed]],
Cell[CellGroupData[{
Cell[27754, 939, 142, 3, 41, "Subsection",
 CellTags->{"c:8", "b:3.1.5"}],
Cell[27899, 944, 137, 4, 22, "Text",
 CellTags->"b:3.1.5"],
Cell[28039, 950, 477, 15, 44, "Input",
 CellTags->"b:3.1.5"],
Cell[28519, 967, 127, 4, 44, "Input",
 CellTags->"b:3.1.5"],
Cell[28649, 973, 438, 13, 50, "Input",
 CellTags->"b:3.1.5"],
Cell[29090, 988, 291, 8, 60, "Input",
 CellTags->"b:3.1.5"],
Cell[29384, 998, 114, 3, 44, "Input",
 CellTags->"b:3.1.5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[29535, 1006, 189, 6, 57, "Subsection",
 CellTags->{"c:9", "b:3.1.6"}],
Cell[29727, 1014, 154, 5, 22, "Text",
 CellTags->"b:3.1.6"],
Cell[29884, 1021, 120, 4, 44, "Input",
 CellTags->"b:3.1.6"],
Cell[30007, 1027, 678, 21, 50, "Input",
 CellTags->"b:3.1.6"],
Cell[30688, 1050, 156, 5, 22, "Text",
 CellTags->"b:3.1.6"],
Cell[30847, 1057, 803, 22, 75, "Input",
 CellTags->"b:3.1.6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[31687, 1084, 169, 5, 57, "Subsection",
 CellTags->{"c:10", "b:3.1.7"}],
Cell[31859, 1091, 512, 12, 130, "Text",
 CellTags->"b:3.1.7"],
Cell[32374, 1105, 89, 3, 44, "Input",
 CellTags->"b:3.1.7"],
Cell[32466, 1110, 4219, 115, 265, "Input",
 CellTags->"b:3.1.7"],
Cell[36688, 1227, 1016, 27, 120, "Input",
 CellTags->"b:3.1.7"],
Cell[37707, 1256, 81, 2, 44, "Input",
 CellTags->"b:3.1.7"],
Cell[37791, 1260, 264, 7, 76, "Text",
 CellTags->"b:3.1.7"],
Cell[38058, 1269, 413, 13, 66, "Input",
 CellTags->"b:3.1.7"],
Cell[38474, 1284, 43, 1, 44, "Input",
 CellTags->"b:3.1.7"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[38566, 1291, 129, 4, 31, "Section",
 CellTags->"c:11"],
Cell[CellGroupData[{
Cell[38720, 1299, 180, 5, 57, "Subsection",
 CellTags->{"c:12", "b:3.2.0"}],
Cell[38903, 1306, 133, 3, 46, "Input",
 CellTags->"b:3.2.0"],
Cell[39039, 1311, 112, 3, 46, "Input",
 CellTags->"b:3.2.0"],
Cell[39154, 1316, 166, 5, 22, "Text",
 CellTags->"b:3.2.0"],
Cell[39323, 1323, 1050, 34, 60, "Input",
 CellTags->"b:3.2.0"],
Cell[40376, 1359, 2076, 55, 90, "Input",
 CellTags->"b:3.2.0"],
Cell[42455, 1416, 520, 14, 60, "Input",
 CellTags->"b:3.2.0"],
Cell[42978, 1432, 2134, 57, 90, "Input",
 CellTags->"b:3.2.0"],
Cell[45115, 1491, 521, 14, 60, "Input",
 CellTags->"b:3.2.0"],
Cell[45639, 1507, 252, 7, 49, "Text",
 CellTags->"b:3.2.0"],
Cell[45894, 1516, 407, 13, 63, "Input",
 CellTags->"b:3.2.0"],
Cell[46304, 1531, 112, 2, 22, "Text",
 CellTags->"b:3.2.0"],
Cell[46419, 1535, 115, 4, 44, "Input",
 CellTags->"b:3.2.0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[46571, 1544, 206, 6, 57, "Subsection",
 CellTags->{"c:13", "b:3.2.1"}],
Cell[46780, 1552, 104, 2, 22, "Text",
 CellTags->"b:3.2.1"],
Cell[46887, 1556, 96, 3, 44, "Input",
 CellTags->"b:3.2.1"],
Cell[46986, 1561, 119, 2, 22, "Text",
 CellTags->"b:3.2.1"],
Cell[47108, 1565, 90, 3, 44, "Input",
 CellTags->"b:3.2.1"],
Cell[47201, 1570, 175, 5, 22, "Text",
 CellTags->"b:3.2.1"],
Cell[47379, 1577, 327, 11, 44, "Input",
 CellTags->"b:3.2.1"],
Cell[47709, 1590, 277, 8, 44, "Input",
 CellTags->"b:3.2.1"],
Cell[47989, 1600, 680, 19, 60, "Input",
 CellTags->"b:3.2.1"],
Cell[48672, 1621, 1123, 37, 157, "Text",
 CellTags->"b:3.2.1"],
Cell[49798, 1660, 215, 7, 44, "Input",
 CellTags->"b:3.2.1"],
Cell[50016, 1669, 284, 9, 22, "Text",
 CellTags->"b:3.2.1"],
Cell[50303, 1680, 562, 17, 105, "Input",
 CellTags->"b:3.2.1"],
Cell[50868, 1699, 249, 7, 49, "Text",
 CellTags->"b:3.2.1"],
Cell[51120, 1708, 379, 12, 44, "Input",
 CellTags->"b:3.2.1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[51536, 1725, 353, 11, 59, "Subsection",
 CellTags->{"c:14", "b:3.2.2"}],
Cell[51892, 1738, 896, 29, 95, "Text",
 CellTags->"b:3.2.2"]
}, Closed]],
Cell[CellGroupData[{
Cell[52825, 1772, 469, 15, 47, "Subsection",
 CellTags->{"c:15", "b:3.2.3"}],
Cell[53297, 1789, 99, 2, 22, "Text",
 CellTags->"b:3.2.3"],
Cell[53399, 1793, 499, 16, 44, "Input",
 CellTags->"b:3.2.3"],
Cell[53901, 1811, 77, 2, 44, "Input",
 CellTags->"b:3.2.3"],
Cell[53981, 1815, 1154, 40, 60, "Text",
 CellTags->"b:3.2.3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[55172, 1860, 149, 3, 57, "Subsection",
 CellTags->{"c:16", "b:3.2.4"}],
Cell[55324, 1865, 286, 9, 52, "Text",
 CellTags->"b:3.2.4"],
Cell[55613, 1876, 363, 12, 59, "Input",
 CellTags->"b:3.2.4"],
Cell[55979, 1890, 315, 10, 82, "Input",
 CellTags->"b:3.2.4"],
Cell[56297, 1902, 425, 16, 22, "Text",
 CellTags->"b:3.2.4"],
Cell[56725, 1920, 446, 14, 44, "Input",
 CellTags->"b:3.2.4"],
Cell[57174, 1936, 287, 10, 22, "Text",
 CellTags->"b:3.2.4"],
Cell[57464, 1948, 1054, 34, 84, "Input",
 CellTags->"b:3.2.4"],
Cell[58521, 1984, 134, 4, 22, "Text",
 CellTags->"b:3.2.4"],
Cell[58658, 1990, 764, 25, 75, "Input",
 CellTags->"b:3.2.4"],
Cell[59425, 2017, 81, 2, 22, "Text",
 CellTags->"b:3.2.4"],
Cell[59509, 2021, 98, 3, 44, "Input",
 CellTags->"b:3.2.4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[59644, 2029, 143, 3, 57, "Subsection",
 CellTags->{"c:17", "b:3.2.5"}],
Cell[59790, 2034, 160, 5, 22, "Text",
 CellTags->"b:3.2.5"],
Cell[59953, 2041, 127, 4, 44, "Input",
 CellTags->"b:3.2.5"],
Cell[60083, 2047, 913, 26, 75, "Input",
 CellTags->"b:3.2.5"],
Cell[60999, 2075, 291, 8, 60, "Input",
 CellTags->"b:3.2.5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[61327, 2088, 190, 6, 57, "Subsection",
 CellTags->{"c:18", "b:3.2.6"}],
Cell[61520, 2096, 154, 5, 22, "Text",
 CellTags->"b:3.2.6"],
Cell[61677, 2103, 120, 4, 44, "Input",
 CellTags->"b:3.2.6"],
Cell[61800, 2109, 750, 23, 70, "Input",
 CellTags->"b:3.2.6"],
Cell[62553, 2134, 156, 5, 22, "Text",
 CellTags->"b:3.2.6"],
Cell[62712, 2141, 803, 22, 75, "Input",
 CellTags->"b:3.2.6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[63552, 2168, 169, 5, 57, "Subsection",
 CellTags->{"c:19", "b:3.2.7"}],
Cell[63724, 2175, 512, 12, 130, "Text",
 CellTags->"b:3.2.7"],
Cell[64239, 2189, 89, 3, 44, "Input",
 CellTags->"b:3.2.7"],
Cell[64331, 2194, 4219, 115, 265, "Input",
 CellTags->"b:3.2.7"],
Cell[68553, 2311, 767, 20, 105, "Input",
 CellTags->"b:3.2.7"],
Cell[69323, 2333, 81, 2, 44, "Input",
 CellTags->"b:3.2.7"],
Cell[69407, 2337, 264, 7, 76, "Text",
 CellTags->"b:3.2.7"],
Cell[69674, 2346, 413, 13, 66, "Input",
 CellTags->"b:3.2.7"],
Cell[70090, 2361, 43, 1, 44, "Input",
 CellTags->"b:3.2.7"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[70182, 2368, 162, 5, 31, "Section",
 CellTags->"c:20"],
Cell[CellGroupData[{
Cell[70369, 2377, 264, 9, 57, "Subsection",
 CellTags->{"c:21", "b:3.3.0"}],
Cell[70636, 2388, 133, 3, 46, "Input",
 CellTags->"b:3.3.0"],
Cell[70772, 2393, 112, 3, 46, "Input",
 CellTags->"b:3.3.0"],
Cell[70887, 2398, 139, 4, 22, "Text",
 CellTags->"b:3.3.0"],
Cell[71029, 2404, 1050, 34, 60, "Input",
 CellTags->"b:3.3.0"],
Cell[72082, 2440, 2076, 55, 90, "Input",
 CellTags->"b:3.3.0"],
Cell[74161, 2497, 520, 14, 60, "Input",
 CellTags->"b:3.3.0"],
Cell[74684, 2513, 2134, 57, 90, "Input",
 CellTags->"b:3.3.0"],
Cell[76821, 2572, 521, 14, 60, "Input",
 CellTags->"b:3.3.0"],
Cell[77345, 2588, 260, 6, 49, "Text",
 CellTags->"b:3.3.0"],
Cell[77608, 2596, 407, 13, 63, "Input",
 CellTags->"b:3.3.0"],
Cell[78018, 2611, 112, 2, 22, "Text",
 CellTags->"b:3.3.0"],
Cell[78133, 2615, 115, 4, 44, "Input",
 CellTags->"b:3.3.0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[78285, 2624, 214, 6, 57, "Subsection",
 CellTags->{"c:22", "b:3.3.1"}],
Cell[78502, 2632, 107, 2, 22, "Text",
 CellTags->"b:3.3.1"],
Cell[78612, 2636, 90, 3, 44, "Input",
 CellTags->"b:3.3.1"],
Cell[78705, 2641, 119, 2, 22, "Text",
 CellTags->"b:3.3.1"],
Cell[78827, 2645, 90, 3, 44, "Input",
 CellTags->"b:3.3.1"],
Cell[78920, 2650, 175, 5, 22, "Text",
 CellTags->"b:3.3.1"],
Cell[79098, 2657, 301, 10, 44, "Input",
 CellTags->"b:3.3.1"],
Cell[79402, 2669, 680, 19, 60, "Input",
 CellTags->"b:3.3.1"],
Cell[80085, 2690, 215, 7, 44, "Input",
 CellTags->"b:3.3.1"],
Cell[80303, 2699, 576, 17, 103, "Text",
 CellTags->"b:3.3.1"],
Cell[80882, 2718, 513, 16, 90, "Input",
 CellTags->"b:3.3.1"],
Cell[81398, 2736, 248, 7, 49, "Text",
 CellTags->"b:3.3.1"],
Cell[81649, 2745, 379, 12, 44, "Input",
 CellTags->"b:3.3.1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[82065, 2762, 353, 11, 59, "Subsection",
 CellTags->{"c:23", "b:3.3.2"}],
Cell[82421, 2775, 748, 24, 65, "Text",
 CellTags->"b:3.3.2"],
Cell[83172, 2801, 503, 18, 60, "Input",
 CellTags->"b:3.3.2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[83712, 2824, 469, 15, 63, "Subsection",
 CellTags->{"c:24", "b:3.3.3"}],
Cell[84184, 2841, 118, 2, 22, "Text",
 CellTags->"b:3.3.3"],
Cell[84305, 2845, 499, 16, 44, "Input",
 CellTags->"b:3.3.3"],
Cell[84807, 2863, 156, 5, 49, "Text",
 CellTags->"b:3.3.3"],
Cell[84966, 2870, 1224, 41, 80, "Input",
 CellTags->"b:3.3.3"],
Cell[86193, 2913, 201, 6, 60, "Input",
 CellTags->"b:3.3.3"],
Cell[86397, 2921, 106, 2, 22, "Text",
 CellTags->"b:3.3.3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[86540, 2928, 129, 3, 57, "Subsection",
 CellTags->{"c:25", "b:3.3.4"}],
Cell[86672, 2933, 216, 6, 49, "Text",
 CellTags->"b:3.3.4"],
Cell[86891, 2941, 363, 12, 59, "Input",
 CellTags->"b:3.3.4"],
Cell[87257, 2955, 258, 8, 22, "Text",
 CellTags->"b:3.3.4"],
Cell[87518, 2965, 736, 23, 75, "Input",
 CellTags->"b:3.3.4"],
Cell[88257, 2990, 228, 7, 60, "Input",
 CellTags->"b:3.3.4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[88522, 3002, 138, 3, 57, "Subsection",
 CellTags->{"c:26", "b:3.3.5"}],
Cell[88663, 3007, 240, 9, 22, "Text",
 CellTags->"b:3.3.5"],
Cell[88906, 3018, 127, 4, 44, "Input",
 CellTags->"b:3.3.5"],
Cell[89036, 3024, 905, 27, 81, "Input",
 CellTags->"b:3.3.5"],
Cell[89944, 3053, 127, 4, 44, "Input",
 CellTags->"b:3.3.5"],
Cell[90074, 3059, 180, 4, 44, "Input",
 CellTags->"b:3.3.5"],
Cell[90257, 3065, 143, 4, 22, "Text",
 CellTags->"b:3.3.5"],
Cell[90403, 3071, 120, 4, 44, "Input",
 CellTags->"b:3.3.5"],
Cell[90526, 3077, 750, 23, 70, "Input",
 CellTags->"b:3.3.5"],
Cell[91279, 3102, 496, 15, 75, "Input",
 CellTags->"b:3.3.5"],
Cell[91778, 3119, 810, 23, 75, "Input",
 CellTags->"b:3.3.5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[92625, 3147, 198, 6, 57, "Subsection",
 CellTags->{"c:27", "b:3.3.6"}],
Cell[92826, 3155, 201, 6, 49, "Text",
 CellTags->"b:3.3.6"],
Cell[93030, 3163, 54, 1, 44, "Input",
 CellTags->"b:3.3.6"],
Cell[93087, 3166, 89, 3, 44, "Input",
 CellTags->"b:3.3.6"],
Cell[93179, 3171, 4219, 115, 265, "Input",
 CellTags->"b:3.3.6"],
Cell[97401, 3288, 666, 18, 90, "Input",
 CellTags->"b:3.3.6"],
Cell[98070, 3308, 81, 2, 44, "Input",
 CellTags->"b:3.3.6"],
Cell[98154, 3312, 52, 1, 44, "Input",
 CellTags->"b:3.3.6"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[98255, 3319, 174, 7, 31, "Section",
 CellTags->"c:28"],
Cell[CellGroupData[{
Cell[98454, 3330, 180, 5, 57, "Subsection",
 CellTags->{"c:29", "b:3.4.0"}],
Cell[98637, 3337, 133, 3, 46, "Input",
 CellTags->"b:3.4.0"],
Cell[98773, 3342, 112, 3, 46, "Input",
 CellTags->"b:3.4.0"],
Cell[98888, 3347, 168, 5, 22, "Text",
 CellTags->"b:3.4.0"],
Cell[99059, 3354, 252, 7, 49, "Text",
 CellTags->"b:3.4.0"],
Cell[99314, 3363, 407, 13, 63, "Input",
 CellTags->"b:3.4.0"],
Cell[99724, 3378, 112, 2, 22, "Text",
 CellTags->"b:3.4.0"],
Cell[99839, 3382, 115, 4, 44, "Input",
 CellTags->"b:3.4.0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[99991, 3391, 206, 6, 57, "Subsection",
 CellTags->{"c:30", "b:3.4.1"}],
Cell[100200, 3399, 104, 2, 22, "Text",
 CellTags->"b:3.4.1"],
Cell[100307, 3403, 95, 3, 44, "Input",
 CellTags->"b:3.4.1"],
Cell[100405, 3408, 119, 2, 22, "Text",
 CellTags->"b:3.4.1"],
Cell[100527, 3412, 90, 3, 44, "Input",
 CellTags->"b:3.4.1"],
Cell[100620, 3417, 157, 5, 22, "Text",
 CellTags->"b:3.4.1"],
Cell[100780, 3424, 327, 11, 44, "Input",
 CellTags->"b:3.4.1"],
Cell[101110, 3437, 277, 8, 44, "Input",
 CellTags->"b:3.4.1"],
Cell[101390, 3447, 680, 19, 60, "Input",
 CellTags->"b:3.4.1"],
Cell[102073, 3468, 1121, 37, 157, "Text",
 CellTags->"b:3.4.1"],
Cell[103197, 3507, 215, 7, 44, "Input",
 CellTags->"b:3.4.1"],
Cell[103415, 3516, 464, 14, 90, "Input",
 CellTags->"b:3.4.1"],
Cell[103882, 3532, 248, 7, 49, "Text",
 CellTags->"b:3.4.1"],
Cell[104133, 3541, 379, 12, 44, "Input",
 CellTags->"b:3.4.1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[104549, 3558, 353, 11, 59, "Subsection",
 CellTags->{"c:31", "b:3.4.2"}],
Cell[104905, 3571, 896, 29, 92, "Text",
 CellTags->"b:3.4.2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[105838, 3605, 469, 15, 63, "Subsection",
 CellTags->{"c:32", "b:3.4.3"}],
Cell[106310, 3622, 99, 2, 22, "Text",
 CellTags->"b:3.4.3"],
Cell[106412, 3626, 499, 16, 44, "Input",
 CellTags->"b:3.4.3"],
Cell[106914, 3644, 1154, 40, 60, "Text",
 CellTags->"b:3.4.3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[108105, 3689, 149, 3, 57, "Subsection",
 CellTags->{"c:33", "b:3.4.4"}],
Cell[108257, 3694, 286, 9, 52, "Text",
 CellTags->"b:3.4.4"],
Cell[108546, 3705, 363, 12, 59, "Input",
 CellTags->"b:3.4.4"],
Cell[108912, 3719, 315, 10, 82, "Input",
 CellTags->"b:3.4.4"],
Cell[109230, 3731, 425, 16, 22, "Text",
 CellTags->"b:3.4.4"],
Cell[109658, 3749, 906, 29, 60, "Input",
 CellTags->"b:3.4.4"],
Cell[110567, 3780, 287, 10, 22, "Text",
 CellTags->"b:3.4.4"],
Cell[110857, 3792, 1964, 62, 104, "Input",
 CellTags->"b:3.4.4"],
Cell[112824, 3856, 134, 4, 22, "Text",
 CellTags->"b:3.4.4"],
Cell[112961, 3862, 764, 25, 75, "Input",
 CellTags->"b:3.4.4"],
Cell[113728, 3889, 80, 2, 44, "Input",
 CellTags->"b:3.4.4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[113845, 3896, 143, 3, 57, "Subsection",
 CellTags->{"c:34", "b:3.4.5"}],
Cell[113991, 3901, 160, 5, 22, "Text",
 CellTags->"b:3.4.5"],
Cell[114154, 3908, 127, 4, 44, "Input",
 CellTags->"b:3.4.5"],
Cell[114284, 3914, 132, 4, 44, "Input",
 CellTags->"b:3.4.5"],
Cell[114419, 3920, 291, 8, 60, "Input",
 CellTags->"b:3.4.5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[114747, 3933, 190, 6, 57, "Subsection",
 CellTags->{"c:35", "b:3.4.6"}],
Cell[114940, 3941, 154, 5, 22, "Text",
 CellTags->"b:3.4.6"],
Cell[115097, 3948, 120, 4, 44, "Input",
 CellTags->"b:3.4.6"],
Cell[115220, 3954, 688, 22, 70, "Input",
 CellTags->"b:3.4.6"],
Cell[115911, 3978, 156, 5, 22, "Text",
 CellTags->"b:3.4.6"],
Cell[116070, 3985, 803, 22, 75, "Input",
 CellTags->"b:3.4.6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[116910, 4012, 169, 5, 57, "Subsection",
 CellTags->{"c:36", "b:3.4.7"}],
Cell[117082, 4019, 514, 12, 130, "Text",
 CellTags->"b:3.4.7"],
Cell[117599, 4033, 89, 3, 44, "Input",
 CellTags->"b:3.4.7"],
Cell[117691, 4038, 4219, 115, 265, "Input",
 CellTags->"b:3.4.7"],
Cell[121913, 4155, 767, 20, 105, "Input",
 CellTags->"b:3.4.7"],
Cell[122683, 4177, 81, 2, 44, "Input",
 CellTags->"b:3.4.7"],
Cell[122767, 4181, 264, 7, 76, "Text",
 CellTags->"b:3.4.7"],
Cell[123034, 4190, 441, 14, 60, "Input",
 CellTags->"b:3.4.7"],
Cell[123478, 4206, 43, 1, 44, "Input",
 CellTags->"b:3.4.7"]
}, Open  ]]
}, Closed]]
}
]
*)

(* End of internal cache information *)
