(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    243569,       7623]
NotebookOptionsPosition[    129253,       4712]
NotebookOutlinePosition[    223281,       6946]
CellTagsIndexPosition[    221264,       6867]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["Teleportation", "Title",
 CellTags->"c:1"],

Cell["Several Examples of Teleportation circuits", "Subtitle"],

Cell[TextData[{
 "Version: 3.0-April-2011--For ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " 6.0-8.0"
}], "Abstract",
 CellChangeTimes->{{3.395090887981901*^9, 3.395090925377634*^9}, 
   3.512212791983045*^9}],

Cell[TextData[ButtonBox["Click here to get the palette: QDENSpalette.nb",
 BaseStyle->"Hyperlink",
 ButtonData:>{"QDENSpalette.nb", None}]], "Text"],

Cell[CellGroupData[{

Cell["\<\
Teleportation Algorithm: One Qubit.                           To open double \
click at down arrow----------------->>\
\>", "Section",
 CellChangeTimes->{{3.512212804904114*^9, 3.512212806228137*^9}, {
  3.512214565679203*^9, 3.512214625017166*^9}},
 FontFamily->"Times",
 CellTags->"c:2"],

Cell[CellGroupData[{

Cell["Introduction", "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:3", "b:4.0.0"}],

Cell[TextData[StyleBox["Teleportation with Density Matrices July 2003 uses \
Qdensity package",
 FontFamily->"Helvetica"]], "Text",
 FontFamily->"Courier New",
 CellTags->"b:4.0.0"],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<QDENSITY`Qdensity`\>\"", "]"}]], "Input",
 FontFamily->"Courier New",
 CellTags->"b:4.0.0"],

Cell[BoxData[
 RowBox[{"?", "QDENSITY`Qdensity`*"}]], "Input",
 FontFamily->"Courier New",
 CellTags->"b:4.0.0"],

Cell[TextData[StyleBox["In the following figure we present the key \
ingredients in the teleportation process:", "DisplayText",
 FontWeight->"Plain",
 FontVariations->{"CompatibilityType"->0},
 Background->None]], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.0.0"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"figure", "=", 
   RowBox[{"Import", "[", 
    RowBox[{"\"\<QDENSITY/drawings/1tele.png\>\"", ",", "\"\<PNG\>\""}], 
    "]"}]}], ";"}], "\n", 
 RowBox[{"Show", "[", "figure", "]"}]}], "Input",
 CellTags->"b:4.0.0"],

Cell[TextData[{
 StyleBox["NOTE: The ", "DisplayText",
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0},
  Background->None],
 ButtonBox["Hadamard and CNOT gates",
  BaseStyle->"Hyperlink",
  ButtonData:>{"Tutorial.nb", "Quantum Gates"}],
 StyleBox[" acting on qubits 2 and 3 are used to build the a \nprecise EPR \
state  ", "DisplayText",
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0},
  Background->None],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"1", "/", 
         SqrtBox["2"]}], 
        RowBox[{"(", 
         RowBox[{"|", "00"}], "\[RightAngleBracket]"}]}], " ", "+"}], " ", 
      "|", "11"}], "\[RightAngleBracket]"}], " ", ")"}], TraditionalForm]]],
 StyleBox[", in the following the 4 different EPR states are considered", 
  "DisplayText",
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0},
  Background->None]
}], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.0.0"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Step 1: Alice prepares the state to be teleported", "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:3", "b:4.0.1"}],

Cell[TextData[StyleBox["Alice needs to specify qubit which will be teleported \
during the process. \nIn this example we construct it by choosing a random \
polarization vector:\nNote that if the magnitude of the polarization vector \
is less than 1, the state is not pure ", "DisplayText",
 FontWeight->"Plain",
 FontVariations->{"CompatibilityType"->0},
 Background->None]], "Text",
 Evaluatable->False,
 FontFamily->"Helvetica",
 CellTags->"b:4.0.1"],

Cell[BoxData[{
 RowBox[{"thet", "=", 
  RowBox[{"N", "[", 
   RowBox[{"RandomReal", "[", 
    RowBox[{"{", 
     RowBox[{"0", ",", "\[Pi]"}], "}"}], "]"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{" ", 
  RowBox[{"phi", "=", 
   RowBox[{"RandomReal", "[", 
    RowBox[{"{", 
     RowBox[{"0", ",", 
      RowBox[{"2", " ", "\[Pi]"}]}], "}"}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{" ", 
  RowBox[{"P", "=", 
   RowBox[{"RandomReal", "[", 
    RowBox[{"{", 
     RowBox[{"0", ",", "1"}], "}"}], "]"}]}]}]}], "Input",
 CellChangeTimes->{{3.395091186351873*^9, 3.395091189108654*^9}, {
   3.5122136672080393`*^9, 3.5122136715934267`*^9}, 3.512213743667622*^9, {
   3.512214177620192*^9, 3.5122141852552834`*^9}},
 CellTags->"b:4.0.1"],

Cell["Therefore its cartesian components are:", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.0.1"],

Cell["\<\
Px = P Sin[thet] Cos[phi]
Py = P Sin[thet] Sin[phi]
Pz = P Cos[thet]\
\>", "Input",
 CellChangeTimes->{{3.51221370954722*^9, 3.512213750240114*^9}, {
  3.51221419908955*^9, 3.5122142183035192`*^9}},
 CellTags->"b:4.0.1"],

Cell["\<\
This example permits both an algebraic computation or a numerical one. 
This is controlled by the value of Icalc: 1 [Algebraic] / Else [Numerical]\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.0.1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Icalc", "=", "0"}], ";"}]], "Input",
 CellChangeTimes->{{3.3950912467501907`*^9, 3.395091247300149*^9}},
 CellTags->"b:4.0.1"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"Icalc", "==", "1"}], ",", 
     RowBox[{"Clear", "[", 
      RowBox[{"Px", ",", "Py", ",", "Pz"}], "]"}], ","}], " ", "]"}], ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{"Px", ",", " ", "Py", ",", " ", "Pz"}], "}"}]}], "Input",
 FontFamily->"Courier New",
 CellTags->"b:4.0.1"],

Cell["\<\
Once the polarization vector has been chosen, in this case at random, we can 
write down its density matrix\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.0.1"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["\[Rho]", "\[Psi]"], " ", "=", " ", 
   RowBox[{
    RowBox[{"(", 
     StyleBox[
      RowBox[{"1", "/", "2"}],
      FontSize->12], 
     StyleBox[")",
      FontSize->12]}], 
    StyleBox[
     RowBox[{"(", " ", 
      RowBox[{"\[DoubleStruckCapitalI]", " ", "+", " ", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Px", ",", "Py", ",", "Pz"}], "}"}], ".", " ", 
        RowBox[{"{", 
         RowBox[{
          SubscriptBox["\[Sigma]", "1"], ",", " ", 
          SubscriptBox["\[Sigma]", "2"], " ", ",", 
          SubscriptBox["\[Sigma]", "3"]}], "}"}]}]}], ")"}],
     FontSize->12]}]}], 
  StyleBox[";",
   FontSize->12], 
  StyleBox[
   RowBox[{"Chop", "[", 
    SubscriptBox["\[Rho]", "\[Psi]"], " ", "]"}],
   FontSize->12], " "}]], "Input",
 FontFamily->"Courier New",
 CellTags->"b:4.0.1"],

Cell["\<\
If everything went ok, the density matrix should be Hermitian:\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.0.1"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"Icalc", "\[Equal]", "0"}], ",", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Chop", "[", 
        RowBox[{
         RowBox[{"Adj", "[", 
          SubscriptBox["\[Rho]", "\[Psi]"], "]"}], " ", "-", 
         SubscriptBox["\[Rho]", "\[Psi]"]}], "]"}], "\[Equal]", 
       RowBox[{"ZeroMatrix", "[", 
        RowBox[{"Length", "[", 
         SubscriptBox["\[Rho]", "\[Psi]"], "]"}], "]"}]}], ",", 
      RowBox[{"Print", "[", "\"\<Hermitian\>\"", "]"}], ",", 
      RowBox[{"Print", "[", "\"\<Not Hermitian\>\"", "]"}]}], "]"}], ",", 
    "\"\<\>\""}], "]"}]}]], "Input",
 FontFamily->"Courier New",
 CellTags->"b:4.0.1"],

Cell["Its Eigenvalues, Trace and Purity can be readily computed:", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.0.1"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"evPsi", ":=", 
   RowBox[{"Eigenvalues", "[", 
    SubscriptBox["\[Rho]", "\[Psi]"], "]"}]}], ";"}], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{"Chop", "[", "evPsi", "]"}],
  FontSize->12], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"Chop", "[", 
   RowBox[{"Tr", "[", 
    SubscriptBox["\[Rho]", "\[Psi]"], " ", "]"}], 
   StyleBox["]",
    FontSize->12]}], 
  StyleBox["]",
   FontSize->12]}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"Chop", "[", 
   RowBox[{"Purity", "[", 
    StyleBox[
     SubscriptBox["\[Rho]", "\[Psi]"],
     FontSize->12], 
    StyleBox["]",
     FontSize->12]}], 
   StyleBox["]",
    FontSize->12]}], 
  StyleBox["]",
   FontSize->12]}]}], "Input",
 FontFamily->"Courier New",
 CellTags->"b:4.0.1"],

Cell["Eigenvalues should be positive", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.0.1"],

Cell[BoxData[
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Chop", "[", 
       RowBox[{"evPsi", "[", 
        RowBox[{"[", "i", "]"}], "]"}], "]"}], "\[GreaterEqual]", "0"}], ",", 
     RowBox[{"Print", "[", "\"\<Positive eigenvalue\>\"", "]"}], ",", 
     RowBox[{"Print", "[", "\"\<Negative\>\"", "]"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "1", ",", "2"}], "}"}]}], "]"}]], "Input",
 FontFamily->"Courier New",
 CellTags->{"Do", "b:4.0.1"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Step 2: Bob prepares the Bell state", "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:4", "b:4.0.2"}],

Cell["\<\
Bob needs to share a Bell state, 2 qubits, with Alice. He prepares it in the \
following way. 
First, he constructs the four density matrices needed:\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.0.2"],

Cell[BoxData[{
 RowBox[{
  StyleBox[
   SubscriptBox["\[Rho]", "00"],
   FontSize->12], 
  StyleBox["=",
   FontSize->12], 
  RowBox[{
   SubscriptBox["\[ScriptCapitalP]", "0"], "  ", "\[CircleTimes]", "  ", 
   SubscriptBox["\[ScriptCapitalP]", "0"]}]}], "\[IndentingNewLine]", 
 RowBox[{
  StyleBox[
   SubscriptBox["\[Rho]", "01"],
   FontSize->12], 
  StyleBox["=",
   FontSize->12], 
  RowBox[{
   SubscriptBox["\[ScriptCapitalP]", "0"], "  ", "\[CircleTimes]", "  ", 
   SubscriptBox["\[ScriptCapitalP]", "1"]}]}], "\[IndentingNewLine]", 
 RowBox[{
  StyleBox[
   SubscriptBox["\[Rho]", "10"],
   FontSize->12], 
  StyleBox["=",
   FontSize->12], 
  RowBox[{
   SubscriptBox["\[ScriptCapitalP]", "1"], "  ", "\[CircleTimes]", "  ", 
   SubscriptBox["\[ScriptCapitalP]", "0"]}]}], "\[IndentingNewLine]", 
 RowBox[{
  StyleBox[
   SubscriptBox["\[Rho]", "11"],
   FontSize->12], 
  StyleBox["=",
   FontSize->12], 
  RowBox[{
   SubscriptBox["\[ScriptCapitalP]", "1"], "  ", "\[CircleTimes]", "  ", 
   SubscriptBox["\[ScriptCapitalP]", "1"]}]}]}], "Input",
 CellTags->"b:4.0.2"],

Cell["\<\
The Bell state operator of qubits i and j can be decomposed into the action \
of a Hadamard 
on qubit i and a CNOT gate on qubits i and j.\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.0.2"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"Bellop", "[", 
    RowBox[{"qi_", ",", "qj_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"CNOT", "[", 
     RowBox[{"2", ",", "qi", ",", "qj"}], "]"}], ".", 
    RowBox[{"had", "[", 
     RowBox[{"2", ",", "qi"}], "]"}]}], " "}]}]], "Input",
 FontFamily->"Courier New",
 CellTags->"b:4.0.2"],

Cell["\<\
NOTE: an alternative way using LEFT operator \
BellOp[qi_,qj_]:=CNOT[2,qi,qj].had[2,qi].(\[Sigma]\[CircleTimes]\
\[DoubleStruckCapitalI])\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.0.2"],

Cell[BoxData[
 RowBox[{"Bellop", "[", 
  RowBox[{"1", ",", "2"}], "]"}]], "Input",
 FontFamily->"Courier New",
 CellTags->"b:4.0.2"],

Cell["\<\
The density matrix for any of the four Bell states produced by Bob from \
qubits 2 & 3. 
Afterwards, Bob sends one of these qubits to Alice who has qubit 1 in state \
\[Psi]\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.0.2"],

Cell[BoxData[
 StyleBox[
  RowBox[{" ", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["\[Rho]", "B00"], "  ", ":=", " ", 
      RowBox[{
       RowBox[{"Bellop", "[", 
        RowBox[{"1", ",", "2"}], "]"}], ".", 
       SubscriptBox["\[Rho]", "00"], ".", 
       RowBox[{"Adj", "[", 
        RowBox[{"Bellop", "[", 
         RowBox[{"1", ",", "2"}], "]"}], "]"}]}]}], ";"}], 
    "\[IndentingNewLine]", " ", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Rho]", "B01"], "  ", ":=", " ", 
      RowBox[{
       RowBox[{"Bellop", "[", 
        RowBox[{"1", ",", "2"}], "]"}], ".", 
       SubscriptBox["\[Rho]", "01"], ".", 
       RowBox[{"Adj", "[", 
        RowBox[{"Bellop", "[", 
         RowBox[{"1", ",", "2"}], "]"}], "]"}]}]}], ";"}], 
    "\[IndentingNewLine]", " ", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Rho]", "B10"], "  ", ":=", " ", 
      RowBox[{
       RowBox[{"Bellop", "[", 
        RowBox[{"1", ",", "2"}], "]"}], ".", 
       SubscriptBox["\[Rho]", "10"], ".", 
       RowBox[{"Adj", "[", 
        RowBox[{"Bellop", "[", 
         RowBox[{"1", ",", "2"}], "]"}], "]"}]}]}], ";"}], 
    "\[IndentingNewLine]", " ", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Rho]", "B11"], "  ", ":=", " ", 
      RowBox[{
       RowBox[{"Bellop", "[", 
        RowBox[{"1", ",", "2"}], "]"}], ".", 
       SubscriptBox["\[Rho]", "11"], ".", 
       RowBox[{"Adj", "[", 
        RowBox[{"Bellop", "[", 
         RowBox[{"1", ",", "2"}], "]"}], "]"}]}]}], ";"}]}]}],
  FontSize->12]], "Input",
 FontFamily->"Courier New",
 FontSize->12,
 CellTags->"b:4.0.2"],

Cell["Checks on Bell states", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.0.2"],

Cell[BoxData[{
 StyleBox[
  SubscriptBox["\[Rho]", "B00"],
  FontSize->12], "\[IndentingNewLine]", 
 StyleBox[
  SubscriptBox["\[Rho]", "B01"],
  FontSize->12], "\[IndentingNewLine]", 
 StyleBox[
  SubscriptBox["\[Rho]", "B10"],
  FontSize->12], "\[IndentingNewLine]", 
 StyleBox[
  SubscriptBox["\[Rho]", "B11"],
  FontSize->12]}], "Input",
 CellTags->"b:4.0.2"],

Cell["\<\
Bob needs to know the type of Bell state shared with Alice, either by \
preparing it himself or 
by being informed of its type by a message from Alice or from a third party \
distributor of Bell states  
In our example we pick one of the 4 Bell States at random\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.0.2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Ipick", "=", 
   RowBox[{"RandomInteger", "[", 
    RowBox[{"{", 
     RowBox[{"1", ",", "4"}], "}"}], "]"}]}], ";"}]], "Input",
 CellTags->"b:4.0.2"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Rho]", 
   RowBox[{"B", " "}]], "=", 
  RowBox[{"Which", "[", 
   RowBox[{
    RowBox[{"Ipick", "==", "1"}], ",", 
    SubscriptBox["\[Rho]", "B00"], ",", 
    RowBox[{"Ipick", "==", "2"}], ",", 
    SubscriptBox["\[Rho]", "B01"], ",", 
    RowBox[{"Ipick", "==", "3"}], ",", 
    SubscriptBox["\[Rho]", "B10"], ",", 
    RowBox[{"Ipick", "==", "4"}], ",", 
    SubscriptBox["\[Rho]", "B11"]}], "]"}]}]], "Input",
 CellTags->"b:4.0.2"],

Cell["\<\
He computes the vector and tensor polarizations of the Bell state in the \
following way:\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.0.2"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"T", "[", 
    RowBox[{"i_", ",", "j_"}], "]"}], ":=", 
   RowBox[{"Tr", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Sigma]", "i"], "\[CircleTimes]", 
       SubscriptBox["\[Sigma]", "j"]}], ")"}], ".", 
     StyleBox[
      SubscriptBox["\[Rho]", "B"],
      FontSize->12]}], 
    StyleBox[" ",
     FontSize->12], 
    StyleBox["]",
     FontSize->12]}]}], 
  StyleBox[";",
   FontSize->12]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   StyleBox["PA",
    FontSize->12], 
   StyleBox["=",
    FontSize->12], 
   RowBox[{
    StyleBox["{",
     FontSize->12], 
    RowBox[{
     StyleBox[
      RowBox[{"T", "[", 
       RowBox[{"1", ",", "0"}], "]"}],
      FontSize->12], 
     StyleBox[",",
      FontSize->12], 
     RowBox[{"T", "[", 
      RowBox[{"2", ",", "0"}], "]"}], ",", 
     RowBox[{"T", "[", 
      RowBox[{"3", ",", "0"}], "]"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   StyleBox["PB",
    FontSize->12], 
   StyleBox["=",
    FontSize->12], 
   RowBox[{
    StyleBox["{",
     FontSize->12], 
    RowBox[{
     StyleBox[
      RowBox[{"T", "[", 
       RowBox[{"0", ",", "1"}], "]"}],
      FontSize->12], 
     StyleBox[",",
      FontSize->12], 
     RowBox[{"T", "[", 
      RowBox[{"0", ",", "2"}], "]"}], ",", 
     RowBox[{"T", "[", 
      RowBox[{"0", ",", "3"}], "]"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   StyleBox[
    RowBox[{"T", 
     StyleBox["AB",
      FontSize->12]}]], 
   StyleBox["=",
    FontSize->12], 
   RowBox[{
    StyleBox["{",
     FontSize->12], 
    RowBox[{
     StyleBox["Table",
      FontSize->12], 
     StyleBox["[",
      FontSize->12], 
     RowBox[{
      StyleBox[
       RowBox[{"T", "[", 
        RowBox[{"i", ",", "j"}], "]"}],
       FontSize->12], 
      StyleBox[",",
       FontSize->12], 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "1", ",", "3"}], "}"}]}], "]"}], "}"}]}], 
  ";"}]}], "Input",
 FontFamily->"Courier New",
 CellTags->"b:4.0.2"],

Cell["Vector polarizations are zero for Bell states", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.0.2"],

Cell[BoxData[{"PA", "\[IndentingNewLine]", "PB"}], "Input",
 CellTags->"b:4.0.2"],

Cell["Tensor polarizations for Bell state", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.0.2"],

Cell[BoxData[
 RowBox[{"Flatten", "[", 
  RowBox[{"TAB", ",", "1"}], "]"}]], "Input",
 CellTags->"b:4.0.2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Step 3: The three Qubits", "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:5", "b:4.0.3"}],

Cell["\<\
The tensor product of both the qubit prepared by Alice and the Bell state \
prepared 
by Bob can be computed. The complete density matrix is then:\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.0.3"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   SubscriptBox["\[Rho]", "C"],
   FontSize->12], 
  StyleBox["=",
   FontSize->12], 
  StyleBox[" ",
   FontSize->12], 
  RowBox[{
   SubscriptBox["\[Rho]", "\[Psi]"], " ", "\[CircleTimes]", " ", 
   StyleBox[
    SubscriptBox["\[Rho]", "B"],
    FontSize->12]}]}]], "Input",
 FontFamily->"Courier New",
 CellTags->"b:4.0.3"],

Cell["We check its length and Trace:", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.0.3"],

Cell[BoxData[
 RowBox[{"Length", "[", 
  StyleBox[
   SubscriptBox["\[Rho]", "C"],
   FontSize->12], 
  StyleBox["]",
   FontSize->12]}]], "Input",
 FontFamily->"Courier New",
 CellTags->"b:4.0.3"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"Chop", "[", 
   RowBox[{"Tr", "[", 
    StyleBox[
     SubscriptBox["\[Rho]", "C"],
     FontSize->12], 
    StyleBox["]",
     FontSize->12]}], 
   StyleBox["]",
    FontSize->12]}], 
  StyleBox["]",
   FontSize->12]}]], "Input",
 FontFamily->"Courier New",
 CellTags->"b:4.0.3"],

Cell[TextData[{
 "The Trace of ",
 Cell[BoxData[
  StyleBox[
   SubscriptBox["\[Rho]", "C"],
   FontSize->12]],
  FontFamily->"Helvetica"],
 "squared is a meassure of the purity of the state of the whole system:"
}], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.0.3"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"Chop", "[", 
   RowBox[{"Tr", "[", 
    RowBox[{
     SubscriptBox["\[Rho]", "C"], 
     StyleBox[".",
      FontSize->12], 
     SubscriptBox["\[Rho]", "C"]}], 
    StyleBox["]",
     FontSize->12]}], 
   StyleBox["]",
    FontSize->12]}], 
  StyleBox["]",
   FontSize->12]}]], "Input",
 FontFamily->"Courier New",
 CellTags->"b:4.0.3"],

Cell["\<\
Finally we check its eigenvalues are positive as they should be:\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.0.3"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"evC", ":=", 
   RowBox[{"Eigenvalues", "[", 
    StyleBox[
     SubscriptBox["\[Rho]", "C"],
     FontSize->12], 
    StyleBox["]",
     FontSize->12]}]}], 
  StyleBox[";",
   FontSize->12]}], "\[IndentingNewLine]", 
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Chop", "[", 
       RowBox[{"evC", "[", 
        RowBox[{"[", "i", "]"}], "]"}], "]"}], "\[GreaterEqual]", "0"}], ",", 
     RowBox[{"Print", "[", "\"\<Positive eigenvalue\>\"", "]"}], ",", 
     RowBox[{"Print", "[", "\"\<Negative\>\"", "]"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "1", ",", 
     RowBox[{"Length", "[", "evC", "]"}]}], "}"}]}], "]"}]}], "Input",
 FontFamily->"Courier New",
 CellTags->{"Do", "b:4.0.3"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Step 4: Bob sends qubit 2 to Alice", "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:6", "b:4.0.4"}],

Cell["\<\
Alice, now receives one qubit from Bob and performs the following operations. \
Let us remind that the labelling is 
now: 
\tQubit 1: Original unknown qubit Alice wants to teleport
\tQubit 2: Qubit that Bob is sending her from the EPR pair
\tQubit 3: Bob's qubit that was in a Bell state with Qubit 2
\
\>", "Text",
 TextJustification->0,
 FontFamily->"Helvetica",
 CellTags->"b:4.0.4"],

Cell["\<\
Now Alice performs a series of operations with her original qubit and the one \
received from Bob.
CNOT on Alice's Qubits 1,2; 
Followed by Hadamard on qubit 1, 
whereby Alice entangles her original qubit with one of the shared ones\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.0.4"],

Cell[BoxData[
 RowBox[{"Three", " ", "qubit", " ", "density", "  ", "is", " ", "now", " ", 
  "denoted", " ", "by", " ", 
  SubscriptBox["\[Rho]", "T"]}]], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.0.4"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["\[Rho]", "T"], "=", 
   RowBox[{
    RowBox[{"had", "[", 
     RowBox[{"3", ",", "1"}], "]"}], ".", 
    RowBox[{"CNOT", "[", 
     RowBox[{"3", ",", "1", ",", "2"}], "]"}], ".", 
    StyleBox[
     SubscriptBox["\[Rho]", "C"],
     FontSize->12], ".", 
    RowBox[{"CNOT", "[", 
     RowBox[{"3", ",", "1", ",", "2"}], "]"}], ".", 
    RowBox[{"had", "[", 
     RowBox[{"3", ",", "1"}], "]"}]}]}], ";"}]], "Input",
 FontFamily->"Courier New",
 CellTags->"b:4.0.4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Some", " ", "Checks", " ", "on", " ", 
   SubscriptBox["\[Rho]", "T"]}], ",", " ", "Trace", ",", " ", "purity", ",", 
  " ", 
  RowBox[{"eigenvalues", " ", "and", " ", 
   RowBox[{"length", "."}]}]}]], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.0.4"],

Cell[BoxData[{
 RowBox[{"Simplify", "[", 
  RowBox[{"Chop", "[", 
   RowBox[{"Tr", "[", 
    SubscriptBox["\[Rho]", "T"], "]"}], "]"}], "]"}], "\n", 
 RowBox[{"Simplify", "[", 
  RowBox[{"Chop", "[", 
   RowBox[{"Tr", "[", 
    RowBox[{
     SubscriptBox["\[Rho]", "T"], ".", 
     SubscriptBox["\[Rho]", "T"]}], "]"}], "]"}], "]"}]}], "Input",
 FontFamily->"Courier New",
 CellTags->"b:4.0.4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"evF", ":=", 
   RowBox[{"Eigenvalues", "[", 
    SubscriptBox["\[Rho]", "T"], "]"}]}], ";", 
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Chop", "[", 
        RowBox[{"evF", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "]"}], "\[GreaterEqual]", "0"}], ",", 
      RowBox[{"Print", "[", "\"\<Positive eigenvalue\>\"", "]"}], ",", 
      RowBox[{"Print", "[", "\"\<Negative\>\"", "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", 
      RowBox[{"Length", "[", "evF", "]"}]}], "}"}]}], "]"}]}]], "Input",
 FontFamily->"Courier New",
 CellTags->"b:4.0.4"],

Cell[BoxData[
 RowBox[{"Length", "[", 
  SubscriptBox["\[Rho]", "T"], "]"}]], "Input",
 FontFamily->"Courier New",
 CellTags->"b:4.0.4"],

Cell[TextData[{
 "Four Projection Operators for Qubits 1 and 2 are used for ",
 ButtonBox["projective measurements",
  BaseStyle->"Hyperlink",
  ButtonData:>{"Tutorial.nb", None}],
 " on Qubits 1 & 2 by Alice"
}], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.0.4"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["P", 
   RowBox[{"a_", ",", "b_"}]], "  ", ":=", "  ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["\[ScriptCapitalP]", "a"], "  ", "\[CircleTimes]", "  ", 
     SubscriptBox["\[ScriptCapitalP]", "b"]}], ")"}], "\[CircleTimes]", " ", 
   "\[DoubleStruckCapitalI]"}]}]], "Input",
 CellTags->"b:4.0.4"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{
    SubscriptBox["P", 
     RowBox[{"0", ",", "0"}]], ";"}], "\n", " ", 
   RowBox[{
    SubscriptBox["P", 
     RowBox[{"0", ",", "1"}]], " ", ";"}], " ", "\[IndentingNewLine]", " ", 
   RowBox[{
    SubscriptBox["P", 
     RowBox[{"1", ",", "0"}]], " ", ";"}], "\n", " ", 
   RowBox[{
    SubscriptBox["P", 
     RowBox[{"1", ",", "1"}]], ";"}]}]}]], "Input",
 FontFamily->"Courier New",
 CellTags->"b:4.0.4"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Step 5: Alice measures the state of her Qubits", "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:7", "b:4.0.5"}],

Cell[TextData[{
 "After receiving the qubit form Bob and performing the abovementioned \
operations, \nshe measures the state of her two qubits obtaining values: ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "a"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "b"], TraditionalForm]]],
 ". Bob's  Density Matrix, \nafter Alice measures is computed:"
}], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.0.5"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   SubscriptBox["a", "A"], "=", 
   RowBox[{"RandomInteger", "[", 
    RowBox[{"{", 
     RowBox[{"0", ",", "1"}], "}"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   SubscriptBox["a", "B"], "=", 
   RowBox[{"RandomInteger", "[", 
    RowBox[{"{", 
     RowBox[{"0", ",", "1"}], "}"}], "]"}]}], ";"}]}], "Input",
 CellTags->"b:4.0.5"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["\[Rho]", "Bob"], "[", 
   RowBox[{"a_", ",", "b_"}], "]"}], ":=", " ", 
  RowBox[{"PTr", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "2"}], "}"}], ",", 
    RowBox[{"4", "*", 
     RowBox[{
      SubscriptBox["P", 
       RowBox[{"a", ",", "b"}]], ".", 
      SubscriptBox["\[Rho]", "T"], ".", 
      SubscriptBox["P", 
       RowBox[{"a", ",", "b"}]]}]}]}], "]"}], " "}]], "Input",
 CellTags->"b:4.0.5"],

Cell["\<\
Qubit 3 has no polarization, but if Alice makes a measurement, its state is \
delineated \
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.0.5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Chop", "[", " ", 
   RowBox[{"PTr", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", " ", 
     SubscriptBox["\[Rho]", "T"]}], "]"}], "]"}], " "}]], "Input",
 CellTags->"b:4.0.5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Rho]", "Bob"], "[", 
     RowBox[{"0", ",", "0"}], "]"}], "+", 
    RowBox[{
     SubscriptBox["\[Rho]", "Bob"], "[", 
     RowBox[{"0", ",", "1"}], "]"}], "+", 
    RowBox[{
     SubscriptBox["\[Rho]", "Bob"], "[", 
     RowBox[{"1", ",", "0"}], "]"}], "+", 
    RowBox[{
     SubscriptBox["\[Rho]", "Bob"], "[", 
     RowBox[{"1", ",", "1"}], "]"}]}], "]"}], "/", "4"}]], "Input",
 CellTags->"b:4.0.5"],

Cell[BoxData["Ipick"], "Input",
 CellTags->"b:4.0.5"],

Cell[BoxData[{
 RowBox[{
  SubscriptBox["\[Rho]", "Bob"], "[", 
  RowBox[{"0", ",", "0"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["\[Rho]", "Bob"], "[", 
  RowBox[{"0", ",", "1"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["\[Rho]", "Bob"], "[", 
  RowBox[{"1", ",", "0"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["\[Rho]", "Bob"], "[", 
  RowBox[{"1", ",", "1"}], "]"}]}], "Input",
 CellTags->"b:4.0.5"],

Cell[TextData[{
 "Alice Clasically Transmits the result of her measurement to Bob (",
 Cell[BoxData[
  SubscriptBox["a", "A"]]],
 ", ",
 Cell[BoxData[
  SubscriptBox["a", "B"]]],
 ") as one of the \nfour cases \
|00\[RightAngleBracket],|01\[RightAngleBracket],|10\[RightAngleBracket] or \
|11\[RightAngleBracket]. \nBob, chooses his corresponding density matrix once \
he has received the data from Alice."
}], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.0.5"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Rho]", "B"], "=", 
  RowBox[{
   SubscriptBox["\[Rho]", "Bob"], "[", 
   RowBox[{
    SubscriptBox["a", "A"], ",", 
    SubscriptBox["a", "B"]}], "]"}]}]], "Input",
 CellTags->"b:4.0.5"],

Cell["\<\
Also need to know the type of Bell state shared marked by Ipick\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.0.5"],

Cell["Ipick", "Input",
 CellTags->"b:4.0.5"],

Cell["\<\
Then he will need to perform rotations which will be made of:\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.0.5"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["S", 
   RowBox[{"i_", " ", ",", "j_", " "}]], "  ", ":=", "  ", 
  RowBox[{
   SubscriptBox["\[Sigma]", "i"], " ", ".", "  ", 
   SubscriptBox["\[Sigma]", "j"]}]}]], "Input",
 CellTags->"b:4.0.5"],

Cell["\<\
Here we detail the four possibilities explicitly:
\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.0.5"],

Cell[TextData[{
 StyleBox["If Qubits 1 & 2 are in |00> State:Bob",
  FontWeight->"Bold"],
 "\n        Ipick=1 (Does Nothing)\n        Ipick=2 (rotates about x-axis  )\n\
        Ipick=3 (rotates about the z-axis)\n        Ipick=4 (rotates about \
x-axis and then the z-axis )\n                and would have the following \
polarization for his qubit 3\n      \n",
 StyleBox["If Qubits 1 & 2 are in |01> State:Bob",
  FontWeight->"Bold"],
 "\n        Ipick=1 (rotates about x-axis )\n        Ipick=2 (Does Nothing)\n \
       Ipick=3 (rotates about x-axis and then the z-axis)\n        Ipick=4 \
(rotates about the z-axis)\n                 and would have the following \
polarization for his qubit 3   \n\n",
 StyleBox["If Qubits 1 & 2 are in |10> State:Bob",
  FontWeight->"Bold"],
 "\n        Ipick=1 (rotates about the z-axis)\n        Ipick=2 (rotates \
about x-axis and then the z-axis)\n        Ipick=3 (Does Nothing)\n        \
Ipick=4 (rotates about x-axis)\n                 and would have the following \
polarization for his qubit 3           \n\n",
 StyleBox["If Qubits 1 & 2 are in |11> State:Bob",
  FontWeight->"Bold"],
 "\n        Ipick=1 (rotates about x-axis and then the z-axis)\n        \
Ipick=2 (rotates about the z-axis)\n        Ipick=3 (rotates about x-axis )\n \
       Ipick=4 (Does Nothing)\n                and would have the following \
polarization for his qubit 3"
}], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.0.5"],

Cell[BoxData[{
 RowBox[{"Rot", "=", 
  RowBox[{"Which", "[", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["a", "A"], ",", 
       SubscriptBox["a", "B"]}], "}"}], "\[Equal]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}]}], ",", " ", 
    RowBox[{"Which", "[", " ", 
     RowBox[{
      RowBox[{"Ipick", "\[Equal]", "1"}], ",", 
      SubscriptBox["S", 
       RowBox[{"0", " ", ",", "0"}]], ",", 
      StyleBox[
       RowBox[{"Ipick", "\[Equal]", "2"}],
       FontSize->12], 
      StyleBox[",",
       FontSize->12], 
      StyleBox[
       SubscriptBox["S", 
        RowBox[{"1", ",", " ", "0"}]],
       FontSize->12], 
      StyleBox[",",
       FontSize->12], 
      StyleBox[
       RowBox[{"Ipick", "\[Equal]", "3"}],
       FontSize->12], 
      StyleBox[",",
       FontSize->12], 
      StyleBox[
       SubscriptBox["S", 
        RowBox[{" ", 
         RowBox[{"3", ",", "0"}]}]],
       FontSize->12], 
      StyleBox[",",
       FontSize->12], 
      StyleBox[
       RowBox[{"Ipick", "\[Equal]", "4"}],
       FontSize->12], 
      StyleBox[",",
       FontSize->12], 
      StyleBox[
       SubscriptBox["S", 
        RowBox[{"3", ",", "1"}]],
       FontSize->12]}], 
     StyleBox["]",
      FontSize->12]}], 
    StyleBox[",",
     FontSize->12], 
    StyleBox["\[IndentingNewLine]",
     FontSize->12], 
    StyleBox["                      ",
     FontSize->12], 
    RowBox[{
     RowBox[{
      StyleBox["{",
       FontSize->12], 
      RowBox[{
       SubscriptBox["a", "A"], ",", 
       SubscriptBox["a", "B"]}], "}"}], "\[Equal]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}]}], ",", " ", 
    RowBox[{"Which", "[", " ", 
     RowBox[{
      RowBox[{"Ipick", "\[Equal]", "1"}], ",", 
      SubscriptBox["S", 
       RowBox[{"1", " ", ",", "0"}]], ",", 
      StyleBox[
       RowBox[{"Ipick", "\[Equal]", "2"}],
       FontSize->12], 
      StyleBox[",",
       FontSize->12], 
      StyleBox[
       SubscriptBox["S", 
        RowBox[{"0", ",", " ", "0"}]],
       FontSize->12], 
      StyleBox[",",
       FontSize->12], 
      StyleBox[
       RowBox[{"Ipick", "\[Equal]", "3"}],
       FontSize->12], 
      StyleBox[",",
       FontSize->12], 
      StyleBox[
       SubscriptBox["S", 
        RowBox[{" ", 
         RowBox[{"3", ",", "1"}]}]],
       FontSize->12], 
      StyleBox[",",
       FontSize->12], 
      StyleBox[
       RowBox[{"Ipick", "\[Equal]", "4"}],
       FontSize->12], 
      StyleBox[",",
       FontSize->12], 
      StyleBox[
       SubscriptBox["S", 
        RowBox[{"3", ",", "0"}]],
       FontSize->12]}], 
     StyleBox["]",
      FontSize->12]}], 
    StyleBox[",",
     FontSize->12], 
    StyleBox["\[IndentingNewLine]",
     FontSize->12], 
    StyleBox["                      ",
     FontSize->12], 
    StyleBox[
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        SubscriptBox["a", "A"], ",", 
        SubscriptBox["a", "B"]}], "}"}], "==", 
      RowBox[{"{", 
       RowBox[{"1", ",", "0"}], "}"}]}],
     FontSize->12], ",", " ", 
    RowBox[{"Which", "[", " ", 
     RowBox[{
      RowBox[{"Ipick", "\[Equal]", "1"}], ",", 
      SubscriptBox["S", 
       RowBox[{"0", " ", ",", "3"}]], ",", 
      StyleBox[
       RowBox[{"Ipick", "\[Equal]", "2"}],
       FontSize->12], 
      StyleBox[",",
       FontSize->12], 
      StyleBox[
       SubscriptBox["S", 
        RowBox[{"3", ",", " ", "1"}]],
       FontSize->12], 
      StyleBox[",",
       FontSize->12], 
      StyleBox[
       RowBox[{"Ipick", "\[Equal]", "3"}],
       FontSize->12], 
      StyleBox[",",
       FontSize->12], 
      StyleBox[
       SubscriptBox["S", 
        RowBox[{" ", 
         RowBox[{"0", ",", "0"}]}]],
       FontSize->12], 
      StyleBox[",",
       FontSize->12], 
      StyleBox[
       RowBox[{"Ipick", "\[Equal]", "4"}],
       FontSize->12], 
      StyleBox[",",
       FontSize->12], 
      StyleBox[
       SubscriptBox["S", 
        RowBox[{"1", ",", "0"}]],
       FontSize->12]}], 
     StyleBox["]",
      FontSize->12]}], 
    StyleBox[",",
     FontSize->12], 
    StyleBox["\[IndentingNewLine]",
     FontSize->12], 
    StyleBox["                      ",
     FontSize->12], 
    RowBox[{
     RowBox[{
      StyleBox["{",
       FontSize->12], 
      RowBox[{
       SubscriptBox["a", "A"], ",", 
       SubscriptBox["a", "B"]}], "}"}], "\[Equal]", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}]}], ",", 
    RowBox[{"Which", "[", " ", 
     RowBox[{
      RowBox[{"Ipick", "\[Equal]", "1"}], ",", 
      SubscriptBox["S", 
       RowBox[{"1", " ", ",", "3"}]], ",", 
      StyleBox[
       RowBox[{"Ipick", "\[Equal]", "2"}],
       FontSize->12], 
      StyleBox[",",
       FontSize->12], 
      StyleBox[
       SubscriptBox["S", 
        RowBox[{"3", ",", " ", "0"}]],
       FontSize->12], 
      StyleBox[",",
       FontSize->12], 
      StyleBox[
       RowBox[{"Ipick", "\[Equal]", "3"}],
       FontSize->12], 
      StyleBox[",",
       FontSize->12], 
      StyleBox[
       SubscriptBox["S", 
        RowBox[{" ", 
         RowBox[{"1", ",", "0"}]}]],
       FontSize->12], 
      StyleBox[",",
       FontSize->12], 
      StyleBox[
       RowBox[{"Ipick", "\[Equal]", "4"}],
       FontSize->12], 
      StyleBox[",",
       FontSize->12], 
      StyleBox[
       SubscriptBox["S", 
        RowBox[{"0", ",", "0"}]],
       FontSize->12]}], 
     StyleBox["]",
      FontSize->12]}]}], 
   StyleBox["]",
    FontSize->12]}]}], "\[IndentingNewLine]", 
 RowBox[{"Adj", "[", "Rot", "]"}], "\n", 
 RowBox[{
  RowBox[{"X", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Rot", ".", 
     SubscriptBox["\[Rho]", "B"], ".", 
     RowBox[{"Adj", "[", "Rot", "]"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"Simplify", "[", "X", "]"}], "\n", 
 RowBox[{
  RowBox[{"Chop", "[", 
   SubscriptBox["\[Rho]", "B"], "]"}], ";"}]}], "Input",
 CellTags->"b:4.0.5"],

Cell["\<\
... finally, Bob, extracts the polarization for his 3 qubit
and gets....\
\>", "DisplayText",
 FontFamily->"Helvetica",
 CellTags->"b:4.0.5"],

Cell[BoxData[
 RowBox[{"PFINAL", "=", 
  RowBox[{"Chop", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Simplify", "[", " ", 
      RowBox[{"Tr", "[", 
       RowBox[{"X", ".", 
        SubscriptBox["\[Sigma]", "1"]}], "]"}], "]"}], ",", 
     RowBox[{"Simplify", "[", 
      RowBox[{"Tr", "[", 
       RowBox[{"X", ".", 
        SubscriptBox["\[Sigma]", "2"]}], "]"}], "]"}], ",", 
     RowBox[{"Simplify", "[", 
      RowBox[{"Tr", "[", 
       RowBox[{"X", ".", 
        SubscriptBox["\[Sigma]", "3"]}], "]"}], "]"}]}], "}"}], 
   "]"}]}]], "Input",
 CellTags->"b:4.0.5"],

Cell["\<\
... which you can now compare to the original
state in the hands of Alice:\
\>", "DisplayText",
 FontFamily->"Helvetica",
 CellTags->"b:4.0.5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"Px", ",", "Py", ",", "Pz"}], "}"}]], "Input",
 CellTags->"b:4.0.5"],

Cell["Quit", "Input",
 CellTags->"b:4.0.5"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Two qubit teleportation algorithm using 6 qubits.       To open double click \
at down arrow----------------->>\
\>", "Section",
 CellChangeTimes->{{3.512212808903927*^9, 3.512212836239826*^9}, {
  3.512214568142479*^9, 3.512214572092629*^9}, {3.512214618478846*^9, 
  3.512214627667285*^9}},
 FontFamily->"Times",
 CellTags->"c:8"],

Cell[CellGroupData[{

Cell["Introduction", "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:3", "b:4.1.0"}],

Cell[TextData[StyleBox["Uses the Qdensity package:",
 FontFamily->"Helvetica"]], "Text",
 FontFamily->"Courier New",
 CellTags->"b:4.1.0"],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<QDENSITY`Qdensity`\>\"", "]"}]], "Input",
 FontFamily->"Courier New",
 CellTags->"b:4.1.0"],

Cell[BoxData[
 RowBox[{"?", "QDENSITY`Qdensity`*"}]], "Input",
 FontFamily->"Courier New",
 CellTags->"b:4.1.0"],

Cell[TextData[StyleBox["We set the number of Qubits to 6", "DisplayText",
 FontWeight->"Plain",
 FontVariations->{"CompatibilityType"->0},
 Background->None]], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.1.0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"nqx", "=", "6"}], ";"}]], "Input",
 CellTags->"b:4.1.0"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"figure", "=", 
   RowBox[{"Import", "[", 
    RowBox[{"\"\<QDENSITY/drawings/2teleport.png\>\"", ",", "\"\<PNG\>\""}], 
    "]"}]}], ";"}], "\n", 
 RowBox[{"Show", "[", "figure", "]"}]}], "Input",
 CellTags->"b:4.1.0"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Step 1: Alice  prepares the two qubit state to be teleported and a four qubit \
entangled state is provided\
\>", "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:9", "b:4.1.1"}],

Cell[TextData[StyleBox["We prepare a random two qubit state. First a random \
one qubit state is prepared.", "DisplayText",
 FontWeight->"Plain",
 FontVariations->{"CompatibilityType"->0},
 Background->None]], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.1.1"],

Cell[BoxData[
 RowBox[{"a", "=", "RandomQubit1"}]], "Input",
 CellTags->"b:4.1.1"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   SubscriptBox["\[Rho]", "AB"], "=", "RandomQubit2"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PA", "=", 
   RowBox[{"Chop", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Tr", "[", 
       RowBox[{
        SubscriptBox["\[Rho]", "AB"], "  ", ".", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Sigma]", "1"], " ", "\[CircleTimes]", " ", 
          SubscriptBox["\[Sigma]", "0"]}], ")"}]}], "]"}], ",", 
      RowBox[{"Tr", "[", 
       RowBox[{
        SubscriptBox["\[Rho]", "AB"], "  ", ".", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Sigma]", "2"], " ", "\[CircleTimes]", " ", 
          SubscriptBox["\[Sigma]", "0"]}], ")"}]}], "]"}], " ", ",", 
      RowBox[{"Tr", "[", 
       RowBox[{
        SubscriptBox["\[Rho]", "AB"], "  ", ".", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Sigma]", "3"], " ", "\[CircleTimes]", " ", 
          SubscriptBox["\[Sigma]", "0"]}], ")"}]}], "]"}]}], " ", "}"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PB", "=", 
   RowBox[{"Chop", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Tr", "[", 
       RowBox[{
        SubscriptBox["\[Rho]", "AB"], " ", ".", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Sigma]", "0"], " ", "\[CircleTimes]", " ", 
          SubscriptBox["\[Sigma]", "1"]}], ")"}]}], "]"}], ",", 
      RowBox[{"Tr", "[", 
       RowBox[{
        SubscriptBox["\[Rho]", "AB"], " ", ".", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Sigma]", "0"], " ", "\[CircleTimes]", " ", 
          SubscriptBox["\[Sigma]", "2"]}], ")"}]}], "]"}], " ", ",", " ", 
      RowBox[{"Tr", "[", 
       RowBox[{
        SubscriptBox["\[Rho]", "AB"], " ", ".", 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[Sigma]", "0"], " ", "\[CircleTimes]", " ", 
          SubscriptBox["\[Sigma]", "3"]}], ")"}]}], "]"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"T", "[", 
    RowBox[{"i_", ",", "j_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"T", "[", 
     RowBox[{"i", ",", "j"}], "]"}], "=", " ", 
    RowBox[{"Chop", "[", 
     RowBox[{"Tr", "[", 
      RowBox[{
       SubscriptBox["\[Rho]", "AB"], " ", ".", 
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Sigma]", "i"], " ", "\[CircleTimes]", " ", 
         SubscriptBox["\[Sigma]", "j"]}], ")"}]}], "]"}], " ", "]"}]}]}], 
  "  "}], "\[IndentingNewLine]", "PA", "\[IndentingNewLine]", "PB"}], "Input",
 FontFamily->"Courier New",
 CellTags->"b:4.1.1"],

Cell[TextData[StyleBox["The density matrix to be teleported and its \
eigenvalues are:", "DisplayText",
 FontWeight->"Plain",
 FontVariations->{"CompatibilityType"->0},
 Background->None]], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.1.1"],

Cell[BoxData[{
 SubscriptBox["\[Rho]", "AB"], "\[IndentingNewLine]", 
 RowBox[{"Chop", "[", 
  RowBox[{"Eigenvalues", "[", 
   SubscriptBox["\[Rho]", "AB"], "]"}], "]"}]}], "Input",
 CellTags->"b:4.1.1"],

Cell[TextData[{
 "We also need the ",
 StyleBox["entangled state made of qubits 3, 4, 5, and 6",
  FontWeight->"Bold"],
 " which is constructed as:"
}], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.1.1"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   SubscriptBox["\[Rho]", "1"], "=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[ScriptCapitalP]", "0"], "\[CircleTimes]", 
         SubscriptBox["\[ScriptCapitalP]", "0"]}], ")"}], "\[CircleTimes]", 
       SubscriptBox["\[ScriptCapitalP]", "0"]}], ")"}], "\[CircleTimes]", 
     SubscriptBox["\[ScriptCapitalP]", "0"]}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"OpE", "=", 
   RowBox[{
    RowBox[{"CNOT", "[", 
     RowBox[{"4", ",", "2", ",", "4"}], "]"}], ".", 
    RowBox[{"had", "[", 
     RowBox[{"4", ",", "2"}], "]"}], ".", 
    RowBox[{"CNOT", "[", 
     RowBox[{"4", ",", "1", ",", "3"}], "]"}], ".", 
    RowBox[{"had", "[", 
     RowBox[{"4", ",", "1"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["\[Rho]", "3456"], "=", " ", 
  RowBox[{"OpE", ".", 
   SubscriptBox["\[Rho]", "1"], ".", 
   RowBox[{"Adj", "[", "OpE", "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"Tr", "[", 
  SubscriptBox["\[Rho]", "3456"], "]"}]}], "Input",
 CellTags->"b:4.1.1"],

Cell["Then the FULL density matrix for the \"initial\" system is:", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.1.1"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   SubscriptBox["\[Rho]", "0"], "=", 
   RowBox[{
    SubscriptBox["\[Rho]", "AB"], "\[CircleTimes]", 
    SubscriptBox["\[Rho]", "3456"]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Tr", "[", 
  SubscriptBox["\[Rho]", "0"], "]"}]}], "Input",
 CellTags->"b:4.1.1"],

Cell["is the full density matrix hermitian?", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.1.1"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Chop", "[", 
      RowBox[{
       RowBox[{"Adj", "[", 
        SubscriptBox["\[Rho]", "0"], "]"}], " ", "-", 
       SubscriptBox["\[Rho]", "0"]}], "]"}], "\[Equal]", 
     RowBox[{"ConstantArray", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Length", "[", 
          SubscriptBox["\[Rho]", "0"], "]"}], ",", 
         RowBox[{"Length", "[", 
          SubscriptBox["\[Rho]", "0"], "]"}]}], "}"}]}], "]"}]}], ",", 
    RowBox[{"Print", "[", "\"\<Hermitian\>\"", "]"}], ",", 
    RowBox[{"Print", "[", "\"\<Not Hermitian\>\"", "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.395092188543119*^9, 3.3950922073352137`*^9}},
 FontFamily->"Courier New",
 CellTags->"b:4.1.1"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Step 2: Alice operates on her four qubits", "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:10", "b:4.1.2"}],

Cell["\<\
Alice operations can be constructed easily in the 6 qubit space: 
[This is one of the important features of working in the Density matrix \
approach:
the mapping between the circuit in the Figure and the operations is \
straightforward] \
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.1.2"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"Bop", "[", 
    RowBox[{
    "qi_", ",", "qj_", ",", "qk_", ",", "ql_", ",", "qm_", ",", "qn_"}], 
    "]"}], ":=", 
   RowBox[{
    RowBox[{"had", "[", 
     RowBox[{"6", ",", "qi"}], "]"}], ".", 
    RowBox[{"had", "[", 
     RowBox[{"6", ",", "qj"}], "]"}], ".", 
    RowBox[{"CNOT", "[", 
     RowBox[{"6", ",", "qi", ",", "qk"}], "]"}], ".", 
    RowBox[{"CNOT", "[", 
     RowBox[{"6", ",", "qj", ",", "ql"}], "]"}]}]}]}]], "Input",
 FontFamily->"Courier New",
 CellTags->"b:4.1.2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Step 3: The final state density matrix is obtained", "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:11", "b:4.1.3"}],

Cell["\<\
The application of Alice operations to the initial density matrix is readily \
evaluated:\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.1.3"],

Cell[BoxData[
 RowBox[{
  StyleBox[" ",
   FontSize->12], 
  RowBox[{
   StyleBox[
    RowBox[{
     RowBox[{
      SubscriptBox["\[Rho]", "E"], "  ", ":=", " ", 
      RowBox[{
       RowBox[{"Bop", "[", 
        RowBox[{"1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6"}], 
        "]"}], ".", 
       SubscriptBox["\[Rho]", "0"], ".", 
       RowBox[{"Adj", "[", 
        RowBox[{"Bop", "[", 
         RowBox[{"1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6"}], 
         "]"}], "]"}]}]}], ";"}],
    FontSize->12], 
   StyleBox["\[IndentingNewLine]",
    FontSize->12], 
   RowBox[{
    StyleBox["Chop",
     FontSize->12], 
    StyleBox["[",
     FontSize->12], 
    RowBox[{"Tr", "[", 
     SubscriptBox["\[Rho]", "E"], "]"}], "]"}]}]}]], "Input",
 FontFamily->"Courier New",
 FontSize->12,
 CellTags->"b:4.1.3"],

Cell["\<\
We can check that the density matrix is indeed so by computing its trace and \
the trace 
of it squared (Purity):\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.1.3"],

Cell[BoxData[{
 RowBox[{"Simplify", "[", 
  RowBox[{"Chop", "[", 
   RowBox[{"Tr", "[", 
    SubscriptBox["\[Rho]", "E"], "]"}], "]"}], "]"}], "\n", 
 RowBox[{"Simplify", "[", 
  RowBox[{"Chop", "[", 
   RowBox[{"Purity", "[", 
    SubscriptBox["\[Rho]", "E"], "]"}], "]"}], "]"}]}], "Input",
 CellTags->"b:4.1.3"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Step 4: Alice measures her four qubits, 1,2,3,4", "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:12", "b:4.1.4"}],

Cell["\<\
Measurements are performed by means of projection operators. The projection \
operator on qubits 1,2,3,4 is written:\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.1.4"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["P", 
   RowBox[{"a_", ",", "b_", ",", "c_", ",", "d_"}]], ":=", 
  RowBox[{"(", 
   StyleBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["\[ScriptCapitalP]", 
              StyleBox["a",
               ScriptLevel->0]], "\[CircleTimes]", 
             SubscriptBox["\[ScriptCapitalP]", 
              StyleBox["b",
               ScriptLevel->0]]}], ")"}], "\[CircleTimes]", 
           SubscriptBox["\[ScriptCapitalP]", 
            StyleBox["c",
             ScriptLevel->0]]}], ")"}], "\[CircleTimes]", 
         SubscriptBox["\[ScriptCapitalP]", 
          StyleBox["d",
           ScriptLevel->0]]}], ")"}], "\[CircleTimes]", 
       "\[DoubleStruckCapitalI]"}], ")"}], "\[CircleTimes]", 
     "\[DoubleStruckCapitalI]"}],
    ScriptLevel->0], 
   StyleBox[")",
    ScriptLevel->0]}]}]], "Input",
 CellTags->"b:4.1.4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  FormBox[Cell[TextData[Cell[BoxData[
    FormBox[Cell[""], TraditionalForm]]]]], TraditionalForm]]],
 "Step 5: Bob state is computed "
}], "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:13", "b:4.1.5"}],

Cell["\<\
Bob's two qubit state, made of qubits 5 and 6, is obtained by taking the \
partial trace of the full final state after 
Alice's measurement (here is written in general depending on the four values \
of alice measurement)\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.1.5"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Bob", "[", 
    RowBox[{"a_", ",", "b_", ",", "c_", ",", "d_"}], "]"}], ":=", 
   RowBox[{"Chop", "[", " ", 
    RowBox[{"PTr", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "2", ",", "3", ",", "4"}], "}"}], "  ", ",", 
      RowBox[{
       RowBox[{"2", "^", "4"}], "*", 
       RowBox[{
        SubscriptBox["P", 
         RowBox[{"a", ",", "b", ",", "c", ",", "d"}]], ".", 
        SubscriptBox["\[Rho]", "E"], ".", 
        SubscriptBox["P", 
         RowBox[{"a", ",", "b", ",", "c", ",", "d"}]]}]}]}], " ", "]"}], 
    "]"}]}], ";"}]], "Input",
 CellTags->"b:4.1.5"],

Cell["\<\
Alice measurement is produced at random, the result of her measurement is \
P1,P2,P3,P4\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.1.5"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"P1", "=", 
   RowBox[{"RandomInteger", "[", 
    RowBox[{"{", 
     RowBox[{"0", ",", "1"}], "}"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"P2", "=", 
   RowBox[{"RandomInteger", "[", 
    RowBox[{"{", 
     RowBox[{"0", ",", "1"}], "}"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"P3", "=", 
   RowBox[{"RandomInteger", "[", 
    RowBox[{"{", 
     RowBox[{"0", ",", "1"}], "}"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"P4", "=", 
   RowBox[{"RandomInteger", "[", 
    RowBox[{"{", 
     RowBox[{"0", ",", "1"}], "}"}], "]"}]}], ";"}], "\n", 
 RowBox[{"{", 
  RowBox[{"P1", ",", "P2", ",", "P3", ",", "P4"}], "}"}]}], "Input",
 CellTags->"b:4.1.5"],

Cell[TextData[{
 "Bob state, once Alice has ",
 StyleBox["clasically communicated",
  FontWeight->"Bold"],
 " P1,P2,P3,P4 reads:"
}], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.1.5"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Rho]", "Bob"], "=", 
  RowBox[{"Bob", "[", 
   RowBox[{"P1", ",", "P2", ",", "P3", ",", "P4"}], "]"}]}]], "Input",
 CellTags->"b:4.1.5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  FormBox[Cell[TextData[Cell[BoxData[
    FormBox[Cell[""], TraditionalForm]]]]], TraditionalForm]]],
 "Step 6: Bob performs an arranged transformation on its state to recover the \
initial state"
}], "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:14", "b:4.1.6"}],

Cell["\<\
The coding of the operations is quite compact altough it could be improved \
slightly\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.1.6"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"I1", "=", 
   RowBox[{
    RowBox[{"P1", "*", "2"}], "+", "P3"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"I2", "=", 
   RowBox[{
    RowBox[{"P2", "*", "2"}], "+", "P4"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"If", " ", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"P1", "*", "2"}], "+", "P3"}], "\[Equal]", "2"}], ",", " ", 
    RowBox[{"I1", "=", "3"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"If", " ", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"P1", "*", "2"}], "+", "P3"}], "\[Equal]", "3"}], ",", " ", 
    RowBox[{"I1", "=", "2"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"If", " ", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"P2", "*", "2"}], "+", "P4"}], "\[Equal]", "2"}], ",", " ", 
    RowBox[{"I2", "=", "3"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"If", " ", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"P2", "*", "2"}], "+", "P4"}], "\[Equal]", "3"}], ",", " ", 
    RowBox[{"I2", "=", "2"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"TrasF", "=", 
  RowBox[{
   SubscriptBox["\[Sigma]", "I1"], " ", "\[CircleTimes]", " ", 
   SubscriptBox["\[Sigma]", "I2"]}]}]}], "Input",
 CellTags->"b:4.1.6"],

Cell["\<\
The 2 qubit state in bobs hands after the transformation reads:\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.1.6"],

Cell[BoxData[{
 RowBox[{"BobT", "=", " ", 
  RowBox[{"Chop", "[", 
   RowBox[{"TrasF", ".", 
    SubscriptBox["\[Rho]", "Bob"], ".", 
    RowBox[{"Adj", "[", "TrasF", "]"}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Chop", "[", 
  RowBox[{"Eigenvalues", "[", "BobT", "]"}], "]"}]}], "Input",
 CellTags->"b:4.1.6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  FormBox[Cell[TextData[Cell[BoxData[
    FormBox[Cell[""], TraditionalForm]]]]], TraditionalForm]]],
 "Step 7: Moment of truth, we compare both initial Alice state and final Bob \
state"
}], "Subsection",
 CellFrame->True,
 CellChangeTimes->{3.512214416691491*^9},
 FontFamily->"Times",
 CellTags->{"c:15", "b:4.1.7"}],

Cell["\<\
The 2qubit state density matrix that bob has is characterized by :\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.1.7"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"T", "[", 
    RowBox[{"i_", ",", "j_"}], "]"}], ":=", 
   RowBox[{"Tr", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Sigma]", "i"], "\[CircleTimes]", 
       SubscriptBox["\[Sigma]", "j"]}], ")"}], ".", "BobT"}], 
    StyleBox[" ",
     FontSize->12], 
    StyleBox["]",
     FontSize->12]}]}], 
  StyleBox[";",
   FontSize->12]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   StyleBox["PA",
    FontSize->12], 
   StyleBox["=",
    FontSize->12], 
   RowBox[{
    StyleBox["{",
     FontSize->12], 
    RowBox[{
     StyleBox[
      RowBox[{"T", "[", 
       RowBox[{"1", ",", "0"}], "]"}],
      FontSize->12], 
     StyleBox[",",
      FontSize->12], 
     RowBox[{"T", "[", 
      RowBox[{"2", ",", "0"}], "]"}], ",", 
     RowBox[{"T", "[", 
      RowBox[{"3", ",", "0"}], "]"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   StyleBox["PB",
    FontSize->12], 
   StyleBox["=",
    FontSize->12], 
   RowBox[{
    StyleBox["{",
     FontSize->12], 
    RowBox[{
     StyleBox[
      RowBox[{"T", "[", 
       RowBox[{"0", ",", "1"}], "]"}],
      FontSize->12], 
     StyleBox[",",
      FontSize->12], 
     RowBox[{"T", "[", 
      RowBox[{"0", ",", "2"}], "]"}], ",", 
     RowBox[{"T", "[", 
      RowBox[{"0", ",", "3"}], "]"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   StyleBox[
    RowBox[{"T", 
     StyleBox["AB",
      FontSize->12]}]], 
   StyleBox["=",
    FontSize->12], 
   RowBox[{
    StyleBox["{",
     FontSize->12], 
    RowBox[{
     StyleBox["Table",
      FontSize->12], 
     StyleBox["[",
      FontSize->12], 
     RowBox[{
      StyleBox[
       RowBox[{"T", "[", 
        RowBox[{"i", ",", "j"}], "]"}],
       FontSize->12], 
      StyleBox[",",
       FontSize->12], 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "1", ",", "3"}], "}"}]}], "]"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Chop", "[", "PA", "]"}], "\[IndentingNewLine]", 
 RowBox[{"Chop", "[", "PB", "]"}], "\[IndentingNewLine]", 
 RowBox[{"Chop", "[", "TAB", "]"}]}], "Input",
 CellTags->"b:4.1.7"],

Cell["\<\
...which we can compare to the original two qubit density matrix:\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.1.7"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"TT", "[", 
    RowBox[{"i_", ",", "j_"}], "]"}], ":=", 
   RowBox[{"Tr", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Sigma]", "i"], "\[CircleTimes]", 
       SubscriptBox["\[Sigma]", "j"]}], ")"}], ".", 
     SubscriptBox["\[Rho]", "AB"]}], 
    StyleBox[" ",
     FontSize->12], 
    StyleBox["]",
     FontSize->12]}]}], 
  StyleBox[";",
   FontSize->12]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   StyleBox[
    RowBox[{"T", 
     StyleBox["PA",
      FontSize->12]}]], 
   StyleBox["=",
    FontSize->12], 
   RowBox[{
    StyleBox["{",
     FontSize->12], 
    RowBox[{
     StyleBox[
      RowBox[{"TT", "[", 
       RowBox[{"1", ",", "0"}], "]"}],
      FontSize->12], 
     StyleBox[",",
      FontSize->12], 
     RowBox[{"TT", "[", 
      RowBox[{"2", ",", "0"}], "]"}], ",", 
     RowBox[{"TT", "[", 
      RowBox[{"3", ",", "0"}], "]"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   StyleBox[
    RowBox[{"T", 
     StyleBox["PB",
      FontSize->12]}]], 
   StyleBox["=",
    FontSize->12], 
   RowBox[{
    StyleBox["{",
     FontSize->12], 
    RowBox[{
     StyleBox[
      RowBox[{"TT", "[", 
       RowBox[{"0", ",", "1"}], "]"}],
      FontSize->12], 
     StyleBox[",",
      FontSize->12], 
     RowBox[{"TT", "[", 
      RowBox[{"0", ",", "2"}], "]"}], ",", 
     RowBox[{"TT", "[", 
      RowBox[{"0", ",", "3"}], "]"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   StyleBox[
    RowBox[{"TT", 
     StyleBox["AB",
      FontSize->12]}]], 
   StyleBox["=",
    FontSize->12], 
   RowBox[{
    StyleBox["{",
     FontSize->12], 
    RowBox[{
     StyleBox["Table",
      FontSize->12], 
     StyleBox["[",
      FontSize->12], 
     RowBox[{
      StyleBox[
       RowBox[{"TT", "[", 
        RowBox[{"i", ",", "j"}], "]"}],
       FontSize->12], 
      StyleBox[",",
       FontSize->12], 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "1", ",", "3"}], "}"}]}], "]"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Chop", "[", "TPA", "]"}], "\[IndentingNewLine]", 
 RowBox[{"Chop", "[", "TPB", "]"}], "\[IndentingNewLine]", 
 RowBox[{"Chop", "[", "TTAB", "]"}]}], "Input",
 CellTags->"b:4.1.7"],

Cell[BoxData[
 RowBox[{"Chop", "[", 
  RowBox[{
   SubscriptBox["\[Rho]", "AB"], "-", "BobT"}], 
  StyleBox[" ",
   FontSize->12], 
  StyleBox["]",
   FontSize->12]}]], "Input",
 CellTags->"b:4.1.7"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Step 8: For completeness all one qubit partial traces are shown\
\>", "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:16", "b:4.1.8"}],

Cell[BoxData[{
 StyleBox[
  RowBox[{
   SubscriptBox["\[Rho]", 
    RowBox[{"1", "F"}]], "=", 
   RowBox[{"Chop", "[", 
    RowBox[{"PTr", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", "3", ",", "4", ",", "5", ",", "6"}], "}"}], ",", 
      SubscriptBox["\[Rho]", "E"]}], "]"}], "]"}]}],
  FontSize->12], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{
   SubscriptBox["\[Rho]", 
    RowBox[{"2", "F"}]], "=", 
   RowBox[{"Chop", "[", 
    RowBox[{"PTr", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "3", ",", "4", ",", "5", ",", "6"}], "}"}], ",", 
      SubscriptBox["\[Rho]", "E"]}], "]"}], "]"}]}],
  FontSize->12], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{
   SubscriptBox["\[Rho]", 
    RowBox[{"3", "F"}]], "=", 
   RowBox[{"Chop", "[", 
    RowBox[{"PTr", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "2", ",", "4", ",", "5", ",", "6"}], "}"}], ",", 
      SubscriptBox["\[Rho]", "E"]}], "]"}], "]"}]}],
  FontSize->12], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{
   SubscriptBox["\[Rho]", 
    RowBox[{"4", "F"}]], "=", 
   RowBox[{"Chop", "[", 
    RowBox[{"PTr", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "2", ",", "3", ",", "5", ",", "6"}], "}"}], ",", 
      SubscriptBox["\[Rho]", "E"]}], "]"}], "]"}]}],
  FontSize->12], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{
   SubscriptBox["\[Rho]", 
    RowBox[{"5", "F"}]], "=", 
   RowBox[{"Chop", "[", 
    RowBox[{"PTr", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "2", ",", "3", ",", "4", ",", "6"}], "}"}], ",", 
      SubscriptBox["\[Rho]", "E"]}], "]"}], "]"}]}],
  FontSize->12], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{
   SubscriptBox["\[Rho]", 
    RowBox[{"6", "F"}]], "=", 
   RowBox[{"Chop", "[", 
    RowBox[{"PTr", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "2", ",", "3", ",", "4", ",", "5"}], "}"}], ",", 
      SubscriptBox["\[Rho]", "E"]}], "]"}], "]"}]}],
  FontSize->12]}], "Input",
 CellTags->"b:4.1.8"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Three qubit teleportation algorithm using 9 qubits.     To open double click \
at down arrow---------------->>\
\>", "Section",
 CellChangeTimes->{{3.512212824851755*^9, 3.512212842876913*^9}, {
  3.5122145762167873`*^9, 3.512214579366783*^9}, {3.512214621492093*^9, 
  3.51221463179173*^9}},
 FontFamily->"Times",
 CellTags->"c:17"],

Cell[CellGroupData[{

Cell["Introduction", "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:3", "b:4.2.0"}],

Cell[TextData[StyleBox["Uses the Qdensity package:",
 FontFamily->"Helvetica"]], "Text",
 FontFamily->"Courier New",
 CellTags->"b:4.2.0"],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<QDENSITY`Qdensity`\>\"", "]"}]], "Input",
 FontFamily->"Courier New",
 CellTags->"b:4.2.0"],

Cell[BoxData[
 RowBox[{"?", "QDENSITY`Qdensity`*"}]], "Input",
 FontFamily->"Courier New",
 CellTags->"b:4.2.0"],

Cell[TextData[StyleBox["We set the number of Qubits to 9", "DisplayText",
 FontWeight->"Plain",
 FontVariations->{"CompatibilityType"->0},
 Background->None]], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.2.0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"nqx", "=", 
   RowBox[{"3", "*", "3"}]}], ";"}]], "Input",
 CellTags->"b:4.2.0"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"figure", "=", 
   RowBox[{"Import", "[", 
    RowBox[{"\"\<QDENSITY/drawings/3teleport.png\>\"", ",", "\"\<PNG\>\""}], 
    "]"}]}], ";"}], "\n", 
 RowBox[{"Show", "[", "figure", "]"}]}], "Input",
 CellTags->"b:4.2.0"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Step 1: Alice  prepares the three qubit state to be teleported\
\>", "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:18", "b:4.2.1"}],

Cell["\<\
Alice builds the density matrix to be teleported. Qubits 1, 2 and 3. Here the \
teleported
state is constructed at random in the following way:\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.2.1"],

Cell[BoxData[
 RowBox[{"RandomQubit3", "=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"i", ",", "j", ",", "k", ",", "U"}], "}"}], ",", 
    RowBox[{
     RowBox[{"A1", "=", "RandomQubit1"}], ";", 
     RowBox[{"A2", "=", "RandomQubit1"}], ";", 
     RowBox[{"A3", "=", "RandomQubit1"}], ";", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        SubscriptBox["J", 
         RowBox[{"i", ",", "j", ",", "k"}]], "=", 
        RowBox[{"RandomReal", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "100"}], ",", "100"}], "}"}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "1", ",", "3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "1", ",", "3"}], "}"}]}], "]"}], ";", 
     RowBox[{"U", "=", 
      RowBox[{"MatrixExp", "[", 
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"i", "=", "1"}], "3"], 
        RowBox[{
         UnderoverscriptBox["\[Sum]", 
          RowBox[{"j", "=", "1"}], "3"], 
         RowBox[{
          UnderoverscriptBox["\[Sum]", 
           RowBox[{"k", "=", "1"}], "3"], 
          RowBox[{"\[ImaginaryI]", " ", 
           SubscriptBox["J", 
            RowBox[{"i", ",", "j", ",", "k"}]], " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["\[Sigma]", "i"], "\[CircleTimes]", 
              SubscriptBox["\[Sigma]", "j"]}], ")"}], "\[CircleTimes]", 
            SubscriptBox["\[Sigma]", "k"]}]}]}]}]}], "]"}]}], ";", 
     RowBox[{
      SubscriptBox["\[Rho]", "123"], "=", 
      RowBox[{"Chop", "[", 
       RowBox[{
        RowBox[{"Adj", "[", "U", "]"}], ".", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"A1", "\[CircleTimes]", "A2"}], ")"}], "\[CircleTimes]", 
          "A3"}], ")"}], ".", "U"}], "]"}]}], ";", 
     SubscriptBox["\[Rho]", "123"]}]}], "]"}]}]], "Input",
 CellTags->"b:4.2.1"],

Cell["Its trace and purity can be readily obtained:", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.2.1"],

Cell[BoxData[{
 RowBox[{"Tr", "[", 
  SubscriptBox["\[Rho]", "123"], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Chop", "[", 
  RowBox[{"Purity", "[", 
   SubscriptBox["\[Rho]", "123"], "]"}], "]"}]}], "Input",
 CellTags->"b:4.2.1"],

Cell["And its eigenvalues:", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.2.1"],

Cell[BoxData[
 RowBox[{"Chop", "[", 
  RowBox[{"Eigenvalues", "[", 
   SubscriptBox["\[Rho]", "123"], "]"}], "]"}]], "Input",
 CellTags->"b:4.2.1"],

Cell[TextData[{
 "We also need to construct the entangled state of qubits 4,5,6,7,8 and 9.\n",
 StyleBox["[NOTE: The parentheses are essential in the tensor product]",
  FontWeight->"Bold"]
}], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.2.1"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   SubscriptBox["\[Rho]", "1"], "=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["\[ScriptCapitalP]", "0"], "\[CircleTimes]", 
             SubscriptBox["\[ScriptCapitalP]", "0"]}], ")"}], 
           "\[CircleTimes]", 
           SubscriptBox["\[ScriptCapitalP]", "0"]}], ")"}], "\[CircleTimes]", 
         SubscriptBox["\[ScriptCapitalP]", "0"]}], ")"}], "\[CircleTimes]", 
       SubscriptBox["\[ScriptCapitalP]", "0"]}], ")"}], "\[CircleTimes]", 
     SubscriptBox["\[ScriptCapitalP]", "0"]}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"OpE", "=", 
   RowBox[{
    RowBox[{"CNOT", "[", 
     RowBox[{"6", ",", "3", ",", "6"}], "]"}], ".", 
    RowBox[{"had", "[", 
     RowBox[{"6", ",", "3"}], "]"}], ".", 
    RowBox[{"CNOT", "[", 
     RowBox[{"6", ",", "2", ",", "5"}], "]"}], ".", 
    RowBox[{"had", "[", 
     RowBox[{"6", ",", "2"}], "]"}], ".", 
    RowBox[{"CNOT", "[", 
     RowBox[{"6", ",", "1", ",", "4"}], "]"}], ".", 
    RowBox[{"had", "[", 
     RowBox[{"6", ",", "1"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["\[Rho]", "3456"], "=", " ", 
   RowBox[{"N", "[", 
    RowBox[{"OpE", ".", 
     SubscriptBox["\[Rho]", "1"], ".", 
     RowBox[{"Adj", "[", "OpE", "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Tr", "[", 
  SubscriptBox["\[Rho]", "3456"], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Tr", "[", 
  RowBox[{
   SubscriptBox["\[Rho]", "3456"], ".", 
   SubscriptBox["\[Rho]", "3456"]}], "]"}]}], "Input",
 CellTags->"b:4.2.1"],

Cell["Then the density matrix for the \"initial\" system is:", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.2.1"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   SubscriptBox["\[Rho]", "0"], "=", 
   RowBox[{"N", "[", 
    RowBox[{
     SubscriptBox["\[Rho]", "123"], "\[CircleTimes]", 
     SubscriptBox["\[Rho]", "3456"]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"N", "[", 
  RowBox[{"Tr", "[", 
   SubscriptBox["\[Rho]", "0"], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Chop", "[", 
  RowBox[{"Purity", "[", 
   RowBox[{
    SubscriptBox["\[Rho]", "0"], ".", 
    SubscriptBox["\[Rho]", "0"]}], "]"}], "]"}]}], "Input",
 CellTags->"b:4.2.1"],

Cell["is the full density matrix hermitian?", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.2.1"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Chop", "[", 
      RowBox[{
       RowBox[{"Adj", "[", 
        SubscriptBox["\[Rho]", "0"], "]"}], " ", "-", 
       SubscriptBox["\[Rho]", "0"]}], "]"}], "\[Equal]", 
     RowBox[{"ConstantArray", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Length", "[", 
          SubscriptBox["\[Rho]", "0"], "]"}], ",", 
         RowBox[{"Length", "[", 
          SubscriptBox["\[Rho]", "0"], "]"}]}], "}"}]}], "]"}]}], ",", 
    RowBox[{"Print", "[", "\"\<Hermitian\>\"", "]"}], ",", 
    RowBox[{"Print", "[", "\"\<Not Hermitian\>\"", "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.395093008447339*^9, 3.395093022757456*^9}},
 FontFamily->"Courier New",
 CellTags->"b:4.2.1"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Step 2: Alice operates on its four qubits", "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:19", "b:4.2.2"}],

Cell["\<\
Alice operations can be constructed easily in the 6 qubit space: \
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.2.2"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{
    RowBox[{"Bop", "[", 
     RowBox[{
     "qi_", ",", "qj_", ",", "qk_", ",", "ql_", ",", "qm_", ",", "qn_", ",", 
      "qo_", ",", "qp_", ",", "qq_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"had", "[", 
      RowBox[{"9", ",", "qi"}], "]"}], ".", 
     RowBox[{"had", "[", 
      RowBox[{"9", ",", "qj"}], "]"}], ".", 
     RowBox[{"had", "[", 
      RowBox[{"9", ",", "qk"}], "]"}], ".", 
     RowBox[{"CNOT", "[", 
      RowBox[{"9", ",", "qi", ",", "ql"}], "]"}], ".", 
     RowBox[{"CNOT", "[", 
      RowBox[{"9", ",", "qj", ",", "qm"}], "]"}], ".", 
     RowBox[{"CNOT", "[", 
      RowBox[{"9", ",", "qk", ",", "qn"}], "]"}]}]}], ";"}]}]], "Input",
 FontFamily->"Courier New",
 CellTags->"b:4.2.2"],

Cell["(we precompile the operator)", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.2.2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CompBop", "=", 
   RowBox[{"Compile", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"qi", ",", "_Integer", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"qj", ",", "_Integer", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"qk", ",", "_Integer", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"ql", ",", "_Integer", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"qm", ",", "_Integer", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"qn", ",", "_Integer", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"qo", ",", "_Integer", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"qp", ",", "_Integer", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"qq", ",", "_Integer", ",", "0"}], "}"}]}], "}"}], ",", " ", 
     RowBox[{"Bop", "[", 
      RowBox[{
      "qi", ",", "qj", ",", "qk", ",", "ql", ",", "qm", ",", "qn", ",", "qo", 
       ",", "qp", ",", "qq"}], "]"}], " ", ",", 
     RowBox[{"{", 
      RowBox[{"{", "   ", 
       RowBox[{
        RowBox[{"Bop", "[", 
         RowBox[{
         "qi", ",", "qj", ",", "qk", ",", "ql", ",", "qm", ",", "qn", ",", 
          "qo", ",", "qp", ",", "qq"}], "]"}], ",", "_Complex", ",", "2"}], 
       "}"}], "}"}]}], "]"}]}], "  ", ";"}]], "Input",
 FontFamily->"Courier New",
 CellTags->"b:4.2.2"],

Cell[BoxData[
 RowBox[{"Length", "[", 
  SubscriptBox["\[Rho]", "0"], "]"}]], "Input",
 CellTags->"b:4.2.2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Step 3: The final state density matrix is obtained", "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:20", "b:4.2.3"}],

Cell["\<\
The application of Alice operations to the initial density matrix is readily \
evaluated:\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.2.3"],

Cell[BoxData[
 StyleBox[
  RowBox[{" ", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Rho]", "E"], "  ", ":=", " ", 
     RowBox[{"N", "[", 
      RowBox[{
       RowBox[{"CompBop", "[", 
        RowBox[{
        "1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "7", ",", 
         "8", ",", "9"}], "]"}], ".", 
       SubscriptBox["\[Rho]", "0"], ".", 
       RowBox[{"Adj", "[", 
        RowBox[{"CompBop", "[", 
         RowBox[{
         "1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "7", ",",
           "8", ",", "9"}], "]"}], "]"}]}], "]"}]}], ";"}]}],
  FontSize->12]], "Input",
 FontFamily->"Courier New",
 FontSize->12,
 CellTags->"b:4.2.3"],

Cell["\<\
We can check that the density matrix is indeed so by computing its 
trace and the trace of it squared:\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.2.3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"N", "[", 
    RowBox[{"Chop", "[", 
     RowBox[{"Tr", "[", 
      SubscriptBox["\[Rho]", "E"], "]"}], "]"}], "]"}], "*)"}], "\n", 
  RowBox[{"(*", 
   RowBox[{"N", "[", 
    RowBox[{"Chop", "[", 
     RowBox[{"Tr", "[", 
      RowBox[{
       SubscriptBox["\[Rho]", "E"], ".", 
       SubscriptBox["\[Rho]", "E"]}], "]"}], "]"}], "]"}], "*)"}]}]], "Input",
 CellTags->"b:4.2.3"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Step 4: Alice measures her four qubits, 1,2,3,4,5,6", "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:21", "b:4.2.4"}],

Cell["\<\
Alice measurement is produced here at random, the result of her measurement is 
P1,P2,P3,P4,P5,P6\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.2.4"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"P1", "=", 
   RowBox[{"RandomInteger", "[", 
    RowBox[{"{", 
     RowBox[{"0", ",", "1"}], "}"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"P2", "=", 
   RowBox[{"RandomInteger", "[", 
    RowBox[{"{", 
     RowBox[{"0", ",", "1"}], "}"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"P3", "=", 
   RowBox[{"RandomInteger", "[", 
    RowBox[{"{", 
     RowBox[{"0", ",", "1"}], "}"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"P4", "=", 
   RowBox[{"RandomInteger", "[", 
    RowBox[{"{", 
     RowBox[{"0", ",", "1"}], "}"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"P5", "=", 
   RowBox[{"RandomInteger", "[", 
    RowBox[{"{", 
     RowBox[{"0", ",", "1"}], "}"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"P6", "=", 
   RowBox[{"RandomInteger", "[", 
    RowBox[{"{", 
     RowBox[{"0", ",", "1"}], "}"}], "]"}]}], ";"}], "\n", 
 RowBox[{"{", 
  RowBox[{"P1", ",", "P2", ",", "P3", ",", "P4", ",", "P5", ",", "P6"}], 
  "}"}]}], "Input",
 CellTags->"b:4.2.4"],

Cell["\<\
The projection operator on qubits 1,2,3,4,5 and 6 is written:\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.2.4"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["P", 
   RowBox[{"a_", ",", "b_", ",", "c_", ",", "d_", ",", "e_", ",", "f_"}]], 
  "  ", ":=", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", " ", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  SubscriptBox["\[ScriptCapitalP]", "a"], "  ", 
                  "\[CircleTimes]", "  ", 
                  SubscriptBox["\[ScriptCapitalP]", "b"]}], ")"}], 
                "\[CircleTimes]", "  ", 
                SubscriptBox["\[ScriptCapitalP]", "c"]}], ")"}], 
              "\[CircleTimes]", 
              SubscriptBox["\[ScriptCapitalP]", "d"]}], " ", ")"}], 
            "\[CircleTimes]", "  ", 
            SubscriptBox["\[ScriptCapitalP]", "e"]}], ")"}], "\[CircleTimes]", 
          SubscriptBox["\[ScriptCapitalP]", "f"]}], " ", ")"}], 
        "\[CircleTimes]", " ", "\[DoubleStruckCapitalI]"}], ")"}], 
      "\[CircleTimes]", " ", "\[DoubleStruckCapitalI]"}], ")"}], 
    "\[CircleTimes]", " ", "\[DoubleStruckCapitalI]"}], ")"}]}]], "Input",
 CellTags->"b:4.2.4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  FormBox[Cell[TextData[Cell[BoxData[
    FormBox[Cell[""], TraditionalForm]]]]], TraditionalForm]]],
 "Step 5: Bob state is computed "
}], "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:22", "b:4.2.5"}],

Cell["\<\
Bob's three qubit state, made of qubits 7, 8 and 9, is obtained by taking the 
partial trace of the full final state after Alice measurement (here is \
written in general depending on the 
six values of alice measurement)\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.2.5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"time1", "=", 
   RowBox[{"SessionTime", "[", "]"}]}], ";"}]], "Input",
 CellTags->"b:4.2.5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Bob", " ", "=", " ", 
   RowBox[{"Chop", "[", 
    RowBox[{"CompPTr", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6"}], "}"}],
       "  ", ",", 
      RowBox[{
       RowBox[{"2", "^", "6"}], "*", 
       RowBox[{
        SubscriptBox["P", 
         RowBox[{
         "P1", ",", "P2", ",", "P3", ",", "P4", ",", "P5", ",", "P6"}]], ".", 
        SubscriptBox["\[Rho]", "E"], ".", 
        SubscriptBox["P", 
         RowBox[{
         "P1", ",", "P2", ",", "P3", ",", "P4", ",", "P5", ",", "P6"}]]}]}]}],
      " ", "]"}], "]"}]}], ";"}]], "Input",
 CellTags->"b:4.2.5"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"time2", "=", 
   RowBox[{"SessionTime", "[", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<The computation of Bob's density matrix took \>\"", ",", 
   RowBox[{"time2", "-", "time1"}], ",", "\"\< seconds\>\""}], 
  "]"}]}], "Input",
 CellTags->"b:4.2.5"],

Cell[TextData[{
 "Bob state, once Alice has ",
 StyleBox["clasically communicated",
  FontWeight->"Bold"],
 " P1,P2,P3,P4,P5 and P6 reads:"
}], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.2.5"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Rho]", "Bob"], "=", "Bob"}]], "Input",
 CellTags->"b:4.2.5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  FormBox[Cell[TextData[Cell[BoxData[
    FormBox[Cell[""], TraditionalForm]]]]], TraditionalForm]]],
 "Step 6: Bob performs an arranged transformation on its state to recover the \
initial state"
}], "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:23", "b:4.2.6"}],

Cell["\<\
The coding of the operations is quite compact altough it could be improved \
slightly\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.2.6"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"I1", "=", 
   RowBox[{
    RowBox[{"P1", "*", "2"}], "+", "P4"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"I2", "=", 
   RowBox[{
    RowBox[{"P2", "*", "2"}], "+", "P5"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"I3", "=", 
  RowBox[{
   RowBox[{"P3", "*", "2"}], "+", "P6"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"If", " ", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"P1", "*", "2"}], "+", "P4"}], "\[Equal]", "2"}], ",", " ", 
    RowBox[{"I1", "=", "3"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"If", " ", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"P1", "*", "2"}], "+", "P4"}], "\[Equal]", "3"}], ",", " ", 
    RowBox[{"I1", "=", "2"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"If", " ", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"P2", "*", "2"}], "+", "P5"}], "\[Equal]", "2"}], ",", " ", 
    RowBox[{"I2", "=", "3"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"If", " ", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"P2", "*", "2"}], "+", "P5"}], "\[Equal]", "3"}], ",", " ", 
    RowBox[{"I2", "=", "2"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"If", " ", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"P3", "*", "2"}], "+", "P6"}], "\[Equal]", "2"}], ",", " ", 
    RowBox[{"I3", "=", "3"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"If", " ", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"P3", "*", "2"}], "+", "P6"}], "\[Equal]", "3"}], ",", " ", 
    RowBox[{"I3", "=", "2"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"TrasF", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["\[Sigma]", "I1"], " ", "\[CircleTimes]", " ", 
     SubscriptBox["\[Sigma]", "I2"]}], ")"}], "\[CircleTimes]", " ", 
   SubscriptBox["\[Sigma]", "I3"]}]}]}], "Input",
 CellTags->"b:4.2.6"],

Cell["\<\
The three qubit state in Bob's hands after the transformation is:\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.2.6"],

Cell[BoxData[{
 RowBox[{"BobT", "=", " ", 
  RowBox[{"N", "[", 
   RowBox[{"Chop", "[", 
    RowBox[{"TrasF", ".", 
     SubscriptBox["\[Rho]", "Bob"], ".", 
     RowBox[{"Adj", "[", "TrasF", "]"}]}], "]"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Chop", "[", 
  RowBox[{"Eigenvalues", "[", "BobT", "]"}], "]"}]}], "Input",
 CellTags->"b:4.2.6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  FormBox[Cell[TextData[Cell[BoxData[
    FormBox[Cell[""], TraditionalForm]]]]], TraditionalForm]]],
 "Step 7: Moment of truth, we compare both  initial Alice and final Bob state"
}], "Subsection",
 CellFrame->True,
 CellChangeTimes->{3.512214376194934*^9},
 FontFamily->"Times",
 CellTags->{"c:24", "b:4.2.7"}],

Cell["\<\
...we can compare Bobs three qubit state to the original three qubit density \
matrix:\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.2.7"],

Cell[BoxData[
 RowBox[{"Chop", "[", 
  RowBox[{"BobT", " ", "-", 
   SubscriptBox["\[Rho]", "123"]}], "]"}]], "Input",
 CellTags->"b:4.2.7"],

Cell[BoxData["Quit"], "Input",
 CellTags->"b:4.2.7"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
EPR teleportation using an GHZ state.              To open double click at \
down arrow----------------------->>\
\>", "Section",
 CellChangeTimes->{{3.5122128273908653`*^9, 3.512212828065277*^9}, {
  3.512214533171061*^9, 3.512214548029138*^9}, {3.512214640729178*^9, 
  3.5122146555167294`*^9}},
 FontFamily->"Times",
 CellTags->"c:25"],

Cell[CellGroupData[{

Cell["Introduction", "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:3", "b:4.3.0"}],

Cell["\<\
 Load the Qdensity Package, defines total number of qubits and plots the \
circuit:\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.3.0"],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<QDENSITY`Qdensity`\>\"", "]"}]], "Input",
 FontFamily->"Courier New",
 CellTags->"b:4.3.0"],

Cell[BoxData[
 RowBox[{"?", "QDENSITY`Qdensity`*"}]], "Input",
 FontFamily->"Courier New",
 CellTags->"b:4.3.0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"nqx", "=", "5"}], ";"}]], "Input",
 FontFamily->"Courier New",
 CellTags->"b:4.3.0"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"figure1", "=", 
   RowBox[{"Import", "[", 
    RowBox[{"\"\<QDENSITY/drawings/GHZ.png\>\"", ",", "\"\<PNG\>\""}], 
    "]"}]}], ";"}], "\n", 
 RowBox[{"Show", "[", "figure1", "]"}]}], "Input",
 CellTags->"b:4.3.0"],

Cell[TextData[{
 StyleBox["Icalc=1 computes using symbols",
  FontSlant->"Italic"],
 ", anyother Icalc value performs the computation\nnumerically."
}], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.3.0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Icalc", "=", "1"}], ";"}]], "Input",
 CellTags->"b:4.3.0"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  FormBox[Cell[TextData[Cell[BoxData[
    FormBox[Cell[""], TraditionalForm]]]]], TraditionalForm]]],
 "Step 1: Alice builds the EPR state to be teleported"
}], "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:26", "b:4.3.1"}],

Cell["\<\
 The EPR state is of the form A|00\[RightAngleBracket]+B|11\
\[RightAngleBracket]. It is built by first constructing (A|0\
\[RightAngleBracket]+B|1\[RightAngleBracket])|0\[RightAngleBracket] and then 
applying a CNOT(2,1,2). The first qubit is thus generated at random in the \
following way:\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.3.1"],

Cell["\<\
 A general one qubit state is built by rotating the |0\[RightAngleBracket] \
state around the x axis an angle \[Theta]\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.3.1"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["\[Rho]", "1"], "=", "RandomQubit1"}], ";"}]], "Input",
 CellTags->"b:4.3.1"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"Icalc", "\[Equal]", "1"}], ",", 
     RowBox[{
      SubscriptBox["\[Rho]", "1"], "=", 
      RowBox[{
       RowBox[{"1", "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"A", "^", "2"}], "+", 
          RowBox[{"B", "^", "2"}]}], ")"}]}], "*", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"A", "*", 
           RowBox[{"Ket", "[", "0", "]"}]}], "+", 
          RowBox[{"B", "*", 
           RowBox[{"Ket", "[", "1", "]"}]}]}], ")"}], "\[CircleTimes]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"A", "*", 
           RowBox[{"Bra", "[", "0", "]"}]}], "+", 
          RowBox[{"B", "*", 
           RowBox[{"Bra", "[", "1", "]"}]}]}], ")"}]}]}]}]}], "]"}], 
   ";"}]}]], "Input",
 CellTags->"b:4.3.1"],

Cell["Then we construct the EPR state using a CNOT gate:", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.3.1"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"OpEPR", "=", 
   RowBox[{"CNOT", "[", 
    RowBox[{"2", ",", "1", ",", "2"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["\[Rho]", "12"], "=", " ", 
   RowBox[{
    SubscriptBox["\[Rho]", "1"], "\[CircleTimes]", 
    SubscriptBox["\[ScriptCapitalP]", "0"]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["\[Rho]", "EPR"], "=", 
  RowBox[{"Chop", "[", 
   RowBox[{"OpEPR", ".", 
    SubscriptBox["\[Rho]", "12"], ".", 
    RowBox[{"Adj", "[", "OpEPR", "]"}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Tr", "[", 
  SubscriptBox["\[Rho]", "EPR"], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Tr", "[", 
  RowBox[{
   SubscriptBox["\[Rho]", "EPR"], ".", 
   SubscriptBox["\[Rho]", "EPR"]}], "]"}]}], "Input",
 CellTags->"b:4.3.1"],

Cell["Check on Hermiticity of the EPR (only if Icalc=0)", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.3.1"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"Icalc", "\[Equal]", "0"}], ",", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Chop", "[", 
        RowBox[{
         RowBox[{"Adj", "[", 
          SubscriptBox["\[Rho]", "EPR"], 
          StyleBox["  ",
           FontSize->12], "]"}], " ", "-", 
         SubscriptBox["\[Rho]", 
          RowBox[{"EPR", " "}]]}], "]"}], "\[Equal]", 
       RowBox[{"ConstantArray", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Length", "[", 
            SubscriptBox["\[Rho]", "EPR"], "]"}], ",", 
           RowBox[{"Length", "[", 
            SubscriptBox["\[Rho]", "EPR"], "]"}]}], "}"}]}], "]"}]}], ",", 
      RowBox[{"Print", "[", "\"\<Hermitian\>\"", "]"}], ",", 
      RowBox[{"Print", "[", "\"\<Not Hermitian\>\"", "]"}]}], "]"}], ",", 
    "\"\<\>\""}], "]"}]}]], "Input",
 CellChangeTimes->{{3.395093222183462*^9, 3.395093242281027*^9}},
 FontFamily->"Courier New",
 CellTags->"b:4.3.1"],

Cell["Check on Eigenvalues of the EPR", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.3.1"],

Cell[BoxData[{
 RowBox[{"evEPR", ":=", 
  RowBox[{"Chop", "[", 
   RowBox[{"Eigenvalues", "[", 
    SubscriptBox["\[Rho]", "EPR"], "]"}], 
   "]"}]}], "\[IndentingNewLine]", "evEPR", "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"Chop", "[", 
   RowBox[{"Tr", "[", 
    SubscriptBox["\[Rho]", "EPR"], "]"}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"Chop", "[", 
   RowBox[{"Tr", "[", 
    RowBox[{
     SubscriptBox["\[Rho]", "EPR"], ".", 
     SubscriptBox["\[Rho]", "EPR"]}], "]"}], "]"}], "]"}]}], "Input",
 CellTags->"b:4.3.1"],

Cell["Test Positivity:", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.3.1"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"Icalc", "\[Equal]", "0"}], ",", 
    RowBox[{"Do", "[", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"evEPR", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "]"}], "\[GreaterEqual]", "0"}], 
        ",", 
        RowBox[{"Print", "[", "\"\<Positive eigenvalue\>\"", "]"}], ",", 
        RowBox[{"Print", "[", "\"\<Negative\>\"", "]"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "4"}], "}"}]}], "]"}], ",", "\"\<\>\""}], 
   "]"}]}]], "Input",
 FontFamily->"Courier New",
 CellTags->{"Do", "b:4.3.1"}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  FormBox[Cell[TextData[Cell[BoxData[
    FormBox[Cell[""], TraditionalForm]]]]], TraditionalForm]]],
 "Step 2: The GHZ state made of qubits 345 is built"
}], "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:27", "b:4.3.2"}],

Cell[BoxData[
 RowBox[{"  ", 
  RowBox[{
  "Build", " ", "the", " ", "Three", " ", "Qubit", " ", "entangled", " ", 
   "state", "   ", 
   StyleBox[
    SubscriptBox["\[Rho]", "GHZ"],
    FontSize->12], "  ", 
   RowBox[{"(", " ", 
    RowBox[{"Entangled", " ", "State", " ", "Resource"}], " ", ")"}]}], " ", 
  " "}]], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.3.2"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   SubscriptBox["\[Rho]", "00"],
   FontSize->12], 
  StyleBox["=",
   FontSize->12], 
  RowBox[{
   SubscriptBox["\[ScriptCapitalP]", "0"], "  ", "\[CircleTimes]", " ", 
   RowBox[{"(", " ", 
    RowBox[{
     SubscriptBox["\[ScriptCapitalP]", "0"], " ", "\[CircleTimes]", "  ", 
     SubscriptBox["\[ScriptCapitalP]", "0"]}], ")"}]}]}]], "Input",
 CellTags->"b:4.3.2"],

Cell[" Generate GHZ state operator ", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.3.2"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"figure2", "=", 
   RowBox[{"Import", "[", 
    RowBox[{"\"\<QDENSITY/drawings/gGHZ.png\>\"", ",", "\"\<PNG\>\""}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", "figure2", "]"}]}], "Input",
 CellTags->"b:4.3.2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"GHZop", "[", 
   RowBox[{"qi_", ",", "qj_", ",", "qk_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"CNOT", "[", 
     RowBox[{"3", ",", "qi", ",", "qk"}], "]"}], ".", 
    RowBox[{"CNOT", "[", 
     RowBox[{"3", ",", "qi", ",", "qj"}], "]"}]}], ".", 
   RowBox[{"had", "[", 
    RowBox[{"3", ",", "qi"}], "]"}]}], " "}]], "Input",
 FontFamily->"Courier New",
 CellTags->"b:4.3.2"],

Cell[BoxData[
 RowBox[{"  ", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["\[Rho]", "GHZ"], "   ", "is", " ", "the", " ", "density", 
     " ", "matrix", "  ", "of", " ", "the", " ", "GHZ", " ", "state", " ", 
     "produced", " ", "by", " ", "Bob", "  ", 
     RowBox[{"(", 
      RowBox[{"or", " ", "Eve"}], ")"}], " ", "from", " ", "qubits", " ", 
     "3"}], ",", 
    RowBox[{
     RowBox[{"4", " ", "&"}], " ", "5"}]}], " ", "\[IndentingNewLine]", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{
     "Bob", " ", "sends", " ", "one", " ", "of", " ", "these", " ", "qubits", 
      " ", "to", " ", "Alice", " ", "who", " ", "has", " ", "qubits", " ", 
      "1"}], " ", "&"}], " ", "2", " ", "in", " ", "state", " ", 
    SubscriptBox["\[Rho]", "EPR"]}]}]}]], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.3.2"],

Cell[BoxData[
 StyleBox[
  RowBox[{" ", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Rho]", "GHZ"], "  ", ":=", 
     RowBox[{
      RowBox[{"GHZop", "[", 
       RowBox[{"1", ",", "2", ",", "3"}], "]"}], ".", 
      SubscriptBox["\[Rho]", "00"], ".", 
      RowBox[{"Adj", "[", 
       RowBox[{"GHZop", "[", 
        RowBox[{"1", ",", "2", ",", "3"}], "]"}], "]"}]}]}], ";"}]}],
  FontSize->12]], "Input",
 FontFamily->"Courier New",
 FontSize->12,
 CellTags->"b:4.3.2"],

Cell[" Checks on GHZ states ", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.3.2"],

Cell[BoxData[
 SubscriptBox["\[Rho]", "GHZ"]], "Input",
 CellTags->"b:4.3.2"],

Cell["\<\
 Vector and tensor polarizations of GHZ state 
 Vector polarizations are zero for GHZ states 
 Rank 2 Tensor polarizations for GHZ state 
 Rank 3 Tensor polarizations for GHZ state \
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.3.2"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"T", "[", 
    RowBox[{"i_", ",", "j_", ",", "k_"}], "]"}], ":=", 
   RowBox[{"Tr", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Sigma]", "i"], "\[CircleTimes]", 
         SubscriptBox["\[Sigma]", "j"]}], ")"}], "\[CircleTimes]", 
       SubscriptBox["\[Sigma]", "k"]}], ")"}], ".", 
     StyleBox[
      SubscriptBox["\[Rho]", "GHZ"],
      FontSize->12]}], 
    StyleBox[" ",
     FontSize->12], 
    StyleBox["]",
     FontSize->12]}]}], 
  StyleBox[";",
   FontSize->12]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   StyleBox[
    RowBox[{
     StyleBox["P",
      FontSize->12], "GHZ", 
     StyleBox["A",
      FontSize->12]}]], 
   StyleBox["=",
    FontSize->12], 
   RowBox[{
    StyleBox["{",
     FontSize->12], 
    RowBox[{
     StyleBox[
      RowBox[{"T", "[", 
       RowBox[{"1", ",", "0", ",", "0"}], "]"}],
      FontSize->12], 
     StyleBox[",",
      FontSize->12], 
     RowBox[{"T", "[", 
      RowBox[{"2", ",", "0", ",", "0"}], "]"}], ",", 
     RowBox[{"T", "[", 
      RowBox[{"3", ",", "0", ",", "0"}], "]"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   StyleBox[
    RowBox[{
     StyleBox["P",
      FontSize->12], "GHZ", 
     StyleBox["B",
      FontSize->12]}]], 
   StyleBox["=",
    FontSize->12], 
   RowBox[{
    StyleBox["{",
     FontSize->12], 
    RowBox[{
     StyleBox[
      RowBox[{"T", "[", 
       RowBox[{"0", ",", "1", ",", "0"}], "]"}],
      FontSize->12], 
     StyleBox[",",
      FontSize->12], 
     RowBox[{"T", "[", 
      RowBox[{"0", ",", "2", ",", "0"}], "]"}], ",", 
     RowBox[{"T", "[", 
      RowBox[{"0", ",", "3", ",", "0"}], "]"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    StyleBox[
     RowBox[{
      StyleBox["P",
       FontSize->12], "GHZ", 
      StyleBox["C",
       FontSize->12]}]], 
    StyleBox["=",
     FontSize->12], 
    RowBox[{
     StyleBox["{",
      FontSize->12], 
     RowBox[{
      StyleBox[
       RowBox[{"T", "[", 
        RowBox[{"0", ",", "0", ",", "1"}], "]"}],
       FontSize->12], 
      StyleBox[",",
       FontSize->12], 
      RowBox[{"T", "[", 
       RowBox[{"0", ",", "0", ",", "2"}], "]"}], ",", 
      RowBox[{"T", "[", 
       RowBox[{"0", ",", "0", ",", "3"}], "]"}]}], "}"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   StyleBox[
    RowBox[{"TGHZ", 
     StyleBox["AB",
      FontSize->12]}]], 
   StyleBox["=",
    FontSize->12], 
   RowBox[{
    StyleBox["{",
     FontSize->12], 
    RowBox[{
     StyleBox["Table",
      FontSize->12], 
     StyleBox["[",
      FontSize->12], 
     RowBox[{
      StyleBox[
       RowBox[{"T", "[", 
        RowBox[{"i", ",", "j", ",", "0"}], "]"}],
       FontSize->12], 
      StyleBox[",",
       FontSize->12], 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "1", ",", "3"}], "}"}]}], "]"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   StyleBox[
    RowBox[{"TGHZ", 
     StyleBox["AC",
      FontSize->12]}]], 
   StyleBox["=",
    FontSize->12], 
   RowBox[{
    StyleBox["{",
     FontSize->12], 
    RowBox[{
     StyleBox["Table",
      FontSize->12], 
     StyleBox["[",
      FontSize->12], 
     RowBox[{
      StyleBox[
       RowBox[{"T", "[", 
        RowBox[{"i", ",", "0", ",", "j"}], "]"}],
       FontSize->12], 
      StyleBox[",",
       FontSize->12], 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "1", ",", "3"}], "}"}]}], "]"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"TGHZBC", 
   StyleBox["=",
    FontSize->12], 
   RowBox[{
    StyleBox["{",
     FontSize->12], 
    RowBox[{
     StyleBox["Table",
      FontSize->12], 
     StyleBox["[",
      FontSize->12], 
     RowBox[{
      StyleBox[
       RowBox[{"T", "[", 
        RowBox[{"i", ",", "j", ",", "0"}], "]"}],
       FontSize->12], 
      StyleBox[",",
       FontSize->12], 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "1", ",", "3"}], "}"}]}], "]"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   StyleBox[
    RowBox[{"TGHZ", 
     StyleBox["ABC",
      FontSize->12]}]], 
   StyleBox["=",
    FontSize->12], 
   RowBox[{
    StyleBox["{",
     FontSize->12], 
    RowBox[{
     StyleBox["Table",
      FontSize->12], 
     StyleBox["[",
      FontSize->12], 
     RowBox[{
      StyleBox[
       RowBox[{"T", "[", 
        RowBox[{"i", ",", "j", ",", "k"}], "]"}],
       FontSize->12], 
      StyleBox[",",
       FontSize->12], 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "1", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"k", ",", "1", ",", "3"}], "}"}]}], "]"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", "PGHZA", "\[IndentingNewLine]", "PGHZB", "\
\[IndentingNewLine]", "PGHZC", "\[IndentingNewLine]", 
 RowBox[{"Flatten", "[", 
  RowBox[{"TGHZAB", ",", "1"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Flatten", "[", 
  RowBox[{"TGHZAC", ",", "1"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Flatten", "[", 
  RowBox[{"TGHZBC", ",", "1"}], 
  "]"}], "\[IndentingNewLine]", "TGHZABC"}], "Input",
 FontFamily->"Courier New",
 CellTags->"b:4.3.2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  FormBox[Cell[TextData[Cell[BoxData[
    FormBox[Cell[""], TraditionalForm]]]]], TraditionalForm]]],
 "Step 3: The initial 5 qubit state"
}], "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:28", "b:4.3.3"}],

Cell[BoxData[
 RowBox[{
  RowBox[{
  "The", " ", "initial", " ", "5", " ", "qubit", " ", "density", " ", 
   "matrix", " ", "is", " ", 
   RowBox[{"thus", ":", " ", 
    StyleBox[
     SubscriptBox["\[Rho]", "I"],
     FontSize->12]}]}], 
  StyleBox["=",
   FontSize->12], 
  StyleBox[
   RowBox[{
    StyleBox[" ",
     FontSize->12], " "}]], 
  RowBox[{
   StyleBox[
    SubscriptBox["\[Rho]", "EPR"],
    FontSize->12], " ", "\[CircleTimes]", " ", 
   StyleBox[
    SubscriptBox["\[Rho]", "GHZ"],
    FontSize->12]}]}]], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.3.3"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   StyleBox[
    SubscriptBox["\[Rho]", "I"],
    FontSize->12], 
   StyleBox["=",
    FontSize->12], 
   StyleBox["  ",
    FontSize->12], 
   RowBox[{
    StyleBox[
     SubscriptBox["\[Rho]", "EPR"],
     FontSize->12], "\[CircleTimes]", 
    StyleBox[
     SubscriptBox["\[Rho]", "GHZ"],
     FontSize->12]}]}], 
  StyleBox[";",
   FontSize->12]}]], "Input",
 FontFamily->"Courier New",
 CellTags->"b:4.3.3"],

Cell[BoxData[
 RowBox[{"Checks", " ", "on", " ", "Full", " ", "Initial", "  ", 
  StyleBox[
   SubscriptBox["\[Rho]", "I"],
   FontSize->12], " ", "Density", " ", "Matrix"}]], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.3.3"],

Cell[BoxData[
 RowBox[{"Length", "[", 
  StyleBox[
   SubscriptBox["\[Rho]", "I"],
   FontSize->12], 
  StyleBox["]",
   FontSize->12]}]], "Input",
 FontFamily->"Courier New",
 CellTags->"b:4.3.3"],

Cell[BoxData[
 RowBox[{"Trace", " ", "and", " ", "purity", " ", "of", "  ", 
  StyleBox[
   SubscriptBox["\[Rho]", "I"],
   FontSize->12], " ", "Density", " ", "Matrix"}]], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.3.3"],

Cell[BoxData[{
 RowBox[{"Simplify", "[", 
  RowBox[{"Chop", "[", 
   RowBox[{"Tr", "[", 
    StyleBox[
     SubscriptBox["\[Rho]", "I"],
     FontSize->12], 
    StyleBox["]",
     FontSize->12]}], 
   StyleBox["]",
    FontSize->12]}], 
  StyleBox["]",
   FontSize->12]}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"Purity", "[", 
   StyleBox[
    SubscriptBox["\[Rho]", "I"],
    FontSize->12], 
   StyleBox["]",
    FontSize->12]}], 
  StyleBox["]",
   FontSize->12]}]}], "Input",
 FontFamily->"Courier New",
 CellTags->"b:4.3.3"],

Cell[BoxData[
 RowBox[{"If", "[", 
  RowBox[{
   RowBox[{"Icalc", "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"evI", ":=", 
     RowBox[{"Eigenvalues", "[", 
      StyleBox[
       SubscriptBox["\[Rho]", "I"],
       FontSize->12], 
      StyleBox["]",
       FontSize->12]}]}], 
    StyleBox[";",
     FontSize->12], "\[IndentingNewLine]", 
    RowBox[{"Do", "[", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Chop", "[", 
          RowBox[{"evI", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "]"}], "\[GreaterEqual]", "0"}], 
        ",", 
        RowBox[{"Print", "[", "\"\<Positive eigenvalue\>\"", "]"}], ",", 
        RowBox[{"Print", "[", "\"\<Negative\>\"", "]"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", 
        StyleBox[
         RowBox[{"Length", "[", "evI", "]"}],
         FontSize->12]}], "}"}]}], "]"}]}], ",", "\"\<\>\""}], "]"}]], "Input",
 FontFamily->"Courier New",
 CellTags->{"Do", "b:4.3.3"}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  FormBox[Cell[TextData[Cell[BoxData[
    FormBox[Cell[""], TraditionalForm]]]]], TraditionalForm]]],
 "Step 4: Alice receives qubit 3 and performs an operation on qubits 1,2,3 \
and then Measures them"
}], "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:29", "b:4.3.4"}],

Cell["\<\
Alice performs an operation defined by (see the figure above):\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.3.4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"AliceOp", "=", " ", 
   RowBox[{
    RowBox[{"had", "[", 
     RowBox[{"5", ",", "2"}], "]"}], ".", 
    RowBox[{"CNOT", "[", 
     RowBox[{"5", ",", "3", ",", "2"}], "]"}], ".", 
    RowBox[{"had", "[", 
     RowBox[{"5", ",", "1"}], "]"}], ".", 
    RowBox[{"CNOT", "[", 
     RowBox[{"5", ",", "1", ",", "3"}], "]"}]}]}], ";"}]], "Input",
 CellTags->"b:4.3.4"],

Cell["\<\
 And therefore the density matrix of the 5 qubit system after Alice operation \
reads:\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.3.4"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   SubscriptBox["\[Rho]", "T"], " ", "=", 
   RowBox[{"AliceOp", ".", 
    SubscriptBox["\[Rho]", "I"], ".", 
    RowBox[{"Adj", "[", "AliceOp", "]"}]}]}], ";"}], "\n", 
 RowBox[{"Simplify", "[", 
  RowBox[{"Chop", "[", 
   RowBox[{"Tr", "[", 
    SubscriptBox["\[Rho]", "T"], "]"}], "]"}], "]"}], "\n", 
 RowBox[{"Simplify", "[", 
  RowBox[{"Chop", "[", 
   RowBox[{"Tr", "[", 
    RowBox[{
     SubscriptBox["\[Rho]", "T"], ".", 
     SubscriptBox["\[Rho]", "T"]}], "]"}], "]"}], "]"}]}], "Input",
 FontFamily->"Courier New",
 CellTags->"b:4.3.4"],

Cell[BoxData[
 RowBox[{"If", "[", 
  RowBox[{
   RowBox[{"Icalc", "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"evF", ":=", 
     RowBox[{"Eigenvalues", "[", 
      SubscriptBox["\[Rho]", "T"], "]"}]}], ";", 
    RowBox[{"Do", "[", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Chop", "[", 
          RowBox[{"evF", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "]"}], "\[GreaterEqual]", "0"}], 
        ",", 
        RowBox[{"Print", "[", "\"\<Positive eigenvalue\>\"", "]"}], ",", 
        RowBox[{"Print", "[", "\"\<Negative\>\"", "]"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", 
        RowBox[{"Length", "[", "evF", "]"}]}], "}"}]}], "]"}]}], ",", 
   "\"\<\>\""}], "]"}]], "Input",
 FontFamily->"Courier New",
 CellTags->"b:4.3.4"],

Cell[BoxData[
 RowBox[{"Length", "[", 
  SubscriptBox["\[Rho]", "T"], "]"}]], "Input",
 FontFamily->"Courier New",
 CellTags->"b:4.3.4"],

Cell["\<\
 Eight  Projection Operators for Alice's Measurement on Qubits 1,2 and 3 \
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.3.4"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["P", 
   RowBox[{"a_", ",", "b_", ",", "c_"}]], "  ", ":=", " ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[ScriptCapitalP]", "a"], "  ", "\[CircleTimes]", "  ", 
         SubscriptBox["\[ScriptCapitalP]", "b"]}], ")"}], "\[CircleTimes]", 
       "  ", 
       SubscriptBox["\[ScriptCapitalP]", "c"]}], ")"}], "\[CircleTimes]", " ",
      "\[DoubleStruckCapitalI]"}], ")"}], "\[CircleTimes]", " ", 
   "\[DoubleStruckCapitalI]"}]}]], "Input",
 CellTags->"b:4.3.4"],

Cell["\<\
Bob's 2-Qubit Density Matrix--After measurement by Alice of abc \
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.3.4"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"RhoBob", "[", 
    RowBox[{"a_", ",", "b_", ",", "c_"}], "]"}], ":=", 
   RowBox[{"Chop", "[", " ", 
    RowBox[{"PTr", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "2", ",", "3"}], "}"}], "  ", ",", 
      RowBox[{
       RowBox[{"2", "^", "3."}], 
       RowBox[{
        SubscriptBox["P", 
         RowBox[{"a", ",", "b", ",", "c"}]], ".", 
        SubscriptBox["\[Rho]", "T"], ".", 
        SubscriptBox["P", 
         RowBox[{"a", ",", "b", ",", "c"}]]}]}]}], " ", "]"}], "]"}]}], 
  ";"}]], "Input",
 FontFamily->"Courier New",
 CellTags->"b:4.3.4"],

Cell["\<\
   Alice measures 1,2,3 and gets values P1,P2,P3. 
Here we produce them at random.\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.3.4"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"P1", "=", 
   RowBox[{"RandomInteger", "[", 
    RowBox[{"{", 
     RowBox[{"0", ",", "1"}], "}"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"P2", "=", 
   RowBox[{"RandomInteger", "[", 
    RowBox[{"{", 
     RowBox[{"0", ",", "1"}], "}"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"P3", "=", 
   RowBox[{"RandomInteger", "[", 
    RowBox[{"{", 
     RowBox[{"0", ",", "1"}], "}"}], "]"}]}], 
  ";"}], "\n", "P1", "\n", "P2", "\n", "P3"}], "Input",
 CellTags->"b:4.3.4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  FormBox[Cell[TextData[Cell[BoxData[
    FormBox[Cell[""], TraditionalForm]]]]], TraditionalForm]]],
 "Step 5: Alice sends the result of her measurement to Bob "
}], "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:30", "b:4.3.5"}],

Cell["\<\
 Alice classically transmits P1,P2 and P3 to Bob, which has then the following 
density matrix for qubits 4 and 5:\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.3.5"],

Cell[BoxData[{
 RowBox[{
  SubscriptBox["\[Rho]", "45"], "=", " ", 
  RowBox[{"RhoBob", "[", 
   RowBox[{"P1", ",", "P2", ",", "P3"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"Tr", "[", 
   SubscriptBox["\[Rho]", "45"], "]"}], "]"}]}], "Input",
 CellTags->"b:4.3.5"],

Cell["\<\
 Bob, with the values of the measurements made by Alice, performs a set of 
operations on its two qubit system depending on P1,P2,P3\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.3.5"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["S", 
   RowBox[{"i_", " ", ",", "j_", "  "}]], "  ", ":=", "  ", 
  RowBox[{"(", " ", 
   RowBox[{
    SubscriptBox["\[Sigma]", "i"], " ", "\[CircleTimes]", " ", 
    SubscriptBox["\[Sigma]", "j"]}], " ", ")"}], " "}]], "Input",
 CellTags->"b:4.3.5"],

Cell[BoxData[
 RowBox[{"BobOp", "=", 
  RowBox[{"Which", "[", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"P1", ",", "P2", ",", "P3"}], "}"}], "\[Equal]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], ",", 
    SubscriptBox["S", 
     RowBox[{"0", " ", ",", "0"}]], 
    StyleBox[",",
     FontSize->12], 
    StyleBox["\[IndentingNewLine]",
     FontSize->12], 
    StyleBox["                      ",
     FontSize->12], 
    RowBox[{
     RowBox[{
      StyleBox["{",
       FontSize->12], 
      RowBox[{"P1", ",", "P2", ",", "P3"}], "}"}], "\[Equal]", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "0"}], "}"}]}], ",", " ", 
    StyleBox[
     SubscriptBox["S", 
      RowBox[{"0", ",", "0"}]],
     FontSize->12], 
    StyleBox[",",
     FontSize->12], 
    StyleBox["\[IndentingNewLine]",
     FontSize->12], 
    StyleBox["                      ",
     FontSize->12], 
    StyleBox[
     RowBox[{
      RowBox[{"{", 
       RowBox[{"P1", ",", "P2", ",", "P3"}], "}"}], "==", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "1"}], "}"}]}],
     FontSize->12], ",", 
    StyleBox[
     SubscriptBox["S", 
      RowBox[{"1", ",", "1"}]],
     FontSize->12], 
    StyleBox[",",
     FontSize->12], 
    StyleBox["\[IndentingNewLine]",
     FontSize->12], 
    StyleBox["                      ",
     FontSize->12], 
    RowBox[{
     RowBox[{
      StyleBox["{",
       FontSize->12], 
      RowBox[{"P1", ",", "P2", ",", "P3"}], "}"}], "\[Equal]", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], ",", 
    StyleBox[
     SubscriptBox["S", 
      RowBox[{"1", ",", "1"}]],
     FontSize->12], 
    StyleBox[",",
     FontSize->12], 
    StyleBox["\[IndentingNewLine]",
     FontSize->12], 
    StyleBox[
     RowBox[{
      StyleBox["                     ",
       FontSize->12], " "}]], 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"P1", ",", "P2", ",", "P3"}], "}"}], "\[Equal]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1", ",", "1"}], "}"}]}], ",", 
    SubscriptBox["S", 
     RowBox[{"1", " ", ",", "2"}]], 
    StyleBox[",",
     FontSize->12], 
    StyleBox["\[IndentingNewLine]",
     FontSize->12], 
    StyleBox["                      ",
     FontSize->12], 
    RowBox[{
     RowBox[{
      StyleBox["{",
       FontSize->12], 
      RowBox[{"P1", ",", "P2", ",", "P3"}], "}"}], "\[Equal]", 
     RowBox[{"{", 
      RowBox[{"1", ",", "0", ",", "1"}], "}"}]}], ",", " ", 
    StyleBox[
     SubscriptBox["S", 
      RowBox[{"1", ",", "2"}]],
     FontSize->12], 
    StyleBox[",",
     FontSize->12], 
    StyleBox["\[IndentingNewLine]",
     FontSize->12], 
    StyleBox["                      ",
     FontSize->12], 
    StyleBox[
     RowBox[{
      RowBox[{"{", 
       RowBox[{"P1", ",", "P2", ",", "P3"}], "}"}], "==", 
      RowBox[{"{", 
       RowBox[{"1", ",", "0", ",", "0"}], "}"}]}],
     FontSize->12], ",", 
    StyleBox[
     SubscriptBox["S", 
      RowBox[{"3", ",", "0"}]],
     FontSize->12], 
    StyleBox[",",
     FontSize->12], 
    StyleBox["\[IndentingNewLine]",
     FontSize->12], 
    StyleBox["                      ",
     FontSize->12], 
    RowBox[{
     RowBox[{
      StyleBox["{",
       FontSize->12], 
      RowBox[{"P1", ",", "P2", ",", "P3"}], "}"}], "\[Equal]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1", ",", "0"}], "}"}]}], ",", 
    StyleBox[
     SubscriptBox["S", 
      RowBox[{"3", ",", "0"}]],
     FontSize->12]}], 
   StyleBox["]",
    FontSize->12]}]}]], "Input",
 CellTags->"b:4.3.5"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Rho]", "BobF"], "=", 
  RowBox[{"Chop", "[", 
   RowBox[{"BobOp", ".", 
    SubscriptBox["\[Rho]", "45"], ".", 
    RowBox[{"Adj", "[", "BobOp", "]"}]}], "]"}]}]], "Input",
 CellTags->"b:4.3.5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  FormBox[Cell[TextData[Cell[BoxData[
    FormBox[Cell[""], TraditionalForm]]]]], TraditionalForm]]],
 "Step 6: Final comparison, we compare the EPR state and the state in Bob \
hands:"
}], "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:31", "b:4.3.6"}],

Cell[BoxData[
 RowBox[{"Chop", "[", 
  RowBox[{
   SubscriptBox["\[Rho]", "EPR"], " ", "-", 
   SubscriptBox["\[Rho]", "BobF"]}], "]"}]], "Input",
 CellTags->"b:4.3.6"],

Cell[BoxData["Quit"], "Input",
 CellTags->"b:4.3.6"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
EPR teleportation Algorithm: (Gorbachev and Trubilko quant-ph/9906110). 
                                                                          To \
open double click at down arrow---------------------------->>\
\>", "Section",
 CellChangeTimes->{{3.512212829391058*^9, 3.5122128614691973`*^9}, 
   3.5122145541214247`*^9},
 FontFamily->"Times",
 CellTags->"c:32"],

Cell[CellGroupData[{

Cell["Introduction", "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:3", "b:4.4.0"}],

Cell[TextData[StyleBox["Uses the Qdensity package:",
 FontFamily->"Helvetica"]], "Text",
 FontFamily->"Courier New",
 CellTags->"b:4.4.0"],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<QDENSITY`Qdensity`\>\"", "]"}]], "Input",
 FontFamily->"Courier New",
 CellTags->"b:4.4.0"],

Cell[BoxData[
 RowBox[{"?", "QDENSITY`Qdensity`*"}]], "Input",
 FontFamily->"Courier New",
 CellTags->"b:4.4.0"],

Cell[TextData[StyleBox["We set the number of Qubits to 5", "DisplayText",
 FontWeight->"Plain",
 FontVariations->{"CompatibilityType"->0},
 Background->None]], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.4.0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"nqx", "=", "5"}], ";"}]], "Input",
 CellTags->"b:4.4.0"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Step 1: Alice  prepares the EPR state to be teleported and the GHZ state is \
given\
\>", "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:33", "b:4.4.1"}],

Cell[BoxData[
 RowBox[{
  RowBox[{"A", "=", 
   RowBox[{"RandomReal", "[", 
    RowBox[{"{", 
     RowBox[{"0", ",", "1"}], "}"}], "]"}]}], ";", 
  RowBox[{"B", "=", 
   SqrtBox[
    RowBox[{"1", "-", 
     SuperscriptBox["A", "2"]}]]}], ";"}]], "Input",
 CellTags->"b:4.4.1"],

Cell["\<\
This example permits both an algebraic computation or a numerical one. This \
is controlled
by the value of Icalc: 1 [Algebraic] / Else [Numerical]\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.4.1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Icalc", "=", "1"}], ";"}]], "Input",
 CellTags->"b:4.4.1"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"Icalc", "==", "1"}], ",", 
     RowBox[{"Clear", "[", 
      RowBox[{"A", ",", "B"}], "]"}], ","}], " ", "]"}], ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{"A", ",", " ", "B"}], "}"}]}], "Input",
 FontFamily->"Courier New",
 CellTags->"b:4.4.1"],

Cell["\<\
Alice builds the EPR density matrix to be teleported. Qubits 1 and 2
And we also need the GHZ state made of qubits 3, 4 and 5\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.4.1"],

Cell[BoxData[{
 RowBox[{
  SubscriptBox["\[Rho]", "1"], "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"A", "^", "2"}], ",", 
      RowBox[{"A", " ", "B"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"A", " ", "B"}], ",", 
      RowBox[{"B", "^", "2"}]}], "}"}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"OpEPR", "=", 
   RowBox[{"CNOT", "[", 
    RowBox[{"2", ",", "1", ",", "2"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["\[Rho]", "12"], "=", " ", 
   RowBox[{
    SubscriptBox["\[Rho]", "1"], "\[CircleTimes]", 
    SubscriptBox["\[ScriptCapitalP]", "1"]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"EPR", "=", 
  RowBox[{"OpEPR", ".", 
   SubscriptBox["\[Rho]", "12"], ".", 
   RowBox[{"Adj", "[", "OpEPR", "]"}]}]}]}], "Input",
 CellTags->"b:4.4.1"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   SubscriptBox["\[Rho]", "345"], "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["\[ScriptCapitalP]", "0"], "\[CircleTimes]", 
      SubscriptBox["\[ScriptCapitalP]", "0"]}], ")"}], "\[CircleTimes]", 
    SubscriptBox["\[ScriptCapitalP]", "0"]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"OpGHZ", "=", 
   RowBox[{
    RowBox[{"CNOT", "[", 
     RowBox[{"3", ",", "1", ",", "3"}], "]"}], ".", 
    RowBox[{"CNOT", "[", 
     RowBox[{"3", ",", "1", ",", "2"}], "]"}], ".", 
    RowBox[{"had", "[", 
     RowBox[{"3", ",", "1"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"GHZ", "=", 
  RowBox[{"OpGHZ", ".", 
   SubscriptBox["\[Rho]", "345"], ".", 
   RowBox[{"Adj", "[", "OpGHZ", "]"}]}]}]}], "Input",
 CellTags->"b:4.4.1"],

Cell["Then the density matrix for the \"initial\" system is:", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.4.1"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["\[Rho]", "0"], "=", 
   RowBox[{"EPR", "\[CircleTimes]", "GHZ"}]}], ";"}]], "Input",
 CellTags->"b:4.4.1"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Step 2: The operator corresponding to the network is built", \
"Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:34", "b:4.4.2"}],

Cell["\<\
The bulk of the network which is depicted in Fig. 3 of the abovementioned \
reference can be constructed easily: \
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.4.2"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{
    RowBox[{"Bop", "[", 
     RowBox[{"qi_", ",", "qj_", ",", "qk_", ",", "ql_", ",", "qm_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"CNOT", "[", 
      RowBox[{"5", ",", "qm", ",", "qi"}], "]"}], ".", 
     RowBox[{"had", "[", 
      RowBox[{"5", ",", "qm"}], "]"}], ".", 
     RowBox[{"CNOT", "[", 
      RowBox[{"5", ",", "qi", ",", "ql"}], "]"}], ".", 
     RowBox[{"CNOT", "[", 
      RowBox[{"5", ",", "qm", ",", "ql"}], "]"}], ".", 
     RowBox[{"CNOT", "[", 
      RowBox[{"5", ",", "qk", ",", "qm"}], "]"}], ".", 
     RowBox[{"had", "[", 
      RowBox[{"5", ",", "ql"}], "]"}], ".", 
     RowBox[{"CNOT", "[", 
      RowBox[{"5", ",", "qj", ",", "ql"}], "]"}], ".", 
     RowBox[{"had", "[", 
      RowBox[{"5", ",", "ql"}], "]"}], ".", 
     RowBox[{"CNOT", "[", 
      RowBox[{"5", ",", "qk", ",", "ql"}], "]"}], ".", 
     RowBox[{"had", "[", 
      RowBox[{"5", ",", "qj"}], "]"}], ".", 
     RowBox[{"CNOT", "[", 
      RowBox[{"5", ",", "qj", ",", "qk"}], "]"}], ".", 
     RowBox[{"had", "[", 
      RowBox[{"5", ",", "qj"}], "]"}]}]}], ";"}]}]], "Input",
 FontFamily->"Courier New",
 CellTags->"b:4.4.2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Step 3: The final state density matrix is obtained", "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:35", "b:4.4.3"}],

Cell["\<\
The application of the network to the initial density matrix is readily \
evaluated:\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.4.3"],

Cell[BoxData[
 StyleBox[
  RowBox[{" ", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Rho]", "E"], "  ", ":=", " ", 
     RowBox[{
      RowBox[{"Bop", "[", 
       RowBox[{"1", ",", "2", ",", "3", ",", "4", ",", "5"}], "]"}], ".", 
      SubscriptBox["\[Rho]", "0"], ".", 
      RowBox[{"Adj", "[", 
       RowBox[{"Bop", "[", 
        RowBox[{"1", ",", "2", ",", "3", ",", "4", ",", "5"}], "]"}], 
       "]"}]}]}], ";"}]}],
  FontSize->12]], "Input",
 FontFamily->"Courier New",
 FontSize->12,
 CellTags->"b:4.4.3"],

Cell["\<\
We can check that the density matrix is indeed so by computing its 
trace and the trace of it squared:\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.4.3"],

Cell[BoxData[{
 RowBox[{"Simplify", "[", 
  RowBox[{"Chop", "[", 
   RowBox[{"Tr", "[", 
    SubscriptBox["\[Rho]", "E"], "]"}], "]"}], "]"}], "\n", 
 RowBox[{"Simplify", "[", 
  RowBox[{"Chop", "[", 
   RowBox[{"Tr", "[", 
    RowBox[{
     SubscriptBox["\[Rho]", "E"], ".", 
     SubscriptBox["\[Rho]", "E"]}], "]"}], "]"}], "]"}]}], "Input",
 CellTags->"b:4.4.3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  FormBox[Cell[TextData[Cell[BoxData[
    FormBox[Cell[""], TraditionalForm]]]]], TraditionalForm]]],
 "Step 4: Bob state is computed and compared to the initial EPR"
}], "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:36", "b:4.4.4"}],

Cell["\<\
Bob's 2 qubit state, made of qubits 4 and 5, is obtained by taking the 
partial trace of the full final state:\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.4.4"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Rho]", "Bob"], "=", 
  RowBox[{"PTr", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "2", ",", "3"}], "}"}], ",", 
    SubscriptBox["\[Rho]", "E"]}], "]"}]}]], "Input",
 CellTags->"b:4.4.4"],

Cell["The 2qubit state density matrix is characterized by :", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.4.4"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"T", "[", 
    RowBox[{"i_", ",", "j_"}], "]"}], ":=", 
   RowBox[{"Tr", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Sigma]", "i"], "\[CircleTimes]", 
       SubscriptBox["\[Sigma]", "j"]}], ")"}], ".", 
     StyleBox[
      SubscriptBox["\[Rho]", "Bob"],
      FontSize->12]}], 
    StyleBox[" ",
     FontSize->12], 
    StyleBox["]",
     FontSize->12]}]}], 
  StyleBox[";",
   FontSize->12]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   StyleBox["PA",
    FontSize->12], 
   StyleBox["=",
    FontSize->12], 
   RowBox[{
    StyleBox["{",
     FontSize->12], 
    RowBox[{
     StyleBox[
      RowBox[{"T", "[", 
       RowBox[{"1", ",", "0"}], "]"}],
      FontSize->12], 
     StyleBox[",",
      FontSize->12], 
     RowBox[{"T", "[", 
      RowBox[{"2", ",", "0"}], "]"}], ",", 
     RowBox[{"T", "[", 
      RowBox[{"3", ",", "0"}], "]"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   StyleBox["PB",
    FontSize->12], 
   StyleBox["=",
    FontSize->12], 
   RowBox[{
    StyleBox["{",
     FontSize->12], 
    RowBox[{
     StyleBox[
      RowBox[{"T", "[", 
       RowBox[{"0", ",", "1"}], "]"}],
      FontSize->12], 
     StyleBox[",",
      FontSize->12], 
     RowBox[{"T", "[", 
      RowBox[{"0", ",", "2"}], "]"}], ",", 
     RowBox[{"T", "[", 
      RowBox[{"0", ",", "3"}], "]"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   StyleBox[
    RowBox[{"T", 
     StyleBox["AB",
      FontSize->12]}]], 
   StyleBox["=",
    FontSize->12], 
   RowBox[{
    StyleBox["{",
     FontSize->12], 
    RowBox[{
     StyleBox["Table",
      FontSize->12], 
     StyleBox["[",
      FontSize->12], 
     RowBox[{
      StyleBox[
       RowBox[{"T", "[", 
        RowBox[{"i", ",", "j"}], "]"}],
       FontSize->12], 
      StyleBox[",",
       FontSize->12], 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "1", ",", "3"}], "}"}]}], "]"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", "PA", "\[IndentingNewLine]", "PB", "\
\[IndentingNewLine]", "TAB"}], "Input",
 CellTags->"b:4.4.4"],

Cell["...which we can compare to the original EPR state:", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:4.4.4"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"TT", "[", 
    RowBox[{"i_", ",", "j_"}], "]"}], ":=", 
   RowBox[{"Tr", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Sigma]", "i"], "\[CircleTimes]", 
       SubscriptBox["\[Sigma]", "j"]}], ")"}], ".", "EPR"}], 
    StyleBox[" ",
     FontSize->12], 
    StyleBox["]",
     FontSize->12]}]}], 
  StyleBox[";",
   FontSize->12]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   StyleBox[
    RowBox[{"T", 
     StyleBox["PA",
      FontSize->12]}]], 
   StyleBox["=",
    FontSize->12], 
   RowBox[{
    StyleBox["{",
     FontSize->12], 
    RowBox[{
     StyleBox[
      RowBox[{"TT", "[", 
       RowBox[{"1", ",", "0"}], "]"}],
      FontSize->12], 
     StyleBox[",",
      FontSize->12], 
     RowBox[{"TT", "[", 
      RowBox[{"2", ",", "0"}], "]"}], ",", 
     RowBox[{"TT", "[", 
      RowBox[{"3", ",", "0"}], "]"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   StyleBox[
    RowBox[{"T", 
     StyleBox["PB",
      FontSize->12]}]], 
   StyleBox["=",
    FontSize->12], 
   RowBox[{
    StyleBox["{",
     FontSize->12], 
    RowBox[{
     StyleBox[
      RowBox[{"TT", "[", 
       RowBox[{"0", ",", "1"}], "]"}],
      FontSize->12], 
     StyleBox[",",
      FontSize->12], 
     RowBox[{"TT", "[", 
      RowBox[{"0", ",", "2"}], "]"}], ",", 
     RowBox[{"TT", "[", 
      RowBox[{"0", ",", "3"}], "]"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   StyleBox[
    RowBox[{"TT", 
     StyleBox["AB",
      FontSize->12]}]], 
   StyleBox["=",
    FontSize->12], 
   RowBox[{
    StyleBox["{",
     FontSize->12], 
    RowBox[{
     StyleBox["Table",
      FontSize->12], 
     StyleBox["[",
      FontSize->12], 
     RowBox[{
      StyleBox[
       RowBox[{"TT", "[", 
        RowBox[{"i", ",", "j"}], "]"}],
       FontSize->12], 
      StyleBox[",",
       FontSize->12], 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "1", ",", "3"}], "}"}]}], "]"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", "TPA", "\[IndentingNewLine]", "TPB", "\
\[IndentingNewLine]", "TTAB"}], "Input",
 CellTags->"b:4.4.4"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Step 5: For completeness all one qubit partial traces are shown\
\>", "Subsection",
 CellFrame->True,
 FontFamily->"Times",
 CellTags->{"c:37", "b:4.4.5"}],

Cell[BoxData[{
 StyleBox[
  RowBox[{
   SubscriptBox["\[Rho]", 
    RowBox[{"1", "F"}]], "=", 
   RowBox[{"PTr", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "3", ",", "4", ",", "5"}], "}"}], ",", 
     SubscriptBox["\[Rho]", "E"]}], "]"}]}],
  FontSize->12], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{
   SubscriptBox["\[Rho]", 
    RowBox[{"2", "F"}]], "=", 
   RowBox[{"PTr", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "3", ",", "4", ",", "5"}], "}"}], ",", 
     SubscriptBox["\[Rho]", "E"]}], "]"}]}],
  FontSize->12], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{
   SubscriptBox["\[Rho]", 
    RowBox[{"3", "F"}]], "=", 
   RowBox[{"PTr", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2", ",", "4", ",", "5"}], "}"}], ",", 
     SubscriptBox["\[Rho]", "E"]}], "]"}]}],
  FontSize->12], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{
   SubscriptBox["\[Rho]", 
    RowBox[{"4", "F"}]], "=", 
   RowBox[{"PTr", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2", ",", "3", ",", "5"}], "}"}], ",", 
     SubscriptBox["\[Rho]", "E"]}], "]"}]}],
  FontSize->12], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{
   SubscriptBox["\[Rho]", 
    RowBox[{"5", "F"}]], "=", 
   RowBox[{"PTr", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2", ",", "3", ",", "4"}], "}"}], ",", 
     SubscriptBox["\[Rho]", "E"]}], "]"}]}],
  FontSize->12]}], "Input",
 CellTags->"b:4.4.5"],

Cell[BoxData["Quit"], "Input",
 CellTags->"b:4.4.5"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["References", "Section",
 FontFamily->"Times",
 CellTags->{"c:32", "b:4.5"}],

Cell[TextData[{
 "\n",
 Cell[BoxData[
  FormBox[GridBox[{
     {
      RowBox[{"References", ":"}], 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"[", "1", "]"}], " ", 
         RowBox[{"C", ".", "H", ".", "Bennett"}]}], ",", " ", 
        RowBox[{"et", " ", 
         RowBox[{
         "al", ".", " ", "Phys", ".", "Rev", ".", "Lett", ".", "70"}]}], ",", 
        RowBox[{"1895", "-", 
         RowBox[{"1899", " ", 
          RowBox[{"(", "1993", ")"}]}]}]}], "\n", 
       RowBox[{
        RowBox[{
         RowBox[{"[", "2", "]"}], " ", "QDENSITY", " ", "manual"}], ",", " ", 
        RowBox[{"Sect", ".", " ", "7"}]}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {Right, {Left}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}], TraditionalForm]], 
  "DefinitionBox",
  GridBoxOptions->{
  GridBoxDividers->{
   "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
    "RowsIndexed" -> {}},
  GridBoxSpacings->{"Columns" -> {
      Offset[0.27999999999999997`], {
       Offset[0.5599999999999999]}, 
      Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
      Offset[0.2], {
       Offset[0.16]}, 
      Offset[0.2]}, "RowsIndexed" -> {}}},
  CellTags->"S5.1.1"]
}], "Abstract",
 CellChangeTimes->{3.5122146834445267`*^9},
 CellTags->"b:4.5"]
}, Open  ]]
},
WindowToolbars->{},
WindowSize->{789, 621},
WindowMargins->{{Automatic, 151}, {Automatic, 77}},
PrintingStartingPageNumber->15,
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"Magnification"->1,
"PaperOrientation"->"Portrait",
"PaperSize"->{612, 792},
"PostScriptOutputFile":>FrontEnd`FileName[{"home", "bruno", "PITT", "QC"}, 
  "Test1.1.nb.ps", CharacterEncoding -> "WindowsANSI"]},
ShowSelection->True,
TaggingRules:>{
 "PaginationCache" -> {{2005, 8, 9, 3, 36, 19.580426`8.04439712024133}, {15, 
    15, 15, 15, 15, 15, 15, 15, 15, 15, 15, 15, 15, 16, 16, 16, 16, 16, 16, 
    16, 16, 16, 16, 16, 16, 16, 16, 17, 17, 17, 17, 17, 17, 17, 17, 17, 17, 
    17, 17, 17, 17, 18, 18, 18, 18, 18, 18, 18, 18, 18, 18, 18, 18, 18, 18, 
    18, 18, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 19, 20, 20, 20, 20, 
    20, 20, 20, 20, 20, 20, 20, 20, 20, 20, 20, 21, 21, 22, 22, 22, 22, 22, 
    22, 22, 22, 22, 22, 22, 22, 22, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 
    23, 23, 23, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 25, 25, 25, 25, 
    25, 25, 25, 25, 25, 25, 25, 25, 26, 26, 26, 26, 26, 26, 26, 26, 26, 26, 
    27, 27, 27, 27, 27, 27, 27, 27, 27, 27, 27, 27, 27, 27, 28, 28, 28, 28, 
    28, 28, 28, 28, 28, 28, 28, 28, 28, 29, 29, 29, 29, 29, 29, 29, 29, 29, 
    29, 29, 29, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 30, 31, 31, 31, 
    31, 31, 31, 31, 31, 31, 31, 31, 31, 31, 31, 31, 32, 32, 32, 32, 32, 32, 
    32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 33, 33, 33, 33, 33, 33, 33, 33, 
    33, 33, 33, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 34, 
    35, 35, 35, 35, 35, 35, 35, 35, 35, 35, 35, 35, 35, 36, 36, 36, 36, 36, 
    36, 36, 36, 36, 36, 36, 36, 36, 37, 37, 37, 37, 37, 37, 37, 37, 37, 37, 
    37, 37, 38, 38, 38}, Automatic}},
CellLabelAutoDelete->True,
Magnification->1,
FrontEndVersion->"8.0 for Mac OS X x86 (32-bit) (November 6, 2010)",
StyleDefinitions->Notebook[{
   Cell[
    CellGroupData[{
      Cell["Style Definitions", "Title"], 
      Cell[
      "Modify the definitions below to change the default appearance of all \
cells in a given style.  Make modifications to any definition using commands \
in the Format menu.", "Text"], 
      Cell[
       CellGroupData[{
         Cell["Style Environment Names", "Section"], 
         Cell[
          StyleData[All, "Working"], PageWidth -> WindowWidth, ScriptMinSize -> 
          9], 
         Cell[
          StyleData[All, "Presentation"], PageWidth -> WindowWidth, 
          ScriptMinSize -> 12, FontSize -> 16], 
         Cell[
          StyleData[All, "SlideShow"], PageWidth -> WindowWidth, 
          ScrollingOptions -> {
           "PagewiseDisplay" -> True, "VerticalScrollRange" -> Fit}, 
          ShowCellBracket -> False, ScriptMinSize -> 9], 
         Cell[
          StyleData[All, "Condensed"], PageWidth -> WindowWidth, 
          CellBracketOptions -> {"Margins" -> {1, 1}, "Widths" -> {0, 5}}, 
          ScriptMinSize -> 8, FontSize -> 11], 
         Cell[
          StyleData[All, "Printout"], PageWidth -> PaperWidth, ScriptMinSize -> 
          7, FontSize -> 10, 
          PrivateFontOptions -> {"FontType" -> "Outline"}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Notebook Options", "Section"], 
         Cell[
         "The options defined for the style below will be used at the \
Notebook level.", "Text"], 
         Cell[
          StyleData["Notebook"], PageHeaders -> {{
             Cell[
              TextData[{
                CounterBox["Page"]}], "PageNumber"], None, 
             Cell[
              TextData[{
                ValueBox["FileName"]}], "Header"]}, {
             Cell[
              TextData[{
                ValueBox["FileName"]}], "Header"], None, 
             Cell[
              TextData[{
                CounterBox["Page"]}], "PageNumber"]}}, 
          PageHeaderLines -> {True, True}, 
          PrintingOptions -> {
           "FacingPages" -> True, "FirstPageHeader" -> False}, 
          CellFrameLabelMargins -> 6, StyleMenuListing -> None]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Headings", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Title"], ShowCellBracket -> False, 
             CellMargins -> {{0, 0}, {0, 0}}, PageBreakBelow -> False, 
             InputAutoReplacements -> {"TeX" -> StyleBox[
                 RowBox[{"T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> StyleBox[
                 RowBox[{"L", 
                   StyleBox[
                    AdjustmentBox[
                    "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                    BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "mma" -> "Mathematica", 
               "Mma" -> "Mathematica", "MMA" -> "Mathematica", 
               "gridMathematica" -> FormBox[
                 RowBox[{"grid", 
                   AdjustmentBox[
                    StyleBox["Mathematica", FontSlant -> "Italic"], 
                    BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
               "webMathematica" -> FormBox[
                 RowBox[{"web", 
                   AdjustmentBox[
                    StyleBox["Mathematica", FontSlant -> "Italic"], 
                    BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
               Inherited}, LineSpacing -> {1, 11}, CounterIncrements -> 
             "Title", 
             CounterAssignments -> {{"Section", 0}, {"Equation", 0}, {
               "Figure", 0}, {"Subtitle", 0}, {"Subsubtitle", 0}}, FontSize -> 
             34, FontColor -> GrayLevel[1], Background -> 
             RGBColor[0.571389, 0.19675, 0.570504]], 
            Cell[
             StyleData["Title", "Presentation"], 
             CellMargins -> {{0, 0}, {0, 0}}, 
             CellFrameMargins -> {{12, 10}, {24, 24}}, LineSpacing -> {1, 0}, 
             FontSize -> 46], 
            Cell[
             StyleData["Title", "Condensed"], CellMargins -> {{0, 0}, {0, 0}},
              FontSize -> 20], 
            Cell[
             StyleData["Title", "Printout"], CellMargins -> {{0, 0}, {0, 0}}, 
             FontSize -> 24, FontTracking -> "Plain", Background -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subtitle"], ShowCellBracket -> False, 
             CellMargins -> {{0, 0}, {0, 0}}, PageBreakBelow -> False, 
             InputAutoReplacements -> {"TeX" -> StyleBox[
                 RowBox[{"T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> StyleBox[
                 RowBox[{"L", 
                   StyleBox[
                    AdjustmentBox[
                    "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                    BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "mma" -> "Mathematica", 
               "Mma" -> "Mathematica", "MMA" -> "Mathematica", 
               "gridMathematica" -> FormBox[
                 RowBox[{"grid", 
                   AdjustmentBox[
                    StyleBox["Mathematica", FontSlant -> "Italic"], 
                    BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
               "webMathematica" -> FormBox[
                 RowBox[{"web", 
                   AdjustmentBox[
                    StyleBox["Mathematica", FontSlant -> "Italic"], 
                    BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
               Inherited}, LineSpacing -> {1, 3}, ParagraphIndent -> -96, 
             CounterIncrements -> "Subtitle", 
             CounterAssignments -> {{"Section", 0}, {"Equation", 0}, {
               "Figure", 0}, {"Subsubtitle", 0}}, FontFamily -> "Helvetica", 
             FontSize -> 18, FontColor -> GrayLevel[1], Background -> 
             RGBColor[0.2, 0.700008, 0.700008]], 
            Cell[
             StyleData["Subtitle", "Presentation"], 
             CellMargins -> {{0, 0}, {4, 0}}, 
             CellFrameMargins -> {{12, 10}, {12, 8}}, LineSpacing -> {1, 6}, 
             ParagraphIndent -> -157, FontSize -> 28], 
            Cell[
             StyleData["Subtitle", "Condensed"], 
             CellMargins -> {{0, 0}, {0, 0}}, ParagraphIndent -> -78, 
             FontSize -> 14], 
            Cell[
             StyleData["Subtitle", "Printout"], 
             CellMargins -> {{0, 0}, {0, 0}}, ParagraphIndent -> -85, 
             FontSize -> 16, Background -> GrayLevel[0.6]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsubtitle"], ShowCellBracket -> False, 
             CellMargins -> {{10, 4}, {30, 10}}, PageBreakBelow -> False, 
             InputAutoReplacements -> {"TeX" -> StyleBox[
                 RowBox[{"T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> StyleBox[
                 RowBox[{"L", 
                   StyleBox[
                    AdjustmentBox[
                    "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                    BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "mma" -> "Mathematica", 
               "Mma" -> "Mathematica", "MMA" -> "Mathematica", 
               "gridMathematica" -> FormBox[
                 RowBox[{"grid", 
                   AdjustmentBox[
                    StyleBox["Mathematica", FontSlant -> "Italic"], 
                    BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
               "webMathematica" -> FormBox[
                 RowBox[{"web", 
                   AdjustmentBox[
                    StyleBox["Mathematica", FontSlant -> "Italic"], 
                    BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
               Inherited}, CounterIncrements -> "Subsubtitle", 
             CounterAssignments -> {{"Section", 0}, {"Equation", 0}, {
               "Figure", 0}}, FontFamily -> "Helvetica", FontSize -> 14, 
             FontSlant -> "Italic"], 
            Cell[
             StyleData["Subsubtitle", "Presentation"], 
             CellMargins -> {{15, 10}, {50, 10}}, LineSpacing -> {1, 0}, 
             FontSize -> 22], 
            Cell[
             StyleData["Subsubtitle", "Condensed"], 
             CellMargins -> {{8, 10}, {12, 8}}, FontSize -> 12], 
            Cell[
             StyleData["Subsubtitle", "Printout"], 
             CellMargins -> {{9, 10}, {50, 10}}, FontSize -> 14]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Section"], CellFrame -> {{6, 0}, {0, 1}}, CellDingbat -> 
             None, CellMargins -> {{12, Inherited}, {4, 24}}, 
             CellGroupingRules -> {"SectionGrouping", 30}, PageBreakBelow -> 
             False, CellFrameMargins -> 6, 
             InputAutoReplacements -> {"TeX" -> StyleBox[
                 RowBox[{"T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> StyleBox[
                 RowBox[{"L", 
                   StyleBox[
                    AdjustmentBox[
                    "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                    BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "mma" -> "Mathematica", 
               "Mma" -> "Mathematica", "MMA" -> "Mathematica", 
               "gridMathematica" -> FormBox[
                 RowBox[{"grid", 
                   AdjustmentBox[
                    StyleBox["Mathematica", FontSlant -> "Italic"], 
                    BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
               "webMathematica" -> FormBox[
                 RowBox[{"web", 
                   AdjustmentBox[
                    StyleBox["Mathematica", FontSlant -> "Italic"], 
                    BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
               Inherited}, LineSpacing -> {1, 7}, CounterIncrements -> 
             "Section", 
             CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}}, 
             FontFamily -> "Helvetica", FontSize -> 16, FontWeight -> "Bold", 
             FontColor -> RGBColor[0.571389, 0.19675, 0.570504]], 
            Cell[
             StyleData["Section", "Presentation"], 
             CellFrame -> {{8, 0}, {0, 2}}, 
             CellMargins -> {{15, 10}, {14, 32}}, 
             CellFrameMargins -> {{8, 10}, {10, 14}}, LineSpacing -> {1, 2}, 
             FontSize -> 24, FontTracking -> "Condensed"], 
            Cell[
             StyleData["Section", "Condensed"], 
             CellMargins -> {{8, Inherited}, {2, 12}}, FontSize -> 12], 
            Cell[
             StyleData["Section", "Printout"], 
             CellMargins -> {{9, 0}, {2, 50}}, FontSize -> 14, FontTracking -> 
             "Plain", FontColor -> GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsection"], 
             CellMargins -> {{12, Inherited}, {8, 20}}, 
             CellGroupingRules -> {"SectionGrouping", 40}, PageBreakBelow -> 
             False, InputAutoReplacements -> {"TeX" -> StyleBox[
                 RowBox[{"T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> StyleBox[
                 RowBox[{"L", 
                   StyleBox[
                    AdjustmentBox[
                    "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                    BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "mma" -> "Mathematica", 
               "Mma" -> "Mathematica", "MMA" -> "Mathematica", 
               "gridMathematica" -> FormBox[
                 RowBox[{"grid", 
                   AdjustmentBox[
                    StyleBox["Mathematica", FontSlant -> "Italic"], 
                    BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
               "webMathematica" -> FormBox[
                 RowBox[{"web", 
                   AdjustmentBox[
                    StyleBox["Mathematica", FontSlant -> "Italic"], 
                    BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
               Inherited}, LineSpacing -> {1, 7}, CounterIncrements -> 
             "Subsection", CounterAssignments -> {{"Subsubsection", 0}}, 
             FontFamily -> "Helvetica", FontSize -> 13, FontWeight -> "Bold"], 
            Cell[
             StyleData["Subsection", "Presentation"], 
             CellMargins -> {{15, 10}, {12, 32}}, LineSpacing -> {1, 0}, 
             FontSize -> 22], 
            Cell[
             StyleData["Subsection", "Condensed"], 
             CellMargins -> {{8, Inherited}, {2, 12}}, FontSize -> 12], 
            Cell[
             StyleData["Subsection", "Printout"], 
             CellMargins -> {{9, 0}, {4, 40}}, FontSize -> 12]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsubsection"], CellDingbat -> "\[FilledSquare]", 
             CellMargins -> {{25, Inherited}, {8, 12}}, 
             CellGroupingRules -> {"SectionGrouping", 50}, PageBreakBelow -> 
             False, InputAutoReplacements -> {"TeX" -> StyleBox[
                 RowBox[{"T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> StyleBox[
                 RowBox[{"L", 
                   StyleBox[
                    AdjustmentBox[
                    "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                    BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "mma" -> "Mathematica", 
               "Mma" -> "Mathematica", "MMA" -> "Mathematica", 
               "gridMathematica" -> FormBox[
                 RowBox[{"grid", 
                   AdjustmentBox[
                    StyleBox["Mathematica", FontSlant -> "Italic"], 
                    BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
               "webMathematica" -> FormBox[
                 RowBox[{"web", 
                   AdjustmentBox[
                    StyleBox["Mathematica", FontSlant -> "Italic"], 
                    BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
               Inherited}, LineSpacing -> {1, 9}, CounterIncrements -> 
             "Subsubsection", FontFamily -> "Times", FontSize -> 13, 
             FontWeight -> "Bold"], 
            Cell[
             StyleData["Subsubsection", "Presentation"], 
             CellMargins -> {{34, 10}, {18, 28}}, LineSpacing -> {1, 0}, 
             FontSize -> 18], 
            Cell[
             StyleData["Subsubsection", "Condensed"], 
             CellMargins -> {{22, Inherited}, {2, 12}}, FontSize -> 10], 
            Cell[
             StyleData["Subsubsection", "Printout"], 
             CellMargins -> {{21, 0}, {4, 20}}, FontSize -> 11]}, Closed]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Body Text", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Text"], CellMargins -> {{12, 10}, {5, 5}}, 
             InputAutoReplacements -> {"TeX" -> StyleBox[
                 RowBox[{"T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> StyleBox[
                 RowBox[{"L", 
                   StyleBox[
                    AdjustmentBox[
                    "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                    BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "mma" -> "Mathematica", 
               "Mma" -> "Mathematica", "MMA" -> "Mathematica", 
               "gridMathematica" -> FormBox[
                 RowBox[{"grid", 
                   AdjustmentBox[
                    StyleBox["Mathematica", FontSlant -> "Italic"], 
                    BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
               "webMathematica" -> FormBox[
                 RowBox[{"web", 
                   AdjustmentBox[
                    StyleBox["Mathematica", FontSlant -> "Italic"], 
                    BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
               Inherited}, LineSpacing -> {1, 3}, ParagraphSpacing -> {0, 12},
              CounterIncrements -> "Text", FontFamily -> "Times"], 
            Cell[
             StyleData["Text", "Presentation"], 
             CellMargins -> {{15, 10}, {8, 10}}, LineSpacing -> {1, 5}, 
             ParagraphSpacing -> {0, 12}, FontSize -> 18], 
            Cell[
             StyleData["Text", "Condensed"], CellMargins -> {{8, 10}, {4, 4}},
              LineSpacing -> {1, 1}, ParagraphSpacing -> {0, 4}], 
            Cell[
             StyleData["Text", "Printout"], CellMargins -> {{9, 0}, {4, 4}}, 
             Hyphenation -> True, ParagraphSpacing -> {0, 6}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SmallText"], CellMargins -> {{12, 10}, {5, 5}}, 
             InputAutoReplacements -> {"TeX" -> StyleBox[
                 RowBox[{"T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> StyleBox[
                 RowBox[{"L", 
                   StyleBox[
                    AdjustmentBox[
                    "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                    BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "mma" -> "Mathematica", 
               "Mma" -> "Mathematica", "MMA" -> "Mathematica", 
               "gridMathematica" -> FormBox[
                 RowBox[{"grid", 
                   AdjustmentBox[
                    StyleBox["Mathematica", FontSlant -> "Italic"], 
                    BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
               "webMathematica" -> FormBox[
                 RowBox[{"web", 
                   AdjustmentBox[
                    StyleBox["Mathematica", FontSlant -> "Italic"], 
                    BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
               Inherited}, LineSpacing -> {1, 3}, ParagraphSpacing -> {0, 6}, 
             CounterIncrements -> "SmallText", FontFamily -> "Helvetica", 
             FontSize -> 9], 
            Cell[
             StyleData["SmallText", "Presentation"], 
             CellMargins -> {{15, 10}, {8, 10}}, LineSpacing -> {1, 5}, 
             FontSize -> 14], 
            Cell[
             StyleData["SmallText", "Condensed"], 
             CellMargins -> {{8, 10}, {2, 2}}, LineSpacing -> {1, 2}, 
             FontSize -> 9], 
            Cell[
             StyleData["SmallText", "Printout"], 
             CellMargins -> {{9, 0}, {4, 4}}, Hyphenation -> True, FontSize -> 
             7]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Inline Formatting", "Section"], 
         Cell[
         "These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.", "Text"], 
         Cell[
          StyleData["RM"], StyleMenuListing -> None, FontWeight -> "Plain", 
          FontSlant -> "Plain"], 
         Cell[
          StyleData["BF"], StyleMenuListing -> None, FontWeight -> "Bold"], 
         Cell[
          StyleData["IT"], StyleMenuListing -> None, FontSlant -> "Italic"], 
         Cell[
          StyleData["TR"], StyleMenuListing -> None, FontFamily -> "Times", 
          FontWeight -> "Plain", FontSlant -> "Plain"], 
         Cell[
          StyleData["TI"], StyleMenuListing -> None, FontFamily -> "Times", 
          FontWeight -> "Plain", FontSlant -> "Italic"], 
         Cell[
          StyleData["TB"], StyleMenuListing -> None, FontFamily -> "Times", 
          FontWeight -> "Bold", FontSlant -> "Plain"], 
         Cell[
          StyleData["TBI"], StyleMenuListing -> None, FontFamily -> "Times", 
          FontWeight -> "Bold", FontSlant -> "Italic"], 
         Cell[
          StyleData["MR"], "TwoByteSyntaxCharacterAutoReplacement" -> True, 
          HyphenationOptions -> {"HyphenationCharacter" -> "\[Continuation]"},
           StyleMenuListing -> None, FontFamily -> "Courier", FontWeight -> 
          "Plain", FontSlant -> "Plain"], 
         Cell[
          StyleData["MO"], "TwoByteSyntaxCharacterAutoReplacement" -> True, 
          HyphenationOptions -> {"HyphenationCharacter" -> "\[Continuation]"},
           StyleMenuListing -> None, FontFamily -> "Courier", FontWeight -> 
          "Plain", FontSlant -> "Italic"], 
         Cell[
          StyleData["MB"], "TwoByteSyntaxCharacterAutoReplacement" -> True, 
          HyphenationOptions -> {"HyphenationCharacter" -> "\[Continuation]"},
           StyleMenuListing -> None, FontFamily -> "Courier", FontWeight -> 
          "Bold", FontSlant -> "Plain"], 
         Cell[
          StyleData["MBO"], "TwoByteSyntaxCharacterAutoReplacement" -> True, 
          HyphenationOptions -> {"HyphenationCharacter" -> "\[Continuation]"},
           StyleMenuListing -> None, FontFamily -> "Courier", FontWeight -> 
          "Bold", FontSlant -> "Italic"], 
         Cell[
          StyleData["SR"], StyleMenuListing -> None, FontFamily -> 
          "Helvetica", FontWeight -> "Plain", FontSlant -> "Plain"], 
         Cell[
          StyleData["SO"], StyleMenuListing -> None, FontFamily -> 
          "Helvetica", FontWeight -> "Plain", FontSlant -> "Italic"], 
         Cell[
          StyleData["SB"], StyleMenuListing -> None, FontFamily -> 
          "Helvetica", FontWeight -> "Bold", FontSlant -> "Plain"], 
         Cell[
          StyleData["SBO"], StyleMenuListing -> None, FontFamily -> 
          "Helvetica", FontWeight -> "Bold", FontSlant -> "Italic"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SO10"], StyleMenuListing -> None, FontFamily -> 
             "Helvetica", FontSize -> 10, FontWeight -> "Plain", FontSlant -> 
             "Italic"], 
            Cell[
             StyleData["SO10", "Printout"], StyleMenuListing -> None, 
             FontFamily -> "Helvetica", FontSize -> 7, FontWeight -> "Plain", 
             FontSlant -> "Italic"]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Inert"], StyleMenuListing -> None, Background -> 
             RGBColor[0.870588, 0.905882, 0.972549]], 
            Cell[
             StyleData["Inert", "Printout"], StyleMenuListing -> None, 
             Background -> GrayLevel[1]]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Input/Output", "Section"], 
         Cell[
         "The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Input"], CellFrame -> {{3, 0}, {0, 0}}, 
             CellMargins -> {{52, 10}, {8, 8}}, Evaluatable -> True, 
             CellGroupingRules -> "InputGrouping", CellHorizontalScrolling -> 
             True, PageBreakWithin -> False, GroupPageBreakWithin -> False, 
             CellLabelMargins -> {{5, Inherited}, {Inherited, Inherited}}, 
             DefaultFormatType -> DefaultInputFormatType, 
             "TwoByteSyntaxCharacterAutoReplacement" -> True, 
             HyphenationOptions -> {
              "HyphenationCharacter" -> "\[Continuation]"}, LanguageCategory -> 
             "Formula", FormatType -> InputForm, ShowStringCharacters -> True,
              NumberMarks -> True, 
             LinebreakAdjustments -> {0.85, 2, 10, 0, 1}, CounterIncrements -> 
             "Input", FontWeight -> "Bold", Background -> 
             RGBColor[1, 0.700008, 0.4]], 
            Cell[
             StyleData["Input", "Presentation"], 
             CellFrame -> {{5, 0}, {0, 0}}, 
             CellMargins -> {{74, 10}, {8, 10}}, 
             CellFrameMargins -> {{10, 10}, {14, 14}}, LineSpacing -> {1, 0}, 
             FontSize -> 18], 
            Cell[
             StyleData["Input", "Condensed"], 
             CellMargins -> {{40, Inherited}, {1, 4}}], 
            Cell[
             StyleData["Input", "Printout"], CellMargins -> {{44, 0}, {2, 6}},
              Background -> GrayLevel[0.900008]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["InlineInput"], Evaluatable -> True, CellGroupingRules -> 
             "InputGrouping", CellHorizontalScrolling -> True, 
             PageBreakWithin -> False, GroupPageBreakWithin -> False, 
             DefaultFormatType -> DefaultInputFormatType, 
             "TwoByteSyntaxCharacterAutoReplacement" -> True, 
             HyphenationOptions -> {
              "HyphenationCharacter" -> "\[Continuation]"}, 
             AutoItalicWords -> {}, FormatType -> InputForm, 
             ShowStringCharacters -> True, NumberMarks -> True, 
             CounterIncrements -> "Input", FontWeight -> "Bold"], 
            Cell[
             StyleData["InlineInput", "Presentation"], FontSize -> 18], 
            Cell[
             StyleData["InlineInput", "Condensed"]], 
            Cell[
             StyleData["InlineInput", "Printout"], FontSize -> 10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Output"], CellFrame -> {{3, 0}, {0, 0}}, 
             CellMargins -> {{52, 10}, {8, 8}}, CellEditDuplicate -> True, 
             CellGroupingRules -> "OutputGrouping", CellHorizontalScrolling -> 
             True, PageBreakWithin -> False, GroupPageBreakWithin -> False, 
             GeneratedCell -> True, CellAutoOverwrite -> True, 
             CellLabelMargins -> {{3, Inherited}, {Inherited, Inherited}}, 
             DefaultFormatType -> DefaultOutputFormatType, 
             "TwoByteSyntaxCharacterAutoReplacement" -> True, 
             HyphenationOptions -> {
              "HyphenationCharacter" -> "\[Continuation]"}, LanguageCategory -> 
             "Formula", FormatType -> InputForm, CounterIncrements -> 
             "Output", Background -> RGBColor[1, 0.900008, 0.900008]], 
            Cell[
             StyleData["Output", "Presentation"], 
             CellFrame -> {{5, 0}, {0, 0}}, 
             CellMargins -> {{74, 10}, {12, 5}}, 
             CellFrameMargins -> {{10, 10}, {14, 14}}, LineSpacing -> {1, 0}, 
             FontSize -> 18], 
            Cell[
             StyleData["Output", "Condensed"], 
             CellMargins -> {{40, Inherited}, {4, 1}}], 
            Cell[
             StyleData["Output", "Printout"], 
             CellMargins -> {{44, 0}, {6, 2}}, Background -> 
             GrayLevel[0.900008]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Message"], 
             CellMargins -> {{62, Inherited}, {Inherited, Inherited}}, 
             CellGroupingRules -> "OutputGrouping", PageBreakWithin -> False, 
             GroupPageBreakWithin -> False, GeneratedCell -> True, 
             CellAutoOverwrite -> True, ShowCellLabel -> False, 
             DefaultFormatType -> DefaultOutputFormatType, 
             "TwoByteSyntaxCharacterAutoReplacement" -> True, 
             HyphenationOptions -> {
              "HyphenationCharacter" -> "\[Continuation]"}, FormatType -> 
             InputForm, CounterIncrements -> "Message", StyleMenuListing -> 
             None, FontColor -> RGBColor[1, 0, 0]], 
            Cell[
             StyleData["Message", "Presentation"], 
             CellMargins -> {{86, 20}, {10, 10}}, LineSpacing -> {1, 0}, 
             FontSize -> 18], 
            Cell[
             StyleData["Message", "Condensed"], 
             CellMargins -> {{50, Inherited}, {Inherited, Inherited}}], 
            Cell[
             StyleData["Message", "Printout"], 
             CellMargins -> {{54, Inherited}, {Inherited, Inherited}}, 
             FontColor -> GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Print"], 
             CellMargins -> {{62, Inherited}, {Inherited, Inherited}}, 
             CellGroupingRules -> "OutputGrouping", CellHorizontalScrolling -> 
             True, PageBreakWithin -> False, GroupPageBreakWithin -> False, 
             GeneratedCell -> True, CellAutoOverwrite -> True, ShowCellLabel -> 
             False, DefaultFormatType -> DefaultOutputFormatType, 
             "TwoByteSyntaxCharacterAutoReplacement" -> True, 
             HyphenationOptions -> {
              "HyphenationCharacter" -> "\[Continuation]"}, FormatType -> 
             InputForm, CounterIncrements -> "Print", StyleMenuListing -> 
             None], 
            Cell[
             StyleData["Print", "Presentation"], 
             CellMargins -> {{86, 20}, {4, 4}}, LineSpacing -> {1, 0}, 
             FontSize -> 18], 
            Cell[
             StyleData["Print", "Condensed"], 
             CellMargins -> {{50, Inherited}, {Inherited, Inherited}}], 
            Cell[
             StyleData["Print", "Printout"], 
             CellMargins -> {{54, Inherited}, {Inherited, Inherited}}]}, 
           Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Graphics"], 
             CellMargins -> {{62, Inherited}, {Inherited, Inherited}}, 
             CellGroupingRules -> "GraphicsGrouping", CellHorizontalScrolling -> 
             True, PageBreakWithin -> False, GeneratedCell -> True, 
             CellAutoOverwrite -> True, ShowCellLabel -> False, 
             DefaultFormatType -> DefaultOutputFormatType, FormatType -> 
             InputForm, CounterIncrements -> "Graphics", StyleMenuListing -> 
             None], 
            Cell[
             StyleData["Graphics", "Presentation"], 
             CellMargins -> {{86, 20}, {8, 8}}, FontSize -> 18], 
            Cell[
             StyleData["Graphics", "Condensed"], 
             CellMargins -> {{52, Inherited}, {Inherited, Inherited}}, 
             ImageSize -> {175, 175}], 
            Cell[
             StyleData["Graphics", "Printout"], 
             CellMargins -> {{54, Inherited}, {Inherited, Inherited}}, 
             ImageSize -> {250, 250}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["CellLabel"], StyleMenuListing -> None, FontFamily -> 
             "Helvetica", FontSize -> 11, FontWeight -> "Bold", FontColor -> 
             RGBColor[0.571389, 0.19675, 0.570504]], 
            Cell[
             StyleData["CellLabel", "Presentation"], FontSize -> 12], 
            Cell[
             StyleData["CellLabel", "Condensed"], FontSize -> 8], 
            Cell[
             StyleData["CellLabel", "Printout"], FontSize -> 8, FontColor -> 
             GrayLevel[0]]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Unique Styles", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Author"], ShowCellBracket -> False, 
             CellMargins -> {{10, 4}, {2, 10}}, LineSpacing -> {1, 5}, 
             FontSize -> 16, FontSlant -> "Italic"], 
            Cell[
             StyleData["Author", "Presentation"], 
             CellMargins -> {{15, 10}, {4, 16}}, LineSpacing -> {1, 5}, 
             ParagraphSpacing -> {0, 12}, FontSize -> 24], 
            Cell[
             StyleData["Author", "Condensed"], 
             CellMargins -> {{8, 10}, {1, 4}}, LineSpacing -> {1, 1}, 
             ParagraphSpacing -> {0, 4}, FontSize -> 12], 
            Cell[
             StyleData["Author", "Printout"], 
             CellMargins -> {{9, 0}, {4, 12}}, ParagraphSpacing -> {0, 6}, 
             FontSize -> 14]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Copyright"], ShowCellBracket -> False, 
             CellMargins -> {{10, 10}, {40, 2}}, FontFamily -> "Helvetica", 
             FontSize -> 9], 
            Cell[
             StyleData["Copyright", "Presentation"], 
             CellMargins -> {{15, 10}, {50, 4}}, LineSpacing -> {1, 5}, 
             FontSize -> 14], 
            Cell[
             StyleData["Copyright", "Condensed"], 
             CellMargins -> {{8, 10}, {12, 1}}, LineSpacing -> {1, 2}, 
             FontSize -> 9], 
            Cell[
             StyleData["Copyright", "Printout"], 
             CellMargins -> {{9, 0}, {72, 4}}, FontSize -> 7]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Example"], CellMargins -> {{12, 10}, {5, 12}}, 
             LineSpacing -> {1, 3}, ParagraphSpacing -> {0, 12}, 
             CounterIncrements -> "Example", FontFamily -> "Times", 
             FontWeight -> "Bold"], 
            Cell[
             StyleData["Example", "Presentation"], 
             CellMargins -> {{18, 10}, {8, 20}}, LineSpacing -> {1, 5}, 
             ParagraphSpacing -> {0, 12}, FontSize -> 18], 
            Cell[
             StyleData["Example", "Condensed"], 
             CellMargins -> {{8, 10}, {4, 8}}, LineSpacing -> {1, 1}, 
             ParagraphSpacing -> {0, 4}], 
            Cell[
             StyleData["Example", "Printout"], 
             CellMargins -> {{9, 0}, {4, 10}}, ParagraphSpacing -> {0, 6}]}, 
           Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Definition"], CellFrame -> {{3, 0}, {0, 0}}, 
             CellMargins -> {{52, 10}, {8, 8}}, PageBreakWithin -> False, 
             GroupPageBreakWithin -> False, 
             CellLabelMargins -> {{23, Inherited}, {Inherited, Inherited}}, 
             ShowStringCharacters -> True, CounterIncrements -> "Definition", 
             FontFamily -> "Helvetica", FontWeight -> "Bold", FontColor -> 
             GrayLevel[1], Background -> RGBColor[0.2, 0.700008, 0.700008]], 
            Cell[
             StyleData["Definition", "Presentation"], 
             CellFrame -> {{5, 0}, {0, 0}}, 
             CellMargins -> {{74, 10}, {8, 12}}, 
             CellFrameMargins -> {{10, 10}, {14, 14}}, LineSpacing -> {1, 0}, 
             FontSize -> 18], 
            Cell[
             StyleData["Definition", "Condensed"], 
             CellMargins -> {{40, 10}, {1, 4}}], 
            Cell[
             StyleData["Definition", "Printout"], 
             CellMargins -> {{44, 0}, {2, 6}}, Hyphenation -> True, 
             Background -> GrayLevel[0.6]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Theorem"], CellFrame -> {{3, 0}, {0, 0}}, 
             CellMargins -> {{52, 10}, {8, 8}}, PageBreakWithin -> False, 
             GroupPageBreakWithin -> False, 
             CellLabelMargins -> {{23, Inherited}, {Inherited, Inherited}}, 
             ShowStringCharacters -> True, CounterIncrements -> "Theorem", 
             FontFamily -> "Helvetica", FontWeight -> "Bold", FontColor -> 
             GrayLevel[1], Background -> 
             RGBColor[0.571389, 0.19675, 0.570504]], 
            Cell[
             StyleData["Theorem", "Presentation"], 
             CellFrame -> {{5, 0}, {0, 0}}, 
             CellMargins -> {{74, 10}, {8, 12}}, 
             CellFrameMargins -> {{10, 10}, {14, 14}}, LineSpacing -> {1, 0}, 
             FontSize -> 18], 
            Cell[
             StyleData["Theorem", "Condensed"], 
             CellMargins -> {{40, 10}, {1, 4}}], 
            Cell[
             StyleData["Theorem", "Printout"], 
             CellMargins -> {{44, 0}, {2, 6}}, Hyphenation -> True, 
             Background -> GrayLevel[0.4]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ExerciseMain"], CellFrame -> {{6, 0}, {0, 1}}, 
             CellMargins -> {{12, Inherited}, {4, 20}}, 
             CellGroupingRules -> {"SectionGrouping", 30}, PageBreakBelow -> 
             False, CellFrameColor -> RGBColor[0.571389, 0.19675, 0.570504], 
             LineSpacing -> {1, 7}, CounterIncrements -> "Subsection", 
             CounterAssignments -> {{"Subsubsection", 0}}, FontFamily -> 
             "Helvetica", FontSize -> 16, FontWeight -> "Bold", FontColor -> 
             RGBColor[0.571389, 0.19675, 0.570504]], 
            Cell[
             StyleData["ExerciseMain", "Presentation"], 
             CellFrame -> {{8, 0}, {0, 2}}, 
             CellMargins -> {{18, 10}, {12, 32}}, 
             CellFrameMargins -> {{10, 10}, {14, 14}}, LineSpacing -> {1, 2}, 
             FontSize -> 24, FontTracking -> "Condensed"], 
            Cell[
             StyleData["ExerciseMain", "Condensed"], 
             CellMargins -> {{8, Inherited}, {2, 12}}, FontSize -> 12], 
            Cell[
             StyleData["ExerciseMain", "Printout"], 
             CellMargins -> {{9, 0}, {2, 50}}, CellFrameColor -> 
             GrayLevel[0.500008], FontSize -> 14, FontTracking -> "Plain", 
             FontColor -> GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Exercise"], CellDingbat -> "\[FilledDownTriangle]", 
             CellMargins -> {{23, Inherited}, {4, 18}}, 
             CellGroupingRules -> {"SectionGrouping", 50}, PageBreakBelow -> 
             False, LineSpacing -> {1, 7}, CounterIncrements -> 
             "Subsubsection", FontFamily -> "Times", FontSize -> 13, 
             FontWeight -> "Bold", FontColor -> 
             RGBColor[0.571389, 0.19675, 0.570504]], 
            Cell[
             StyleData["Exercise", "Presentation"], 
             CellMargins -> {{28, 10}, {10, 34}}, LineSpacing -> {1, 0}, 
             FontSize -> 22], 
            Cell[
             StyleData["Exercise", "Condensed"], 
             CellMargins -> {{17, Inherited}, {2, 12}}, FontSize -> 10], 
            Cell[
             StyleData["Exercise", "Printout"], 
             CellFrame -> {{0, 0}, {0.5, 0}}, CellDingbat -> None, 
             CellMargins -> {{9, 0}, {6, 20}}, Hyphenation -> True, FontSize -> 
             11, FontColor -> GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ExerciseText"], CellMargins -> {{62, 10}, {5, 5}}, 
             LineSpacing -> {1, 3}, ParagraphSpacing -> {0, 8}, 
             CounterIncrements -> "ExerciseText", FontFamily -> "Times"], 
            Cell[
             StyleData["ExerciseText", "Presentation"], 
             CellMargins -> {{100, 10}, {8, 8}}, LineSpacing -> {1, 5}, 
             ParagraphSpacing -> {0, 12}, FontSize -> 18], 
            Cell[
             StyleData["ExerciseText", "Condensed"], 
             CellMargins -> {{52, 10}, {2, 2}}, LineSpacing -> {1, 1}, 
             ParagraphSpacing -> {0, 4}], 
            Cell[
             StyleData["ExerciseText", "Printout"], 
             CellMargins -> {{54, 0}, {4, 4}}, Hyphenation -> True, 
             ParagraphSpacing -> {0, 6}]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Formulas and Programming", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["DisplayFormula"], CellMargins -> {{62, 10}, {2, 10}}, 
             CellHorizontalScrolling -> True, DefaultFormatType -> 
             DefaultInputFormatType, "TwoByteSyntaxCharacterAutoReplacement" -> 
             True, HyphenationOptions -> {
              "HyphenationCharacter" -> "\[Continuation]"}, LanguageCategory -> 
             "Formula", ScriptLevel -> 0, SingleLetterItalics -> True, 
             UnderoverscriptBoxOptions -> {LimitsPositioning -> True}], 
            Cell[
             StyleData["DisplayFormula", "Presentation"], 
             CellMargins -> {{100, 10}, {8, 16}}, FontSize -> 18], 
            Cell[
             StyleData["DisplayFormula", "Condensed"], 
             CellMargins -> {{52, 10}, {2, 10}}, FontSize -> 10], 
            Cell[
             StyleData["DisplayFormula", "Printout"], 
             CellMargins -> {{54, 10}, {2, 10}}, FontSize -> 10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ChemicalFormula"], CellMargins -> {{62, 10}, {2, 10}},
              DefaultFormatType -> DefaultInputFormatType, 
             "TwoByteSyntaxCharacterAutoReplacement" -> True, 
             HyphenationOptions -> {
              "HyphenationCharacter" -> "\[Continuation]"}, LanguageCategory -> 
             "Formula", AutoSpacing -> False, 
             ScriptBaselineShifts -> {0.6, Automatic}, ScriptLevel -> 1, 
             SingleLetterItalics -> False, ZeroWidthTimes -> True], 
            Cell[
             StyleData["ChemicalFormula", "Presentation"], 
             CellMargins -> {{100, 10}, {8, 12}}, FontSize -> 18], 
            Cell[
             StyleData["ChemicalFormula", "Condensed"], 
             CellMargins -> {{52, 10}, {2, 10}}, FontSize -> 10], 
            Cell[
             StyleData["ChemicalFormula", "Printout"], 
             CellMargins -> {{54, 10}, {2, 10}}, FontSize -> 10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Program"], CellMargins -> {{12, 10}, {Inherited, 6}}, 
             Hyphenation -> False, LanguageCategory -> "Formula", FontFamily -> 
             "Courier"], 
            Cell[
             StyleData["Program", "Presentation"], 
             CellMargins -> {{20, 30}, {4, 4}}, FontSize -> 18], 
            Cell[
             StyleData["Program", "Condensed"], 
             CellMargins -> {{8, 10}, {Inherited, 4}}, FontSize -> 9.5], 
            Cell[
             StyleData["Program", "Printout"], 
             CellMargins -> {{9, 0}, {Inherited, 4}}, FontSize -> 9.5]}, 
           Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Automatic Numbering", "Section"], 
         Cell[
         "The following styles are useful for numbered equations, figures, \
etc.  They automatically give the cell a FrameLabel containing a reference to \
a particular counter, and also increment that counter.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["NumberedEquation"], 
             CellMargins -> {{62, 10}, {Inherited, Inherited}}, 
             CellFrameLabels -> {{None, 
                Cell[
                 TextData[{"(", 
                   CounterBox["NumberedEquation"], ")"}]]}, {None, None}}, 
             DefaultFormatType -> DefaultInputFormatType, 
             "TwoByteSyntaxCharacterAutoReplacement" -> True, 
             HyphenationOptions -> {
              "HyphenationCharacter" -> "\[Continuation]"}, CounterIncrements -> 
             "NumberedEquation", FormatTypeAutoConvert -> False], 
            Cell[
             StyleData["NumberedEquation", "Presentation"], 
             CellMargins -> {{100, 10}, {6, 8}}, FontSize -> 18], 
            Cell[
             StyleData["NumberedEquation", "Condensed"], 
             CellMargins -> {{52, 10}, {Inherited, Inherited}}], 
            Cell[
             StyleData["NumberedEquation", "Printout"], 
             CellMargins -> {{54, 0}, {Inherited, Inherited}}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["NumberedFigure"], 
             CellMargins -> {{62, 145}, {Inherited, Inherited}}, 
             CellFrameLabels -> {{None, None}, {
                Cell[
                 TextData[{"Figure ", 
                   CounterBox["NumberedFigure"]}]], None}}, CounterIncrements -> 
             "NumberedFigure", 
             ImageMargins -> {{43, Inherited}, {Inherited, 0}}, 
             FormatTypeAutoConvert -> False], 
            Cell[
             StyleData["NumberedFigure", "Presentation"], 
             CellMargins -> {{100, 145}, {8, 6}}, FontSize -> 18], 
            Cell[
             StyleData["NumberedFigure", "Condensed"]], 
            Cell[
             StyleData["NumberedFigure", "Printout"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["NumberedTable"], 
             CellMargins -> {{62, 145}, {Inherited, Inherited}}, 
             CellFrameLabels -> {{None, None}, {
                Cell[
                 TextData[{"Table ", 
                   CounterBox["NumberedTable"]}]], None}}, TextAlignment -> 
             Center, CounterIncrements -> "NumberedTable", 
             FormatTypeAutoConvert -> False], 
            Cell[
             StyleData["NumberedTable", "Presentation"], 
             CellMargins -> {{100, 145}, {8, 8}}, FontSize -> 18], 
            Cell[
             StyleData["NumberedTable", "Condensed"]], 
            Cell[
             StyleData["NumberedTable", "Printout"]]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Headers and Footers", "Section"], 
         Cell[
          StyleData["Header"], CellMargins -> {{0, 0}, {4, 1}}, 
          StyleMenuListing -> None, FontFamily -> "Helvetica", FontSize -> 9, 
          FontSlant -> "Italic"], 
         Cell[
          StyleData["Footer"], CellMargins -> {{0, 0}, {0, 4}}, 
          StyleMenuListing -> None, FontFamily -> "Helvetica", FontSize -> 6], 
         Cell[
          StyleData["PageNumber"], CellMargins -> {{0, 0}, {4, 1}}, 
          StyleMenuListing -> None, FontFamily -> "Helvetica", FontSize -> 9, 
          FontWeight -> "Bold"]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Hyperlink Styles", "Section"], 
         Cell[
         "The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Hyperlink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, FontColor -> 
             RGBColor[0.269993, 0.308507, 0.6], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`NotebookLocate[#2]}]& ), ButtonNote -> 
               ButtonData}], 
            Cell[
             StyleData["Hyperlink", "Presentation"], FontSize -> 16], 
            Cell[
             StyleData["Hyperlink", "Condensed"], FontSize -> 11], 
            Cell[
             StyleData["Hyperlink", "SlideShow"]], 
            Cell[
             StyleData["Hyperlink", "Printout"], FontSize -> 10, 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
         "The following styles are for linking automatically to the on-line \
help system.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["MainBookLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, FontColor -> 
             RGBColor[0.269993, 0.308507, 0.6], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["MainBook", #]}]& )}], 
            Cell[
             StyleData["MainBookLink", "Presentation"], FontSize -> 16], 
            Cell[
             StyleData["MainBookLink", "Condensed"], FontSize -> 11], 
            Cell[
             StyleData["MainBookLink", "SlideShow"]], 
            Cell[
             StyleData["MainBookLink", "Printout"], FontSize -> 10, 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["AddOnsLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, FontFamily -> "Courier", 
             FontColor -> RGBColor[0.269993, 0.308507, 0.6], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["AddOns", #]}]& )}], 
            Cell[
             StyleData["AddOnsLink", "Presentation"], FontSize -> 16], 
            Cell[
             StyleData["AddOnsLink", "Condensed"], FontSize -> 11], 
            Cell[
             StyleData["AddOnsLink", "SlideShow"]], 
            Cell[
             StyleData["AddOnsLink", "Printout"], FontSize -> 10, 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["RefGuideLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, FontFamily -> "Courier", 
             FontColor -> RGBColor[0.269993, 0.308507, 0.6], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["RefGuide", #]}]& )}], 
            Cell[
             StyleData["RefGuideLink", "Presentation"], FontSize -> 16], 
            Cell[
             StyleData["RefGuideLink", "Condensed"], FontSize -> 11], 
            Cell[
             StyleData["RefGuideLink", "SlideShow"]], 
            Cell[
             StyleData["RefGuideLink", "Printout"], FontSize -> 10, 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["RefGuideLinkText"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, FontColor -> 
             RGBColor[0.269993, 0.308507, 0.6], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["RefGuide", #]}]& )}], 
            Cell[
             StyleData["RefGuideLinkText", "Presentation"], FontSize -> 16], 
            Cell[
             StyleData["RefGuideLinkText", "Condensed"], FontSize -> 11], 
            Cell[
             StyleData["RefGuideLinkText", "SlideShow"]], 
            Cell[
             StyleData["RefGuideLinkText", "Printout"], FontSize -> 10, 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["GettingStartedLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, FontColor -> 
             RGBColor[0.269993, 0.308507, 0.6], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["GettingStarted", #]}]& )}], 
            Cell[
             StyleData["GettingStartedLink", "Presentation"], FontSize -> 16], 
            Cell[
             StyleData["GettingStartedLink", "Condensed"], FontSize -> 11], 
            Cell[
             StyleData["GettingStartedLink", "SlideShow"]], 
            Cell[
             StyleData["GettingStartedLink", "Printout"], FontSize -> 10, 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["DemosLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, FontColor -> 
             RGBColor[0.269993, 0.308507, 0.6], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["Demos", #]}]& )}], 
            Cell[
             StyleData["DemosLink", "SlideShow"]], 
            Cell[
             StyleData["DemosLink", "Printout"], 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["TourLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, FontColor -> 
             RGBColor[0.269993, 0.308507, 0.6], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["Tour", #]}]& )}], 
            Cell[
             StyleData["TourLink", "SlideShow"]], 
            Cell[
             StyleData["TourLink", "Printout"], 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["OtherInformationLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, FontColor -> 
             RGBColor[0.269993, 0.308507, 0.6], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["OtherInformation", #]}]& )}], 
            Cell[
             StyleData["OtherInformationLink", "Presentation"], FontSize -> 
             16], 
            Cell[
             StyleData["OtherInformationLink", "Condensed"], FontSize -> 11], 
            Cell[
             StyleData["OtherInformationLink", "SlideShow"]], 
            Cell[
             StyleData["OtherInformationLink", "Printout"], FontSize -> 10, 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["MasterIndexLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, FontColor -> 
             RGBColor[0.269993, 0.308507, 0.6], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["MasterIndex", #]}]& )}], 
            Cell[
             StyleData["MasterIndexLink", "SlideShow"]], 
            Cell[
             StyleData["MasterIndexLink", "Printout"], 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Palette Styles", "Section"], 
         Cell[
         "The cells below define styles that define standard ButtonFunctions, \
for use in palette buttons.", "Text"], 
         Cell[
          StyleData["Paste"], StyleMenuListing -> None, 
          ButtonStyleMenuListing -> Automatic, 
          ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
               FrontEnd`NotebookApply[
                FrontEnd`InputNotebook[], #, After]}]& )}], 
         Cell[
          StyleData["Evaluate"], StyleMenuListing -> None, 
          ButtonStyleMenuListing -> Automatic, 
          ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
               FrontEnd`NotebookApply[
                FrontEnd`InputNotebook[], #, All], 
               FrontEnd`SelectionEvaluate[
                FrontEnd`InputNotebook[], All]}]& )}], 
         Cell[
          StyleData["EvaluateCell"], StyleMenuListing -> None, 
          ButtonStyleMenuListing -> Automatic, 
          ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
               FrontEnd`NotebookApply[
                FrontEnd`InputNotebook[], #, All], 
               FrontEnd`SelectionMove[
                FrontEnd`InputNotebook[], All, Cell, 1], 
               FrontEnd`SelectionEvaluateCreateCell[
                FrontEnd`InputNotebook[], All]}]& )}], 
         Cell[
          StyleData["CopyEvaluate"], StyleMenuListing -> None, 
          ButtonStyleMenuListing -> Automatic, 
          ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
               FrontEnd`SelectionCreateCell[
                FrontEnd`InputNotebook[], All], 
               FrontEnd`NotebookApply[
                FrontEnd`InputNotebook[], #, All], 
               FrontEnd`SelectionEvaluate[
                FrontEnd`InputNotebook[], All]}]& )}], 
         Cell[
          StyleData["CopyEvaluateCell"], StyleMenuListing -> None, 
          ButtonStyleMenuListing -> Automatic, 
          ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
               FrontEnd`SelectionCreateCell[
                FrontEnd`InputNotebook[], All], 
               FrontEnd`NotebookApply[
                FrontEnd`InputNotebook[], #, All], 
               FrontEnd`SelectionEvaluateCreateCell[
                FrontEnd`InputNotebook[], All]}]& )}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Slide Show Styles", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SlideShowNavigationBar"], Editable -> False, 
             CellFrame -> True, CellMargins -> {{0, 0}, {3, 3}}, 
             CellElementSpacings -> {"CellMinHeight" -> 0.8125}, 
             CellGroupingRules -> {"SectionGrouping", 30}, CellFrameMargins -> 
             False, CellFrameColor -> GrayLevel[1], CellFrameLabelMargins -> 
             False, TextAlignment -> Center, CounterIncrements -> 
             "SlideShowNavigationBar", StyleMenuListing -> None, FontSize -> 
             10, Magnification -> 1, Background -> GrayLevel[0.8], 
             GridBoxOptions -> {
              BaselinePosition -> Center, 
               GridBoxAlignment -> {
                "Columns" -> {
                  Center, Center, Center, Center, Center, Center, Right, {
                   Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
                 "RowsIndexed" -> {}}, 
               GridBoxItemSize -> {
                "Columns" -> {3.5, 3.5, 3.5, 3.5, 13, 5, {4}}, 
                 "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
                 "RowsIndexed" -> {}}, GridBoxSpacings -> {"Columns" -> {
                   Offset[0.27999999999999997`], {
                    Offset[0.]}, 
                   Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {
                   Offset[0.2], {
                    Offset[0.]}, 
                   Offset[0.2]}, "RowsIndexed" -> {}}}], 
            Cell[
             StyleData["SlideShowNavigationBar", "Presentation"]], 
            Cell[
             StyleData["SlideShowNavigationBar", "SlideShow"], Deletable -> 
             False, ShowCellBracket -> False, 
             CellMargins -> {{-1, -1}, {-1, -1}}, PageBreakAbove -> True, 
             CellFrameMargins -> {{1, 1}, {0, 0}}], 
            Cell[
             StyleData["SlideShowNavigationBar", "Printout"], 
             CellMargins -> {{18, 4}, {4, 4}}, LineSpacing -> {1, 3}, 
             FontSize -> 10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SlideShowSection"], CellFrame -> {{0, 0}, {0, 0.5}}, 
             CellMargins -> {{0, 0}, {10, 0}}, 
             CellGroupingRules -> {"SectionGrouping", 40}, PageBreakBelow -> 
             False, CellFrameMargins -> {{12, 4}, {6, 12}}, 
             InputAutoReplacements -> {"TeX" -> StyleBox[
                 RowBox[{"T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> StyleBox[
                 RowBox[{"L", 
                   StyleBox[
                    AdjustmentBox[
                    "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                    BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "mma" -> "Mathematica", 
               "Mma" -> "Mathematica", "MMA" -> "Mathematica", 
               "gridMathematica" -> FormBox[
                 RowBox[{"grid", 
                   AdjustmentBox[
                    StyleBox["Mathematica", FontSlant -> "Italic"], 
                    BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
               "webMathematica" -> FormBox[
                 RowBox[{"web", 
                   AdjustmentBox[
                    StyleBox["Mathematica", FontSlant -> "Italic"], 
                    BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
               Inherited}, CounterIncrements -> "Section", 
             CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}}, 
             StyleMenuListing -> None, FontFamily -> "Helvetica", FontSize -> 
             18, FontWeight -> "Plain", FontColor -> GrayLevel[1], Background -> 
             RGBColor[0.408011, 0.440726, 0.8]], 
            Cell[
             StyleData["SlideShowSection", "Presentation"], 
             CellFrameMargins -> {{18, 10}, {10, 16}}, FontSize -> 27], 
            Cell[
             StyleData["SlideShowSection", "SlideShow"], ShowCellBracket -> 
             False, PageBreakAbove -> True], 
            Cell[
             StyleData["SlideShowSection", "Printout"], 
             CellMargins -> {{18, 30}, {0, 30}}, CellFrameMargins -> 5, 
             FontSize -> 14]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SlideHyperlink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, FontSize -> 26, FontColor -> 
             GrayLevel[0.400015], 
             ButtonBoxOptions -> {
              Active -> True, ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`NotebookLocate[#2]}]& ), ButtonMargins -> 0.5, 
               ButtonMinHeight -> 0.85, ButtonNote -> None}], 
            Cell[
             StyleData["SlideHyperlink", "Presentation"], 
             CellMargins -> {{10, 10}, {8, 12}}, FontSize -> 36], 
            Cell[
             StyleData["SlideHyperlink", "SlideShow"]], 
            Cell[
             StyleData["SlideHyperlink", "Printout"], FontSize -> 10, 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SlideTOCLink"], 
             CellMargins -> {{24, Inherited}, {Inherited, Inherited}}, 
             StyleMenuListing -> None, ButtonStyleMenuListing -> Automatic, 
             FontFamily -> "Helvetica", 
             ButtonBoxOptions -> {
              Active -> True, ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`NotebookLocate[#2]}]& ), ButtonMargins -> 1.5, 
               ButtonNote -> ButtonData}], 
            Cell[
             StyleData["SlideTOCLink", "Presentation"], 
             CellMargins -> {{35, 10}, {4, 6}}, FontSize -> 18], 
            Cell[
             StyleData["SlideTOCLink", "SlideShow"]], 
            Cell[
             StyleData["SlideTOCLink", "Printout"], 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SlideTOC"], CellDingbat -> "\[Bullet]", 
             CellMargins -> {{18, Inherited}, {Inherited, Inherited}}, 
             StyleMenuListing -> None, FontFamily -> "Helvetica"], 
            Cell[
             StyleData["SlideTOC", "Presentation"], 
             CellMargins -> {{25, 10}, {8, 6}}, FontSize -> 18], 
            Cell[
             StyleData["SlideTOC", "SlideShow"], FontSize -> 14], 
            Cell[
             StyleData["SlideTOC", "Printout"], FontSize -> 10, FontColor -> 
             GrayLevel[0]]}, Closed]]}, Closed]]}, Open]]}, Visible -> False, 
  FrontEndVersion -> "8.0 for Mac OS X x86 (32-bit) (November 6, 2010)", 
  StyleDefinitions -> "Default.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "c:1"->{
  Cell[545, 20, 48, 1, 50, "Title",
   CellTags->"c:1"]},
 "c:2"->{
  Cell[1055, 40, 299, 7, 51, "Section",
   CellTags->"c:2"]},
 "c:3"->{
  Cell[1379, 51, 105, 3, 57, "Subsection",
   CellTags->{"c:3", "b:4.0.0"}],
  Cell[3492, 126, 142, 3, 57, "Subsection",
   CellTags->{"c:3", "b:4.0.1"}],
  Cell[38080, 1398, 105, 3, 57, "Subsection",
   CellTags->{"c:3", "b:4.1.0"}],
  Cell[62398, 2282, 105, 3, 57, "Subsection",
   CellTags->{"c:3", "b:4.2.0"}],
  Cell[83361, 2996, 105, 3, 57, "Subsection",
   CellTags->{"c:3", "b:4.3.0"}],
  Cell[113551, 4116, 105, 3, 57, "Subsection",
   CellTags->{"c:3", "b:4.4.0"}]},
 "b:4.0.0"->{
  Cell[1379, 51, 105, 3, 57, "Subsection",
   CellTags->{"c:3", "b:4.0.0"}],
  Cell[1487, 56, 181, 4, 22, "Text",
   CellTags->"b:4.0.0"],
  Cell[1671, 62, 133, 3, 46, "Input",
   CellTags->"b:4.0.0"],
  Cell[1807, 67, 112, 3, 46, "Input",
   CellTags->"b:4.0.0"],
  Cell[1922, 72, 269, 6, 22, "Text",
   CellTags->"b:4.0.0"],
  Cell[2194, 80, 250, 7, 60, "Input",
   CellTags->"b:4.0.0"],
  Cell[2447, 89, 1008, 32, 53, "Text",
   CellTags->"b:4.0.0"]},
 "b:4.0.1"->{
  Cell[3492, 126, 142, 3, 57, "Subsection",
   CellTags->{"c:3", "b:4.0.1"}],
  Cell[3637, 131, 453, 9, 76, "Text",
   Evaluatable->False,
   CellTags->"b:4.0.1"],
  Cell[4093, 142, 742, 21, 75, "Input",
   CellTags->"b:4.0.1"],
  Cell[4838, 165, 103, 2, 22, "Text",
   CellTags->"b:4.0.1"],
  Cell[4944, 169, 230, 7, 70, "Input",
   CellTags->"b:4.0.1"],
  Cell[5177, 178, 218, 5, 49, "Text",
   CellTags->"b:4.0.1"],
  Cell[5398, 185, 161, 4, 44, "Input",
   CellTags->"b:4.0.1"],
  Cell[5562, 191, 384, 12, 65, "Input",
   CellTags->"b:4.0.1"],
  Cell[5949, 205, 179, 5, 49, "Text",
   CellTags->"b:4.0.1"],
  Cell[6131, 212, 863, 30, 46, "Input",
   CellTags->"b:4.0.1"],
  Cell[6997, 244, 134, 4, 22, "Text",
   CellTags->"b:4.0.1"],
  Cell[7134, 250, 720, 20, 65, "Input",
   CellTags->"b:4.0.1"],
  Cell[7857, 272, 122, 2, 22, "Text",
   CellTags->"b:4.0.1"],
  Cell[7982, 276, 804, 29, 101, "Input",
   CellTags->"b:4.0.1"],
  Cell[8789, 307, 94, 2, 22, "Text",
   CellTags->"b:4.0.1"],
  Cell[8886, 311, 512, 14, 65, "Input",
   CellTags->{"Do", "b:4.0.1"}]},
 "Do"->{
  Cell[8886, 311, 512, 14, 65, "Input",
   CellTags->{"Do", "b:4.0.1"}],
  Cell[19960, 744, 788, 25, 83, "Input",
   CellTags->{"Do", "b:4.0.3"}],
  Cell[89272, 3202, 682, 20, 65, "Input",
   CellTags->{"Do", "b:4.3.1"}],
  Cell[101637, 3683, 1000, 31, 83, "Input",
   CellTags->{"Do", "b:4.3.3"}]},
 "c:4"->{
  Cell[9435, 330, 128, 3, 57, "Subsection",
   CellTags->{"c:4", "b:4.0.2"}]},
 "b:4.0.2"->{
  Cell[9435, 330, 128, 3, 57, "Subsection",
   CellTags->{"c:4", "b:4.0.2"}],
  Cell[9566, 335, 221, 6, 49, "Text",
   CellTags->"b:4.0.2"],
  Cell[9790, 343, 1083, 37, 90, "Input",
   CellTags->"b:4.0.2"],
  Cell[10876, 382, 210, 6, 49, "Text",
   CellTags->"b:4.0.2"],
  Cell[11089, 390, 340, 11, 46, "Input",
   CellTags->"b:4.0.2"],
  Cell[11432, 403, 209, 6, 22, "Text",
   CellTags->"b:4.0.2"],
  Cell[11644, 411, 132, 4, 46, "Input",
   CellTags->"b:4.0.2"],
  Cell[11779, 417, 245, 7, 49, "Text",
   CellTags->"b:4.0.2"],
  Cell[12027, 426, 1594, 50, 101, "Input",
   CellTags->"b:4.0.2"],
  Cell[13624, 478, 85, 2, 22, "Text",
   CellTags->"b:4.0.2"],
  Cell[13712, 482, 363, 13, 90, "Input",
   CellTags->"b:4.0.2"],
  Cell[14078, 497, 333, 8, 76, "Text",
   CellTags->"b:4.0.2"],
  Cell[14414, 507, 185, 6, 44, "Input",
   CellTags->"b:4.0.2"],
  Cell[14602, 515, 477, 14, 44, "Input",
   CellTags->"b:4.0.2"],
  Cell[15082, 531, 161, 5, 22, "Text",
   CellTags->"b:4.0.2"],
  Cell[15246, 538, 2125, 89, 101, "Input",
   CellTags->"b:4.0.2"],
  Cell[17374, 629, 109, 2, 22, "Text",
   CellTags->"b:4.0.2"],
  Cell[17486, 633, 81, 1, 60, "Input",
   CellTags->"b:4.0.2"],
  Cell[17570, 636, 99, 2, 22, "Text",
   CellTags->"b:4.0.2"],
  Cell[17672, 640, 107, 3, 44, "Input",
   CellTags->"b:4.0.2"]},
 "c:5"->{
  Cell[17816, 648, 117, 3, 57, "Subsection",
   CellTags->{"c:5", "b:4.0.3"}]},
 "b:4.0.3"->{
  Cell[17816, 648, 117, 3, 57, "Subsection",
   CellTags->{"c:5", "b:4.0.3"}],
  Cell[17936, 653, 218, 6, 49, "Text",
   CellTags->"b:4.0.3"],
  Cell[18157, 661, 362, 15, 46, "Input",
   CellTags->"b:4.0.3"],
  Cell[18522, 678, 94, 2, 22, "Text",
   CellTags->"b:4.0.3"],
  Cell[18619, 682, 197, 8, 46, "Input",
   CellTags->"b:4.0.3"],
  Cell[18819, 692, 332, 14, 46, "Input",
   CellTags->"b:4.0.3"],
  Cell[19154, 708, 272, 10, 22, "Text",
   CellTags->"b:4.0.3"],
  Cell[19429, 720, 389, 16, 46, "Input",
   CellTags->"b:4.0.3"],
  Cell[19821, 738, 136, 4, 22, "Text",
   CellTags->"b:4.0.3"],
  Cell[19960, 744, 788, 25, 83, "Input",
   CellTags->{"Do", "b:4.0.3"}]},
 "c:6"->{
  Cell[20785, 774, 127, 3, 57, "Subsection",
   CellTags->{"c:6", "b:4.0.4"}]},
 "b:4.0.4"->{
  Cell[20785, 774, 127, 3, 57, "Subsection",
   CellTags->{"c:6", "b:4.0.4"}],
  Cell[20915, 779, 396, 11, 157, "Text",
   CellTags->"b:4.0.4"],
  Cell[21314, 792, 304, 8, 103, "Text",
   CellTags->"b:4.0.4"],
  Cell[21621, 802, 211, 5, 22, "Text",
   CellTags->"b:4.0.4"],
  Cell[21835, 809, 517, 17, 46, "Input",
   CellTags->"b:4.0.4"],
  Cell[22355, 828, 292, 8, 22, "Text",
   CellTags->"b:4.0.4"],
  Cell[22650, 838, 394, 12, 65, "Input",
   CellTags->"b:4.0.4"],
  Cell[23047, 852, 669, 19, 83, "Input",
   CellTags->"b:4.0.4"],
  Cell[23719, 873, 136, 4, 46, "Input",
   CellTags->"b:4.0.4"],
  Cell[23858, 879, 269, 8, 22, "Text",
   CellTags->"b:4.0.4"],
  Cell[24130, 889, 355, 10, 47, "Input",
   CellTags->"b:4.0.4"],
  Cell[24488, 901, 463, 16, 101, "Input",
   CellTags->"b:4.0.4"]},
 "c:7"->{
  Cell[24988, 922, 139, 3, 57, "Subsection",
   CellTags->{"c:7", "b:4.0.5"}]},
 "b:4.0.5"->{
  Cell[24988, 922, 139, 3, 57, "Subsection",
   CellTags->{"c:7", "b:4.0.5"}],
  Cell[25130, 927, 444, 13, 78, "Text",
   CellTags->"b:4.0.5"],
  Cell[25577, 942, 372, 13, 60, "Input",
   CellTags->"b:4.0.5"],
  Cell[25952, 957, 471, 16, 50, "Input",
   CellTags->"b:4.0.5"],
  Cell[26426, 975, 161, 5, 22, "Text",
   CellTags->"b:4.0.5"],
  Cell[26590, 982, 246, 8, 44, "Input",
   CellTags->"b:4.0.5"],
  Cell[26839, 992, 502, 16, 44, "Input",
   CellTags->"b:4.0.5"],
  Cell[27344, 1010, 53, 1, 44, "Input",
   CellTags->"b:4.0.5"],
  Cell[27400, 1013, 451, 13, 90, "Input",
   CellTags->"b:4.0.5"],
  Cell[27854, 1028, 466, 13, 76, "Text",
   CellTags->"b:4.0.5"],
  Cell[28323, 1043, 228, 8, 44, "Input",
   CellTags->"b:4.0.5"],
  Cell[28554, 1053, 135, 4, 22, "Text",
   CellTags->"b:4.0.5"],
  Cell[28692, 1059, 44, 1, 44, "Input",
   CellTags->"b:4.0.5"],
  Cell[28739, 1062, 133, 4, 22, "Text",
   CellTags->"b:4.0.5"],
  Cell[28875, 1068, 236, 7, 47, "Input",
   CellTags->"b:4.0.5"],
  Cell[29114, 1077, 122, 5, 49, "Text",
   CellTags->"b:4.0.5"],
  Cell[29239, 1084, 1457, 27, 724, "Text",
   CellTags->"b:4.0.5"],
  Cell[30699, 1113, 5919, 225, 251, "Input",
   CellTags->"b:4.0.5"],
  Cell[36621, 1340, 151, 5, 33, "DisplayText",
   CellTags->"b:4.0.5"],
  Cell[36775, 1347, 577, 18, 44, "Input",
   CellTags->"b:4.0.5"],
  Cell[37355, 1367, 153, 5, 33, "DisplayText",
   CellTags->"b:4.0.5"],
  Cell[37511, 1374, 107, 3, 44, "Input",
   CellTags->"b:4.0.5"],
  Cell[37621, 1379, 43, 1, 44, "Input",
   CellTags->"b:4.0.5"]},
 "c:8"->{
  Cell[37713, 1386, 342, 8, 31, "Section",
   CellTags->"c:8"]},
 "b:4.1.0"->{
  Cell[38080, 1398, 105, 3, 57, "Subsection",
   CellTags->{"c:3", "b:4.1.0"}],
  Cell[38188, 1403, 138, 3, 22, "Text",
   CellTags->"b:4.1.0"],
  Cell[38329, 1408, 133, 3, 46, "Input",
   CellTags->"b:4.1.0"],
  Cell[38465, 1413, 112, 3, 46, "Input",
   CellTags->"b:4.1.0"],
  Cell[38580, 1418, 215, 5, 22, "Text",
   CellTags->"b:4.1.0"],
  Cell[38798, 1425, 91, 3, 44, "Input",
   CellTags->"b:4.1.0"],
  Cell[38892, 1430, 254, 7, 60, "Input",
   CellTags->"b:4.1.0"]},
 "c:9"->{
  Cell[39183, 1442, 208, 6, 57, "Subsection",
   CellTags->{"c:9", "b:4.1.1"}]},
 "b:4.1.1"->{
  Cell[39183, 1442, 208, 6, 57, "Subsection",
   CellTags->{"c:9", "b:4.1.1"}],
  Cell[39394, 1450, 265, 6, 22, "Text",
   CellTags->"b:4.1.1"],
  Cell[39662, 1458, 82, 2, 44, "Input",
   CellTags->"b:4.1.1"],
  Cell[39747, 1462, 2612, 76, 137, "Input",
   CellTags->"b:4.1.1"],
  Cell[42362, 1540, 245, 6, 22, "Text",
   CellTags->"b:4.1.1"],
  Cell[42610, 1548, 203, 5, 60, "Input",
   CellTags->"b:4.1.1"],
  Cell[42816, 1555, 208, 7, 22, "Text",
   CellTags->"b:4.1.1"],
  Cell[43027, 1564, 1129, 33, 90, "Input",
   CellTags->"b:4.1.1"],
  Cell[44159, 1599, 123, 2, 22, "Text",
   CellTags->"b:4.1.1"],
  Cell[44285, 1603, 301, 9, 60, "Input",
   CellTags->"b:4.1.1"],
  Cell[44589, 1614, 101, 2, 22, "Text",
   CellTags->"b:4.1.1"],
  Cell[44693, 1618, 804, 22, 65, "Input",
   CellTags->"b:4.1.1"]},
 "c:10"->{
  Cell[45534, 1645, 135, 3, 57, "Subsection",
   CellTags->{"c:10", "b:4.1.2"}]},
 "b:4.1.2"->{
  Cell[45534, 1645, 135, 3, 57, "Subsection",
   CellTags->{"c:10", "b:4.1.2"}],
  Cell[45672, 1650, 309, 8, 76, "Text",
   CellTags->"b:4.1.2"],
  Cell[45984, 1660, 540, 17, 46, "Input",
   CellTags->"b:4.1.2"]},
 "c:11"->{
  Cell[46561, 1682, 144, 3, 57, "Subsection",
   CellTags->{"c:11", "b:4.1.3"}]},
 "b:4.1.3"->{
  Cell[46561, 1682, 144, 3, 57, "Subsection",
   CellTags->{"c:11", "b:4.1.3"}],
  Cell[46708, 1687, 161, 5, 22, "Text",
   CellTags->"b:4.1.3"],
  Cell[46872, 1694, 827, 30, 65, "Input",
   CellTags->"b:4.1.3"],
  Cell[47702, 1726, 185, 6, 49, "Text",
   CellTags->"b:4.1.3"],
  Cell[47890, 1734, 314, 9, 60, "Input",
   CellTags->"b:4.1.3"]},
 "c:12"->{
  Cell[48241, 1748, 141, 3, 57, "Subsection",
   CellTags->{"c:12", "b:4.1.4"}]},
 "b:4.1.4"->{
  Cell[48241, 1748, 141, 3, 57, "Subsection",
   CellTags->{"c:12", "b:4.1.4"}],
  Cell[48385, 1753, 188, 5, 22, "Text",
   CellTags->"b:4.1.4"],
  Cell[48576, 1760, 1019, 32, 47, "Input",
   CellTags->"b:4.1.4"]},
 "c:13"->{
  Cell[49632, 1797, 256, 8, 57, "Subsection",
   CellTags->{"c:13", "b:4.1.5"}]},
 "b:4.1.5"->{
  Cell[49632, 1797, 256, 8, 57, "Subsection",
   CellTags->{"c:13", "b:4.1.5"}],
  Cell[49891, 1807, 292, 7, 49, "Text",
   CellTags->"b:4.1.5"],
  Cell[50186, 1816, 638, 19, 50, "Input",
   CellTags->"b:4.1.5"],
  Cell[50827, 1837, 159, 5, 22, "Text",
   CellTags->"b:4.1.5"],
  Cell[50989, 1844, 696, 23, 105, "Input",
   CellTags->"b:4.1.5"],
  Cell[51688, 1869, 189, 7, 22, "Text",
   CellTags->"b:4.1.5"],
  Cell[51880, 1878, 178, 5, 44, "Input",
   CellTags->"b:4.1.5"]},
 "c:14"->{
  Cell[52095, 1888, 317, 9, 57, "Subsection",
   CellTags->{"c:14", "b:4.1.6"}]},
 "b:4.1.6"->{
  Cell[52095, 1888, 317, 9, 57, "Subsection",
   CellTags->{"c:14", "b:4.1.6"}],
  Cell[52415, 1899, 157, 5, 22, "Text",
   CellTags->"b:4.1.6"],
  Cell[52575, 1906, 1309, 41, 135, "Input",
   CellTags->"b:4.1.6"],
  Cell[53887, 1949, 135, 4, 22, "Text",
   CellTags->"b:4.1.6"],
  Cell[54025, 1955, 316, 8, 60, "Input",
   CellTags->"b:4.1.6"]},
 "c:15"->{
  Cell[54378, 1968, 350, 10, 57, "Subsection",
   CellTags->{"c:15", "b:4.1.7"}]},
 "b:4.1.7"->{
  Cell[54378, 1968, 350, 10, 57, "Subsection",
   CellTags->{"c:15", "b:4.1.7"}],
  Cell[54731, 1980, 138, 4, 22, "Text",
   CellTags->"b:4.1.7"],
  Cell[54872, 1986, 2211, 88, 141, "Input",
   CellTags->"b:4.1.7"],
  Cell[57086, 2076, 137, 4, 22, "Text",
   CellTags->"b:4.1.7"],
  Cell[57226, 2082, 2327, 93, 141, "Input",
   CellTags->"b:4.1.7"],
  Cell[59556, 2177, 199, 8, 44, "Input",
   CellTags->"b:4.1.7"]},
 "c:16"->{
  Cell[59792, 2190, 165, 5, 57, "Subsection",
   CellTags->{"c:16", "b:4.1.8"}]},
 "b:4.1.8"->{
  Cell[59792, 2190, 165, 5, 57, "Subsection",
   CellTags->{"c:16", "b:4.1.8"}],
  Cell[59960, 2197, 2021, 67, 120, "Input",
   CellTags->"b:4.1.8"]},
 "c:17"->{
  Cell[62030, 2270, 343, 8, 31, "Section",
   CellTags->"c:17"]},
 "b:4.2.0"->{
  Cell[62398, 2282, 105, 3, 57, "Subsection",
   CellTags->{"c:3", "b:4.2.0"}],
  Cell[62506, 2287, 138, 3, 22, "Text",
   CellTags->"b:4.2.0"],
  Cell[62647, 2292, 133, 3, 46, "Input",
   CellTags->"b:4.2.0"],
  Cell[62783, 2297, 112, 3, 46, "Input",
   CellTags->"b:4.2.0"],
  Cell[62898, 2302, 215, 5, 22, "Text",
   CellTags->"b:4.2.0"],
  Cell[63116, 2309, 115, 4, 44, "Input",
   CellTags->"b:4.2.0"],
  Cell[63234, 2315, 254, 7, 60, "Input",
   CellTags->"b:4.2.0"]},
 "c:18"->{
  Cell[63525, 2327, 164, 5, 57, "Subsection",
   CellTags->{"c:18", "b:4.2.1"}]},
 "b:4.2.1"->{
  Cell[63525, 2327, 164, 5, 57, "Subsection",
   CellTags->{"c:18", "b:4.2.1"}],
  Cell[63692, 2334, 215, 6, 49, "Text",
   CellTags->"b:4.2.1"],
  Cell[63910, 2342, 2011, 56, 125, "Input",
   CellTags->"b:4.2.1"],
  Cell[65924, 2400, 109, 2, 22, "Text",
   CellTags->"b:4.2.1"],
  Cell[66036, 2404, 229, 6, 60, "Input",
   CellTags->"b:4.2.1"],
  Cell[66268, 2412, 84, 2, 22, "Text",
   CellTags->"b:4.2.1"],
  Cell[66355, 2416, 147, 4, 44, "Input",
   CellTags->"b:4.2.1"],
  Cell[66505, 2422, 249, 6, 49, "Text",
   CellTags->"b:4.2.1"],
  Cell[66757, 2430, 1738, 51, 105, "Input",
   CellTags->"b:4.2.1"],
  Cell[68498, 2483, 118, 2, 22, "Text",
   CellTags->"b:4.2.1"],
  Cell[68619, 2487, 536, 16, 75, "Input",
   CellTags->"b:4.2.1"],
  Cell[69158, 2505, 101, 2, 22, "Text",
   CellTags->"b:4.2.1"],
  Cell[69262, 2509, 802, 22, 65, "Input",
   CellTags->"b:4.2.1"]},
 "c:19"->{
  Cell[70101, 2536, 135, 3, 57, "Subsection",
   CellTags->{"c:19", "b:4.2.2"}]},
 "b:4.2.2"->{
  Cell[70101, 2536, 135, 3, 57, "Subsection",
   CellTags->{"c:19", "b:4.2.2"}],
  Cell[70239, 2541, 137, 4, 22, "Text",
   CellTags->"b:4.2.2"],
  Cell[70379, 2547, 763, 22, 65, "Input",
   CellTags->"b:4.2.2"],
  Cell[71145, 2571, 92, 2, 22, "Text",
   CellTags->"b:4.2.2"],
  Cell[71240, 2575, 1440, 38, 101, "Input",
   CellTags->"b:4.2.2"],
  Cell[72683, 2615, 108, 3, 44, "Input",
   CellTags->"b:4.2.2"]},
 "c:20"->{
  Cell[72828, 2623, 144, 3, 57, "Subsection",
   CellTags->{"c:20", "b:4.2.3"}]},
 "b:4.2.3"->{
  Cell[72828, 2623, 144, 3, 57, "Subsection",
   CellTags->{"c:20", "b:4.2.3"}],
  Cell[72975, 2628, 161, 5, 22, "Text",
   CellTags->"b:4.2.3"],
  Cell[73139, 2635, 677, 21, 46, "Input",
   CellTags->"b:4.2.3"],
  Cell[73819, 2658, 174, 5, 49, "Text",
   CellTags->"b:4.2.3"],
  Cell[73996, 2665, 432, 14, 60, "Input",
   CellTags->"b:4.2.3"]},
 "c:21"->{
  Cell[74465, 2684, 145, 3, 57, "Subsection",
   CellTags->{"c:21", "b:4.2.4"}]},
 "b:4.2.4"->{
  Cell[74465, 2684, 145, 3, 57, "Subsection",
   CellTags->{"c:21", "b:4.2.4"}],
  Cell[74613, 2689, 169, 5, 49, "Text",
   CellTags->"b:4.2.4"],
  Cell[74785, 2696, 1009, 34, 135, "Input",
   CellTags->"b:4.2.4"],
  Cell[75797, 2732, 133, 4, 22, "Text",
   CellTags->"b:4.2.4"],
  Cell[75933, 2738, 1279, 34, 47, "Input",
   CellTags->"b:4.2.4"]},
 "c:22"->{
  Cell[77249, 2777, 256, 8, 57, "Subsection",
   CellTags->{"c:22", "b:4.2.5"}]},
 "b:4.2.5"->{
  Cell[77249, 2777, 256, 8, 57, "Subsection",
   CellTags->{"c:22", "b:4.2.5"}],
  Cell[77508, 2787, 293, 7, 76, "Text",
   CellTags->"b:4.2.5"],
  Cell[77804, 2796, 127, 4, 44, "Input",
   CellTags->"b:4.2.5"],
  Cell[77934, 2802, 668, 20, 50, "Input",
   CellTags->"b:4.2.5"],
  Cell[78605, 2824, 323, 8, 60, "Input",
   CellTags->"b:4.2.5"],
  Cell[78931, 2834, 199, 7, 22, "Text",
   CellTags->"b:4.2.5"],
  Cell[79133, 2843, 102, 3, 44, "Input",
   CellTags->"b:4.2.5"]},
 "c:23"->{
  Cell[79272, 2851, 317, 9, 57, "Subsection",
   CellTags->{"c:23", "b:4.2.6"}]},
 "b:4.2.6"->{
  Cell[79272, 2851, 317, 9, 57, "Subsection",
   CellTags->{"c:23", "b:4.2.6"}],
  Cell[79592, 2862, 157, 5, 22, "Text",
   CellTags->"b:4.2.6"],
  Cell[79752, 2869, 1953, 61, 180, "Input",
   CellTags->"b:4.2.6"],
  Cell[81708, 2932, 137, 4, 22, "Text",
   CellTags->"b:4.2.6"],
  Cell[81848, 2938, 352, 10, 60, "Input",
   CellTags->"b:4.2.6"]},
 "c:24"->{
  Cell[82237, 2953, 343, 9, 57, "Subsection",
   CellTags->{"c:24", "b:4.2.7"}]},
 "b:4.2.7"->{
  Cell[82237, 2953, 343, 9, 57, "Subsection",
   CellTags->{"c:24", "b:4.2.7"}],
  Cell[82583, 2964, 158, 5, 22, "Text",
   CellTags->"b:4.2.7"],
  Cell[82744, 2971, 140, 4, 44, "Input",
   CellTags->"b:4.2.7"],
  Cell[82887, 2977, 52, 1, 44, "Input",
   CellTags->"b:4.2.7"]},
 "c:25"->{
  Cell[82988, 2984, 348, 8, 31, "Section",
   CellTags->"c:25"]},
 "b:4.3.0"->{
  Cell[83361, 2996, 105, 3, 57, "Subsection",
   CellTags->{"c:3", "b:4.3.0"}],
  Cell[83469, 3001, 155, 5, 22, "Text",
   CellTags->"b:4.3.0"],
  Cell[83627, 3008, 133, 3, 46, "Input",
   CellTags->"b:4.3.0"],
  Cell[83763, 3013, 112, 3, 46, "Input",
   CellTags->"b:4.3.0"],
  Cell[83878, 3018, 119, 4, 46, "Input",
   CellTags->"b:4.3.0"],
  Cell[84000, 3024, 250, 7, 60, "Input",
   CellTags->"b:4.3.0"],
  Cell[84253, 3033, 208, 6, 49, "Text",
   CellTags->"b:4.3.0"],
  Cell[84464, 3041, 93, 3, 44, "Input",
   CellTags->"b:4.3.0"]},
 "c:26"->{
  Cell[84594, 3049, 277, 8, 57, "Subsection",
   CellTags->{"c:26", "b:4.3.1"}]},
 "b:4.3.1"->{
  Cell[84594, 3049, 277, 8, 57, "Subsection",
   CellTags->{"c:26", "b:4.3.1"}],
  Cell[84874, 3059, 364, 8, 49, "Text",
   CellTags->"b:4.3.1"],
  Cell[85241, 3069, 190, 5, 22, "Text",
   CellTags->"b:4.3.1"],
  Cell[85434, 3076, 128, 4, 44, "Input",
   CellTags->"b:4.3.1"],
  Cell[85565, 3082, 857, 28, 44, "Input",
   CellTags->"b:4.3.1"],
  Cell[86425, 3112, 114, 2, 22, "Text",
   CellTags->"b:4.3.1"],
  Cell[86542, 3116, 808, 23, 105, "Input",
   CellTags->"b:4.3.1"],
  Cell[87353, 3141, 113, 2, 22, "Text",
   CellTags->"b:4.3.1"],
  Cell[87469, 3145, 1035, 29, 65, "Input",
   CellTags->"b:4.3.1"],
  Cell[88507, 3176, 95, 2, 22, "Text",
   CellTags->"b:4.3.1"],
  Cell[88605, 3180, 581, 16, 90, "Input",
   CellTags->"b:4.3.1"],
  Cell[89189, 3198, 80, 2, 22, "Text",
   CellTags->"b:4.3.1"],
  Cell[89272, 3202, 682, 20, 65, "Input",
   CellTags->{"Do", "b:4.3.1"}]},
 "c:27"->{
  Cell[89991, 3227, 275, 8, 57, "Subsection",
   CellTags->{"c:27", "b:4.3.2"}]},
 "b:4.3.2"->{
  Cell[89991, 3227, 275, 8, 57, "Subsection",
   CellTags->{"c:27", "b:4.3.2"}],
  Cell[90269, 3237, 375, 12, 22, "Text",
   CellTags->"b:4.3.2"],
  Cell[90647, 3251, 406, 13, 44, "Input",
   CellTags->"b:4.3.2"],
  Cell[91056, 3266, 93, 2, 22, "Text",
   CellTags->"b:4.3.2"],
  Cell[91152, 3270, 268, 7, 60, "Input",
   CellTags->"b:4.3.2"],
  Cell[91423, 3279, 423, 13, 46, "Input",
   CellTags->"b:4.3.2"],
  Cell[91849, 3294, 828, 21, 38, "Text",
   CellTags->"b:4.3.2"],
  Cell[92680, 3317, 473, 16, 46, "Input",
   CellTags->"b:4.3.2"],
  Cell[93156, 3335, 86, 2, 22, "Text",
   CellTags->"b:4.3.2"],
  Cell[93245, 3339, 77, 2, 44, "Input",
   CellTags->"b:4.3.2"],
  Cell[93325, 3343, 253, 7, 103, "Text",
   CellTags->"b:4.3.2"],
  Cell[93581, 3352, 5505, 218, 317, "Input",
   CellTags->"b:4.3.2"]},
 "c:28"->{
  Cell[99123, 3575, 259, 8, 57, "Subsection",
   CellTags->{"c:28", "b:4.3.3"}]},
 "b:4.3.3"->{
  Cell[99123, 3575, 259, 8, 57, "Subsection",
   CellTags->{"c:28", "b:4.3.3"}],
  Cell[99385, 3585, 579, 23, 22, "Text",
   CellTags->"b:4.3.3"],
  Cell[99967, 3610, 447, 20, 46, "Input",
   CellTags->"b:4.3.3"],
  Cell[100417, 3632, 231, 6, 22, "Text",
   CellTags->"b:4.3.3"],
  Cell[100651, 3640, 197, 8, 46, "Input",
   CellTags->"b:4.3.3"],
  Cell[100851, 3650, 228, 6, 22, "Text",
   CellTags->"b:4.3.3"],
  Cell[101082, 3658, 552, 23, 65, "Input",
   CellTags->"b:4.3.3"],
  Cell[101637, 3683, 1000, 31, 83, "Input",
   CellTags->{"Do", "b:4.3.3"}]},
 "c:29"->{
  Cell[102674, 3719, 323, 9, 57, "Subsection",
   CellTags->{"c:29", "b:4.3.4"}]},
 "b:4.3.4"->{
  Cell[102674, 3719, 323, 9, 57, "Subsection",
   CellTags->{"c:29", "b:4.3.4"}],
  Cell[103000, 3730, 134, 4, 22, "Text",
   CellTags->"b:4.3.4"],
  Cell[103137, 3736, 398, 12, 44, "Input",
   CellTags->"b:4.3.4"],
  Cell[103538, 3750, 158, 5, 22, "Text",
   CellTags->"b:4.3.4"],
  Cell[103699, 3757, 585, 18, 83, "Input",
   CellTags->"b:4.3.4"],
  Cell[104287, 3777, 819, 24, 83, "Input",
   CellTags->"b:4.3.4"],
  Cell[105109, 3803, 136, 4, 46, "Input",
   CellTags->"b:4.3.4"],
  Cell[105248, 3809, 145, 4, 22, "Text",
   CellTags->"b:4.3.4"],
  Cell[105396, 3815, 604, 17, 47, "Input",
   CellTags->"b:4.3.4"],
  Cell[106003, 3834, 136, 4, 22, "Text",
   CellTags->"b:4.3.4"],
  Cell[106142, 3840, 622, 20, 46, "Input",
   CellTags->"b:4.3.4"],
  Cell[106767, 3862, 154, 5, 49, "Text",
   CellTags->"b:4.3.4"],
  Cell[106924, 3869, 511, 17, 120, "Input",
   CellTags->"b:4.3.4"]},
 "c:30"->{
  Cell[107472, 3891, 283, 8, 57, "Subsection",
   CellTags->{"c:30", "b:4.3.5"}]},
 "b:4.3.5"->{
  Cell[107472, 3891, 283, 8, 57, "Subsection",
   CellTags->{"c:30", "b:4.3.5"}],
  Cell[107758, 3901, 186, 5, 49, "Text",
   CellTags->"b:4.3.5"],
  Cell[107947, 3908, 296, 8, 60, "Input",
   CellTags->"b:4.3.5"],
  Cell[108246, 3918, 204, 5, 49, "Text",
   CellTags->"b:4.3.5"],
  Cell[108453, 3925, 290, 8, 50, "Input",
   CellTags->"b:4.3.5"],
  Cell[108746, 3935, 3546, 130, 177, "Input",
   CellTags->"b:4.3.5"],
  Cell[112295, 4067, 236, 7, 44, "Input",
   CellTags->"b:4.3.5"]},
 "c:31"->{
  Cell[112568, 4079, 306, 9, 57, "Subsection",
   CellTags->{"c:31", "b:4.3.6"}]},
 "b:4.3.6"->{
  Cell[112568, 4079, 306, 9, 57, "Subsection",
   CellTags->{"c:31", "b:4.3.6"}],
  Cell[112877, 4090, 168, 5, 44, "Input",
   CellTags->"b:4.3.6"],
  Cell[113048, 4097, 52, 1, 44, "Input",
   CellTags->"b:4.3.6"]},
 "c:32"->{
  Cell[113149, 4104, 377, 8, 54, "Section",
   CellTags->"c:32"],
  Cell[127813, 4665, 81, 2, 31, "Section",
   CellTags->{"c:32", "b:4.5"}]},
 "b:4.4.0"->{
  Cell[113551, 4116, 105, 3, 57, "Subsection",
   CellTags->{"c:3", "b:4.4.0"}],
  Cell[113659, 4121, 138, 3, 22, "Text",
   CellTags->"b:4.4.0"],
  Cell[113800, 4126, 133, 3, 46, "Input",
   CellTags->"b:4.4.0"],
  Cell[113936, 4131, 112, 3, 46, "Input",
   CellTags->"b:4.4.0"],
  Cell[114051, 4136, 215, 5, 22, "Text",
   CellTags->"b:4.4.0"],
  Cell[114269, 4143, 91, 3, 44, "Input",
   CellTags->"b:4.4.0"]},
 "c:33"->{
  Cell[114397, 4151, 185, 6, 57, "Subsection",
   CellTags->{"c:33", "b:4.4.1"}]},
 "b:4.4.1"->{
  Cell[114397, 4151, 185, 6, 57, "Subsection",
   CellTags->{"c:33", "b:4.4.1"}],
  Cell[114585, 4159, 276, 10, 56, "Input",
   CellTags->"b:4.4.1"],
  Cell[114864, 4171, 219, 6, 49, "Text",
   CellTags->"b:4.4.1"],
  Cell[115086, 4179, 93, 3, 44, "Input",
   CellTags->"b:4.4.1"],
  Cell[115182, 4184, 353, 12, 65, "Input",
   CellTags->"b:4.4.1"],
  Cell[115538, 4198, 197, 5, 49, "Text",
   CellTags->"b:4.4.1"],
  Cell[115738, 4205, 857, 27, 90, "Input",
   CellTags->"b:4.4.1"],
  Cell[116598, 4234, 807, 23, 75, "Input",
   CellTags->"b:4.4.1"],
  Cell[117408, 4259, 118, 2, 22, "Text",
   CellTags->"b:4.4.1"],
  Cell[117529, 4263, 158, 5, 44, "Input",
   CellTags->"b:4.4.1"]},
 "c:34"->{
  Cell[117724, 4273, 154, 4, 57, "Subsection",
   CellTags->{"c:34", "b:4.4.2"}]},
 "b:4.4.2"->{
  Cell[117724, 4273, 154, 4, 57, "Subsection",
   CellTags->{"c:34", "b:4.4.2"}],
  Cell[117881, 4279, 185, 5, 22, "Text",
   CellTags->"b:4.4.2"],
  Cell[118069, 4286, 1176, 32, 83, "Input",
   CellTags->"b:4.4.2"]},
 "c:35"->{
  Cell[119282, 4323, 144, 3, 57, "Subsection",
   CellTags->{"c:35", "b:4.4.3"}]},
 "b:4.4.3"->{
  Cell[119282, 4323, 144, 3, 57, "Subsection",
   CellTags->{"c:35", "b:4.4.3"}],
  Cell[119429, 4328, 156, 5, 22, "Text",
   CellTags->"b:4.4.3"],
  Cell[119588, 4335, 519, 17, 46, "Input",
   CellTags->"b:4.4.3"],
  Cell[120110, 4354, 174, 5, 49, "Text",
   CellTags->"b:4.4.3"],
  Cell[120287, 4361, 366, 11, 60, "Input",
   CellTags->"b:4.4.3"]},
 "c:36"->{
  Cell[120690, 4377, 287, 8, 57, "Subsection",
   CellTags->{"c:36", "b:4.4.4"}]},
 "b:4.4.4"->{
  Cell[120690, 4377, 287, 8, 57, "Subsection",
   CellTags->{"c:36", "b:4.4.4"}],
  Cell[120980, 4387, 182, 5, 49, "Text",
   CellTags->"b:4.4.4"],
  Cell[121165, 4394, 244, 8, 44, "Input",
   CellTags->"b:4.4.4"],
  Cell[121412, 4404, 117, 2, 22, "Text",
   CellTags->"b:4.4.4"],
  Cell[121532, 4408, 2189, 89, 141, "Input",
   CellTags->"b:4.4.4"],
  Cell[123724, 4499, 114, 2, 22, "Text",
   CellTags->"b:4.4.4"],
  Cell[123841, 4503, 2210, 90, 141, "Input",
   CellTags->"b:4.4.4"]},
 "c:37"->{
  Cell[126088, 4598, 165, 5, 57, "Subsection",
   CellTags->{"c:37", "b:4.4.5"}]},
 "b:4.4.5"->{
  Cell[126088, 4598, 165, 5, 57, "Subsection",
   CellTags->{"c:37", "b:4.4.5"}],
  Cell[126256, 4605, 1453, 51, 105, "Input",
   CellTags->"b:4.4.5"],
  Cell[127712, 4658, 52, 1, 44, "Input",
   CellTags->"b:4.4.5"]},
 "b:4.5"->{
  Cell[127813, 4665, 81, 2, 31, "Section",
   CellTags->{"c:32", "b:4.5"}],
  Cell[127897, 4669, 1340, 40, 49, "Abstract",
   CellTags->"b:4.5"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"c:1", 196869, 6114},
 {"c:2", 196937, 6117},
 {"c:3", 197009, 6120},
 {"b:4.0.0", 197500, 6133},
 {"b:4.0.1", 197969, 6148},
 {"Do", 199047, 6182},
 {"c:4", 199357, 6191},
 {"b:4.0.2", 199450, 6194},
 {"c:5", 200771, 6235},
 {"b:4.0.3", 200865, 6238},
 {"c:6", 201548, 6259},
 {"b:4.0.4", 201642, 6262},
 {"c:7", 202451, 6287},
 {"b:4.0.5", 202545, 6290},
 {"c:8", 204097, 6337},
 {"b:4.1.0", 204176, 6340},
 {"c:9", 204660, 6355},
 {"b:4.1.1", 204755, 6358},
 {"c:10", 205573, 6383},
 {"b:4.1.2", 205669, 6386},
 {"c:11", 205894, 6393},
 {"b:4.1.3", 205990, 6396},
 {"c:12", 206346, 6407},
 {"b:4.1.4", 206442, 6410},
 {"c:13", 206668, 6417},
 {"b:4.1.5", 206764, 6420},
 {"c:14", 207253, 6435},
 {"b:4.1.6", 207349, 6438},
 {"c:15", 207707, 6449},
 {"b:4.1.7", 207804, 6452},
 {"c:16", 208232, 6465},
 {"b:4.1.8", 208328, 6468},
 {"c:17", 208490, 6473},
 {"b:4.2.0", 208570, 6476},
 {"c:18", 209056, 6491},
 {"b:4.2.1", 209152, 6494},
 {"c:19", 210038, 6521},
 {"b:4.2.2", 210134, 6524},
 {"c:20", 210558, 6537},
 {"b:4.2.3", 210654, 6540},
 {"c:21", 211011, 6551},
 {"b:4.2.4", 211107, 6554},
 {"c:22", 211467, 6565},
 {"b:4.2.5", 211563, 6568},
 {"c:23", 212051, 6583},
 {"b:4.2.6", 212147, 6586},
 {"c:24", 212506, 6597},
 {"b:4.2.7", 212602, 6600},
 {"c:25", 212891, 6609},
 {"b:4.3.0", 212971, 6612},
 {"c:26", 213522, 6629},
 {"b:4.3.1", 213618, 6632},
 {"c:27", 214510, 6659},
 {"b:4.3.2", 214606, 6662},
 {"c:28", 215427, 6687},
 {"b:4.3.3", 215523, 6690},
 {"c:29", 216093, 6707},
 {"b:4.3.4", 216190, 6710},
 {"c:30", 217090, 6737},
 {"b:4.3.5", 217187, 6740},
 {"c:31", 217685, 6755},
 {"b:4.3.6", 217782, 6758},
 {"c:32", 218009, 6765},
 {"b:4.4.0", 218166, 6770},
 {"c:33", 218591, 6783},
 {"b:4.4.1", 218688, 6786},
 {"c:34", 219385, 6807},
 {"b:4.4.2", 219482, 6810},
 {"c:35", 219711, 6817},
 {"b:4.4.3", 219808, 6820},
 {"c:36", 220170, 6831},
 {"b:4.4.4", 220267, 6834},
 {"c:37", 220766, 6849},
 {"b:4.4.5", 220863, 6852},
 {"b:4.5", 221094, 6859}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 48, 1, 50, "Title",
 CellTags->"c:1"],
Cell[596, 23, 62, 0, 34, "Subtitle"],
Cell[661, 25, 218, 7, 20, "Abstract"],
Cell[882, 34, 148, 2, 22, "Text"],
Cell[CellGroupData[{
Cell[1055, 40, 299, 7, 51, "Section",
 CellTags->"c:2"],
Cell[CellGroupData[{
Cell[1379, 51, 105, 3, 57, "Subsection",
 CellTags->{"c:3", "b:4.0.0"}],
Cell[1487, 56, 181, 4, 22, "Text",
 CellTags->"b:4.0.0"],
Cell[1671, 62, 133, 3, 46, "Input",
 CellTags->"b:4.0.0"],
Cell[1807, 67, 112, 3, 46, "Input",
 CellTags->"b:4.0.0"],
Cell[1922, 72, 269, 6, 22, "Text",
 CellTags->"b:4.0.0"],
Cell[2194, 80, 250, 7, 60, "Input",
 CellTags->"b:4.0.0"],
Cell[2447, 89, 1008, 32, 53, "Text",
 CellTags->"b:4.0.0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3492, 126, 142, 3, 57, "Subsection",
 CellTags->{"c:3", "b:4.0.1"}],
Cell[3637, 131, 453, 9, 76, "Text",
 Evaluatable->False,
 CellTags->"b:4.0.1"],
Cell[4093, 142, 742, 21, 75, "Input",
 CellTags->"b:4.0.1"],
Cell[4838, 165, 103, 2, 22, "Text",
 CellTags->"b:4.0.1"],
Cell[4944, 169, 230, 7, 70, "Input",
 CellTags->"b:4.0.1"],
Cell[5177, 178, 218, 5, 49, "Text",
 CellTags->"b:4.0.1"],
Cell[5398, 185, 161, 4, 44, "Input",
 CellTags->"b:4.0.1"],
Cell[5562, 191, 384, 12, 65, "Input",
 CellTags->"b:4.0.1"],
Cell[5949, 205, 179, 5, 49, "Text",
 CellTags->"b:4.0.1"],
Cell[6131, 212, 863, 30, 46, "Input",
 CellTags->"b:4.0.1"],
Cell[6997, 244, 134, 4, 22, "Text",
 CellTags->"b:4.0.1"],
Cell[7134, 250, 720, 20, 65, "Input",
 CellTags->"b:4.0.1"],
Cell[7857, 272, 122, 2, 22, "Text",
 CellTags->"b:4.0.1"],
Cell[7982, 276, 804, 29, 101, "Input",
 CellTags->"b:4.0.1"],
Cell[8789, 307, 94, 2, 22, "Text",
 CellTags->"b:4.0.1"],
Cell[8886, 311, 512, 14, 65, "Input",
 CellTags->{"Do", "b:4.0.1"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[9435, 330, 128, 3, 57, "Subsection",
 CellTags->{"c:4", "b:4.0.2"}],
Cell[9566, 335, 221, 6, 49, "Text",
 CellTags->"b:4.0.2"],
Cell[9790, 343, 1083, 37, 90, "Input",
 CellTags->"b:4.0.2"],
Cell[10876, 382, 210, 6, 49, "Text",
 CellTags->"b:4.0.2"],
Cell[11089, 390, 340, 11, 46, "Input",
 CellTags->"b:4.0.2"],
Cell[11432, 403, 209, 6, 22, "Text",
 CellTags->"b:4.0.2"],
Cell[11644, 411, 132, 4, 46, "Input",
 CellTags->"b:4.0.2"],
Cell[11779, 417, 245, 7, 49, "Text",
 CellTags->"b:4.0.2"],
Cell[12027, 426, 1594, 50, 101, "Input",
 CellTags->"b:4.0.2"],
Cell[13624, 478, 85, 2, 22, "Text",
 CellTags->"b:4.0.2"],
Cell[13712, 482, 363, 13, 90, "Input",
 CellTags->"b:4.0.2"],
Cell[14078, 497, 333, 8, 76, "Text",
 CellTags->"b:4.0.2"],
Cell[14414, 507, 185, 6, 44, "Input",
 CellTags->"b:4.0.2"],
Cell[14602, 515, 477, 14, 44, "Input",
 CellTags->"b:4.0.2"],
Cell[15082, 531, 161, 5, 22, "Text",
 CellTags->"b:4.0.2"],
Cell[15246, 538, 2125, 89, 101, "Input",
 CellTags->"b:4.0.2"],
Cell[17374, 629, 109, 2, 22, "Text",
 CellTags->"b:4.0.2"],
Cell[17486, 633, 81, 1, 60, "Input",
 CellTags->"b:4.0.2"],
Cell[17570, 636, 99, 2, 22, "Text",
 CellTags->"b:4.0.2"],
Cell[17672, 640, 107, 3, 44, "Input",
 CellTags->"b:4.0.2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[17816, 648, 117, 3, 57, "Subsection",
 CellTags->{"c:5", "b:4.0.3"}],
Cell[17936, 653, 218, 6, 49, "Text",
 CellTags->"b:4.0.3"],
Cell[18157, 661, 362, 15, 46, "Input",
 CellTags->"b:4.0.3"],
Cell[18522, 678, 94, 2, 22, "Text",
 CellTags->"b:4.0.3"],
Cell[18619, 682, 197, 8, 46, "Input",
 CellTags->"b:4.0.3"],
Cell[18819, 692, 332, 14, 46, "Input",
 CellTags->"b:4.0.3"],
Cell[19154, 708, 272, 10, 22, "Text",
 CellTags->"b:4.0.3"],
Cell[19429, 720, 389, 16, 46, "Input",
 CellTags->"b:4.0.3"],
Cell[19821, 738, 136, 4, 22, "Text",
 CellTags->"b:4.0.3"],
Cell[19960, 744, 788, 25, 83, "Input",
 CellTags->{"Do", "b:4.0.3"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[20785, 774, 127, 3, 57, "Subsection",
 CellTags->{"c:6", "b:4.0.4"}],
Cell[20915, 779, 396, 11, 157, "Text",
 CellTags->"b:4.0.4"],
Cell[21314, 792, 304, 8, 103, "Text",
 CellTags->"b:4.0.4"],
Cell[21621, 802, 211, 5, 22, "Text",
 CellTags->"b:4.0.4"],
Cell[21835, 809, 517, 17, 46, "Input",
 CellTags->"b:4.0.4"],
Cell[22355, 828, 292, 8, 22, "Text",
 CellTags->"b:4.0.4"],
Cell[22650, 838, 394, 12, 65, "Input",
 CellTags->"b:4.0.4"],
Cell[23047, 852, 669, 19, 83, "Input",
 CellTags->"b:4.0.4"],
Cell[23719, 873, 136, 4, 46, "Input",
 CellTags->"b:4.0.4"],
Cell[23858, 879, 269, 8, 22, "Text",
 CellTags->"b:4.0.4"],
Cell[24130, 889, 355, 10, 47, "Input",
 CellTags->"b:4.0.4"],
Cell[24488, 901, 463, 16, 101, "Input",
 CellTags->"b:4.0.4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24988, 922, 139, 3, 57, "Subsection",
 CellTags->{"c:7", "b:4.0.5"}],
Cell[25130, 927, 444, 13, 78, "Text",
 CellTags->"b:4.0.5"],
Cell[25577, 942, 372, 13, 60, "Input",
 CellTags->"b:4.0.5"],
Cell[25952, 957, 471, 16, 50, "Input",
 CellTags->"b:4.0.5"],
Cell[26426, 975, 161, 5, 22, "Text",
 CellTags->"b:4.0.5"],
Cell[26590, 982, 246, 8, 44, "Input",
 CellTags->"b:4.0.5"],
Cell[26839, 992, 502, 16, 44, "Input",
 CellTags->"b:4.0.5"],
Cell[27344, 1010, 53, 1, 44, "Input",
 CellTags->"b:4.0.5"],
Cell[27400, 1013, 451, 13, 90, "Input",
 CellTags->"b:4.0.5"],
Cell[27854, 1028, 466, 13, 76, "Text",
 CellTags->"b:4.0.5"],
Cell[28323, 1043, 228, 8, 44, "Input",
 CellTags->"b:4.0.5"],
Cell[28554, 1053, 135, 4, 22, "Text",
 CellTags->"b:4.0.5"],
Cell[28692, 1059, 44, 1, 44, "Input",
 CellTags->"b:4.0.5"],
Cell[28739, 1062, 133, 4, 22, "Text",
 CellTags->"b:4.0.5"],
Cell[28875, 1068, 236, 7, 47, "Input",
 CellTags->"b:4.0.5"],
Cell[29114, 1077, 122, 5, 49, "Text",
 CellTags->"b:4.0.5"],
Cell[29239, 1084, 1457, 27, 724, "Text",
 CellTags->"b:4.0.5"],
Cell[30699, 1113, 5919, 225, 251, "Input",
 CellTags->"b:4.0.5"],
Cell[36621, 1340, 151, 5, 33, "DisplayText",
 CellTags->"b:4.0.5"],
Cell[36775, 1347, 577, 18, 44, "Input",
 CellTags->"b:4.0.5"],
Cell[37355, 1367, 153, 5, 33, "DisplayText",
 CellTags->"b:4.0.5"],
Cell[37511, 1374, 107, 3, 44, "Input",
 CellTags->"b:4.0.5"],
Cell[37621, 1379, 43, 1, 44, "Input",
 CellTags->"b:4.0.5"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[37713, 1386, 342, 8, 31, "Section",
 CellTags->"c:8"],
Cell[CellGroupData[{
Cell[38080, 1398, 105, 3, 57, "Subsection",
 CellTags->{"c:3", "b:4.1.0"}],
Cell[38188, 1403, 138, 3, 22, "Text",
 CellTags->"b:4.1.0"],
Cell[38329, 1408, 133, 3, 46, "Input",
 CellTags->"b:4.1.0"],
Cell[38465, 1413, 112, 3, 46, "Input",
 CellTags->"b:4.1.0"],
Cell[38580, 1418, 215, 5, 22, "Text",
 CellTags->"b:4.1.0"],
Cell[38798, 1425, 91, 3, 44, "Input",
 CellTags->"b:4.1.0"],
Cell[38892, 1430, 254, 7, 60, "Input",
 CellTags->"b:4.1.0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[39183, 1442, 208, 6, 57, "Subsection",
 CellTags->{"c:9", "b:4.1.1"}],
Cell[39394, 1450, 265, 6, 22, "Text",
 CellTags->"b:4.1.1"],
Cell[39662, 1458, 82, 2, 44, "Input",
 CellTags->"b:4.1.1"],
Cell[39747, 1462, 2612, 76, 137, "Input",
 CellTags->"b:4.1.1"],
Cell[42362, 1540, 245, 6, 22, "Text",
 CellTags->"b:4.1.1"],
Cell[42610, 1548, 203, 5, 60, "Input",
 CellTags->"b:4.1.1"],
Cell[42816, 1555, 208, 7, 22, "Text",
 CellTags->"b:4.1.1"],
Cell[43027, 1564, 1129, 33, 90, "Input",
 CellTags->"b:4.1.1"],
Cell[44159, 1599, 123, 2, 22, "Text",
 CellTags->"b:4.1.1"],
Cell[44285, 1603, 301, 9, 60, "Input",
 CellTags->"b:4.1.1"],
Cell[44589, 1614, 101, 2, 22, "Text",
 CellTags->"b:4.1.1"],
Cell[44693, 1618, 804, 22, 65, "Input",
 CellTags->"b:4.1.1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[45534, 1645, 135, 3, 57, "Subsection",
 CellTags->{"c:10", "b:4.1.2"}],
Cell[45672, 1650, 309, 8, 76, "Text",
 CellTags->"b:4.1.2"],
Cell[45984, 1660, 540, 17, 46, "Input",
 CellTags->"b:4.1.2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[46561, 1682, 144, 3, 57, "Subsection",
 CellTags->{"c:11", "b:4.1.3"}],
Cell[46708, 1687, 161, 5, 22, "Text",
 CellTags->"b:4.1.3"],
Cell[46872, 1694, 827, 30, 65, "Input",
 CellTags->"b:4.1.3"],
Cell[47702, 1726, 185, 6, 49, "Text",
 CellTags->"b:4.1.3"],
Cell[47890, 1734, 314, 9, 60, "Input",
 CellTags->"b:4.1.3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[48241, 1748, 141, 3, 57, "Subsection",
 CellTags->{"c:12", "b:4.1.4"}],
Cell[48385, 1753, 188, 5, 22, "Text",
 CellTags->"b:4.1.4"],
Cell[48576, 1760, 1019, 32, 47, "Input",
 CellTags->"b:4.1.4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[49632, 1797, 256, 8, 57, "Subsection",
 CellTags->{"c:13", "b:4.1.5"}],
Cell[49891, 1807, 292, 7, 49, "Text",
 CellTags->"b:4.1.5"],
Cell[50186, 1816, 638, 19, 50, "Input",
 CellTags->"b:4.1.5"],
Cell[50827, 1837, 159, 5, 22, "Text",
 CellTags->"b:4.1.5"],
Cell[50989, 1844, 696, 23, 105, "Input",
 CellTags->"b:4.1.5"],
Cell[51688, 1869, 189, 7, 22, "Text",
 CellTags->"b:4.1.5"],
Cell[51880, 1878, 178, 5, 44, "Input",
 CellTags->"b:4.1.5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[52095, 1888, 317, 9, 57, "Subsection",
 CellTags->{"c:14", "b:4.1.6"}],
Cell[52415, 1899, 157, 5, 22, "Text",
 CellTags->"b:4.1.6"],
Cell[52575, 1906, 1309, 41, 135, "Input",
 CellTags->"b:4.1.6"],
Cell[53887, 1949, 135, 4, 22, "Text",
 CellTags->"b:4.1.6"],
Cell[54025, 1955, 316, 8, 60, "Input",
 CellTags->"b:4.1.6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[54378, 1968, 350, 10, 57, "Subsection",
 CellTags->{"c:15", "b:4.1.7"}],
Cell[54731, 1980, 138, 4, 22, "Text",
 CellTags->"b:4.1.7"],
Cell[54872, 1986, 2211, 88, 141, "Input",
 CellTags->"b:4.1.7"],
Cell[57086, 2076, 137, 4, 22, "Text",
 CellTags->"b:4.1.7"],
Cell[57226, 2082, 2327, 93, 141, "Input",
 CellTags->"b:4.1.7"],
Cell[59556, 2177, 199, 8, 44, "Input",
 CellTags->"b:4.1.7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[59792, 2190, 165, 5, 57, "Subsection",
 CellTags->{"c:16", "b:4.1.8"}],
Cell[59960, 2197, 2021, 67, 120, "Input",
 CellTags->"b:4.1.8"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[62030, 2270, 343, 8, 31, "Section",
 CellTags->"c:17"],
Cell[CellGroupData[{
Cell[62398, 2282, 105, 3, 57, "Subsection",
 CellTags->{"c:3", "b:4.2.0"}],
Cell[62506, 2287, 138, 3, 22, "Text",
 CellTags->"b:4.2.0"],
Cell[62647, 2292, 133, 3, 46, "Input",
 CellTags->"b:4.2.0"],
Cell[62783, 2297, 112, 3, 46, "Input",
 CellTags->"b:4.2.0"],
Cell[62898, 2302, 215, 5, 22, "Text",
 CellTags->"b:4.2.0"],
Cell[63116, 2309, 115, 4, 44, "Input",
 CellTags->"b:4.2.0"],
Cell[63234, 2315, 254, 7, 60, "Input",
 CellTags->"b:4.2.0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[63525, 2327, 164, 5, 57, "Subsection",
 CellTags->{"c:18", "b:4.2.1"}],
Cell[63692, 2334, 215, 6, 49, "Text",
 CellTags->"b:4.2.1"],
Cell[63910, 2342, 2011, 56, 125, "Input",
 CellTags->"b:4.2.1"],
Cell[65924, 2400, 109, 2, 22, "Text",
 CellTags->"b:4.2.1"],
Cell[66036, 2404, 229, 6, 60, "Input",
 CellTags->"b:4.2.1"],
Cell[66268, 2412, 84, 2, 22, "Text",
 CellTags->"b:4.2.1"],
Cell[66355, 2416, 147, 4, 44, "Input",
 CellTags->"b:4.2.1"],
Cell[66505, 2422, 249, 6, 49, "Text",
 CellTags->"b:4.2.1"],
Cell[66757, 2430, 1738, 51, 105, "Input",
 CellTags->"b:4.2.1"],
Cell[68498, 2483, 118, 2, 22, "Text",
 CellTags->"b:4.2.1"],
Cell[68619, 2487, 536, 16, 75, "Input",
 CellTags->"b:4.2.1"],
Cell[69158, 2505, 101, 2, 22, "Text",
 CellTags->"b:4.2.1"],
Cell[69262, 2509, 802, 22, 65, "Input",
 CellTags->"b:4.2.1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[70101, 2536, 135, 3, 57, "Subsection",
 CellTags->{"c:19", "b:4.2.2"}],
Cell[70239, 2541, 137, 4, 22, "Text",
 CellTags->"b:4.2.2"],
Cell[70379, 2547, 763, 22, 65, "Input",
 CellTags->"b:4.2.2"],
Cell[71145, 2571, 92, 2, 22, "Text",
 CellTags->"b:4.2.2"],
Cell[71240, 2575, 1440, 38, 101, "Input",
 CellTags->"b:4.2.2"],
Cell[72683, 2615, 108, 3, 44, "Input",
 CellTags->"b:4.2.2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[72828, 2623, 144, 3, 57, "Subsection",
 CellTags->{"c:20", "b:4.2.3"}],
Cell[72975, 2628, 161, 5, 22, "Text",
 CellTags->"b:4.2.3"],
Cell[73139, 2635, 677, 21, 46, "Input",
 CellTags->"b:4.2.3"],
Cell[73819, 2658, 174, 5, 49, "Text",
 CellTags->"b:4.2.3"],
Cell[73996, 2665, 432, 14, 60, "Input",
 CellTags->"b:4.2.3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[74465, 2684, 145, 3, 57, "Subsection",
 CellTags->{"c:21", "b:4.2.4"}],
Cell[74613, 2689, 169, 5, 49, "Text",
 CellTags->"b:4.2.4"],
Cell[74785, 2696, 1009, 34, 135, "Input",
 CellTags->"b:4.2.4"],
Cell[75797, 2732, 133, 4, 22, "Text",
 CellTags->"b:4.2.4"],
Cell[75933, 2738, 1279, 34, 47, "Input",
 CellTags->"b:4.2.4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[77249, 2777, 256, 8, 57, "Subsection",
 CellTags->{"c:22", "b:4.2.5"}],
Cell[77508, 2787, 293, 7, 76, "Text",
 CellTags->"b:4.2.5"],
Cell[77804, 2796, 127, 4, 44, "Input",
 CellTags->"b:4.2.5"],
Cell[77934, 2802, 668, 20, 50, "Input",
 CellTags->"b:4.2.5"],
Cell[78605, 2824, 323, 8, 60, "Input",
 CellTags->"b:4.2.5"],
Cell[78931, 2834, 199, 7, 22, "Text",
 CellTags->"b:4.2.5"],
Cell[79133, 2843, 102, 3, 44, "Input",
 CellTags->"b:4.2.5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[79272, 2851, 317, 9, 57, "Subsection",
 CellTags->{"c:23", "b:4.2.6"}],
Cell[79592, 2862, 157, 5, 22, "Text",
 CellTags->"b:4.2.6"],
Cell[79752, 2869, 1953, 61, 180, "Input",
 CellTags->"b:4.2.6"],
Cell[81708, 2932, 137, 4, 22, "Text",
 CellTags->"b:4.2.6"],
Cell[81848, 2938, 352, 10, 60, "Input",
 CellTags->"b:4.2.6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[82237, 2953, 343, 9, 57, "Subsection",
 CellTags->{"c:24", "b:4.2.7"}],
Cell[82583, 2964, 158, 5, 22, "Text",
 CellTags->"b:4.2.7"],
Cell[82744, 2971, 140, 4, 44, "Input",
 CellTags->"b:4.2.7"],
Cell[82887, 2977, 52, 1, 44, "Input",
 CellTags->"b:4.2.7"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[82988, 2984, 348, 8, 31, "Section",
 CellTags->"c:25"],
Cell[CellGroupData[{
Cell[83361, 2996, 105, 3, 57, "Subsection",
 CellTags->{"c:3", "b:4.3.0"}],
Cell[83469, 3001, 155, 5, 22, "Text",
 CellTags->"b:4.3.0"],
Cell[83627, 3008, 133, 3, 46, "Input",
 CellTags->"b:4.3.0"],
Cell[83763, 3013, 112, 3, 46, "Input",
 CellTags->"b:4.3.0"],
Cell[83878, 3018, 119, 4, 46, "Input",
 CellTags->"b:4.3.0"],
Cell[84000, 3024, 250, 7, 60, "Input",
 CellTags->"b:4.3.0"],
Cell[84253, 3033, 208, 6, 49, "Text",
 CellTags->"b:4.3.0"],
Cell[84464, 3041, 93, 3, 44, "Input",
 CellTags->"b:4.3.0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[84594, 3049, 277, 8, 57, "Subsection",
 CellTags->{"c:26", "b:4.3.1"}],
Cell[84874, 3059, 364, 8, 49, "Text",
 CellTags->"b:4.3.1"],
Cell[85241, 3069, 190, 5, 22, "Text",
 CellTags->"b:4.3.1"],
Cell[85434, 3076, 128, 4, 44, "Input",
 CellTags->"b:4.3.1"],
Cell[85565, 3082, 857, 28, 44, "Input",
 CellTags->"b:4.3.1"],
Cell[86425, 3112, 114, 2, 22, "Text",
 CellTags->"b:4.3.1"],
Cell[86542, 3116, 808, 23, 105, "Input",
 CellTags->"b:4.3.1"],
Cell[87353, 3141, 113, 2, 22, "Text",
 CellTags->"b:4.3.1"],
Cell[87469, 3145, 1035, 29, 65, "Input",
 CellTags->"b:4.3.1"],
Cell[88507, 3176, 95, 2, 22, "Text",
 CellTags->"b:4.3.1"],
Cell[88605, 3180, 581, 16, 90, "Input",
 CellTags->"b:4.3.1"],
Cell[89189, 3198, 80, 2, 22, "Text",
 CellTags->"b:4.3.1"],
Cell[89272, 3202, 682, 20, 65, "Input",
 CellTags->{"Do", "b:4.3.1"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[89991, 3227, 275, 8, 57, "Subsection",
 CellTags->{"c:27", "b:4.3.2"}],
Cell[90269, 3237, 375, 12, 22, "Text",
 CellTags->"b:4.3.2"],
Cell[90647, 3251, 406, 13, 44, "Input",
 CellTags->"b:4.3.2"],
Cell[91056, 3266, 93, 2, 22, "Text",
 CellTags->"b:4.3.2"],
Cell[91152, 3270, 268, 7, 60, "Input",
 CellTags->"b:4.3.2"],
Cell[91423, 3279, 423, 13, 46, "Input",
 CellTags->"b:4.3.2"],
Cell[91849, 3294, 828, 21, 38, "Text",
 CellTags->"b:4.3.2"],
Cell[92680, 3317, 473, 16, 46, "Input",
 CellTags->"b:4.3.2"],
Cell[93156, 3335, 86, 2, 22, "Text",
 CellTags->"b:4.3.2"],
Cell[93245, 3339, 77, 2, 44, "Input",
 CellTags->"b:4.3.2"],
Cell[93325, 3343, 253, 7, 103, "Text",
 CellTags->"b:4.3.2"],
Cell[93581, 3352, 5505, 218, 317, "Input",
 CellTags->"b:4.3.2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[99123, 3575, 259, 8, 57, "Subsection",
 CellTags->{"c:28", "b:4.3.3"}],
Cell[99385, 3585, 579, 23, 22, "Text",
 CellTags->"b:4.3.3"],
Cell[99967, 3610, 447, 20, 46, "Input",
 CellTags->"b:4.3.3"],
Cell[100417, 3632, 231, 6, 22, "Text",
 CellTags->"b:4.3.3"],
Cell[100651, 3640, 197, 8, 46, "Input",
 CellTags->"b:4.3.3"],
Cell[100851, 3650, 228, 6, 22, "Text",
 CellTags->"b:4.3.3"],
Cell[101082, 3658, 552, 23, 65, "Input",
 CellTags->"b:4.3.3"],
Cell[101637, 3683, 1000, 31, 83, "Input",
 CellTags->{"Do", "b:4.3.3"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[102674, 3719, 323, 9, 57, "Subsection",
 CellTags->{"c:29", "b:4.3.4"}],
Cell[103000, 3730, 134, 4, 22, "Text",
 CellTags->"b:4.3.4"],
Cell[103137, 3736, 398, 12, 44, "Input",
 CellTags->"b:4.3.4"],
Cell[103538, 3750, 158, 5, 22, "Text",
 CellTags->"b:4.3.4"],
Cell[103699, 3757, 585, 18, 83, "Input",
 CellTags->"b:4.3.4"],
Cell[104287, 3777, 819, 24, 83, "Input",
 CellTags->"b:4.3.4"],
Cell[105109, 3803, 136, 4, 46, "Input",
 CellTags->"b:4.3.4"],
Cell[105248, 3809, 145, 4, 22, "Text",
 CellTags->"b:4.3.4"],
Cell[105396, 3815, 604, 17, 47, "Input",
 CellTags->"b:4.3.4"],
Cell[106003, 3834, 136, 4, 22, "Text",
 CellTags->"b:4.3.4"],
Cell[106142, 3840, 622, 20, 46, "Input",
 CellTags->"b:4.3.4"],
Cell[106767, 3862, 154, 5, 49, "Text",
 CellTags->"b:4.3.4"],
Cell[106924, 3869, 511, 17, 120, "Input",
 CellTags->"b:4.3.4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[107472, 3891, 283, 8, 57, "Subsection",
 CellTags->{"c:30", "b:4.3.5"}],
Cell[107758, 3901, 186, 5, 49, "Text",
 CellTags->"b:4.3.5"],
Cell[107947, 3908, 296, 8, 60, "Input",
 CellTags->"b:4.3.5"],
Cell[108246, 3918, 204, 5, 49, "Text",
 CellTags->"b:4.3.5"],
Cell[108453, 3925, 290, 8, 50, "Input",
 CellTags->"b:4.3.5"],
Cell[108746, 3935, 3546, 130, 177, "Input",
 CellTags->"b:4.3.5"],
Cell[112295, 4067, 236, 7, 44, "Input",
 CellTags->"b:4.3.5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[112568, 4079, 306, 9, 57, "Subsection",
 CellTags->{"c:31", "b:4.3.6"}],
Cell[112877, 4090, 168, 5, 44, "Input",
 CellTags->"b:4.3.6"],
Cell[113048, 4097, 52, 1, 44, "Input",
 CellTags->"b:4.3.6"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[113149, 4104, 377, 8, 54, "Section",
 CellTags->"c:32"],
Cell[CellGroupData[{
Cell[113551, 4116, 105, 3, 57, "Subsection",
 CellTags->{"c:3", "b:4.4.0"}],
Cell[113659, 4121, 138, 3, 22, "Text",
 CellTags->"b:4.4.0"],
Cell[113800, 4126, 133, 3, 46, "Input",
 CellTags->"b:4.4.0"],
Cell[113936, 4131, 112, 3, 46, "Input",
 CellTags->"b:4.4.0"],
Cell[114051, 4136, 215, 5, 22, "Text",
 CellTags->"b:4.4.0"],
Cell[114269, 4143, 91, 3, 44, "Input",
 CellTags->"b:4.4.0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[114397, 4151, 185, 6, 57, "Subsection",
 CellTags->{"c:33", "b:4.4.1"}],
Cell[114585, 4159, 276, 10, 56, "Input",
 CellTags->"b:4.4.1"],
Cell[114864, 4171, 219, 6, 49, "Text",
 CellTags->"b:4.4.1"],
Cell[115086, 4179, 93, 3, 44, "Input",
 CellTags->"b:4.4.1"],
Cell[115182, 4184, 353, 12, 65, "Input",
 CellTags->"b:4.4.1"],
Cell[115538, 4198, 197, 5, 49, "Text",
 CellTags->"b:4.4.1"],
Cell[115738, 4205, 857, 27, 90, "Input",
 CellTags->"b:4.4.1"],
Cell[116598, 4234, 807, 23, 75, "Input",
 CellTags->"b:4.4.1"],
Cell[117408, 4259, 118, 2, 22, "Text",
 CellTags->"b:4.4.1"],
Cell[117529, 4263, 158, 5, 44, "Input",
 CellTags->"b:4.4.1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[117724, 4273, 154, 4, 57, "Subsection",
 CellTags->{"c:34", "b:4.4.2"}],
Cell[117881, 4279, 185, 5, 22, "Text",
 CellTags->"b:4.4.2"],
Cell[118069, 4286, 1176, 32, 83, "Input",
 CellTags->"b:4.4.2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[119282, 4323, 144, 3, 57, "Subsection",
 CellTags->{"c:35", "b:4.4.3"}],
Cell[119429, 4328, 156, 5, 22, "Text",
 CellTags->"b:4.4.3"],
Cell[119588, 4335, 519, 17, 46, "Input",
 CellTags->"b:4.4.3"],
Cell[120110, 4354, 174, 5, 49, "Text",
 CellTags->"b:4.4.3"],
Cell[120287, 4361, 366, 11, 60, "Input",
 CellTags->"b:4.4.3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[120690, 4377, 287, 8, 57, "Subsection",
 CellTags->{"c:36", "b:4.4.4"}],
Cell[120980, 4387, 182, 5, 49, "Text",
 CellTags->"b:4.4.4"],
Cell[121165, 4394, 244, 8, 44, "Input",
 CellTags->"b:4.4.4"],
Cell[121412, 4404, 117, 2, 22, "Text",
 CellTags->"b:4.4.4"],
Cell[121532, 4408, 2189, 89, 141, "Input",
 CellTags->"b:4.4.4"],
Cell[123724, 4499, 114, 2, 22, "Text",
 CellTags->"b:4.4.4"],
Cell[123841, 4503, 2210, 90, 141, "Input",
 CellTags->"b:4.4.4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[126088, 4598, 165, 5, 57, "Subsection",
 CellTags->{"c:37", "b:4.4.5"}],
Cell[126256, 4605, 1453, 51, 105, "Input",
 CellTags->"b:4.4.5"],
Cell[127712, 4658, 52, 1, 44, "Input",
 CellTags->"b:4.4.5"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[127813, 4665, 81, 2, 31, "Section",
 CellTags->{"c:32", "b:4.5"}],
Cell[127897, 4669, 1340, 40, 49, "Abstract",
 CellTags->"b:4.5"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
